@@ -1,4 +1,4 @@
-// $Id: Svcconf_Handler.cpp 79066 2007-07-30 08:39:04Z johnnyw $
+// $Id: Svcconf_Handler.cpp 87066 2009-10-13 09:38:06Z johnnyw $
 
 #include "Svcconf_Handler.h"
 #include "ace/ACE.h"
@@ -70,11 +70,11 @@ ACEXML_Svcconf_Handler::endElement (const ACEXML_Char *,
       if (svc_dll.open (active_info->path ()) == -1)
         {
           // build the error message
-          ACE_CString msg (ACE_TEXT ("Cannot locate DLL: '"));
-          msg += ACE_CString (ACE_TEXT (active_info->path ()));
-          msg += ACE_CString (ACE_TEXT ("' for entity '"));
-          msg += ACE_CString (ACE_TEXT (active_info->name ()));
-          msg += ACE_CString (ACE_TEXT ("'\n"));
+          ACE_TString msg (ACE_TEXT ("Cannot locate DLL: '"));
+          msg += ACE_TString (active_info->path ());
+          msg += ACE_TString (ACE_TEXT ("' for entity '"));
+          msg += ACE_TString (active_info->name ());
+          msg += ACE_TString (ACE_TEXT ("'\n"));
 
           ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
         }
@@ -90,11 +90,11 @@ ACEXML_Svcconf_Handler::endElement (const ACEXML_Char *,
       if (func == 0)
         {
           // build the error message
-          ACE_CString msg (ACE_TEXT ("Cannot locate init function: '"));
-          msg += ACE_CString (ACE_TEXT (active_info->init_func ()));
-          msg += ACE_CString (ACE_TEXT ("' for entity '"));
-          msg += ACE_CString (ACE_TEXT (active_info->name ()));
-          msg += ACE_CString (ACE_TEXT ("'\n"));
+          ACE_TString msg (ACE_TEXT ("Cannot locate init function: '"));
+          msg += ACE_TString (active_info->init_func ());
+          msg += ACE_TString (ACE_TEXT ("' for entity '"));
+          msg += ACE_TString (active_info->name ());
+          msg += ACE_TString (ACE_TEXT ("'\n"));
 
           ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
         }
@@ -122,10 +122,10 @@ ACEXML_Svcconf_Handler::endElement (const ACEXML_Char *,
               delete stp;
 
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Expecting Stream type in stream header"));
-              msg += ACE_CString (ACE_TEXT (" for entity '"));
-              msg += ACE_CString (ACE_TEXT (active_info->name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Expecting Stream type in stream header"));
+              msg += ACE_TString (ACE_TEXT (" for entity '"));
+              msg += ACE_TString (active_info->name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -160,10 +160,10 @@ ACEXML_Svcconf_Handler::endElement (const ACEXML_Char *,
                   || this->stream_->push (mt) == -1)
                 {
                   // build the error message
-                  ACE_CString msg (ACE_TEXT ("Error initializing module"));
-                  msg += ACE_CString (ACE_TEXT (" for entity '"));
-                  msg += ACE_CString (ACE_TEXT (active_info->name ()));
-                  msg += ACE_CString (ACE_TEXT ("'\n"));
+                  ACE_TString msg (ACE_TEXT ("Error initializing module"));
+                  msg += ACE_TString (ACE_TEXT (" for entity '"));
+                  msg += ACE_TString (active_info->name ());
+                  msg += ACE_TString (ACE_TEXT ("'\n"));
 
                   ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
                 }
@@ -192,10 +192,10 @@ ACEXML_Svcconf_Handler::endElement (const ACEXML_Char *,
                   delete stype;
 
                   // build the error message
-                  ACE_CString msg (ACE_TEXT ("Failed to initialize dynamic service"));
-                  msg += ACE_CString (ACE_TEXT (" for entity '"));
-                  msg += ACE_CString (ACE_TEXT (active_info->name ()));
-                  msg += ACE_CString (ACE_TEXT ("'\n"));
+                  ACE_TString msg (ACE_TEXT ("Failed to initialize dynamic service"));
+                  msg += ACE_TString (ACE_TEXT (" for entity '"));
+                  msg += ACE_TString (active_info->name ());
+                  msg += ACE_TString (ACE_TEXT ("'\n"));
 
                   ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
                 }
@@ -228,10 +228,10 @@ ACEXML_Svcconf_Handler::endElement (const ACEXML_Char *,
                                                   this->parsed_info_.init_params ()) == -1)
                 {
                   // build the error message
-                  ACE_CString msg (ACE_TEXT ("Failed to initialize static service"));
-                  msg += ACE_CString (ACE_TEXT (" for entity '"));
-                  msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-                  msg += ACE_CString (ACE_TEXT ("'\n"));
+                  ACE_TString msg (ACE_TEXT ("Failed to initialize static service"));
+                  msg += ACE_TString (ACE_TEXT (" for entity '"));
+                  msg += ACE_TString (this->parsed_info_.name ());
+                  msg += ACE_TString (ACE_TEXT ("'\n"));
 
                   ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
                 }
@@ -334,9 +334,9 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
            (const ACE_Service_Type **) &this->stream_svc_type_) == -1)
         {
           // build the error message
-          ACE_CString msg (ACE_TEXT ("Cannot find stream '"));
-          msg += ACE_CString (ACE_TEXT (this->stream_info_.name ()));
-          msg += ACE_CString (ACE_TEXT ("'\n"));
+          ACE_TString msg (ACE_TEXT ("Cannot find stream '"));
+          msg += ACE_TString (this->stream_info_.name ());
+          msg += ACE_TString (ACE_TEXT ("'\n"));
 
           ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
         }
@@ -372,9 +372,9 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
           if (mt == 0)
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Can't locate module '"));
-              msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Can't locate module '"));
+              msg += ACE_TString (this->parsed_info_.name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -388,10 +388,10 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
           if (ACE_Service_Config::resume (this->parsed_info_.name ()) == -1)
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Resume failed"));
-              msg += ACE_CString (ACE_TEXT (" for entity '"));
-              msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Resume failed"));
+              msg += ACE_TString (ACE_TEXT (" for entity '"));
+              msg += ACE_TString (this->parsed_info_.name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -413,9 +413,9 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
           if (mt == 0)
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Can't locate module '"));
-              msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Can't locate module '"));
+              msg += ACE_TString (this->parsed_info_.name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -429,10 +429,10 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
           if (ACE_Service_Config::suspend (this->parsed_info_.name ()) == -1)
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Suspend failed"));
-              msg += ACE_CString (ACE_TEXT (" for entity '"));
-              msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Suspend failed"));
+              msg += ACE_TString (ACE_TEXT (" for entity '"));
+              msg += ACE_TString (this->parsed_info_.name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -454,9 +454,9 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
           if (mt == 0)
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Can't locate module '"));
-              msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Can't locate module '"));
+              msg += ACE_TString (this->parsed_info_.name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -470,10 +470,10 @@ ACEXML_Svcconf_Handler::startElement (const ACEXML_Char *,
           if (ACE_Service_Config::remove (this->parsed_info_.name ()) == -1)
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Remove failed"));
-              msg += ACE_CString (ACE_TEXT (" for entity '"));
-              msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Remove failed"));
+              msg += ACE_TString (ACE_TEXT (" for entity '"));
+              msg += ACE_TString (this->parsed_info_.name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW (ACEXML_SAXException (msg.c_str ()));
             }
@@ -574,11 +574,11 @@ ACEXML_Svcconf_Handler::get_stream_id (ACEXML_Attributes *alist ACEXML_ENV_ARG_D
         else
           {
             // build the error message
-            ACE_CString msg (ACE_TEXT ("Invalid stream attribute '"));
-            msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-            msg += ACE_CString (ACE_TEXT ("' for entity '"));
-            msg += ACE_CString (ACE_TEXT (this->stream_info_.name ()));
-            msg += ACE_CString (ACE_TEXT ("'\n"));
+            ACE_TString msg (ACE_TEXT ("Invalid stream attribute '"));
+            msg += ACE_TString (alist->getQName (i));
+            msg += ACE_TString (ACE_TEXT ("' for entity '"));
+            msg += ACE_TString (this->stream_info_.name ());
+            msg += ACE_TString (ACE_TEXT ("'\n"));
 
             ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()),
                                  -1);
@@ -600,12 +600,12 @@ ACEXML_Svcconf_Handler::get_id (ACEXML_Attributes *alist ACEXML_ENV_ARG_DECL)
         else
           {
             // build the error message
-            ACE_CString msg (ACE_TEXT ("Invalid attribute '"));
-            msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-            msg += ACE_CString (ACE_TEXT ("', expecting 'id'"));
-            msg += ACE_CString (ACE_TEXT (" for entity '"));
-            msg += ACE_CString (ACE_TEXT (this->parsed_info_.name ()));
-            msg += ACE_CString (ACE_TEXT ("'\n"));
+            ACE_TString msg (ACE_TEXT ("Invalid attribute '"));
+            msg += ACE_TString (alist->getQName (i));
+            msg += ACE_TString (ACE_TEXT ("', expecting 'id'"));
+            msg += ACE_TString (ACE_TEXT (" for entity '"));
+            msg += ACE_TString (this->parsed_info_.name ());
+            msg += ACE_TString (ACE_TEXT ("'\n"));
 
             ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()),
                             -1);
@@ -641,12 +641,12 @@ ACEXML_Svcconf_Handler::get_dynamic_attrs (ACEXML_Attributes *alist ACEXML_ENV_A
               else
                 {
                   // build the error message
-                  ACE_CString msg (ACE_TEXT ("Invalid attribute value '"));
-                  msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-                  msg += ACE_CString (ACE_TEXT ("', expecting 'active' or 'inactive'"));
-                  msg += ACE_CString (ACE_TEXT (" for entity '"));
-                  msg += ACE_CString (ACE_TEXT (info->name ()));
-                  msg += ACE_CString (ACE_TEXT ("'\n"));
+                  ACE_TString msg (ACE_TEXT ("Invalid attribute value '"));
+                  msg += ACE_TString (alist->getQName (i));
+                  msg += ACE_TString (ACE_TEXT ("', expecting 'active' or 'inactive'"));
+                  msg += ACE_TString (ACE_TEXT (" for entity '"));
+                  msg += ACE_TString (info->name ());
+                  msg += ACE_TString (ACE_TEXT ("'\n"));
 
                   ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()),
                                        -1);
@@ -669,11 +669,11 @@ ACEXML_Svcconf_Handler::get_dynamic_attrs (ACEXML_Attributes *alist ACEXML_ENV_A
               else
                 {
                   // build the error message
-                  ACE_CString msg (ACE_TEXT ("Invalid Service_Object attribute value'"));
-                  msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-                  msg += ACE_CString (ACE_TEXT ("' for entity '"));
-                  msg += ACE_CString (ACE_TEXT (info->name ()));
-                  msg += ACE_CString (ACE_TEXT ("'\n"));
+                  ACE_TString msg (ACE_TEXT ("Invalid Service_Object attribute value'"));
+                  msg += ACE_TString (alist->getQName (i));
+                  msg += ACE_TString (ACE_TEXT ("' for entity '"));
+                  msg += ACE_TString (info->name ());
+                  msg += ACE_TString (ACE_TEXT ("'\n"));
 
                   ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()),
                                   -1);
@@ -682,11 +682,11 @@ ACEXML_Svcconf_Handler::get_dynamic_attrs (ACEXML_Attributes *alist ACEXML_ENV_A
           else
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Invalid attribute'"));
-              msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-              msg += ACE_CString (ACE_TEXT ("' for entity '"));
-              msg += ACE_CString (ACE_TEXT (info->name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Invalid attribute'"));
+              msg += ACE_TString (alist->getQName (i));
+              msg += ACE_TString (ACE_TEXT ("' for entity '"));
+              msg += ACE_TString (info->name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()), -1);
             }
@@ -720,11 +720,11 @@ ACEXML_Svcconf_Handler::get_initializer_attrs (ACEXML_Attributes *alist ACEXML_E
           else
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Invalid initializer attribute'"));
-              msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-              msg += ACE_CString (ACE_TEXT ("' for entity '"));
-              msg += ACE_CString (ACE_TEXT (info->name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Invalid initializer attribute'"));
+              msg += ACE_TString (alist->getQName (i));
+              msg += ACE_TString (ACE_TEXT ("' for entity '"));
+              msg += ACE_TString (info->name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()), -1);
             }
@@ -754,11 +754,11 @@ ACEXML_Svcconf_Handler::get_static_attrs (ACEXML_Attributes *alist ACEXML_ENV_AR
           else
             {
               // build the error message
-              ACE_CString msg (ACE_TEXT ("Invalid static attribute '"));
-              msg += ACE_CString (ACE_TEXT (alist->getQName (i)));
-              msg += ACE_CString (ACE_TEXT ("' for entity '"));
-              msg += ACE_CString (ACE_TEXT (info->name ()));
-              msg += ACE_CString (ACE_TEXT ("'\n"));
+              ACE_TString msg (ACE_TEXT ("Invalid static attribute '"));
+              msg += ACE_TString (alist->getQName (i));
+              msg += ACE_TString (ACE_TEXT ("' for entity '"));
+              msg += ACE_TString (info->name ());
+              msg += ACE_TString (ACE_TEXT ("'\n"));
 
               ACEXML_THROW_RETURN (ACEXML_SAXException (msg.c_str ()), -1);
             }
