@@ -1,4 +1,4 @@
-// $Id: HttpCharStream.cpp 75114 2006-10-27 23:48:24Z ossama $
+// $Id: HttpCharStream.cpp 83341 2008-10-21 12:45:49Z vzykov $
 
 #include "ace/ACE.h"
 #include "ace/ace_wchar.h"
@@ -8,7 +8,7 @@
 #include "ACEXML/common/HttpCharStream.h"
 #include "ACEXML/common/Encoding.h"
 
-ACE_RCSID (common, HttpCharStream, "$Id: HttpCharStream.cpp 75114 2006-10-27 23:48:24Z ossama $")
+ACE_RCSID (common, HttpCharStream, "$Id: HttpCharStream.cpp 83341 2008-10-21 12:45:49Z vzykov $")
 
 /* Header FSM states. */
 static const int HDST_LINE1_PROTOCOL = 0;
@@ -114,22 +114,31 @@ int
 ACEXML_HttpCharStream::get_url (size_t& len)
 {
   if (this->stream_ == 0)
-    return -1;
+    {
+      return -1;
+    }
 
   int header_state = HDST_LINE1_PROTOCOL;
   int status = 0;
   size_t b = 0;
   char const * buf = 0;
   size_t buflen = BUFSIZ;
+  
   for (;;)
     {
       buf = this->stream_->recv (buflen);
 
       if (buf == 0)
-        if (buflen == 0)
-          break;
-        else
-          continue;
+        {
+          if (buflen == 0)
+            {
+              break;
+            }
+          else
+            {
+              continue;
+            }
+        }
 
       for (b = 0; b < buflen; ++b)
         {
@@ -223,8 +232,12 @@ ACEXML_HttpCharStream::get_url (size_t& len)
         }
     }
  end_of_headers:
+ 
   if (b == 0)
-    return -1;
+    {
+      return -1;
+    }
+    
   ++b;
   // Store the address of the beginning of data. We will use it to seek to
   // beginning of the data in the URL.
@@ -242,11 +255,17 @@ ACEXML_HttpCharStream::get_url (size_t& len)
   // Move the pointer to the beginning of the file store.
   this->stream_->rewind();
 
-  this->data_offset_ = data_beg - this->stream_->recv();
+  this->data_offset_ =
+    ACE_Utils::truncate_cast<ACE_OFF_T> (data_beg - this->stream_->recv());
+    
   // Forward to the beginning of data.
   if (this->stream_->seek (this->data_offset_, SEEK_SET) == -1)
-    ACE_ERROR_RETURN ((LM_ERROR, "%s: %m",
-                       "Error in seeking to beginning of data"), -1);
+    {
+      ACE_ERROR_RETURN ((LM_ERROR,
+                         "%s: %m",
+                         "Error in seeking to beginning of data"),
+                        -1);
+    }
 
   return status;
 }
@@ -393,10 +412,10 @@ ACEXML_HttpCharStream::read (ACEXML_Char *str,
   if (this->stream_ == 0)
     return -1;
   len = len * sizeof (ACEXML_Char);
-  char* temp = const_cast<char*> (this->stream_->recv (len));
-  str = ACE_TEXT_CHAR_TO_TCHAR (temp);
-  if (str == 0)
+  const char* temp = this->stream_->recv (len);
+  if (temp == 0)
     return -1;
+  ACE_OS::strncpy (str, ACE_TEXT_CHAR_TO_TCHAR (temp), len);
   return static_cast<int> (len);
 }
 
