@@ -1,4 +1,4 @@
-// $Id: main.cpp 51862 2003-08-23 19:32:56Z dhinton $
+// $Id: main.cpp 80826 2008-03-04 14:51:23Z wotte $
 
 // This server daemon processes SNMP Version 1 get, get-next, and set
 // commands. over the MIB II "System" group only.
@@ -7,15 +7,15 @@
 #include "snmp_agent.h"
 #include "ace/ACE.h"
 
-ACE_RCSID(agent, main, "$Id: main.cpp 51862 2003-08-23 19:32:56Z dhinton $")
+ACE_RCSID(agent, main, "$Id: main.cpp 80826 2008-03-04 14:51:23Z wotte $")
 
-int 
-main (int argc, char *argv[])
+int
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   ACE::init ();
   snmp_agent the_agent;
 
-  if (the_agent.set_args(argc, argv)) 
+  if (the_agent.set_args(argc, argv))
     return 1;
 
   if (!the_agent.valid()) {
