@@ -1,4 +1,4 @@
-// $Id: address.cpp 78673 2007-06-30 04:51:04Z sowayaa $
+// $Id: address.cpp 88870 2010-02-06 12:59:37Z mcorino $
 
 // ============================================================================
 //
@@ -45,7 +45,7 @@
 #include "ace/OS_NS_ctype.h"
 #include "ace/OS_Memory.h"
 
-ACE_RCSID(asnmp, address, "$Id: address.cpp 78673 2007-06-30 04:51:04Z sowayaa $")
+ACE_RCSID(asnmp, address, "$Id: address.cpp 88870 2010-02-06 12:59:37Z mcorino $")
 
 //=================================================================
 //======== Abstract Address Class Implementation ==================
@@ -312,7 +312,8 @@ IpAddress::~IpAddress()
 int IpAddress::is_loopback() const
 {
  if (valid()) {
-   return (*(u_long *)&address_buffer == INADDR_LOOPBACK);
+   u_long *pl = (u_long *)&address_buffer;
+   return (*pl == INADDR_LOOPBACK);
  }
   return 0;
 }
@@ -320,7 +321,8 @@ int IpAddress::is_loopback() const
 int IpAddress::is_multicast() const
 {
  if (valid()) {
-   return (IN_MULTICAST(*(u_long *)&address_buffer));
+   u_long *pl = (u_long *)&address_buffer;
+   return (IN_MULTICAST(*pl));
  }
   return 0;
 }
@@ -358,7 +360,8 @@ void IpAddress::to_octet(OctetStr& octet) const
 int IpAddress::is_broadcast() const
 {
  if (valid()) {
-   return ( (*(u_long *)&address_buffer) & INADDR_BROADCAST);
+   u_long *pl = (u_long *)&address_buffer;
+   return ( (*pl) & INADDR_BROADCAST);
  }
   return 0;
 }
@@ -662,23 +665,34 @@ void IpAddress::mask( const IpAddress& ipaddr)
 //=======================================================================
 
 
-Address_Iter::Address_Iter(const char *hostname): valid_(0), count_(0),
-  entry_(0)
+Address_Iter::Address_Iter (const char *hostname)
+  : valid_(0),
+    count_(0),
+    entry_(0)
 {
-   ACE_OS::memset(&buffer_, 0, sizeof(ACE_HOSTENT_DATA));
-   ACE_OS::memset(&lookupResult_, 0, sizeof(struct hostent));
-   if (ACE_OS::inet_addr(hostname) == (unsigned long) -1)
-     valid_ = query_dns(hostname);
-   else {
-     ACE_ASSERT(0);             // don't support dot-quad lookup yet
-   }
+  ACE_OS::memset (&buffer_, 0, sizeof (ACE_HOSTENT_DATA));
+  ACE_OS::memset (&lookupResult_, 0, sizeof (struct hostent));
+  
+  if (ACE_OS::inet_addr (hostname) == (unsigned long) -1)
+    {
+      valid_ = query_dns (hostname);
+    }
+  else
+    {
+      ACE_ASSERT (0);             // don't support dot-quad lookup yet
+    }
 
-   // count number of hostnames
-   int n;
-   char **pc;
-   for (n = 0, pc = lookupResult_.h_addr_list; *pc != 0; ++n, ++pc);
-   count_ = n;          // plus first one
-   entry_ = lookupResult_.h_addr_list;
+  // count number of hostnames
+  int n;
+  char **pc;
+
+  for (n = 0, pc = lookupResult_.h_addr_list; *pc != 0; ++n, ++pc)
+    {
+      // Do nothing.
+    }
+
+  count_ = n;          // plus first one
+  entry_ = lookupResult_.h_addr_list;
 }
 
 int Address_Iter::valid() const
