@@ -1,4 +1,4 @@
-// $Id: asn1.cpp 77808 2007-03-26 20:47:10Z wotte $
+// $Id: asn1.cpp 82513 2008-08-05 18:52:53Z parsons $
 
 // ============================================================================
 //
@@ -54,7 +54,7 @@
 #include "asnmp/snmp.h"
 #include "ace/OS_NS_string.h"
 
-ACE_RCSID(asnmp, asn1, "$Id: asn1.cpp 77808 2007-03-26 20:47:10Z wotte $")
+ACE_RCSID(asnmp, asn1, "$Id: asn1.cpp 82513 2008-08-05 18:52:53Z parsons $")
 
 /*
  * parse_int - pulls a long out of an ASN int type.
@@ -1020,13 +1020,18 @@ void cmu_snmp::add_var(struct snmp_pdu *pdu,
   struct variable_list *vars = 0;
 
   // if we don't have a vb list ,create one
-  if (pdu->variables == 0) {
-    ACE_NEW(pdu->variables, variable_list);
-    vars = pdu->variables;
-  }
+  if (pdu->variables == 0)
+    {
+      ACE_NEW(pdu->variables, variable_list);
+      vars = pdu->variables;
+    }
   else
     { // we have one, find the end
-      for(vars = pdu->variables; vars->next_variable; vars = vars->next_variable);
+      for (vars = pdu->variables; vars->next_variable; vars = vars->next_variable)
+        {
+          // Do nothing.
+        }
+        
       // create one
       ACE_NEW(vars->next_variable, variable_list);
       // bump ptr
