@@ -1,4 +1,4 @@
-// $Id: wpdu.cpp 80083 2007-11-23 19:52:07Z johnnyw $
+// $Id: wpdu.cpp 85030 2009-04-06 08:57:59Z johnnyw $
 
 // ============================================================================
 // = LIBRARY
@@ -25,7 +25,7 @@
 #define DEFINE_TRAP_CONSTANTS_
 #include "asnmp/enttraps.h"
 
-ACE_RCSID(asnmp, wpdu, "$Id: wpdu.cpp 80083 2007-11-23 19:52:07Z johnnyw $")
+ACE_RCSID(asnmp, wpdu, "$Id: wpdu.cpp 85030 2009-04-06 08:57:59Z johnnyw $")
 
 #define MAX_COMM_STR_LEN 255
 #define V1_COLD_START 0
@@ -98,12 +98,17 @@ wpdu::wpdu(const Pdu& pdu, const UdpTarget& target):
    ACE_NEW(iovec_.iov_base, char [iovec_.iov_len]);
 
    // create raw byte stream
+   // The intermediate integer is to avoid type-punned pointer
+   // dereferencing.
+   int out_length = iovec_.iov_len;
    status = cmu_snmp::build( raw_pdu,
                             (unsigned char *)iovec_.iov_base,
-                            (int *) &iovec_.iov_len,
+                            &out_length,
                             target.get_version(),
                             comm_str.data(),
                             comm_str.length());
+   iovec_.iov_len = out_length;
+
    if ( status != 0) {
      valid_flag_ = SNMP_ERROR_WRONG_ENCODING;
      cmu_snmp::free_pdu( raw_pdu);
@@ -452,6 +457,14 @@ int wpdu::restore_vbs(Pdu& pdu, const snmp_pdu *raw_pdu) const
     }
     break;
 
+    // Gauge32
+    case sNMP_SYNTAX_GAUGE32:
+    {
+       Gauge32 gauge32( (unsigned long) *(vp->val.integer));
+       tempvb.set_value( gauge32);
+    }
+    break;
+
     // 32 bit counter
     case sNMP_SYNTAX_CNTR32:
     {
