@@ -1,4 +1,4 @@
-// $Id: next.cpp 78673 2007-06-30 04:51:04Z sowayaa $
+// $Id: next.cpp 84565 2009-02-23 08:20:39Z johnnyw $
 
 // ============================================================================
 //
@@ -40,7 +40,7 @@
 // FUZZ: disable check_for_streams_include
 #include "ace/streams.h"
 
-ACE_RCSID(next, next, "$Id: next.cpp 78673 2007-06-30 04:51:04Z sowayaa $")
+ACE_RCSID(next, next, "$Id: next.cpp 84565 2009-02-23 08:20:39Z johnnyw $")
 
 //
 // SNMPv1 Get Next Application
@@ -66,9 +66,10 @@ class nextapp {
 
 
 // main entry point
-int main( int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
-  nextapp get(argc, argv);
+  ACE_Argv_Type_Converter atc (argc, argv);
+  nextapp get (atc.get_argc (), atc.get_ASCII_argv ());
   if (get.valid())
      return get.run();
   else
@@ -140,8 +141,8 @@ void nextapp::usage()
 {
   cout << "Usage:\n";
   cout << "next [options] dotted-quad | DNSName[:port]\n";
-  cout << "      -o OID starts with oid after 1.3.6.1.2.1.1.1.0 (mibII sysDescr.0) \n";
-  cout << "      -c Community_name, default is 'public' \n";
+  cout << "      -o OID starts with oid after 1.3.6.1.2.1.1.1.0 (mibII sysDescr.0)\n";
+  cout << "      -c Community_name, default is 'public'\n";
   cout << "      -r N  retries default is N = 1 retry\n";
   cout << "      -t N  timeout in seconds default is 1 second" << endl;
 }
@@ -189,8 +190,8 @@ int nextapp::run()
       else {
         VbIter iter(pdu_);
         while (iter.next(vb)) {
- 	  cout << "\tOid = " << vb.to_string_oid() << "\n";
- 	  cout << "\tValue = " << vb.to_string_value() << "\n";
+          cout << "\tOid = " << vb.to_string_oid() << "\n";
+          cout << "\tValue = " << vb.to_string_value() << "\n";
        }
      }
    }
