@@ -1,4 +1,4 @@
-// $Id: DSRT_CV_Dispatcher_Impl_T.cpp 52750 2003-10-14 08:53:07Z venkita $
+// $Id: DSRT_CV_Dispatcher_Impl_T.cpp 84565 2009-02-23 08:20:39Z johnnyw $
 
 #ifndef DSRT_CV_DISPATCHER_IMPL_T_CPP
 #define DSRT_CV_DISPATCHER_IMPL_T_CPP
@@ -9,11 +9,11 @@
 //#include "DSRT_CV_Dispatcher_Impl_T.i"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Kokyu, DSRT_CV_Dispatcher_Impl_T, "$Id: DSRT_CV_Dispatcher_Impl_T.cpp 52750 2003-10-14 08:53:07Z venkita $")
+ACE_RCSID(Kokyu, DSRT_CV_Dispatcher_Impl_T, "$Id: DSRT_CV_Dispatcher_Impl_T.cpp 84565 2009-02-23 08:20:39Z johnnyw $")
 
 namespace Kokyu
 {
-  
+
 /*
 //@@VS: This is somehow not being recognized by MSVC, which results
 //in a link error. For now, the definition has been moved to the .h
@@ -41,7 +41,7 @@ operator ()(const DSRT_Dispatch_Item_var<DSRT_Scheduler_Traits>& item1,
 
 template <class DSRT_Scheduler_Traits>
 DSRT_CV_Dispatcher_Impl<DSRT_Scheduler_Traits>::
-DSRT_CV_Dispatcher_Impl (ACE_Sched_Params::Policy sched_policy, 
+DSRT_CV_Dispatcher_Impl (ACE_Sched_Params::Policy sched_policy,
                          int sched_scope)
   :DSRT_Dispatcher_Impl<DSRT_Scheduler_Traits> (sched_policy, sched_scope),
    run_cond_ (run_cond_lock_)
@@ -61,16 +61,16 @@ schedule_i (Guid_t id, const DSRT_QoSDescriptor& qos)
 {
 
 #ifdef KOKYU_DSRT_LOGGING
-  ACE_DEBUG ((LM_DEBUG, 
-              "(%t|%T):schedule_i enter\n")); 
+  ACE_DEBUG ((LM_DEBUG,
+              "(%t|%T):schedule_i enter\n"));
 #endif
 
   DSRT_Dispatch_Item<DSRT_Scheduler_Traits>* item;
   ACE_hthread_t thr_handle;
   ACE_Thread::self (thr_handle);
 
-  if (ACE_OS::thr_setprio (thr_handle, 
-                           this->blocked_prio_, 
+  if (ACE_OS::thr_setprio (thr_handle,
+                           this->blocked_prio_,
                            this->sched_policy_) == -1)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
@@ -90,10 +90,10 @@ schedule_i (Guid_t id, const DSRT_QoSDescriptor& qos)
 #ifdef KOKYU_DSRT_LOGGING
   this->ready_queue_.dump ();
 
-  ACE_DEBUG ((LM_DEBUG, 
-              "(%t|%T):schedule_i after ready_q.insert\n")); 
+  ACE_DEBUG ((LM_DEBUG,
+              "(%t|%T):schedule_i after ready_q.insert\n"));
 #endif
-  
+
   DSRT_Dispatch_Item_var<DSRT_Scheduler_Traits> item_var;
 
   ACE_GUARD_RETURN (ACE_SYNCH_MUTEX, cond_guard, run_cond_lock_, -1);
@@ -104,25 +104,25 @@ schedule_i (Guid_t id, const DSRT_QoSDescriptor& qos)
   ACE_hthread_t most_eligible_thr_handle = item_var->thread_handle ();
 
 #ifdef KOKYU_DSRT_LOGGING
-      ACE_DEBUG ((LM_DEBUG, 
-                  "(%t|%T):curr thr handle = %d\n", 
-                  thr_handle)); 
-      ACE_DEBUG ((LM_DEBUG, 
-                  "(%t|%T):curr scheduled thr handle = %d\n", 
-                  this->curr_scheduled_thr_handle_)); 
-      ACE_DEBUG ((LM_DEBUG, 
-                  "(%t|%T):most eligible thr handle = %d \n",
-                  most_eligible_thr_handle)); 
+      ACE_DEBUG ((LM_DEBUG,
+                  "(%t|%T):curr thr handle = %d\n",
+                  thr_handle));
+      ACE_DEBUG ((LM_DEBUG,
+                  "(%t|%T):curr scheduled thr handle = %d\n",
+                  this->curr_scheduled_thr_handle_));
+      ACE_DEBUG ((LM_DEBUG,
+                  "(%t|%T):most eligible thr handle = %d\n",
+                  most_eligible_thr_handle));
 #endif
 
   if (this->curr_scheduled_thr_handle_ == thr_handle &&
       most_eligible_thr_handle != thr_handle)
     {
 #ifdef KOKYU_DSRT_LOGGING
-      ACE_DEBUG ((LM_DEBUG, 
+      ACE_DEBUG ((LM_DEBUG,
                   "(%t|%T):curr sched thr handle = thr_handle & "
                   "most eligible thr handle != curr thr handle. "
-                  "about to do a broadcast on CV to wake up most eligible\n")); 
+                  "about to do a broadcast on CV to wake up most eligible\n"));
 #endif
       this->curr_scheduled_thr_handle_ = most_eligible_thr_handle;
       //wake up the most eligible thread
@@ -133,20 +133,20 @@ schedule_i (Guid_t id, const DSRT_QoSDescriptor& qos)
   //if the current thread is most eligible, but some thread is
   //scheduled currently, then wait.
   while (most_eligible_thr_handle != thr_handle ||
-         (most_eligible_thr_handle == thr_handle && 
+         (most_eligible_thr_handle == thr_handle &&
           this->curr_scheduled_thr_handle_ != thr_handle &&
           this->curr_scheduled_thr_handle_ != 0))
     {
       ACE_Time_Value tv (60,0);
       tv += ACE_OS::gettimeofday ();
-      //wait a maximum of 1 min. This is an escape latch against lockups. 
+      //wait a maximum of 1 min. This is an escape latch against lockups.
 #ifdef KOKYU_DSRT_LOGGING
-      ACE_DEBUG ((LM_DEBUG, 
+      ACE_DEBUG ((LM_DEBUG,
                   "(%t|%T): About to block on cv\n"));
 #endif
-      if (this->run_cond_.wait (&tv) == -1) 
+      if (this->run_cond_.wait (&tv) == -1)
         {
-          ACE_ERROR ((LM_ERROR, 
+          ACE_ERROR ((LM_ERROR,
                       "(%t|%T): run_cond.wait timed out -- Possible Lockup\n"));
         }
       this->ready_queue_.most_eligible (item_var);
@@ -156,23 +156,23 @@ schedule_i (Guid_t id, const DSRT_QoSDescriptor& qos)
   this->curr_scheduled_thr_handle_ = most_eligible_thr_handle;
 
 #ifdef KOKYU_DSRT_LOGGING
-      ACE_DEBUG ((LM_DEBUG, 
+      ACE_DEBUG ((LM_DEBUG,
                   "(%t|%T): %d is currently running\n",
                   thr_handle));
 #endif
 
-  if (ACE_OS::thr_setprio (thr_handle, 
-                           this->active_prio_, 
+  if (ACE_OS::thr_setprio (thr_handle,
+                           this->active_prio_,
                            this->sched_policy_) == -1)
     {
       ACE_ERROR ((LM_ERROR,
                   ACE_TEXT ("%p\n"),
                   ACE_TEXT ("thr_setprio failed")));
     }
-    
+
 #ifdef KOKYU_DSRT_LOGGING
-  ACE_DEBUG ((LM_DEBUG, 
-              "(%t|%T):schedule_i exit\n")); 
+  ACE_DEBUG ((LM_DEBUG,
+              "(%t|%T):schedule_i exit\n"));
 #endif
 
   return 0;
@@ -181,7 +181,7 @@ schedule_i (Guid_t id, const DSRT_QoSDescriptor& qos)
 template <class DSRT_Scheduler_Traits>
 int DSRT_CV_Dispatcher_Impl<DSRT_Scheduler_Traits>::
 update_schedule_i (Guid_t guid, const DSRT_QoSDescriptor& qos)
-{ 
+{
   return this->schedule_i (guid, qos);
 }
 
@@ -205,8 +205,8 @@ update_schedule_i (Guid_t guid, Block_Flag_t flag)
   if (found == 0)
       ACE_DEBUG ((LM_DEBUG, "(%t|%T): %d found in ready queue\n", thr_handle));
   else
-      ACE_DEBUG ((LM_DEBUG, "(%t|%T): %d not found in ready queue\n", 
-                  thr_handle));    
+      ACE_DEBUG ((LM_DEBUG, "(%t|%T): %d not found in ready queue\n",
+                  thr_handle));
 #endif
 
   if (found == 0 && flag == BLOCK)
@@ -217,8 +217,8 @@ update_schedule_i (Guid_t guid, Block_Flag_t flag)
       ACE_DEBUG ((LM_DEBUG, "(%t|%T): update schedule: %d found\n", thr_handle));
 #endif
 
-      if (ACE_OS::thr_setprio (thr_handle, 
-                               this->blocked_prio_, 
+      if (ACE_OS::thr_setprio (thr_handle,
+                               this->blocked_prio_,
                                this->sched_policy_) == -1)
         {
           ACE_ERROR ((LM_ERROR,
