@@ -2,7 +2,7 @@
 /**
  *  @file  DSRT_Sched_Queue_T.cpp
  *
- *  $Id: DSRT_Sched_Queue_T.cpp 78400 2007-05-18 03:53:35Z sowayaa $
+ *  $Id: DSRT_Sched_Queue_T.cpp 82574 2008-08-08 19:35:06Z parsons $
  *
  *  @author Venkita Subramonian (venkita@cs.wustl.edu)
  *
@@ -21,7 +21,7 @@
 
 ACE_RCSID(Kokyu,
           DSRT_Sched_Queue_T,
-          "$Id: DSRT_Sched_Queue_T.cpp 78400 2007-05-18 03:53:35Z sowayaa $")
+          "$Id: DSRT_Sched_Queue_T.cpp 82574 2008-08-08 19:35:06Z parsons $")
 
 namespace Kokyu
 {
@@ -49,9 +49,11 @@ template <class DSRT_Scheduler_Traits,
 int Sched_Ready_Queue<DSRT_Scheduler_Traits,
                       More_Eligible_Comparator,
                       ACE_LOCK>::
-current_size ()
+current_size (void)
 {
-  return dispatch_items_prio_queue_.current_size ();
+  return
+    ACE_Utils::truncate_cast<int> (
+      dispatch_items_prio_queue_.current_size ());
 }
 
 template <class DSRT_Scheduler_Traits,
@@ -63,7 +65,9 @@ int Sched_Ready_Queue<DSRT_Scheduler_Traits,
 most_eligible (DSRT_Dispatch_Item_var<DSRT_Scheduler_Traits>& item)
 {
   if (dispatch_items_prio_queue_.current_size () == 0)
+    {
       return -1;
+    }
 
   PRIO_QUEUE_ITERATOR start = dispatch_items_prio_queue_.begin ();
   PRIO_QUEUE_ENTRY &ent = (*start);
