@@ -1,4 +1,4 @@
-// $Id: Default_Dispatcher_Impl.cpp 73790 2006-07-27 20:43:46Z wotte $
+// $Id: Default_Dispatcher_Impl.cpp 82574 2008-08-08 19:35:06Z parsons $
 
 #include "Default_Dispatcher_Impl.h"
 #include "ace/Sched_Params.h"
@@ -7,7 +7,9 @@
 #include "Default_Dispatcher_Impl.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Kokyu, Default_Dispatcher_Impl, "$Id: Default_Dispatcher_Impl.cpp 73790 2006-07-27 20:43:46Z wotte $")
+ACE_RCSID (Kokyu,
+           Default_Dispatcher_Impl,
+           "$Id: Default_Dispatcher_Impl.cpp 82574 2008-08-08 19:35:06Z parsons $")
 
 namespace Kokyu
 {
@@ -23,11 +25,12 @@ Default_Dispatcher_Impl::init_i (const Dispatcher_Attributes& attrs)
   //create and init the dispatcher tasks here
 
   ACE_DEBUG ((LM_DEBUG, "entering init_t\n" ));
-  int size;
-  size = attrs.config_info_set_.size ();
+  int size = ACE_Utils::truncate_cast<int> (attrs.config_info_set_.size ());
 
   if (size == 0)
-    return -1;
+    {
+      return -1;
+    }
 
   this->ntasks_ = size;
 
