@@ -1,4 +1,4 @@
-// $Id: Kokyu.cpp 73790 2006-07-27 20:43:46Z wotte $
+// $Id: Kokyu.cpp 84972 2009-03-25 19:09:06Z johnnyw $
 
 #include "Kokyu.h"
 
@@ -8,7 +8,7 @@
 #include "Kokyu.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Kokyu, Kokyu, "$Id: Kokyu.cpp 73790 2006-07-27 20:43:46Z wotte $")
+ACE_RCSID(Kokyu, Kokyu, "$Id: Kokyu.cpp 84972 2009-03-25 19:09:06Z johnnyw $")
 
 namespace Kokyu
 {
@@ -43,8 +43,8 @@ Dispatcher*
 Dispatcher_Factory::
 create_dispatcher(const Dispatcher_Attributes& attrs)
 {
-  Dispatcher* disp;
-  Dispatcher_Impl* tmp;
+  Dispatcher* disp = 0;
+  Dispatcher_Impl* tmp = 0;
   ACE_NEW_RETURN (tmp, Default_Dispatcher_Impl, 0);
   ACE_NEW_RETURN (disp, Dispatcher, 0);
   disp->implementation (tmp);
