@@ -13,36 +13,36 @@ package BDS4ProjectCreator;
 use strict;
 
 use ProjectCreator;
-use WinProjectBase;
+use BorlandProjectBase;
 use XMLProjectBase;
 
 use vars qw(@ISA);
-@ISA = qw(XMLProjectBase WinProjectBase ProjectCreator);
+@ISA = qw(XMLProjectBase BorlandProjectBase ProjectCreator);
 
 # ************************************************************
 # Subroutine Section
 # ************************************************************
 
 sub crlf {
-  #my($self) = shift;
+  #my $self = shift;
   return "\n";
 }
 
 
 sub project_file_extension {
-  #my($self) = shift;
+  #my $self = shift;
   return '.bdsproj';
 }
 
 
 sub get_dll_exe_template_input_file {
-  #my($self) = shift;
+  #my $self = shift;
   return 'bds4exe';
 }
 
 
 sub get_dll_template_input_file {
-  #my($self) = shift;
+  #my $self = shift;
   return 'bds4dll';
 }
 
