@@ -23,51 +23,49 @@ use vars qw(@ISA);
 # Data Section
 # ************************************************************
 
-my($assign_key)  = 'assign';
-my($gassign_key) = 'global_assign';
-my(%non_convert) = ('prebuild' => 1,
-                    'postbuild' => 1,
-                   );
-my(@statekeys) = ('global', 'include', 'template', 'ti',
-                  'dynamic', 'static', 'relative', 'addtemp',
-                  'addproj', 'progress', 'toplevel', 'baseprojs',
-                  'features', 'feature_file', 'hierarchy',
-                  'name_modifier', 'apply_project', 'into', 'use_env',
-                  'expand_vars', 'language',
-                 );
+## Constants for use throughout the project
+use constant cplusplus => 'cplusplus';
+use constant csharp    => 'csharp';
+use constant java      => 'java';
+use constant vb        => 'vb';
+use constant website   => 'website';
 
-my(%all_written) = ();
-my($onVMS) = DirectoryManager::onVMS();
+## The default language for MPC
+my $deflang = 'cplusplus';
+
+## A map of all of the allowed languages.  The 'website' value
+## is not here because it isn't really a language.  It is used
+## as a language internally by some project types though.
+my %languages = (cplusplus => 1,
+                 csharp    => 1,
+                 java      => 1,
+                 vb        => 1,
+                );
+
+my $assign_key  = 'assign';
+my $gassign_key = 'global_assign';
+my %non_convert = ('prebuild'  => 1,
+                   'postbuild' => 1,
+                   'postclean' => 1,
+                  );
+my @statekeys = ('global', 'include', 'template', 'ti',
+                 'dynamic', 'static', 'relative', 'addtemp',
+                 'addproj', 'progress', 'toplevel', 'baseprojs',
+                 'features', 'feature_file', 'hierarchy',
+                 'name_modifier', 'apply_project', 'into', 'use_env',
+                 'expand_vars', 'language',
+                );
+
+my %all_written;
+my $onVMS = DirectoryManager::onVMS();
 
 # ************************************************************
 # Subroutine Section
 # ************************************************************
 
 sub new {
-  my($class)      = shift;
-  my($global)     = shift;
-  my($inc)        = shift;
-  my($template)   = shift;
-  my($ti)         = shift;
-  my($dynamic)    = shift;
-  my($static)     = shift;
-  my($relative)   = shift;
-  my($addtemp)    = shift;
-  my($addproj)    = shift;
-  my($progress)   = shift;
-  my($toplevel)   = shift;
-  my($baseprojs)  = shift;
-  my($feature)    = shift;
-  my($features)   = shift;
-  my($hierarchy)  = shift;
-  my($nmodifier)  = shift;
-  my($applypj)    = shift;
-  my($into)       = shift;
-  my($language)   = shift;
-  my($use_env)    = shift;
-  my($expandvars) = shift;
-  my($type)       = shift;
-  my($self)       = Parser::new($class, $inc);
+  my($class, $global, $inc, $template, $ti, $dynamic, $static, $relative, $addtemp, $addproj, $progress, $toplevel, $baseprojs, $feature, $features, $hierarchy, $nmodifier, $applypj, $into, $language, $use_env, $expandvars, $type) = @_;
+  my $self = Parser::new($class, $inc);
 
   $self->{'relative'}        = $relative;
   $self->{'template'}        = $template;
@@ -95,7 +93,7 @@ sub new {
   $self->{'name_modifier'}   = $nmodifier;
   $self->{'apply_project'}   = $applypj;
   $self->{'into'}            = $into;
-  $self->{'language'}        = $language;
+  $self->{'language'}        = defined $language ? $language : $deflang;
   $self->{'use_env'}         = $use_env;
   $self->{'expand_vars'}     = $expandvars;
   $self->{'convert_slashes'} = $self->convert_slashes();
@@ -107,45 +105,40 @@ sub new {
 
 
 sub preprocess_line {
-  my($self) = shift;
-  my($fh)   = shift;
-  my($line) = shift;
+  my($self, $fh, $line) = @_;
 
   $line = $self->strip_line($line);
   while ($line =~ /\\$/) {
     $line =~ s/\s*\\$/ /;
-    my($next) = $fh->getline();
-    if (defined $next) {
-      $line .= $self->strip_line($next);
-    }
+    my $next = $fh->getline();
+    $line .= $self->strip_line($next) if (defined $next);
   }
   return $line;
 }
 
 
 sub generate_default_input {
-  my($self)  = shift;
+  my $self  = shift;
   my($status,
      $error) = $self->parse_line(undef, "$self->{'grammar_type'} {");
 
-  if ($status) {
-    ($status, $error) = $self->parse_line(undef, '}');
-  }
+  ## Parse the finish line if there was no error
+  ($status, $error) = $self->parse_line(undef, '}') if ($status);
 
-  if (!$status) {
-    $self->error($error);
-  }
+  ## Display the error if there was one
+  $self->error($error) if (!$status);
 
   return $status;
 }
 
 
 sub parse_file {
-  my($self)  = shift;
-  my($input) = shift;
-  my($oline) = $self->get_line_number();
+  my($self, $input) = @_;
 
-  ## Read the input file and get the last line number
+  ## Save the last line number so we can put it back later
+  my $oline = $self->get_line_number();
+
+  ## Read the input file
   my($status, $errorString) = $self->read_file($input);
 
   if (!$status) {
@@ -167,9 +160,8 @@ sub parse_file {
 
 
 sub generate {
-  my($self)   = shift;
-  my($input)  = shift;
-  my($status) = 1;
+  my($self, $input) = @_;
+  my $status = 1;
 
   ## Reset the files_written hash array between processing each file
   $self->{'files_written'} = {};
@@ -202,13 +194,31 @@ sub generate {
 }
 
 
+# split an inheritance list like ": a,b, c" into components
+sub parse_parents {
+  my($parents, $errorStringRef, $statusRef) = @_;
+  if (defined $parents) {
+    $parents =~ s/^:\s*//;
+    $parents =~ s/\s+$//;
+    my @parents = split(/\s*,\s*/, $parents);
+    if (!defined $parents[0]) {
+      ## The : was used, but no parents followed.  This
+      ## is an error.
+      $$errorStringRef = 'No parents listed';
+      $$statusRef = 0;
+    }
+    return \@parents;
+  }
+  return undef;
+}
+
+
 sub parse_known {
-  my($self)        = shift;
-  my($line)        = shift;
-  my($status)      = 1;
-  my($errorString) = undef;
-  my($type)        = $self->{'grammar_type'};
-  my(@values)      = ();
+  my($self, $line) = @_;
+  my $status = 1;
+  my $errorString;
+  my $type = $self->{'grammar_type'};
+  my @values;
 
   ##
   ## Each regexp that looks for the '{' looks for it at the
@@ -220,25 +230,14 @@ sub parse_known {
   if ($line eq '') {
   }
   elsif ($line =~ /^$type\s*(\([^\)]+\))?\s*(:.*)?\s*{$/) {
-    my($name)    = $1;
-    my($parents) = $2;
+    my $name    = $1;
+    my $parents = $2;
     if ($self->{$self->{'type_check'}}) {
       $errorString = "Did not find the end of the $type";
       $status = 0;
     }
     else {
-      if (defined $parents) {
-        $parents =~ s/^:\s*//;
-        $parents =~ s/\s+$//;
-        my(@parents) = split(/\s*,\s*/, $parents);
-        if (!defined $parents[0]) {
-          ## The : was used, but no parents followed.  This
-          ## is an error.
-          $errorString = 'No parents listed';
-          $status = 0;
-        }
-        $parents = \@parents;
-      }
+      $parents = parse_parents($parents, \$errorString, \$status);
       push(@values, $type, $name, $parents);
     }
   }
@@ -252,23 +251,11 @@ sub parse_known {
     }
   }
   elsif ($line =~ /^(feature)\s*\(([^\)]+)\)\s*(:.*)?\s*{$/) {
-    my($type)    = $1;
-    my($name)    = $2;
-    my($parents) = $3;
-    my(@names)   = split(/\s*,\s*/, $name);
-
-    if (defined $parents) {
-      $parents =~ s/^:\s*//;
-      $parents =~ s/\s+$//;
-      my(@parents) = split(/\s*,\s*/, $parents);
-      if (!defined $parents[0]) {
-        ## The : was used, but no parents followed.  This
-        ## is an error.
-        $errorString = 'No parents listed';
-        $status = 0;
-      }
-      $parents = \@parents;
-    }
+    my $type    = $1;
+    my $name    = $2;
+    my $parents = $3;
+    my @names   = split(/\s*,\s*/, $name);
+    $parents = parse_parents($parents, \$errorString, \$status);
     push(@values, $type, \@names, $parents);
   }
   elsif (!$self->{$self->{'type_check'}}) {
@@ -278,9 +265,10 @@ sub parse_known {
   elsif ($self->parse_assignment($line, \@values)) {
     ## If this returns true, then we've found an assignment
   }
-  elsif ($line =~ /^(\w+)\s*(\([^\)]+\))?\s*{$/) {
-    my($comp) = lc($1);
-    my($name) = $2;
+  elsif ($line =~ /^(\w+)\s*(\([^\)]+\))?\s*(:.*)?\s*{$/) {
+    my $comp = lc($1);
+    my $name = $2;
+    my $parents = $3;
 
     if (defined $name) {
       $name =~ s/^\(\s*//;
@@ -289,7 +277,8 @@ sub parse_known {
     else {
       $name = $self->get_default_component_name();
     }
-    push(@values, 'component', $comp, $name);
+    $parents = parse_parents($parents, \$errorString, \$status);
+    push(@values, 'component', $comp, $name, $parents);
   }
   else {
     $errorString = "Unrecognized line: $line";
@@ -301,22 +290,15 @@ sub parse_known {
 
 
 sub parse_scope {
-  my($self)        = shift;
-  my($fh)          = shift;
-  my($name)        = shift;
-  my($type)        = shift;
-  my($validNames)  = shift;
-  my($flags)       = shift;
-  my($elseflags)   = shift;
-  my($status)      = 0;
-  my($errorString) = "Unable to process $name";
+  my($self, $fh, $name, $type, $validNames, $flags, $elseflags) = @_;
+  my $status = 0;
+  my $errorString = "Unable to process $name";
 
-  if (!defined $flags) {
-    $flags = {};
-  }
+  ## Make sure $flags has a hash map reference
+  $flags = {} if (!defined $flags);
 
   while(<$fh>) {
-    my($line) = $self->preprocess_line($fh, $_);
+    my $line = $self->preprocess_line($fh, $_);
 
     if ($line eq '') {
     }
@@ -348,7 +330,7 @@ sub parse_scope {
       }
     }
     else {
-      my(@values) = ();
+      my @values;
       if (defined $validNames && $self->parse_assignment($line, \@values)) {
         if (defined $$validNames{$values[1]}) {
           ## If $type is not defined, we don't even need to bother with
@@ -370,9 +352,7 @@ sub parse_scope {
           ($status,
            $errorString) = $self->handle_unknown_assignment($type,
                                                             @values);
-          if (!$status) {
-            last;
-          }
+          last if (!$status);
         }
       }
       else {
@@ -380,9 +360,7 @@ sub parse_scope {
                                                                $type,
                                                                $flags,
                                                                $line);
-        if (!$status) {
-          last;
-        }
+        last if (!$status);
       }
     }
   }
@@ -391,29 +369,25 @@ sub parse_scope {
 
 
 sub base_directory {
-  my($self) = shift;
+  my $self = shift;
   return $self->mpc_basename($self->getcwd());
 }
 
 
 sub generate_default_file_list {
-  my($self)    = shift;
-  my($dir)     = shift;
-  my($exclude) = shift;
-  my($fileexc) = shift;
-  my($recurse) = shift;
-  my($dh)      = new FileHandle();
-  my(@files)   = ();
+  my($self, $dir, $exclude, $fileexc, $recurse) = @_;
+  my $dh = new FileHandle();
+  my @files;
 
   if (opendir($dh, $dir)) {
-    my($prefix)   = ($dir ne '.' ? "$dir/" : '');
-    my($have_exc) = (defined $$exclude[0]);
-    my($skip)     = 0;
+    my $prefix   = ($dir ne '.' ? "$dir/" : '');
+    my $have_exc = (defined $$exclude[0]);
+    my $skip     = 0;
     foreach my $file (grep(!/^\.\.?$/,
                            ($onVMS ? map {$_ =~ s/\.dir$//; $_} readdir($dh) :
                                      readdir($dh)))) {
       ## Prefix each file name with the directory only if it's not '.'
-      my($full) = $prefix . $file;
+      my $full = $prefix . $file;
 
       if ($have_exc) {
         foreach my $exc (@$exclude) {
@@ -435,6 +409,9 @@ sub generate_default_file_list {
                                                  $fileexc, $recurse));
         }
         else {
+          # Strip out ^ symbols
+          $full =~ s/\^//g if ($onVMS);
+
           push(@files, $full);
         }
       }
@@ -451,8 +428,7 @@ sub generate_default_file_list {
 
 
 sub transform_file_name {
-  my($self) = shift;
-  my($name) = shift;
+  my($self, $name) = @_;
 
   $name =~ s/[\s\-]/_/g;
   return $name;
@@ -460,16 +436,14 @@ sub transform_file_name {
 
 
 sub file_written {
-  my($self) = shift;
-  my($file) = shift;
+  my($self, $file) = @_;
   return (defined $all_written{$self->getcwd() . '/' . $file});
 }
 
 
 sub add_file_written {
-  my($self) = shift;
-  my($file) = shift;
-  my($key)  = lc($file);
+  my($self, $file) = @_;
+  my $key = lc($file);
 
   if (defined $self->{'files_written'}->{$key}) {
     $self->warning("$self->{'grammar_type'} $file " .
@@ -487,20 +461,17 @@ sub add_file_written {
 
 
 sub extension_recursive_input_list {
-  my($self)    = shift;
-  my($dir)     = shift;
-  my($exclude) = shift;
-  my($ext)     = shift;
-  my($fh)      = new FileHandle();
-  my(@files)   = ();
+  my($self, $dir, $exclude, $ext) = @_;
+  my $fh = new FileHandle();
+  my @files;
 
   if (opendir($fh, $dir)) {
-    my($prefix) = ($dir ne '.' ? "$dir/" : '');
-    my($skip)   = 0;
+    my $prefix = ($dir ne '.' ? "$dir/" : '');
+    my $skip   = 0;
     foreach my $file (grep(!/^\.\.?$/,
                            ($onVMS ? map {$_ =~ s/\.dir$//; $_} readdir($fh) :
                                      readdir($fh)))) {
-      my($full) = $prefix . $file;
+      my $full = $prefix . $file;
 
       ## Check for command line exclusions
       if (defined $$exclude[0]) {
@@ -534,15 +505,13 @@ sub extension_recursive_input_list {
 }
 
 sub recursive_directory_list {
-  my($self)        = shift;
-  my($dir)         = shift;
-  my($exclude)     = shift;
-  my($directories) = '';
-  my($fh)          = new FileHandle();
+  my($self, $dir, $exclude) = @_;
+  my $directories = '';
+  my $fh = new FileHandle();
 
   if (opendir($fh, $dir)) {
-    my($prefix) = ($dir ne '.' ? "$dir/" : '');
-    my($skip)   = 0;
+    my $prefix = ($dir ne '.' ? "$dir/" : '');
+    my $skip   = 0;
     if (defined $$exclude[0]) {
       foreach my $exc (@$exclude) {
         if ($dir eq $exc) {
@@ -561,14 +530,19 @@ sub recursive_directory_list {
     foreach my $file (grep(!/^\.\.?$/,
                            ($onVMS ? map {$_ =~ s/\.dir$//; $_} readdir($fh) :
                                      readdir($fh)))) {
-      my($full) = $prefix . $file;
+      my $full = $prefix . $file;
 
-      ## Check for command line exclusions
-      if (defined $$exclude[0]) {
-        foreach my $exc (@$exclude) {
-          if ($full eq $exc) {
-            $skip = 1;
-            last;
+      if ($file eq '.svn' || $file eq 'CVS') {
+        $skip = 1;
+      }
+      else {
+        ## Check for command line exclusions
+        if (defined $$exclude[0]) {
+          foreach my $exc (@$exclude) {
+            if ($full eq $exc) {
+              $skip = 1;
+              last;
+            }
           }
         }
       }
@@ -591,9 +565,7 @@ sub recursive_directory_list {
 
 
 sub modify_assignment_value {
-  my($self)  = shift;
-  my($name)  = shift;
-  my($value) = shift;
+  my($self, $name, $value) = @_;
 
   if ($self->{'convert_slashes'} &&
       index($name, 'flags') == -1 && !defined $non_convert{$name}) {
@@ -607,16 +579,13 @@ sub modify_assignment_value {
 sub get_assignment_hash {
   ## NOTE: If anything in this block changes, then you must make the
   ## same change in process_assignment.
-  my($self) = shift;
+  my $self = shift;
   return $self->{$self->{'reading_global'} ? $gassign_key : $assign_key};
 }
 
 
 sub process_assignment {
-  my($self)   = shift;
-  my($name)   = shift;
-  my($value)  = shift;
-  my($assign) = shift;
+  my($self, $name, $value, $assign) = @_;
 
   ## If no hash table was passed in
   if (!defined $assign) {
@@ -630,17 +599,6 @@ sub process_assignment {
     $value =~ s/^\s+//;
     $value =~ s/\s+$//;
 
-    ## Handle both recursive_includes and recursive_libpaths in one
-    ## search and replace.
-    if ($name eq 'recursive_includes' || $name eq 'recursive_libpaths') {
-      $name =~ s/^recursive_//;
-      my @rel = $self->relative($value);
-      $value = $self->get_assignment($name, $assign);
-      foreach my $subdir (@rel) {
-        $value .= ' ' . $self->recursive_directory_list($subdir, []);
-      }
-    }
-
     ## Modify the assignment value before saving it
     $$assign{$name} = $self->modify_assignment_value($name, $value);
   }
@@ -651,11 +609,7 @@ sub process_assignment {
 
 
 sub addition_core {
-  my($self)   = shift;
-  my($name)   = shift;
-  my($value)  = shift;
-  my($nval)   = shift;
-  my($assign) = shift;
+  my($self, $name, $value, $nval, $assign) = @_;
 
   if (defined $nval) {
     if ($self->preserve_assignment_order($name)) {
@@ -673,11 +627,8 @@ sub addition_core {
 
 
 sub process_assignment_add {
-  my($self)   = shift;
-  my($name)   = shift;
-  my($value)  = shift;
-  my($assign) = shift;
-  my($nval)   = $self->get_assignment_for_modification($name, $assign);
+  my($self, $name, $value, $assign) = @_;
+  my $nval = $self->get_assignment_for_modification($name, $assign);
 
   ## Remove all duplicate parts from the value to be added.
   ## Whether anything gets removed or not is up to the implementation
@@ -685,28 +636,22 @@ sub process_assignment_add {
   $value = $self->remove_duplicate_addition($name, $value, $nval);
 
   ## If there is anything to add, then do so
-  if ($value ne '') {
-    $self->addition_core($name, $value, $nval, $assign);
-  }
+  $self->addition_core($name, $value, $nval, $assign) if ($value ne '');
 }
 
 
 sub subtraction_core {
-  my($self)   = shift;
-  my($name)   = shift;
-  my($value)  = shift;
-  my($nval)   = shift;
-  my($assign) = shift;
+  my($self, $name, $value, $nval, $assign) = @_;
 
   if (defined $nval) {
-    my($last)  = 1;
-    my($found) = undef;
+    my $last  = 1;
+    my $found;
 
     ## Escape any regular expression special characters
     $value = $self->escape_regex_special($value);
 
     ## If necessary, split the value into an array
-    my($elements) = ($value =~ /\s/ ? $self->create_array($value) : [$value]);
+    my $elements = ($value =~ /\s/ ? $self->create_array($value) : [$value]);
     for(my $i = 0; $i <= $last; $i++) {
       if ($i == $last) {
         ## If we did not find the string to subtract in the original
@@ -719,7 +664,7 @@ sub subtraction_core {
         ## value if any of the elements were found in the original value
         foreach my $elem (@$elements) {
           ## First try with quotes, then try again without them
-          my($re) = ($j == 0 ? '"' . $elem . '"' : $elem);
+          my $re = ($j == 0 ? '"' . $elem . '"' : $elem);
 
           if ($nval =~ s/\s+$re\s+/ / || $nval =~ s/\s+$re$// ||
               $nval =~ s/^$re\s+//    || $nval =~ s/^$re$//) {
@@ -738,11 +683,8 @@ sub subtraction_core {
 
 
 sub process_assignment_sub {
-  my($self)   = shift;
-  my($name)   = shift;
-  my($value)  = shift;
-  my($assign) = shift;
-  my($nval)   = $self->get_assignment_for_modification($name, $assign);
+  my($self, $name, $value, $assign) = @_;
+  my $nval = $self->get_assignment_for_modification($name, $assign);
 
   ## Remove double quotes if there are any
   $value =~ s/^\"(.*)\"$/$1/;
@@ -752,17 +694,15 @@ sub process_assignment_sub {
 
 
 sub fill_type_name {
-  my($self)  = shift;
-  my($names) = shift;
-  my($def)   = shift;
-  my($array) = ($names =~ /\s/ ? $self->create_array($names) : [$names]);
+  my($self, $names, $def) = @_;
+  my $array = ($names =~ /\s/ ? $self->create_array($names) : [$names]);
 
   $names = '';
   foreach my $name (@$array) {
     if ($name =~ /\*/) {
-      my($pre)  = $def . '_';
-      my($mid)  = '_' . $def . '_';
-      my($post) = '_' . $def;
+      my $pre  = $def . '_';
+      my $mid  = '_' . $def . '_';
+      my $post = '_' . $def;
 
       ## Replace the beginning and end first then the middle
       $name =~ s/^\*/$pre/;
@@ -779,14 +719,14 @@ sub fill_type_name {
       if ($name =~ /[A-Z][0-9a-z_]+/) {
         ## Do the first word
         if ($name =~ /^([a-z])([^_]+)/) {
-          my($first) = uc($1);
-          my($rest)  = $2;
+          my $first = uc($1);
+          my $rest  = $2;
           $name =~ s/^[a-z][^_]+/$first$rest/;
         }
         ## Do subsequent words
         while($name =~ /(_[a-z])([^_]+)/) {
-          my($first) = uc($1);
-          my($rest)  = $2;
+          my $first = uc($1);
+          my $rest  = $2;
           $name =~ s/_[a-z][^_]+/$first$rest/;
         }
       }
@@ -800,30 +740,42 @@ sub fill_type_name {
 }
 
 
+sub clone {
+  my($self, $obj) = @_;
+
+  ## Check for various types of data.  Those that are not found to be
+  ## types that we need to deep copy are just assigned to new values.
+  ## All others are copied by recursively calling this method.
+  if (UNIVERSAL::isa($obj, 'HASH')) {
+    my $new = {};
+    foreach my $key (keys %$obj) {
+      $$new{$key} = $self->clone($$obj{$key});
+    }
+    return $new;
+  }  
+  elsif (UNIVERSAL::isa($obj, 'ARRAY')) {
+    my $new = [];
+    foreach my $o (@$obj) {
+      push(@$new, $self->clone($o));
+    }
+    return $new;
+  }  
+
+  return $obj;
+}                              
+
+
 sub save_state {
-  my($self)     = shift;
-  my($selected) = shift;
-  my(%state)    = ();
+  my($self, $selected) = @_;
+  my %state;
 
   ## Make a deep copy of each state value.  That way our array
   ## references and hash references do not get accidentally modified.
   foreach my $skey (defined $selected ? $selected : @statekeys) {
     if (defined $self->{$skey}) {
-      if (UNIVERSAL::isa($self->{$skey}, 'ARRAY')) {
-        $state{$skey} = [];
-        foreach my $element (@{$self->{$skey}}) {
-          push(@{$state{$skey}}, $element);
-        }
-      }
-      elsif (UNIVERSAL::isa($self->{$skey}, 'HASH')) {
-        $state{$skey} = {};
-        foreach my $key (keys %{$self->{$skey}}) {
-          $state{$skey}->{$key} = $self->{$skey}->{$key};
-        }
-      }
-      else {
-        $state{$skey} = $self->{$skey};
-      }
+      ## It is necessary to clone each value so that nested complex data
+      ## types do not get unknowingly modified.
+      $state{$skey} = $self->clone($self->{$skey});
     }
   }
 
@@ -832,22 +784,23 @@ sub save_state {
 
 
 sub restore_state {
-  my($self)     = shift;
-  my($state)    = shift;
-  my($selected) = shift;
+  my($self, $state, $selected) = @_;
 
   ## Make a deep copy of each state value.  That way our array
   ## references and hash references do not get accidentally modified.
+  ## It's not necessary to do a recursive deep copy (i.e., use the
+  ## clone() method) because the value coming in will now be owned by
+  ## this object and will not be modified unknowingly.
   foreach my $skey (defined $selected ? $selected : @statekeys) {
-    my($old) = $self->{$skey};
+    my $old = $self->{$skey};
     if (defined $state->{$skey} &&
         UNIVERSAL::isa($state->{$skey}, 'ARRAY')) {
-      my(@arr) = @{$state->{$skey}};
+      my @arr = @{$state->{$skey}};
       $self->{$skey} = \@arr;
     }
     elsif (defined $state->{$skey} &&
            UNIVERSAL::isa($state->{$skey}, 'HASH')) {
-      my(%hash) = %{$state->{$skey}};
+      my %hash = %{$state->{$skey}};
       $self->{$skey} = \%hash;
     }
     else {
@@ -859,81 +812,69 @@ sub restore_state {
 
 
 sub get_global_cfg {
-  my($self) = shift;
-  return $self->{'global'};
+  return $_[0]->{'global'};
 }
 
 
 sub get_template_override {
-  my($self) = shift;
-  return $self->{'template'};
+  return $_[0]->{'template'};
 }
 
 
 sub get_ti_override {
-  my($self) = shift;
-  return $self->{'ti'};
+  return $_[0]->{'ti'};
 }
 
 
 sub get_relative {
-  my($self) = shift;
-  return $self->{'relative'};
+  return $_[0]->{'relative'};
 }
 
 
 sub get_progress_callback {
-  my($self) = shift;
-  return $self->{'progress'};
+  return $_[0]->{'progress'};
 }
 
 
 sub get_addtemp {
-  my($self) = shift;
-  return $self->{'addtemp'};
+  return $_[0]->{'addtemp'};
 }
 
 
 sub get_addproj {
-  my($self) = shift;
-  return $self->{'addproj'};
+  return $_[0]->{'addproj'};
 }
 
 
 sub get_toplevel {
-  my($self) = shift;
-  return $self->{'toplevel'};
+  return $_[0]->{'toplevel'};
 }
 
 
 sub get_into {
-  my($self) = shift;
-  return $self->{'into'};
+  return $_[0]->{'into'};
 }
 
 
 sub get_use_env {
-  my($self) = shift;
-  return $self->{'use_env'};
+  return $_[0]->{'use_env'};
 }
 
 
 sub get_expand_vars {
-  my($self) = shift;
-  return $self->{'expand_vars'};
+  return $_[0]->{'expand_vars'};
 }
 
 
 sub get_files_written {
-  my($self)  = shift;
-  return $self->{'real_fwritten'};
+  return $_[0]->{'real_fwritten'};
 }
 
 
 sub get_assignment {
-  my($self)   = shift;
-  my($name)   = $self->resolve_alias(shift);
-  my($assign) = shift;
+  my $self   = shift;
+  my $name = $self->resolve_alias(shift);
+  my $assign = shift;
 
   ## If no hash table was passed in
   if (!defined $assign) {
@@ -946,73 +887,62 @@ sub get_assignment {
 
 
 sub get_assignment_for_modification {
-  my($self)        = shift;
-  my($name)        = shift;
-  my($assign)      = shift;
-  my($subtraction) = shift;
+  my($self, $name, $assign, $subtraction) = @_;
   return $self->get_assignment($name, $assign);
 }
 
 
 sub get_baseprojs {
-  my($self) = shift;
-  return $self->{'baseprojs'};
+  return $_[0]->{'baseprojs'};
 }
 
 
 sub get_dynamic {
-  my($self) = shift;
-  return $self->{'dynamic'};
+  return $_[0]->{'dynamic'};
 }
 
 
 sub get_static {
-  my($self) = shift;
-  return $self->{'static'};
+  return $_[0]->{'static'};
 }
 
 
 sub get_default_component_name {
-  #my($self) = shift;
+  #my $self = shift;
   return 'default';
 }
 
 
 sub get_features {
-  my($self) = shift;
-  return $self->{'features'};
+  return $_[0]->{'features'};
 }
 
 
 sub get_hierarchy {
-  my($self) = shift;
-  return $self->{'hierarchy'};
+  return $_[0]->{'hierarchy'};
 }
 
 
 sub get_name_modifier {
-  my($self) = shift;
-  return $self->{'name_modifier'};
+  return $_[0]->{'name_modifier'};
 }
 
 
 sub get_apply_project {
-  my($self) = shift;
-  return $self->{'apply_project'};
+  return $_[0]->{'apply_project'};
 }
 
 
 sub get_language {
-  my($self) = shift;
-  return $self->{'language'};
+  return $_[0]->{'language'};
 }
 
 
 sub get_outdir {
-  my($self) = shift;
+  my $self = shift;
   if (defined $self->{'into'}) {
-    my($outdir) = $self->getcwd();
-    my($re)     = $self->escape_regex_special($self->getstartdir());
+    my $outdir = $self->getcwd();
+    my $re = $self->escape_regex_special($self->getstartdir());
 
     $outdir =~ s/^$re//;
     return $self->{'into'} . $outdir;
@@ -1024,46 +954,42 @@ sub get_outdir {
 
 
 sub expand_variables {
-  my($self)            = shift;
-  my($value)           = shift;
-  my($rel)             = shift;
-  my($expand_template) = shift;
-  my($scope)           = shift;
-  my($expand)          = shift;
-  my($warn)            = shift;
-  my($cwd)             = $self->getcwd();
-  my($start)           = 0;
+  my($self, $value, $rel, $expand_template, $scope, $expand, $warn) = @_;
+  my $cwd = $self->getcwd();
+  my $start = 0;
+  my $forward_slashes  = $self->{'convert_slashes'} ||
+                         $self->{'requires_forward_slashes'};
 
   ## Fix up the value for Windows switch the \\'s to /
-  $cwd =~ s/\\/\//g if ($self->{'convert_slashes'});
+  $cwd =~ s/\\/\//g if ($forward_slashes);
 
   while(substr($value, $start) =~ /(\$\(([^)]+)\))/) {
-    my($whole) = $1;
-    my($name)  = $2;
+    my $whole = $1;
+    my $name  = $2;
     if (defined $$rel{$name}) {
-      my($val) = $$rel{$name};
+      my $val = $$rel{$name};
       if ($expand) {
-        $val =~ s/\//\\/g if ($self->{'convert_slashes'});
+        $val =~ s/\//\\/g if ($forward_slashes);
         substr($value, $start) =~ s/\$\([^)]+\)/$val/;
         $whole = $val;
       }
       else {
         ## Fix up the value for Windows switch the \\'s to /
-        $val =~ s/\\/\//g if ($self->{'convert_slashes'});
+        $val =~ s/\\/\//g if ($forward_slashes);
 
-        my($icwd) = ($self->{'case_tolerant'} ? lc($cwd) : $cwd);
-        my($ival) = ($self->{'case_tolerant'} ? lc($val) : $val);
-        my($iclen) = length($icwd);
-        my($ivlen) = length($ival);
+        my $icwd = ($self->{'case_tolerant'} ? lc($cwd) : $cwd);
+        my $ival = ($self->{'case_tolerant'} ? lc($val) : $val);
+        my $iclen = length($icwd);
+        my $ivlen = length($ival);
 
         ## If the relative value contains the current working
         ## directory plus additional subdirectories, we must pull
         ## off the additional directories into a temporary where
         ## it can be put back after the relative replacement is done.
-        my($append) = undef;
+        my $append;
         if (index($ival, $icwd) == 0 && $iclen != $ivlen &&
             substr($ival, $iclen, 1) eq '/') {
-          my($diff) = $ivlen - $iclen;
+          my $diff = $ivlen - $iclen;
           $append = substr($ival, $iclen);
           substr($ival, $iclen, $diff) = '';
           $ivlen -= $diff;
@@ -1071,10 +997,10 @@ sub expand_variables {
 
         if (index($icwd, $ival) == 0 &&
             ($iclen == $ivlen || substr($icwd, $ivlen, 1) eq '/')) {
-          my($current) = $icwd;
+          my $current = $icwd;
           substr($current, 0, $ivlen) = '';
 
-          my($dircount) = ($current =~ tr/\///);
+          my $dircount = ($current =~ tr/\///);
           if ($dircount == 0) {
             $ival = '.';
           }
@@ -1082,34 +1008,41 @@ sub expand_variables {
             $ival = '../' x $dircount;
             $ival =~ s/\/$//;
           }
-          if (defined $append) {
-            $ival .= $append;
-          }
+          $ival .= $append if (defined $append);
+
+          ## We have to remove the leading ./ if there is one.
+          ## Otherwise, if this value is used as an exclude value it will
+          ## not match up correctly.
+          $ival =~ s!^\./!!;
+
+          ## Convert the slashes if necessary
           $ival =~ s/\//\\/g if ($self->{'convert_slashes'});
           substr($value, $start) =~ s/\$\([^)]+\)/$ival/;
           $whole = $ival;
         }
-        elsif ($self->convert_all_variables()) {
+        elsif ($self->convert_all_variables() && $warn) {
           ## The user did not choose to expand $() variables directly,
           ## but we could not convert it into a relative path.  So,
-          ## instead of leaving it we will expand it.
+          ## instead of leaving it we will expand it.  But, we will only
+          ## get into this section if this is the secondary attempt to
+          ## replace the variable (indicated by the $warn boolean).
           $val =~ s/\//\\/g if ($self->{'convert_slashes'});
           substr($value, $start) =~ s/\$\([^)]+\)/$val/;
           $whole = $val;
         }
         else {
-          my($loc) = index(substr($value, $start), $whole);
+          my $loc = index(substr($value, $start), $whole);
           $start += $loc if ($loc > 0);
         }
       }
     }
     elsif ($expand_template ||
            $self->expand_variables_from_template_values()) {
-      my($ti) = $self->get_template_input();
-      my($val) = (defined $ti ? $ti->get_value($name) : undef);
-      my($sname) = (defined $scope ? $scope . "::$name" : undef);
-      my($arr) = $self->adjust_value([$sname, $name],
-                                     (defined $val ? $val : []));
+      my $ti = $self->get_template_input();
+      my $val = (defined $ti ? $ti->get_value($name) : undef);
+      my $sname = (defined $scope ? $scope . "::$name" : undef);
+      my $arr = $self->adjust_value([$sname, $name],
+                                    (defined $val ? $val : []));
       if (UNIVERSAL::isa($arr, 'HASH')) {
         $self->warning("$name conflicts with a template variable scope");
       }
@@ -1125,19 +1058,21 @@ sub expand_variables {
         $whole = '' if ($whole ne $val);
       }
       else {
-        if ($expand && $warn) {
-          $self->warning("Unable to expand $name.");
-        }
-        my($loc) = index(substr($value, $start), $whole);
+        $self->warning("Unable to expand $name.") if ($expand && $warn);
+        my $loc = index(substr($value, $start), $whole);
         $start += $loc if ($loc > 0);
       }
     }
-    elsif ($self->convert_all_variables()) {
+    elsif ($self->convert_all_variables() && $warn) {
+      ## We could not find a value to correspond to the variable name.
+      ## Instead of leaving it we will expand it.  But, we will only
+      ## get into this section if this is the secondary attempt to
+      ## replace the variable (indicated by the $warn boolean).
       substr($value, $start) =~ s/\$\([^)]+\)//;
       $whole = '';
     }
     else {
-      my($loc) = index(substr($value, $start), $whole);
+      my $loc = index(substr($value, $start), $whole);
       $start += $loc if ($loc > 0);
     }
     $start += length($whole);
@@ -1149,17 +1084,41 @@ sub expand_variables {
 }
 
 
+sub replace_env_vars {
+  my($self, $lref) = @_;
+  my $one_empty = undef;
+
+  ## Loop through the string until we find no more environment variables.
+  while($$lref =~ /\$(\w+)/) {
+    my $name = $1;
+    my $val  = '';
+
+    ## PWD is a special variable.  It isn't set on Windows, but in MPC we
+    ## must guarantee that it is always there.
+    if ($name eq 'PWD') {
+      $val = $self->getcwd();
+    }
+    elsif (defined $ENV{$name}) {
+      $val = $ENV{$name};
+    }
+    else {
+      ## Keep track of an environment variable not being set.
+      $one_empty = 1;
+    }
+    $$lref =~ s/\$\w+/$val/;
+  }
+  return $one_empty;
+}
+
+
 sub relative {
-  my($self)            = shift;
-  my($value)           = shift;
-  my($expand_template) = shift;
-  my($scope)           = shift;
+  my($self, $value, $expand_template, $scope) = @_;
 
   if (defined $value) {
     if (UNIVERSAL::isa($value, 'ARRAY')) {
-      my(@built) = ();
+      my @built;
       foreach my $val (@$value) {
-        my($rel) = $self->relative($val, $expand_template, $scope);
+        my $rel = $self->relative($val, $expand_template, $scope);
         if (UNIVERSAL::isa($rel, 'ARRAY')) {
           push(@built, @$rel);
         }
@@ -1170,7 +1129,12 @@ sub relative {
       return \@built;
     }
     elsif (index($value, '$') >= 0) {
-      my($ovalue)   = $value;
+      ## A form of this code lives in
+      ## ProjectCreator::create_recursive_settings.  If you are changing
+      ## something in this area, please look at the method in
+      ## ProjectCreator.pm to see if it needs changing too.
+
+      my $ovalue = $value;
       my($rel, $how) = $self->get_initial_relative_values();
       $value = $self->expand_variables($value, $rel,
                                        $expand_template, $scope, $how);
@@ -1184,8 +1148,8 @@ sub relative {
     }
   }
 
-  ## Values that have strings enclosed in double quotes are to
-  ## be interpreted as elements of an array
+  ## Values that have two or more strings enclosed in double quotes are
+  ## to be interpreted as elements of an array
   if (defined $value && $value =~ /^"[^"]+"(\s+"[^"]+")+$/) {
     $value = $self->create_array($value);
   }
@@ -1193,135 +1157,151 @@ sub relative {
   return $value;
 }
 
+
+## Static function.  Returns the default language for MPC.
+sub defaultLanguage {
+  return $deflang;
+}
+
+
+## Static function.  Returns an array of valid languages.
+sub validLanguages {
+  return keys %languages;
+}
+
+
+## Static function.  The one and only argument is the language
+## string to check for validity.
+sub isValidLanguage {
+  return defined $languages{$_[0]};
+}
+
+
+sub languageIs {
+  #my($self, $language) = @_;
+  return $_[0]->{'language'} eq $_[1];
+}
+
 # ************************************************************
 # Virtual Methods To Be Overridden
 # ************************************************************
 
 sub restore_state_helper {
-  #my($self) = shift;
-  #my($skey) = shift;
-  #my($old)  = shift;
-  #my($new)  = shift;
+  #my $self = shift;
+  #my $skey = shift;
+  #my $old  = shift;
+  #my $new  = shift;
 }
 
 
 sub get_initial_relative_values {
-  #my($self) = shift;
+  #my $self = shift;
   return {}, 0;
 }
 
 
 sub get_secondary_relative_values {
-  my($self) = shift;
+  my $self = shift;
   return ($self->{'use_env'} ? \%ENV :
                                $self->{'relative'}), $self->{'expand_vars'};
 }
 
 
 sub convert_all_variables {
-  #my($self) = shift;
+  #my $self = shift;
   return 0;
 }
 
 
 sub expand_variables_from_template_values {
-  #my($self) = shift;
+  #my $self = shift;
   return 0;
 }
 
 
 sub preserve_assignment_order {
-  #my($self) = shift;
-  #my($name) = shift;
+  #my $self = shift;
+  #my $name = shift;
   return 1;
 }
 
 
 sub compare_output {
-  #my($self) = shift;
+  #my $self = shift;
   return 0;
 }
 
 
 sub files_are_different {
-  my($self) = shift;
-  my($old)  = shift;
-  my($new)  = shift;
+  my($self, $old, $new) = @_;
   return !(-r $old && -s $new == -s $old && compare($new, $old) == 0);
 }
 
 
 sub handle_scoped_end {
-  #my($self)  = shift;
-  #my($type)  = shift;
-  #my($flags) = shift;
+  #my $self  = shift;
+  #my $type  = shift;
+  #my $flags = shift;
   return 1, undef;
 }
 
 sub handle_unknown_assignment {
-  my($self)   = shift;
-  my($type)   = shift;
-  my(@values) = @_;
+  my $self   = shift;
+  my $type   = shift;
+  my @values = @_;
   return 0, "Invalid assignment name: '$values[1]'";
 }
 
 
 sub handle_scoped_unknown {
-  my($self)  = shift;
-  my($fh)    = shift;
-  my($type)  = shift;
-  my($flags) = shift;
-  my($line)  = shift;
+  my($self, $fh, $type, $flags, $line) = @_;
   return 0, "Unrecognized line: $line";
 }
 
 
 sub remove_duplicate_addition {
-  my($self)    = shift;
-  my($name)    = shift;
-  my($value)   = shift;
-  my($current) = shift;
+  my($self, $name, $value, $current) = @_;
   return $value;
 }
 
 
 sub generate_recursive_input_list {
-  #my($self)    = shift;
-  #my($dir)     = shift;
-  #my($exclude) = shift;
+  #my $self    = shift;
+  #my $dir     = shift;
+  #my $exclude = shift;
   return ();
 }
 
 
 sub reset_values {
-  #my($self) = shift;
+  #my $self = shift;
 }
 
 
 sub sort_files {
-  #my($self) = shift;
+  #my $self = shift;
   return 1;
 }
 
 
 sub file_sorter {
-  #my($self)  = shift;
-  #my($left)  = shift;
-  #my($right) = shift;
+  #my $self  = shift;
+  #my $left  = shift;
+  #my $right = shift;
   return $_[1] cmp $_[2];
 }
 
 
 sub read_global_configuration {
-  #my($self)  = shift;
-  #my($input) = shift;
+  #my $self  = shift;
+  #my $input = shift;
   return 1;
 }
 
 
 sub set_verbose_ordering {
-  #my($self)  = shift;
-  #my($value) = shift;
+  #my $self  = shift;
+  #my $value = shift;
 }
 
 
