@@ -24,31 +24,33 @@ use vars qw(@ISA);
 # Data Section
 # ************************************************************
 
-my($index)     = 0;
-my(@progress)  = ('|', '/', '-', '\\');
-my(%valid_cfg) = ('command_line'     => 1,
-                  'default_type'     => 1,
-                  'dynamic_types'    => 1,
-                  'includes'         => 1,
-                  'logging'          => 1,
-                  'verbose_ordering' => 1,
-                 );
+my $index     = 0;
+my @progress  = ('|', '/', '-', '\\');
+my %valid_cfg = ('command_line'     => 1,
+                 'default_type'     => 1,
+                 'dynamic_types'    => 1,
+                 'includes'         => 1,
+                 'logging'          => 1,
+                 'main_functions'   => 1,
+                 'verbose_ordering' => 1,
+                );
+my @intype    = ('mwc.pl', 'mpc.pl');
 
 # ************************************************************
 # Subroutine Section
 # ************************************************************
 
 sub new {
-  my($class)    = shift;
-  my($path)     = shift;
-  my($name)     = shift;
-  my(@creators) = @_;
-  my($self)     = $class->SUPER::new();
+  my $class    = shift;
+  my $path     = shift;
+  my $name     = shift;
+  my @creators = @_;
+  my $self = $class->SUPER::new();
 
   $self->{'path'}     = $path;
   $self->{'basepath'} = ::getBasePath();
   $self->{'name'}     = $name;
-  $self->{'type'}     = (lc($self->{'name'}) eq 'mwc.pl' ?
+  $self->{'type'}     = (lc($self->{'name'}) eq $intype[0] ?
                                 'WorkspaceCreator' : 'ProjectCreator');
   $self->{'types'}    = {};
   $self->{'creators'} = \@creators;
@@ -59,10 +61,20 @@ sub new {
 }
 
 
+sub workspaces {
+  return $intype[0];
+}
+
+
+sub projects {
+  return $intype[1];
+}
+
+
 sub locate_default_type {
-  my($self) = shift;
-  my($name) = lc(shift) . lc($self->{'type'}) . '.pm';
-  my($fh)   = new FileHandle();
+  my $self = shift;
+  my $name = lc(shift) . lc($self->{'type'}) . '.pm';
+  my $fh = new FileHandle();
 
   foreach my $dir (@INC) {
     if (opendir($fh, $dir)) {
@@ -81,20 +93,25 @@ sub locate_default_type {
 
 
 sub locate_dynamic_directories {
-  my($self)   = shift;
-  my($dtypes) = shift;
+  my($self, $cfg, $label) = @_;
+  my $dtypes = $cfg->get_value($label);
 
   if (defined $dtypes) {
-    my(@directories) = ();
+    my $count = 0;
+    my @directories;
+    my @unprocessed = split(/\s*,\s*/, $cfg->get_unprocessed($label));
     foreach my $dir (split(/\s*,\s*/, $dtypes)) {
       if (-d $dir) {
         if (-d "$dir/modules" || -d "$dir/config" || -d "$dir/templates") {
           push(@directories, $dir);
         }
       }
-      else {
-        $self->warning("$dir does not exist.");
+      elsif (!(defined $unprocessed[$count] &&
+               $unprocessed[$count] =~ s/\$[\(\w\)]+//g &&
+               $unprocessed[$count] eq $dir)) {
+        $self->diagnostic("'$label' directory $dir not found.");
       }
+      $count++;
     }
     return \@directories;
   }
@@ -104,17 +121,27 @@ sub locate_dynamic_directories {
 
 
 sub add_dynamic_creators {
-  my($self) = shift;
-  my($dirs) = shift;
-  my($type) = $self->{'type'};
+  my($self, $dirs) = @_;
+  my $type = $self->{'type'};
 
   foreach my $dir (@$dirs) {
-    my($fh) = new FileHandle();
+    my $fh = new FileHandle();
     if (opendir($fh, "$dir/modules")) {
       foreach my $file (readdir($fh)) {
         if ($file =~ /(.+$type)\.pm$/i) {
-          $self->debug("Pulling in $1");
-          push(@{$self->{'creators'}}, $1);
+          my $name = $1;
+          if (DirectoryManager::onVMS()) {
+            my $fh = new FileHandle();
+            if (open($fh, $dir . "/modules/" . $file)) {
+              my $line = <$fh>;
+              if ($line =~ /^\s*package\s+(.+);/) {
+                $name = $1;
+              }
+              close($fh);
+            }
+          }
+          $self->debug("Pulling in $name");
+          push(@{$self->{'creators'}}, $name);
         }
       }
       closedir($fh);
@@ -122,19 +149,16 @@ sub add_dynamic_creators {
   }
 }
 
-
 sub parse_line {
-  my($self)        = shift;
-  my($ih)          = shift;
-  my($line)        = shift;
-  my($status)      = 1;
-  my($errorString) = undef;
+  my($self, $ih, $line) = @_;
+  my $status = 1;
+  my $errorString;
 
   if ($line eq '') {
   }
   elsif ($line =~ /^([\w\*]+)(\s*,\s*(.*))?$/) {
-    my($name)  = $1;
-    my($value) = $3;
+    my $name  = $1;
+    my $value = $3;
     if (defined $value) {
       $value =~ s/^\s+//;
       $value =~ s/\s+$//;
@@ -175,8 +199,7 @@ sub parse_line {
 
 
 sub optionError {
-  my($self) = shift;
-  my($line) = shift;
+  my($self, $line) = @_;
 
   $self->printUsage($line, $self->{'name'}, Version::get(),
                     keys %{$self->{'types'}});
@@ -185,9 +208,7 @@ sub optionError {
 
 
 sub find_file {
-  my($self)     = shift;
-  my($includes) = shift;
-  my($file)     = shift;
+  my($self, $includes, $file) = @_;
 
   foreach my $inc (@$includes) {
     if (-r $inc . '/' . $file) {
@@ -200,17 +221,15 @@ sub find_file {
 
 
 sub determine_cfg_file {
-  my($self) = shift;
-  my($cfg)  = shift;
-  my($odir) = shift;
-  my($ci)   = $self->case_insensitive();
+  my($self, $cfg, $odir) = @_;
+  my $ci = $self->case_insensitive();
 
   $odir = lc($odir) if ($ci);
   foreach my $name (@{$cfg->get_names()}) {
-    my($value) = $cfg->get_value($name);
+    my $value = $cfg->get_value($name);
     if (index($odir, ($ci ? lc($name) : $name)) == 0) {
       $self->warning("$value does not exist.") if (!-d $value);
-      my($cfgfile) = $value . '/MPC.cfg';
+      my $cfgfile = $value . '/MPC.cfg';
       return $cfgfile if (-e $cfgfile);
     }
   }
@@ -220,18 +239,18 @@ sub determine_cfg_file {
 
 
 sub run {
-  my($self)    = shift;
-  my(@args)    = @_;
-  my($cfgfile) = undef;
+  my $self = shift;
+  my @args = @_;
+  my $cfgfile;
 
   ## Save the original directory outside of the loop
   ## to avoid calling it multiple times.
-  my($orig_dir) = $self->getcwd();
+  my $orig_dir = $self->getcwd();
 
   ## Read the code base config file from the config directory
   ## under $MPC_ROOT
-  my($cbcfg)  = new ConfigParser();
-  my($cbfile) = "$self->{'basepath'}/config/base.cfg";
+  my $cbcfg  = new ConfigParser();
+  my $cbfile = "$self->{'basepath'}/config/base.cfg";
   if (-r $cbfile) {
     my($status, $error) = $cbcfg->read_file($cbfile);
     if (!$status) {
@@ -251,9 +270,9 @@ sub run {
   }
 
   ## Read the MPC config file
-  my($cfg) = new ConfigParser(\%valid_cfg);
+  my $cfg = new ConfigParser(\%valid_cfg);
   if (defined $cfgfile) {
-    my($ellipses) = $cfgfile;
+    my $ellipses = $cfgfile;
     $ellipses =~ s!.*(/[^/]+/[^/]+/[^/]+/[^/]+/[^/]+/[^/]+)!...$1!;
     $self->diagnostic("Using $ellipses");
     my($status, $error) = $cfg->read_file($cfgfile);
@@ -269,8 +288,7 @@ sub run {
 
   ## After we read the config file, see if the user has provided
   ## dynamic types
-  my($dynamic) = $self->locate_dynamic_directories(
-                          $cfg->get_value('dynamic_types'));
+  my $dynamic = $self->locate_dynamic_directories($cfg, 'dynamic_types');
   if (defined $dynamic) {
     ## If so, add in the creators found in the dynamic directories
     $self->add_dynamic_creators($dynamic);
@@ -288,66 +306,52 @@ sub run {
 
   ## Dynamically load in each perl module and set up
   ## the type tags and project creators
-  my($creators) = $self->{'creators'};
+  my $creators = $self->{'creators'};
   foreach my $creator (@$creators) {
-    my($tag) = $self->extractType($creator);
+    my $tag = $self->extractType($creator);
     $self->{'types'}->{$tag} = $creator;
   }
 
   ## Before we process the arguments, we will prepend the command_line
   ## config variable.
-  my($cmd) = $cfg->get_value('command_line');
+  my $cmd = $cfg->get_value('command_line');
   if (defined $cmd) {
-    my($envargs) = $self->create_array($cmd);
+    my $envargs = $self->create_array($cmd);
     unshift(@args, @$envargs);
   }
 
   ## Now add in the includes to the command line arguments.
   ## It is done this way to allow the Options module to process
   ## the include path as it does all others.
-  my($incs) = $cfg->get_value('includes');
+  my $incs = $cfg->get_value('includes');
   if (defined $incs) {
     foreach my $inc (split(/\s*,\s*/, $incs)) {
-      push(@args, '-include', $inc);
+      ## We must add it to the front so that options provided at the end
+      ## that require a parameter (but are not given one) do not gobble
+      ## up the -include option.
+      unshift(@args, '-include', $inc);
     }
   }
 
-  my($options) = $self->options($self->{'name'},
-                                $self->{'types'},
-                                1,
-                                @args);
-  if (!defined $options) {
-    ## If options are not defined, that means that calling options
-    ## took care of whatever functionality that was required and
-    ## we can now return with a good status.
-    return 0;
-  }
+  my $options = $self->options($self->{'name'},
+                               $self->{'types'},
+                               1,
+                               @args);
+
+  ## If options are not defined, that means that calling options
+  ## took care of whatever functionality that was required and
+  ## we can now return with a good status.
+  return 0 if (!defined $options);
 
   ## Set up a hash that we can use to keep track of what
   ## has been 'required'
-  my(%loaded) = ();
+  my %loaded;
 
   ## Set up the default creator, if no type is selected
   if (!defined $options->{'creators'}->[0]) {
-    my($utype) = $cfg->get_value('default_type');
+    my $utype = $cfg->get_value('default_type');
     if (defined $utype) {
-      my($default) = $self->locate_default_type($utype);
-      if (defined $default) {
-        push(@{$options->{'creators'}}, $default);
-      }
-      else {
-        $self->error("Unable to locate the module that corresponds to " .
-                     "the '$utype' type.");
-        return 1;
-      }
-    }
-  }
-
-  ## Set up the default creator, if no type is selected
-  if (!defined $options->{'creators'}->[0]) {
-    my($utype) = $cfg->get_value('default_type');
-    if (defined $utype) {
-      my($default) = $self->locate_default_type($utype);
+      my $default = $self->locate_default_type($utype);
       if (defined $default) {
         push(@{$options->{'creators'}}, $default);
       }
@@ -363,6 +367,20 @@ sub run {
   if (!defined $options->{'creators'}->[0]) {
     $self->error('There is no longer a default project type.  Please ' .
                  'specify one in MPC.cfg or use the -type option.');
+    return 1;
+  }
+
+  ## Set up additional main functions to recognize
+  my $val = $cfg->get_value('main_functions');
+  if (defined $val) {
+    foreach my $main (split(/\s*,\s*/, $val)) {
+      my $err = ProjectCreator::add_main_function($main);
+      if (defined $err) {
+        $self->error("$err at line " . $cfg->get_line_number() .
+                     " of $cfgfile");
+        return 1;
+      }
+    }
   }
 
   if ($options->{'recurse'}) {
@@ -375,16 +393,16 @@ sub run {
     else {
       ## We have to load at least one creator here in order
       ## to call the generate_recursive_input_list virtual function.
-      my($name) = $options->{'creators'}->[0];
+      my $name = $options->{'creators'}->[0];
       if (!$loaded{$name}) {
         require "$name.pm";
         $loaded{$name} = 1;
       }
 
       ## Generate the recursive input list
-      my($creator) = $name->new();
-      my(@input) = $creator->generate_recursive_input_list(
-                                              '.', $options->{'exclude'});
+      my $creator = $name->new();
+      my @input = $creator->generate_recursive_input_list(
+                                             '.', $options->{'exclude'});
       $options->{'input'} = \@input;
 
       ## If no files were found above, then we issue a warning
@@ -410,11 +428,20 @@ sub run {
   $self->debug("INCLUDES: @{$options->{'include'}}");
 
   ## Set the global feature file
-  my($global_feature_file) = (defined $options->{'gfeature_file'} &&
-                              -r $options->{'gfeature_file'} ?
-                                 $options->{'gfeature_file'} : undef);
-  if (!defined $global_feature_file) {
-    my($gf) = 'global.features';
+  my $global_feature_file = (defined $options->{'gfeature_file'} &&
+                             -r $options->{'gfeature_file'} ?
+                                $options->{'gfeature_file'} : undef);
+  if (defined $global_feature_file) {
+    ## If the specified path is relative, expand it based on
+    ## the current working directory.
+    if ($global_feature_file !~ /^[\/\\]/ &&
+        $global_feature_file !~ /^[A-Za-z]:[\/\\]?/) {
+      $global_feature_file = DirectoryManager::getcwd() . '/' .
+                             $global_feature_file;
+    }
+  }
+  else {
+    my $gf = 'global.features';
     $global_feature_file = $self->find_file($options->{'include'}, $gf);
     if (!defined $global_feature_file) {
       $global_feature_file = $self->{'basepath'} . '/config/' . $gf;
@@ -422,23 +449,21 @@ sub run {
   }
 
   ## Set up default values
-  if (!defined $options->{'input'}->[0]) {
-    push(@{$options->{'input'}}, '');
-  }
-  if (!defined $options->{'feature_file'}) {
-    $options->{'feature_file'} = $self->find_file($options->{'include'},
-                                                  'default.features');
-  }
-  if (!defined $options->{'global'}) {
-    $options->{'global'} = $self->find_file($options->{'include'},
-                                            'global.mpb');
-  }
+  push(@{$options->{'input'}}, '') if (!defined $options->{'input'}->[0]);
+  $options->{'feature_file'} = $self->find_file($options->{'include'},
+                                                'default.features')
+                                 if (!defined $options->{'feature_file'});
+
+  $options->{'global'} = $self->find_file($options->{'include'},
+                                          'global.mpb')
+                                 if (!defined $options->{'global'});
+
   ## Set the relative
-  my($relative_file) = (defined $options->{'relative_file'} &&
-                              -r $options->{'relative_file'} ?
-                                 $options->{'relative_file'} : undef);
+  my $relative_file = (defined $options->{'relative_file'} &&
+                             -r $options->{'relative_file'} ?
+                                $options->{'relative_file'} : undef);
   if (!defined $relative_file) {
-    my($gf) = 'default.rel';
+    my $gf = 'default.rel';
     $relative_file = $self->find_file($options->{'include'}, $gf);
     if (!defined $relative_file) {
       $relative_file = $self->{'basepath'} . '/config/' . $gf;
@@ -460,10 +485,10 @@ sub run {
         }
         if (defined $self->{'reldefs'}->{$key} &&
             !defined $options->{'relative'}->{$key}) {
-          my($value) = $self->{'reldefs'}->{$key};
+          my $value = $self->{'reldefs'}->{$key};
           if ($value =~ /\$(\w+)(.*)?/) {
-            my($var)   = $1;
-            my($extra) = $2;
+            my $var   = $1;
+            my $extra = $2;
             $options->{'relative'}->{$key} =
                        (defined $options->{'relative'}->{$var} ?
                                 $options->{'relative'}->{$var} : '') .
@@ -494,21 +519,19 @@ sub run {
   $| = 1;
 
   ## Keep the starting time for the total output
-  my($startTime) = time();
-  my($loopTimes) = 0;
+  my $startTime = time();
+  my $loopTimes = 0;
 
   ## Generate the files
-  my($status) = 0;
+  my $status = 0;
   foreach my $cfile (@{$options->{'input'}}) {
     ## To correctly reference any pathnames in the input file, chdir to
     ## its directory if there's any directory component to the specified path.
     ## mpc_basename() always expects UNIX file format.
     $cfile =~ s/\\/\//g;
-    my($base) = ($cfile eq '' ? '' : $self->mpc_basename($cfile));
+    my $base = ($cfile eq '' ? '' : $self->mpc_basename($cfile));
 
-    if (-d $cfile) {
-      $base = '';
-    }
+    $base = '' if (-d $cfile);
 
     foreach my $name (@{$options->{'creators'}}) {
       ++$loopTimes;
@@ -517,42 +540,42 @@ sub run {
         require "$name.pm";
         $loaded{$name} = 1;
       }
-      my($file) = $cfile;
-      my($creator) = $name->new($options->{'global'},
-                                $options->{'include'},
-                                $options->{'template'},
-                                $options->{'ti'},
-                                $options->{'dynamic'},
-                                $options->{'static'},
-                                $options->{'relative'},
-                                $options->{'addtemp'},
-                                $options->{'addproj'},
-                                (-t 1 ? \&progress : undef),
-                                $options->{'toplevel'},
-                                $options->{'baseprojs'},
-                                $global_feature_file,
-                                $options->{'relative_file'},
-                                $options->{'feature_file'},
-                                $options->{'features'},
-                                $options->{'hierarchy'},
-                                $options->{'exclude'},
-                                $options->{'coexistence'},
-                                $options->{'name_modifier'},
-                                $options->{'apply_project'},
-                                $options->{'genins'},
-                                $options->{'into'},
-                                $options->{'language'},
-                                $options->{'use_env'},
-                                $options->{'expand_vars'},
-                                $options->{'gendot'},
-                                $options->{'comments'},
-                                $options->{'for_eclipse'});
+      my $file = $cfile;
+      my $creator = $name->new($options->{'global'},
+                               $options->{'include'},
+                               $options->{'template'},
+                               $options->{'ti'},
+                               $options->{'dynamic'},
+                               $options->{'static'},
+                               $options->{'relative'},
+                               $options->{'addtemp'},
+                               $options->{'addproj'},
+                               (-t 1 ? \&progress : undef),
+                               $options->{'toplevel'},
+                               $options->{'baseprojs'},
+                               $global_feature_file,
+                               $options->{'relative_file'},
+                               $options->{'feature_file'},
+                               $options->{'features'},
+                               $options->{'hierarchy'},
+                               $options->{'exclude'},
+                               $options->{'make_coexistence'},
+                               $options->{'name_modifier'},
+                               $options->{'apply_project'},
+                               $options->{'genins'},
+                               $options->{'into'},
+                               $options->{'language'},
+                               $options->{'use_env'},
+                               $options->{'expand_vars'},
+                               $options->{'gendot'},
+                               $options->{'comments'},
+                               $options->{'for_eclipse'});
 
       ## Update settings based on the configuration file
       $creator->set_verbose_ordering($cfg->get_value('verbose_ordering'));
 
       if ($base ne $file) {
-        my($dir) = ($base eq '' ? $file : $self->mpc_dirname($file));
+        my $dir = ($base eq '' ? $file : $self->mpc_dirname($file));
         if (!$creator->cd($dir)) {
           $self->error("Unable to change to directory: $dir");
           $status++;
@@ -560,41 +583,39 @@ sub run {
         }
         $file = $base;
       }
-      my($diag) = 'Generating \'' . $self->extractType($name) .
-                  '\' output using ';
+      my $diag = 'Generating \'' . $self->extractType($name) .
+                 '\' output using ';
       if ($file eq '') {
         $diag .= 'default input';
       }
       else {
-        my($partial)  = $self->getcwd();
-        my($oescaped) = $self->escape_regex_special($orig_dir) . '(/)?';
+        my $partial  = $self->getcwd();
+        my $oescaped = $self->escape_regex_special($orig_dir) . '(/)?';
         $partial =~ s!\\!/!g;
         $partial =~ s/^$oescaped//;
         $diag .= ($partial ne '' ? "$partial/" : '') . $file;
       }
       $self->diagnostic($diag);
-      my($start) = time();
+      my $start = time();
       if (!$creator->generate($file)) {
         $self->error("Unable to process: " .
                      ($file eq '' ? 'default input' : $file));
         $status++;
         last;
       }
-      my($total) = time() - $start;
+      my $total = time() - $start;
       $self->diagnostic('Generation Time: ' .
                         (int($total / 60) > 0 ? int($total / 60) . 'm ' : '') .
                         ($total % 60) . 's');
       $creator->cd($orig_dir);
     }
-    if ($status) {
-      last;
-    }
+    last if ($status);
   }
 
   ## If we went through the loop more than once, we need to print
   ## out the total amount of time
   if ($loopTimes > 1) {
-    my($total) = time() - $startTime;
+    my $total = time() - $startTime;
     $self->diagnostic('     Total Time: ' .
                       (int($total / 60) > 0 ? int($total / 60) . 'm ' : '') .
                       ($total % 60) . 's');
@@ -608,9 +629,7 @@ sub progress {
   ## This method will be called before each output file is written.
   print "$progress[$index]\r";
   $index++;
-  if ($index > $#progress) {
-    $index = 0;
-  }
+  $index = 0 if ($index > $#progress);
 }
 
 
