@@ -16,26 +16,41 @@ use strict;
 # Subroutine Section
 # ************************************************************
 
+sub get_builtin_output {
+  #my($self, $input) = @_;
+  return ['$@'];   
+}
+
 sub dollar_special {
-  #my($self) = shift;
+  #my $self = shift;
   return 1;
 }
 
 
 sub sort_files {
-  #my($self) = shift;
-  if (defined $ENV{MPC_ALWAYS_SORT}) {
-    return 1;
-  }
-  else {
-    return 0;
-  }
+  #my $self = shift;
+  return (defined $ENV{MPC_ALWAYS_SORT});
 }
 
 
 sub project_file_prefix {
-  #my($self) = shift;
+  #my $self = shift;
   return 'Makefile.';
 }
 
+
+sub get_properties {
+  my $self = shift;
+
+  ## Get the base class properties and add the properties that we
+  ## support.
+  my $props = $self->ProjectCreator::get_properties();
+
+  ## All projects that use this base class are 'make' based.
+  $$props{'make'} = 1;
+
+  return $props;
+}
+
+
 1;
