@@ -16,36 +16,24 @@ use DirectoryManager;
 use StringProcessor;
 use ProjectCreator;
 
-# ************************************************************
-# Data Section
-# ************************************************************
-
-my($deflang)   = 'cplusplus';
-my(%languages) = ('cplusplus' => 1,
-                  'csharp'    => 1,
-                  'java'      => 1,
-                  'vb'        => 1,
-                 );
-
 # ************************************************************
 # Subroutine Section
 # ************************************************************
 
 sub printUsage {
-  my($self)    = shift;
-  my($msg)     = shift;
-  my($base)    = shift;
-  my($version) = shift;
-  my(@types)   = @_;
+  my $self    = shift;
+  my $msg     = shift;
+  my $base    = shift;
+  my $version = shift;
+  my @types   = @_;
 
-  if (defined $msg) {
-    print STDERR "ERROR: $msg\n";
-  }
-  my($spaces) = (' ' x (length($base) + 8));
+  print STDERR "ERROR: $msg\n" if (defined $msg);
+
+  my $spaces = (' ' x (length($base) + 8));
   print STDERR "$base v$version\n" .
                "Usage: $base [-global <file>] [-include <directory>] [-recurse]\n" .
                $spaces . "[-ti <dll | lib | dll_exe | lib_exe>:<file>] [-hierarchy]\n" .
-               $spaces . "[-template <file>] [-relative NAME=VAR] [-base <project>]\n" .
+               $spaces . "[-template <file>] [-relative NAME=VAL] [-base <project>]\n" .
                $spaces . "[-noreldefs] [-notoplevel] [-static] [-genins] [-use_env]\n" .
                $spaces . "[-value_template <NAME+=VAL | NAME=VAL | NAME-=VAL>]\n" .
                $spaces . "[-value_project <NAME+=VAL | NAME=VAL | NAME-=VAL>]\n" .
@@ -57,12 +45,12 @@ sub printUsage {
                $spaces . "[-relative_file <file name>] [-for_eclipse]\n" .
                $spaces . "[-language <";
 
-  my($olen) = length($spaces) + 12;
-  my($len)  = $olen;
-  my($mlen) = 77;
-  my(@keys) = sort keys %languages;
+  my $olen = length($spaces) + 12;
+  my $len  = $olen;
+  my $mlen = 77;
+  my @keys = sort(Creator::validLanguages());
   for(my $i = 0; $i <= $#keys; $i++) {
-    my($klen) = length($keys[$i]);
+    my $klen = length($keys[$i]);
     $len += $klen;
     if ($len > $mlen) {
       print STDERR "\n$spaces        ";
@@ -79,9 +67,20 @@ sub printUsage {
 
   $olen = length($spaces) + 8;
   $len  = $olen;
-  @keys = sort @types;
+
+  ## Sort the project types, but keep those that are the same with different
+  ## version numbers in the right order (i.e., vc8, vc9, vc10).  The vc71
+  ## type is a special case and needs to stay betwen vc7 and vc8.
+  @keys = sort { if ($a ne 'vc71' && $b ne 'vc71' && $a =~ /^([^\d]+)(\d+)$/) {
+                   my($a1, $a2) = ($1, $2);
+                   if ($b =~ /^([^\d]+)(\d+)$/ && $a1 eq $1) {
+                     return $a2 <=> $2;
+                   }
+                 }
+                 return $a cmp $b;
+               } @types;
   for(my $i = 0; $i <= $#keys; $i++) {
-    my($klen) = length($keys[$i]);
+    my $klen = length($keys[$i]);
     $len += $klen;
     if ($len > $mlen) {
       print STDERR "\n$spaces        ";
@@ -126,8 +125,8 @@ sub printUsage {
 "                       structure starting at <directory>.  This should be a\n" .
 "                       full path.\n" .
 "       -language       Specify the language preference; possible values are\n",
-"                       [", join(' ', sort keys %languages), "].  The default is\n".
-"                       $deflang.\n",
+"                       [", join(', ', sort(Creator::validLanguages())), "].  The default is\n".
+"                       " . Creator::defaultLanguage() . ".\n",
 "       -make_coexistence If multiple 'make' based project types are\n" .
 "                       generated, they will be named such that they can coexist.\n" .
 "       -name_modifier  Modify output names.  The pattern passed to this\n" .
@@ -142,12 +141,12 @@ sub printUsage {
 "       -recurse        Recurse from the current directory and generate from\n" .
 "                       all found input files.\n" .
 "       -relative       Any \$() variable in an mpc file that is matched to NAME\n" .
-"                       is replaced by VAR only if VAR can be made into a\n" .
+"                       is replaced by VAL only if VAL can be made into a\n" .
 "                       relative path based on the current working directory.\n" .
 "                       This option can be used multiple times to add multiple\n" .
 "                       variables.\n" .
 "       -relative_file  Specifies the relative file to read before processing.\n" .
-"                       The default feature file is default.rel under the\n" .
+"                       The default relative file is default.rel under the\n" .
 "                       config directory.\n" .
 "       -static         Specifies that only static projects will be generated.\n" .
 "                       By default, only dynamic projects are generated.\n" .
@@ -169,46 +168,38 @@ sub printUsage {
 "                       name value pair.  Use += to add VAL to the NAME's\n" .
 "                       value.  Use -= to subtract and = to override the value.\n" .
 "       -version        Print the MPC version and exit.\n";
-
-  exit(0);
 }
 
 
 sub optionError {
-  #my($self) = shift;
-  #my($str)  = shift;
+  #my $self = shift;
+  #my $str  = shift;
 }
 
 
 sub completion_command {
-  my($self)  = shift;
-  my($name)  = shift;
-  my($types) = shift;
-  my($str)   = "complete $name " .
-               "'c/-/(gendot genins global include type template relative " .
-               "ti static noreldefs notoplevel feature_file use_env " .
-               "value_template value_project make_coexistence language " .
-               "hierarchy exclude name_modifier apply_project version " .
-               "expand_vars gfeature_file nocomments for_eclipse relative_file)/' " .
-               "'c/dll:/f/' 'c/dll_exe:/f/' 'c/lib_exe:/f/' 'c/lib:/f/' " .
-               "'n/-ti/(dll lib dll_exe lib_exe)/:' ";
+  my($self, $name, $types) = @_;
+  my $str = "complete $name " .
+            "'c/-/(gendot genins global include type template relative " .
+            "ti static noreldefs notoplevel feature_file use_env " .
+            "value_template value_project make_coexistence language " .
+            "hierarchy exclude name_modifier apply_project version " .
+            "expand_vars gfeature_file nocomments for_eclipse relative_file)/' " .
+            "'c/dll:/f/' 'c/dll_exe:/f/' 'c/lib_exe:/f/' 'c/lib:/f/' " .
+            "'n/-ti/(dll lib dll_exe lib_exe)/:' ";
 
   $str .= "'n/-language/(";
-  my(@keys) = sort keys %languages;
+  my @keys = sort(Creator::validLanguages());
   for(my $i = 0; $i <= $#keys; $i++) {
     $str .= $keys[$i];
-    if ($i != $#keys) {
-      $str .= " ";
-    }
+    $str .= " " if ($i != $#keys);
   }
   $str .= ")/' 'n/-type/(";
 
   @keys = sort keys %$types;
   for(my $i = 0; $i <= $#keys; $i++) {
     $str .= $keys[$i];
-    if ($i != $#keys) {
-      $str .= " ";
-    }
+    $str .= " " if ($i != $#keys);
   }
   $str .= ")/'";
   return $str;
@@ -216,47 +207,47 @@ sub completion_command {
 
 
 sub options {
-  my($self)       = shift;
-  my($name)       = shift;
-  my($types)      = shift;
-  my($defaults)   = shift;
-  my(@args)       = @_;
-  my(@include)    = ();
-  my(@input)      = ();
-  my(@creators)   = ();
-  my(@baseprojs)  = ();
-  my(%ti)         = ();
-  my(%relative)   = ();
-  my(%addtemp)    = ();
-  my(%addproj)    = ();
-  my(@exclude)    = ();
-  my($global)     = undef;
-  my($template)   = undef;
-  my($feature_f)  = undef;
-  my($gfeature_f) = undef;
-  my($relative_f) = undef;
-  my(@features)   = ();
-  my($nmodifier)  = undef;
-  my($into)       = undef;
-  my($hierarchy)  = 0;
-  my($language)   = ($defaults ? $deflang : undef);
-  my($dynamic)    = ($defaults ? 1 : undef);
-  my($comments)   = ($defaults ? 1 : undef);
-  my($reldefs)    = ($defaults ? 1 : undef);
-  my($toplevel)   = ($defaults ? 1 : undef);
-  my($use_env)    = ($defaults ? 0 : undef);
-  my($expandvars) = ($defaults ? 0 : undef);
-  my($static)     = ($defaults ? 0 : undef);
-  my($recurse)    = ($defaults ? 0 : undef);
-  my($makeco)     = ($defaults ? 0 : undef);
-  my($applypj)    = ($defaults ? 0 : undef);
-  my($genins)     = ($defaults ? 0 : undef);
-  my($gendot)     = ($defaults ? 0 : undef);
-  my($foreclipse) = ($defaults ? 0 : undef);
+  my $self     = shift;
+  my $name     = shift;
+  my $types    = shift;
+  my $defaults = shift;
+  my @args     = @_;
+  my @include;
+  my @input;
+  my @creators;
+  my @baseprojs;
+  my %ti;
+  my %relative;
+  my %addtemp;
+  my %addproj;
+  my @exclude;
+  my $global;
+  my $template;
+  my $feature_f;
+  my $gfeature_f;
+  my $relative_f;
+  my @features;
+  my $nmodifier;
+  my $into;
+  my $hierarchy = 0;
+  my $language = ($defaults ? Creator::defaultLanguage() : undef);
+  my $dynamic = ($defaults ? 1 : undef);
+  my $comments = ($defaults ? 1 : undef);
+  my $reldefs = ($defaults ? 1 : undef);
+  my $toplevel = ($defaults ? 1 : undef);
+  my $use_env = ($defaults ? 0 : undef);
+  my $expandvars = ($defaults ? 0 : undef);
+  my $static = ($defaults ? 0 : undef);
+  my $recurse = ($defaults ? 0 : undef);
+  my $makeco = ($defaults ? 0 : undef);
+  my $applypj = ($defaults ? 0 : undef);
+  my $genins = ($defaults ? 0 : undef);
+  my $gendot = ($defaults ? 0 : undef);
+  my $foreclipse = ($defaults ? 0 : undef);
 
   ## Process the command line arguments
   for(my $i = 0; $i <= $#args; $i++) {
-    my($arg) = $args[$i];
+    my $arg = $args[$i];
     $arg =~ s/^--/-/;
 
     if ($arg eq '-apply_project') {
@@ -281,19 +272,17 @@ sub options {
         $self->optionError('-type requires an argument');
       }
       else {
-        my($type) = lc($args[$i]);
+        my $type = lc($args[$i]);
         if (defined $types->{$type}) {
-          my($call)  = $types->{$type};
-          my($found) = 0;
+          my $call  = $types->{$type};
+          my $found = 0;
           foreach my $creator (@creators) {
             if ($creator eq $call) {
               $found = 1;
               last;
             }
           }
-          if (!$found) {
-            push(@creators, $call);
-          }
+          push(@creators, $call) if (!$found);
         }
         else {
           $self->optionError("Invalid type: $args[$i]");
@@ -371,7 +360,7 @@ sub options {
     }
     elsif ($arg eq '-include') {
       $i++;
-      my($include) = $args[$i];
+      my $include = $args[$i];
       if (!defined $include) {
         $self->optionError('-include requires a directory argument');
       }
@@ -399,7 +388,7 @@ sub options {
       if (!defined $language) {
         $self->optionError('-language requires a language argument');
       }
-      elsif (!defined $languages{$language}) {
+      elsif (!Creator::isValidLanguage($language)) {
         $self->optionError("$language is not a valid language");
       }
     }
@@ -408,7 +397,7 @@ sub options {
     }
     elsif ($arg eq '-name_modifier') {
       $i++;
-      my($nmod) = $args[$i];
+      my $nmod = $args[$i];
       if (!defined $nmod) {
         $self->optionError('-name_modifier requires a modifier argument');
       }
@@ -437,14 +426,14 @@ sub options {
     }
     elsif ($arg eq '-relative') {
       $i++;
-      my($rel) = $args[$i];
+      my $rel = $args[$i];
       if (!defined $rel) {
         $self->optionError('-relative requires a variable assignment argument');
       }
       else {
         if ($rel =~ /(\w+)\s*=\s*(.*)/) {
-          my($name) = $1;
-          my($val)  = $2;
+          my $name = $1;
+          my $val  = $2;
           $val =~ s/^\s+//;
           $val =~ s/\s+$//;
 
@@ -455,9 +444,12 @@ sub options {
             $val = DirectoryManager::getcwd() . '/' . $val;
           }
 
-          ## Clean up the path as much as possible
+          ## Clean up the path as much as possible.  For some reason,
+          ## File::Spec->canonpath() on Windows doesn't remove trailing
+          ## /. from the path.
           $relative{$name} = File::Spec->canonpath($val);
           $relative{$name} =~ s/\\/\//g;
+          $relative{$name} =~ s!/\.$!!;
         }
         else {
           $self->optionError('Invalid argument to -relative');
@@ -466,14 +458,14 @@ sub options {
     }
     elsif ($arg eq '-ti') {
       $i++;
-      my($tmpi) = $args[$i];
+      my $tmpi = $args[$i];
       if (!defined $tmpi) {
         $self->optionError('-ti requires a template input argument');
       }
       else {
         if ($tmpi =~ /((dll|lib|dll_exe|lib_exe):)?(.*)/) {
-          my($key)  = $2;
-          my($name) = $3;
+          my $key  = $2;
+          my $name = $3;
           if (defined $key) {
             $ti{$key} = $name;
           }
@@ -493,13 +485,13 @@ sub options {
     }
     elsif ($arg eq '-value_template') {
       $i++;
-      my($value) = $args[$i];
+      my $value = $args[$i];
       if (!defined $value) {
         $self->optionError('-value_template requires a variable assignment argument');
       }
       else {
-        my(@values) = ();
-        my($pc) = new ProjectCreator();
+        my @values;
+        my $pc = new ProjectCreator();
         if ($pc->parse_assignment($value, \@values)) {
           $addtemp{$values[1]} = [] if (!defined $addtemp{$values[1]});
           ## The extra parameter (3rd) indicates that this value was
@@ -507,7 +499,7 @@ sub options {
           ## used in ProjectCreator::update_template_variable().
           push(@{$addtemp{$values[1]}}, [$values[0], $values[2], 1]);
 
-          my($keywords) = ProjectCreator::getKeywords();
+          my $keywords = ProjectCreator::getKeywords();
           if (defined $$keywords{$values[1]}) {
             $self->warning($values[1] . ' is a project keyword; you ' .
                            'should use -value_project instead.');
@@ -520,13 +512,13 @@ sub options {
     }
     elsif ($arg eq '-value_project') {
       $i++;
-      my($value) = $args[$i];
+      my $value = $args[$i];
       if (!defined $value) {
         $self->optionError('-value_project requires a variable assignment argument');
       }
       else {
-        my(@values) = ();
-        my($pc) = new ProjectCreator();
+        my @values;
+        my $pc = new ProjectCreator();
         if ($pc->parse_assignment($value, \@values)) {
           $addproj{$values[1]} = [] if (!defined $addproj{$values[1]});
           push(@{$addproj{$values[1]}}, [$values[0], $values[2]]);
@@ -552,58 +544,52 @@ sub options {
     }
   }
 
-  return {'global'        => $global,
-          'feature_file'  => $feature_f,
-          'gfeature_file' => $gfeature_f,
-          'relative_file' => $relative_f,
-          'features'      => \@features,
-          'for_eclipse'   => $foreclipse,
-          'include'       => \@include,
-          'input'         => \@input,
-          'comments'      => $comments,
-          'creators'      => \@creators,
-          'baseprojs'     => \@baseprojs,
-          'template'      => $template,
-          'ti'            => \%ti,
-          'dynamic'       => $dynamic,
-          'static'        => $static,
-          'relative'      => \%relative,
-          'reldefs'       => $reldefs,
-          'toplevel'      => $toplevel,
-          'recurse'       => $recurse,
-          'addtemp'       => \%addtemp,
-          'addproj'       => \%addproj,
-          'coexistence'   => $makeco,
-          'hierarchy'     => $hierarchy,
-          'exclude'       => \@exclude,
-          'name_modifier' => $nmodifier,
-          'apply_project' => $applypj,
-          'gendot'        => $gendot,
-          'genins'        => $genins,
-          'into'          => $into,
-          'language'      => $language,
-          'use_env'       => $use_env,
-          'expand_vars'   => $expandvars,
+  return {'global'           => $global,
+          'feature_file'     => $feature_f,
+          'gfeature_file'    => $gfeature_f,
+          'relative_file'    => $relative_f,
+          'features'         => \@features,
+          'for_eclipse'      => $foreclipse,
+          'include'          => \@include,
+          'input'            => \@input,
+          'comments'         => $comments,
+          'creators'         => \@creators,
+          'baseprojs'        => \@baseprojs,
+          'template'         => $template,
+          'ti'               => \%ti,
+          'dynamic'          => $dynamic,
+          'static'           => $static,
+          'relative'         => \%relative,
+          'reldefs'          => $reldefs,
+          'toplevel'         => $toplevel,
+          'recurse'          => $recurse,
+          'addtemp'          => \%addtemp,
+          'addproj'          => \%addproj,
+          'make_coexistence' => $makeco,
+          'hierarchy'        => $hierarchy,
+          'exclude'          => \@exclude,
+          'name_modifier'    => $nmodifier,
+          'apply_project'    => $applypj,
+          'gendot'           => $gendot,
+          'genins'           => $genins,
+          'into'             => $into,
+          'language'         => $language,
+          'use_env'          => $use_env,
+          'expand_vars'      => $expandvars,
          };
 }
 
 
 sub is_set {
-  my($self)    = shift;
-  my($key)     = shift;
-  my($options) = shift;
+  my($self, $key, $options) = @_;
 
   if (defined $options->{$key}) {
     if (UNIVERSAL::isa($options->{$key}, 'ARRAY')) {
-      if (defined $options->{$key}->[0]) {
-        return 'ARRAY';
-      }
+      return 'ARRAY' if (defined $options->{$key}->[0]);
     }
     elsif (UNIVERSAL::isa($options->{$key}, 'HASH')) {
-      my(@keys) = keys %{$options->{$key}};
-      if (defined $keys[0]) {
-        return 'HASH';
-      }
+      my @keys = keys %{$options->{$key}};
+      return 'HASH' if (defined $keys[0]);
     }
     else {
       return 'SCALAR';
