@@ -17,7 +17,10 @@ use VC8ProjectCreator;
 use vars qw(@ISA);
 @ISA = qw(VC8ProjectCreator);
 
-my(%config) = ('vcversion' => '9.00',
+my %config = ('vcversion' => '9.00',
+              'prversion' => '9.0.30729',
+              'toolsversion' => '3.5',
+              'xmlheader' => 1,
               );
 
 # ************************************************************
@@ -25,8 +28,7 @@ my(%config) = ('vcversion' => '9.00',
 # ************************************************************
 
 sub get_configurable {
-  my($self)   = shift;
-  my($name)   = shift;
+  my($self, $name) = @_;
   return $config{$name};
 }
 
