@@ -22,13 +22,13 @@ use vars qw(@ISA);
 # ************************************************************
 
 sub compare_output {
-  #my($self) = shift;
+  #my $self = shift;
   return 1;
 }
 
 
 sub require_dependencies {
-  my($self) = shift;
+  my $self = shift;
 
   ## Only write dependencies for non-static projects
   ## and static exe projects, unless the user wants the
@@ -39,9 +39,23 @@ sub require_dependencies {
 
 
 sub dependency_is_filename {
-  #my($self) = shift;
+  #my $self = shift;
   return 0;
 }
 
 
+sub get_properties {
+  my $self = shift;
+
+  ## Get the base class properties and add the properties that we
+  ## support.
+  my $props = $self->WinProjectBase::get_properties();
+
+  ## All projects that use this base class are for Microsoft compilers.
+  $$props{'microsoft'} = 1;
+
+  return $props;
+}
+
+
 1;
