@@ -17,18 +17,17 @@ use strict;
 # ************************************************************
 
 sub crlf {
-  my($self) = shift;
-  return $self->windows_crlf();
+  return $_[0]->windows_crlf();
 }
 
 
 sub convert_slashes {
-  #my($self) = shift;
+  #my $self = shift;
   return 1;
 }
 
 sub case_insensitive {
-  #my($self) = shift;
+  #my $self = shift;
   return 1;
 }
 
