@@ -1,3 +1,4 @@
+#! /usr/bin/perl
 eval '(exit $?0)' && eval 'exec perl -w -S $0 ${1+"$@"}'
     & eval 'exec perl -w -S $0 $argv:q'
     if 0;
@@ -5,7 +6,7 @@ eval '(exit $?0)' && eval 'exec perl -w -S $0 ${1+"$@"}'
 # ******************************************************************
 #      Author: Chad Elliott
 #        Date: 6/17/2002
-#         $Id: mpc.pl 1094 2006-12-05 03:32:14Z elliott_c $
+#         $Id: mpc.pl 1605 2009-08-03 16:51:26Z elliott_c $
 # ******************************************************************
 
 # ******************************************************************
@@ -19,7 +20,8 @@ use FindBin;
 use File::Spec;
 use File::Basename;
 
-my($basePath) = $FindBin::Bin;
+my $basePath = $FindBin::RealBin;
+my $baseName = $FindBin::RealScript;
 if ($^O eq 'VMS') {
   $basePath = File::Spec->rel2abs(dirname($0)) if ($basePath eq '');
   $basePath = VMS::Filespec::unixify($basePath);
@@ -40,5 +42,5 @@ sub getBasePath {
 # Main Section
 # ************************************************************
 
-my($driver) = new Driver($basePath, basename($0));
+my $driver = new Driver($basePath, Driver::projects());
 exit($driver->run(@ARGV));
