@@ -2,7 +2,7 @@
 /**
  *  @file  Any_Handler.h
  *
- *  Any_Handler.h,v 1.3 2005/03/19 22:22:21 jai Exp
+ *  $Id: Any_Handler.h 84406 2009-02-11 14:59:08Z wotte $
  *
  *  @author Jules White <jules@dre.vanderbilt.edu>
  */
@@ -12,36 +12,41 @@
 #define CIAO_CONFIG_HANDLERS_ANY_HANDLER_H
 #include /**/ "ace/pre.h"
 
-#include "Config_Handlers_Export.h"
+#include "Config_Handlers_Common_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "Config_Handlers/Common.h"
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 namespace CORBA
 {
   class Any;
 }
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 namespace CIAO
 {
   namespace Config_Handlers
-  {
-    class Any;
-
-   /*
-    * @class Any_Handler
-    *
-    * @brief Handler class for <ComponentInterfaceDescription> types.
-    *
-    * This class defines handler methods to map values from
-    * XSC Any objects, parsed from the descriptor files, to the
-    * corresponding CORBA IDL Any type.
-    *
-    */
-    class Config_Handlers_Export Any_Handler
     {
-      public:
+      class Any;
+
+      /*
+       * @class Any_Handler
+       *
+       * @brief Handler class for <ComponentInterfaceDescription> types.
+       *
+       * This class defines handler methods to map values from
+       * XSC Any objects, parsed from the descriptor files, to the
+       * corresponding CORBA IDL Any type.
+       *
+       */
+      class Config_Handlers_Common_Export Any_Handler
+    {
+    public:
       Any_Handler (void);
       virtual ~Any_Handler (void);
 
@@ -50,7 +55,7 @@ namespace CIAO
 
       static Any get_any (const CORBA::Any &src);
     };
-  }
+    }
 }
 
 #include /**/ "ace/post.h"
