@@ -1,7 +1,8 @@
-// DnC_Dump.cpp,v 1.5 2005/03/19 22:22:21 jai Exp
+// $Id: DnC_Dump.cpp 88129 2009-12-14 07:42:01Z johnnyw $
 
 #include "ace/Log_Msg.h"
-#include "ciao/Deployment_DataC.h"
+#include "tao/SystemException.h"
+#include "DAnCE/Deployment/Deployment_DataC.h"
 #include "DnC_Dump.h"
 #include "DnC_Dump_T.h"
 #include <iostream>
@@ -20,16 +21,16 @@ namespace Deployment
 
         for (CORBA::ULong i = 0; i < size; ++i)
           {
-            ACE_DEBUG ((LM_DEBUG, "%s%s %d: \n",
+            ACE_DEBUG ((LM_DEBUG, "%s%s %d:\n",
                         Dump_Obj::indent(), caption, i));
-            ACE_DEBUG ((LM_DEBUG, "%s  %s: \n",
+            ACE_DEBUG ((LM_DEBUG, "%s  %s:\n",
                         Dump_Obj::indent(), str_seq[i].in ()));
           }
       }
   }
 
   // Dumps a string
-  void DnC_Dump::dump (const char* caption, const TAO_String_Manager& str)
+  void DnC_Dump::dump (const char* caption, const TAO::String_Manager& str)
   {
     ACE_DEBUG ((LM_DEBUG, "%s%s: %s\n", Dump_Obj::indent(),
                 caption, str.in()));
@@ -99,18 +100,22 @@ namespace Deployment
     dump ("name", node.name);
     dump ("label", node.label);
 
-#if (_MSC_VER > 1200)
+#if (_MSC_VER)
     dump_ref_seq<Deployment::Domain> (
-      "sharedResourceRef",
-      node.sharedResourceRef, "Domain",
-      &Domain::sharedResource);
+                                      "sharedResourceRef",
+                                      node.sharedResourceRef,
+                                      "Domain",
+                                      &Domain::sharedResource);
+#endif
 
+#if (_MSC_VER)
     dump_ref_seq<Deployment::Domain> (
-      "connectionRef",
-      node.connectionRef,
-      "Domain",
-      &Domain::interconnect);
-#endif /* _MSC_VER */
+                                      "connectionRef",
+                                      node.connectionRef,
+                                      "Domain",
+                                      &Domain::interconnect);
+#endif
+
     dump_sequence ("resource",
                    node.resource);
 
@@ -123,20 +128,20 @@ namespace Deployment
     dump ("name", conn.name);
     dump ("label", conn.label);
 
-#if (_MSC_VER > 1200)
+#if (_MSC_VER)
     dump_ref_seq<Deployment::Domain> (
-      "connectionRef",
-      conn.connectionRef,
-      "Domain",
-      &Domain::bridge);
-
+                                      "connectionRef",
+                                      conn.connectionRef,
+                                      "Domain",
+                                      &Domain::bridge);
+#endif
+#if (_MSC_VER)
     dump_ref_seq<Deployment::Domain> (
-      "connectRef",
-      conn.connectRef,
-      "Domain",
-      &Domain::node);
-#endif /*_MSC_VER*/
-
+                                      "connectRef",
+                                      conn.connectRef,
+                                      "Domain",
+                                      &Domain::node);
+#endif
     dump_sequence ("resource",
                    conn.resource);
   }
@@ -148,14 +153,14 @@ namespace Deployment
     Dump_Obj dump_obj("Bridge");
     dump ("name", bridge.name);
     dump ("label", bridge.label);
-#if (_MSC_VER > 1200)
 
+#if (_MSC_VER)
     dump_ref_seq<Deployment::Domain> (
-      "connectRef",
-      bridge.connectRef,
-      "Domain",
-      &Domain::interconnect);
-#endif /*_MSC_VER*/
+                                      "connectRef",
+                                      bridge.connectRef,
+                                      "Domain",
+                                      &Domain::interconnect);
+#endif
 
     dump_sequence ("resource", bridge.resource);
   }
@@ -189,7 +194,7 @@ namespace Deployment
   // ComponentPortDescription
 
   void DnC_Dump::dump (const ::Deployment::ComponentPortDescription
-                         &compportdesc)
+                       &compportdesc)
   {
     Dump_Obj dump_obj("ComponentPortDescription");
 
@@ -209,6 +214,7 @@ namespace Deployment
     case EventEmitter: ACE_DEBUG ((LM_DEBUG, "EventEmitter\n")); break;
     case EventPublisher: ACE_DEBUG ((LM_DEBUG, "EventPublisher\n")); break;
     case EventConsumer: ACE_DEBUG ((LM_DEBUG, "EventConsumer\n")); break;
+    default: ACE_DEBUG ((LM_DEBUG, "Unknown port kind\n")); break;
     }
   }
 
@@ -299,12 +305,12 @@ namespace Deployment
 
     dump ("name", mdd.name);
     dump ("source", mdd.source);
-#if (_MSC_VER > 1200)
 
+#if (_MSC_VER)
     dump_ref_seq<Deployment::DeploymentPlan> ("artifactRef", mdd.artifactRef,
                                               "DeploymentPlan",
                                               &DeploymentPlan::artifact);
-#endif /*_MSC_VER*/
+#endif
     dump_sequence ("execParameter", mdd.execParameter);
     dump_sequence ("deployRequirement", mdd.deployRequirement);
   }
@@ -333,7 +339,7 @@ namespace Deployment
     dump ("requirementName", irdd.requirementName);
     dump ("resourceName", irdd.resourceName);
     ACE_DEBUG ((LM_DEBUG, "%sresourceValue:\n", Dump_Obj::indent()));
-    dump (irdd.resourceValue);
+    dump_sequence ("property",  irdd.property);
   }
 
   // InstanceDeploymentDescription
@@ -346,12 +352,12 @@ namespace Deployment
     dump ("node", idd.node);
     dump ("source", idd.source);
 
-#if (_MSC_VER > 1200)
+#if (_MSC_VER)
     dump_ref<Deployment::DeploymentPlan> ("implementationRef",
                                           idd.implementationRef,
                                           "DeploymentPlan",
                                           &DeploymentPlan::implementation);
-#endif /*_MSC_VER*/
+#endif
     dump_sequence ("configProperty", idd.configProperty);
     dump_sequence ("deployedResource", idd.deployedResource);
     dump_sequence ("deployedSharedResource", idd.deployedSharedResource);
@@ -382,12 +388,13 @@ namespace Deployment
     case EventEmitter: ACE_DEBUG ((LM_DEBUG, "EventEmitter\n")); break;
     case EventPublisher: ACE_DEBUG ((LM_DEBUG, "EventPublisher\n")); break;
     case EventConsumer: ACE_DEBUG ((LM_DEBUG, "EventConsumer\n")); break;
+    default: ACE_DEBUG ((LM_DEBUG, "Unknown port kind\n")); break;
     }
-#if (_MSC_VER > 1200)
+#if (_MSC_VER)
     dump_ref<Deployment::DeploymentPlan> ("instanceRef", pspe.instanceRef,
                                           "DeploymentPlan",
                                           &DeploymentPlan::instance);
-#endif /*_MSC_VER*/
+#endif
   }
 
   // ExternalReferenceEndpoint
@@ -409,7 +416,7 @@ namespace Deployment
     dump ("requirementName", crdd.requirementName);
     dump ("resourceName", crdd.resourceName);
     ACE_DEBUG ((LM_DEBUG, "%sresourceValue:\n", Dump_Obj::indent()));
-    dump (crdd.resourceValue);
+    dump_sequence ("properties", crdd.property);
   }
 
   // PlanConnectionDescription
@@ -435,11 +442,11 @@ namespace Deployment
 
     dump ("propertyName", pspr.propertyName);
 
-#if (_MSC_VER > 1200)
+#if (_MSC_VER)
     dump_ref<Deployment::DeploymentPlan> ("instanceRef", pspr.instanceRef,
                                           "DeploymentPlan",
                                           &DeploymentPlan::instance);
-#endif /*_MSC_VER*/
+#endif
   }
 
   // PlanPropertyMapping
@@ -472,7 +479,7 @@ namespace Deployment
     dump ("requirementName", rdd.requirementName);
     dump ("resourceName", rdd.resourceName);
     ACE_DEBUG ((LM_DEBUG, "%sresourceValue:\n", Dump_Obj::indent()));
-    dump (rdd.resourceValue);
+    dump_sequence ("properties", rdd.property);
   }
 
   // ArtifactDeploymentDescription
@@ -518,7 +525,7 @@ namespace Deployment
 
     dump ("requiredUUID", cpr.requiredUUID);
     dump ("requiredName", cpr.requiredName);
-    dump ("requiredType", cpr.requiredType);
+    dump ("requiredType", cpr.requiredType.specificType);
   }
 
   // SubcomponentInstantiationDescription
@@ -528,10 +535,10 @@ namespace Deployment
     Dump_Obj dump_obj("SubcomponentInstantiationDescription");
 
     dump ("name", sid.name);
-    dump_sequence ("package", sid.package);
+    //    dump_sequence ("basePackage", sid.package);
     dump_sequence ("configProperty", sid.configProperty);
     dump_sequence ("selectRequirement", sid.selectRequirement);
-    dump_sequence ("reference", sid.reference);
+    //    dump_sequence ("reference", sid.reference);
   }
 
   // SubcomponentPortEndpoint
@@ -548,7 +555,7 @@ namespace Deployment
 
     a >>= v;
 
-    ACE_DEBUG ((LM_DEBUG, "%sinstance: %s \n", Dump_Obj::indent (),
+    ACE_DEBUG ((LM_DEBUG, "%sinstance: %s\n", Dump_Obj::indent (),
                 v->instance[value].name.in ()));
   }
 
@@ -581,7 +588,7 @@ namespace Deployment
 
     a >>= v;
 
-    ACE_DEBUG ((LM_DEBUG, "%sinstance: %s \n", Dump_Obj::indent (),
+    ACE_DEBUG ((LM_DEBUG, "%sinstance: %s\n", Dump_Obj::indent (),
                 v->instance[value].name.in ()));
   }
 
@@ -652,11 +659,11 @@ namespace Deployment
   // MonolithicImplementationDescription
 
   void DnC_Dump::dump (const ::Deployment::MonolithicImplementationDescription
-                         &mid)
+                       &mid)
   {
     Dump_Obj dump_obj("MonolithicImplementationDescription");
 
-    dump_sequence ("execParameter", mid.execParameter);
+    //    dump_sequence ("execParameter", mid.execParameter);
     dump_sequence ("primaryArtifact", mid.primaryArtifact);
     dump_sequence ("deployRequirement", mid.deployRequirement);
   }
@@ -675,7 +682,7 @@ namespace Deployment
   // ComponentImplementationDescription
 
   void DnC_Dump::dump (
-        const ::Deployment::ComponentImplementationDescription &cid)
+                       const ::Deployment::ComponentImplementationDescription &cid)
   {
     Dump_Obj dump_obj("ComponentImplementationDescription");
 
@@ -699,20 +706,20 @@ namespace Deployment
 
     dump ("Name", pci.name);
     ACE_DEBUG ((LM_DEBUG,
-                "%sreferencedImplementation: \n", Dump_Obj::indent()));
+                "%sreferencedImplementation:\n", Dump_Obj::indent()));
     DnC_Dump::dump (pci.referencedImplementation);
   }
 
   // ComponentPackageDescription
 
   void DnC_Dump::dump (const ::Deployment::ComponentPackageDescription
-                         &comppkgdesc)
+                       &comppkgdesc)
   {
     Dump_Obj dump_obj("ComponentPackageDescription");
 
     dump ("label", comppkgdesc.label);
     dump ("UUID", comppkgdesc.UUID);
-    ACE_DEBUG ((LM_DEBUG, "%srealizes: \n", Dump_Obj::indent ()));
+    ACE_DEBUG ((LM_DEBUG, "%srealizes:\n", Dump_Obj::indent ()));
     DnC_Dump::dump (comppkgdesc.realizes); // ComponentInterfaceDescription
     dump_sequence ("configProperty", comppkgdesc.configProperty);
     dump_sequence ("implementation", comppkgdesc.implementation);
@@ -729,21 +736,11 @@ namespace Deployment
     dump ("UUID", pc.UUID);
     dump_sequence ("specializedConfig", pc.specializedConfig);
     dump_sequence ("basePackage", pc.basePackage);
-    dump_sequence ("reference", pc.reference);
+    dump_sequence ("reference", pc.referencedPackage);
     dump_sequence ("selectRequirement", pc.selectRequirement);
     dump_sequence ("configProperty", pc.configProperty);
   }
 
-  // Requirement Satisfier
-  void DnC_Dump::dump (const Deployment::RequirementSatisfier& rs)
-  {
-    Dump_Obj dump_obj("RequirementSatisfier");
-
-    dump ("name", rs.name);
-    dump ("resourceType", rs.resourceType);
-    dump_sequence ("property", rs.property);
-  }
-
   // Property
   void DnC_Dump::dump (const Deployment::Property& property)
   {
@@ -766,10 +763,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC_Dump::dump (CORBA::Any), expected short\
-                                  encoded different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -780,7 +777,7 @@ namespace Deployment
         break;
 
       case CORBA::tk_void:
-        ACE_DEBUG ((LM_DEBUG, "Any value: void type encoded \n"));
+        ACE_DEBUG ((LM_DEBUG, "Any value: void type encoded\n"));
         break;
       case CORBA::tk_long:
         {
@@ -788,10 +785,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected long\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -802,10 +799,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected u short\
-                                   encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %u \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %u\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -816,10 +813,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected ulong\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %u \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %u\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -830,10 +827,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected float\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %f \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %f\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -843,10 +840,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected double\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %f \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %f\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -856,14 +853,14 @@ namespace Deployment
           if (! (any >>= CORBA::Any::to_boolean (temp)))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected bool\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
 
           if (temp)
-            ACE_DEBUG ((LM_DEBUG, "Any value: True \n"));
+            ACE_DEBUG ((LM_DEBUG, "Any value: True\n"));
           else
-            ACE_DEBUG ((LM_DEBUG, "Any value: False \n"));
+            ACE_DEBUG ((LM_DEBUG, "Any value: False\n"));
         }
         break;
 
@@ -873,10 +870,10 @@ namespace Deployment
           if (! (any >>= CORBA::Any::to_char (temp)))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected char\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %c \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %c\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -887,10 +884,10 @@ namespace Deployment
           if (! (any >>= CORBA::Any::to_octet (temp)))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected octet\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -901,10 +898,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected string\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %s \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %s\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -914,10 +911,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected longlong\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %l \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %l\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -928,10 +925,10 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected longdouble\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %d\n", Dump_Obj::indent (),
                       temp));
         }
 
@@ -942,10 +939,10 @@ namespace Deployment
           if (! (any >>= CORBA::Any::to_wchar (temp)))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected wchar\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %c \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %c\n", Dump_Obj::indent (),
                       temp));
         }
         break;
@@ -956,17 +953,30 @@ namespace Deployment
           if (! (any >>= temp))
             {
               ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected wstring\
-                                    encoded with different type"));
-              ACE_THROW (CORBA::INTERNAL ());
+encoded with different type"));
+              throw CORBA::INTERNAL ();
             }
-          ACE_DEBUG ((LM_DEBUG, "%sAny value: %s \n", Dump_Obj::indent (),
+          ACE_DEBUG ((LM_DEBUG, "%sAny value: %s\n", Dump_Obj::indent (),
                       temp));
         }
         break;
 
+        case CORBA::tk_enum:
+        {
+/*          CORBA::Enum temp;
+          if (! (any >>= temp))
+            {
+              ACE_DEBUG ((LM_DEBUG, "DnC::dump (CORBA::Any) expected enum \
+encoded with different type"));
+              throw CORBA::INTERNAL ();
+            }
+*/          ACE_DEBUG ((LM_DEBUG, "%sAny value: some enum\n", Dump_Obj::indent ()));
+        }
+        break;
+
       default:
         ACE_DEBUG ((LM_DEBUG, "Unknown type encoded in Any\n"));
-        ACE_THROW (CORBA::INTERNAL ());
+        throw CORBA::INTERNAL ();
       }
   }
 }
