@@ -1,7 +1,7 @@
-// STD_IAD_Handler.cpp,v 1.1 2005/07/26 19:23:09 mxiong Exp
+// $Id: STD_IAD_Handler.cpp 84406 2009-02-11 14:59:08Z wotte $
 #include "STD_IAD_Handler.h"
 #include "Basic_Deployment_Data.hpp"
-#include "ciao/Deployment_DataC.h"
+#include "ciao/Packaging_DataC.h"
 #include "Property_Handler.h"
 
 #include "iad.hpp"
