@@ -1,9 +1,8 @@
-// STD_PCD_Handler.cpp,v 1.1 2005/07/26 19:23:09 mxiong Exp
+// $Id: STD_PCD_Handler.cpp 84406 2009-02-11 14:59:08Z wotte $
 #include "STD_PCD_Handler.h"
 #include "STD_CPD_Handler.h"
 #include "Basic_Deployment_Data.hpp"
-#include "ciao/Deployment_DataC.h"
-#include "XML_Helper.h"
+#include "ciao/Packaging_DataC.h"
 #include "Deployment.hpp"
 
 
@@ -23,13 +22,13 @@ namespace CIAO
       toconfig.UUID =
         desc.UUID ().c_str ();
 
-      if (!this->xml_helper_->is_initialized ())
+      if (!XML_Helper::XML_HELPER.is_initialized ())
         return false;
 
       // parse the .cpd (ComponentPackageDescription) file
       // that <basePackage> links to
       xercesc::DOMDocument* dom =
-        this->xml_helper_->create_dom ((desc.basePackage()).href ().c_str ());
+        XML_Helper::XML_HELPER.create_dom ((desc.basePackage()).href ().c_str ());
 
       if (!dom)
         return false;
@@ -39,7 +38,7 @@ namespace CIAO
 
       Deployment::ComponentPackageDescription idl_cpc;
 
-      STD_CPD_Handler cpd_handler (this->xml_helper_);
+      STD_CPD_Handler cpd_handler;
 
       cpd_handler.component_package_descr (cpc,
                                            idl_cpc);
