@@ -1,17 +1,11 @@
-// STD_PC_Intf.cpp,v 1.1 2005/07/26 19:23:09 mxiong Exp
-
-#if defined (_MSC_VER) && (_MSC_VER < 1300)
-#pragma warning (disable: 4018)
-#pragma warning (disable: 4284)
-#pragma warning (disable: 4146)
-#endif
+// $Id: STD_PC_Intf.cpp 88284 2009-12-22 09:34:06Z johnnyw $
 
 #include "STD_PC_Intf.h"
-#include "XML_Helper.h"
+#include "Utils/XML_Typedefs.h"
 #include "Deployment.hpp"
 #include "STD_PCD_Handler.h"
-#include "ciao/Deployment_DataC.h"
-
+#include "ciao/Packaging_DataC.h"
+#include "DAnCE/Logger/Log_Macros.h"
 
 namespace CIAO
 {
@@ -26,14 +20,12 @@ namespace CIAO
     bool
     STD_PC_Intf::prepare_PC (const char *file)
     {
-      ACE_Auto_Ptr<XML_Helper> helper (new XML_Helper);
+      DANCE_TRACE("STD_PC_Intf::prepare_PC");
 
-      if (!helper->is_initialized ())
-        return false;
 
       // parse the .pcd (PackageConfigurationDescription) file
       xercesc::DOMDocument *dom =
-        helper->create_dom (file);
+        XML_Helper::XML_HELPER.create_dom (file);
 
       if (!dom)
         return false;
@@ -46,7 +38,7 @@ namespace CIAO
       Deployment::PackageConfiguration idl_pc;
 
 
-      STD_PCD_Handler pcd_handler (helper.get ());
+      STD_PCD_Handler pcd_handler;
 
       pcd_handler.package_config (pc,
                                   idl_pc);
