@@ -2,7 +2,7 @@
 /**
  *  @file  STD_PC_Intf.h
  *
- *  STD_PC_Intf.h,v 1.1 2005/07/26 19:23:09 mxiong Exp
+ *  $Id: STD_PC_Intf.h 84406 2009-02-11 14:59:08Z wotte $
  *
  *  @author Ming Xiong <mxiong@dre.vanderbilt.edu>
  */
@@ -12,7 +12,7 @@
 #define CIAO_CONFIG_STD_PC_INTF_H
 #include /**/ "ace/pre.h"
 
-#include "Config_Handlers/Config_Handlers_Export.h"
+#include "Config_Handlers_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
