@@ -2,7 +2,7 @@
 /**
  *  @file  XML_File_Intf.h
  *
- *  XML_File_Intf.h,v 1.5 2005/05/30 20:24:59 turkaye Exp
+ *  $Id: XML_File_Intf.h 88286 2009-12-22 12:46:38Z johnnyw $
  *
  *  @author Bala Natarajan <bala@dre.vanderbilt.edu>
  */
@@ -12,7 +12,7 @@
 #define CIAO_CONFIG_XML_FILE_INTF_H
 #include /**/ "ace/pre.h"
 
-#include "Config_Handlers/Config_Handlers_Export.h"
+#include "Config_Handlers_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -20,10 +20,11 @@
 
 #include "ace/Auto_Ptr.h"
 
+#include <string>
 
 namespace Deployment
 {
-  struct DeploymentPlan ;
+  struct DeploymentPlan;
 }
 
 namespace CIAO
@@ -33,16 +34,20 @@ namespace CIAO
     class Config_Handlers_Export XML_File_Intf
     {
     public:
-      XML_File_Intf (const char *file);
+      XML_File_Intf (const ACE_TCHAR *file);
 
-      ::Deployment::DeploymentPlan const *get_plan (void) const;
-      ::Deployment::DeploymentPlan *get_plan (void);
+      ::Deployment::DeploymentPlan const *get_plan (void);
+      ::Deployment::DeploymentPlan *release_plan (void);
+
+      void add_search_path (const ACE_TCHAR *environment,
+                            const ACE_TCHAR *relpath);
 
     protected:
 
-      bool read_process_file (const char *file);
+      bool read_process_file (const ACE_TCHAR *file);
 
     private:
+      std::basic_string <ACE_TCHAR> file_;
       ACE_Auto_Ptr< ::Deployment::DeploymentPlan> idl_dp_;
     };
   }
