@@ -1,6 +1,6 @@
 // file      : XSCRT/Parser.hpp
 // author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
-// cvs-id    : Parser.hpp,v 1.4 2005/03/31 04:59:38 nanbor Exp
+// cvs-id    : $Id: Parser.hpp 86462 2009-08-12 13:31:27Z wotte $
 
 #ifndef XSCRT_PARSER_HPP
 #define XSCRT_PARSER_HPP
@@ -30,8 +30,7 @@ namespace XSCRT
     XML::Element<C>
     next_element ()
     {
-      return XML::Element<C> (
-        dynamic_cast<xercesc::DOMElement*> (e_->item (ei_++)));
+      return XML::Element<C> (XML::dom_cast <xercesc::DOMElement*> (e_->item (ei_++)));
     }
 
     bool
@@ -44,7 +43,7 @@ namespace XSCRT
     next_attribute ()
     {
       return XML::Attribute<C> (
-        dynamic_cast<xercesc::DOMAttr*> (a_->item (ai_++)));
+        XML::dom_cast <xercesc::DOMAttr*> (a_->item (ai_++)));
     }
 
   private:
