@@ -1,11 +1,10 @@
-
 /* -*- C++ -*- */
 
 //=============================================================================
 /**
  *  @file    URL_Parser.h
  *
- *  $Id: URL_Parser.h 74768 2006-10-16 09:02:12Z johnnyw $
+ *  $Id: URL_Parser.h 89047 2010-02-17 11:41:16Z johnnyw $
  *
  *  Parses a URL into its logical chunks
  *
@@ -17,8 +16,6 @@
 #ifndef URL_PARSER_H
 #define URL_PARSER_H
 
-#include "ace/Get_Opt.h"
-#include "ace/ARGV.h"
 #include "ace/Singleton.h"  //for ACE_Singleton
 #include "ace/Null_Mutex.h" //for ACE_Null_Mutex
 
@@ -37,7 +34,7 @@ public:
   bool parse_args (int argc, ACE_TCHAR *argv[]);
 
   /// Return false on failure
-  bool parseURL (char* url);
+  bool parseURL (ACE_TCHAR* url);
 
   void Error (void);
 
