@@ -1,51 +1,64 @@
-// $Id: DomainDataManager.cpp 77112 2007-02-13 20:55:24Z nilabjar $
+// $Id: DomainDataManager.cpp 89012 2010-02-15 14:04:29Z johnnyw $
 #include "DomainDataManager.h"
+#include "Deployment/Deployment_NodeManagerC.h"
 
 #include "Config_Handlers/DD_Handler.h"
-#include "Config_Handlers/DnC_Dump.h"
-#include "ciao/CIAO_common.h"
-
-const char * domain_file_name = "Domain.cdd";
-
-CIAO::DomainDataManager* CIAO::DomainDataManager::global_data_manager_ = 0;
-
-CIAO::DomainDataManager * CIAO::DomainDataManager::create (CORBA::ORB_ptr orb,
-                            ::Deployment::TargetManager_ptr target
-                            )
-{
-  if (global_data_manager_ == 0)
-    {
-      global_data_manager_ = new DomainDataManager (orb , target);
-    }
-  return global_data_manager_;
-}
-
-// Returns the pointer to the static variable
-CIAO::DomainDataManager*
-CIAO::DomainDataManager::get_data_manager ()
-{
-  return global_data_manager_;
-}
+#include "DAnCE/Logger/Log_Macros.h"
 
+#ifdef GEN_OSTREAM_OPS
+#include <iostream>
+#include <sstream>
+#endif /* GEN_OSTREAM_OPS */
 
 void
-CIAO::DomainDataManager::delete_data_manger ()
+DAnCE::DomainDataManager::init (CORBA::ORB_ptr orb,
+                                ::Deployment::TargetManager_ptr target,
+                                const ACE_TCHAR *domain_name)
 {
-  if (global_data_manager_)
-    delete global_data_manager_;
+  DANCE_TRACE ("DAnCE::DomainDataManager::init");
+
+  this->orb_ = CORBA::ORB::_duplicate (orb);
+  this->target_mgr_ = ::Deployment::TargetManager::_duplicate(target);
+
+  DANCE_DEBUG (6, (LM_DEBUG, DLINFO "DAnCE::DomainDataManager::init - "
+                "Parsing initial domain from file %s\n",
+                domain_name));
+
+  CIAO::Config_Handlers::DD_Handler dd (domain_name);
+  ::Deployment::Domain* dmn = dd.domain_idl ();
+
+  DANCE_DEBUG (9, (LM_TRACE, DLINFO "DAnCE::DomainDataManager::init - "
+                "Initial domain successfully parsed\n"));
+#ifdef GEN_OSTREAM_OPS
+  std::ostringstream _stream;
+  _stream << *dmn << std::endl;
+
+  DANCE_DEBUG (9, (LM_TRACE, DLINFO "DAnCE::DomainDataManager::init - "
+                "Contents of Domain: %C\n",
+                _stream.str ().c_str ()));
+#endif
+
+  current_domain_ = *dmn;
+  initial_domain_ = current_domain_;
+
+  // initialize the provisioning domain
+  provisioned_data_ = initial_domain_;
+
+  update_node_status ();
+
+  call_all_node_managers ();
 }
 
-int CIAO::DomainDataManager::update_domain (
-                             const ::CORBA::StringSeq &,
-                             const ::Deployment::Domain & domainSubset,
-                             ::Deployment::DomainUpdateKind update_kind)
+int DAnCE::DomainDataManager::update_domain (const ::CORBA::StringSeq &,
+                                             const ::Deployment::Domain & domainSubset,
+                                             ::Deployment::DomainUpdateKind update_kind)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::update_domain");
+
   // Update the subset of the domain which the above
   // parameter corresponds to
 
-
-  //check the type of update ..
-
+  // Check the type of update ..
   switch (update_kind)
     {
       case ::Deployment::UpdateAll:
@@ -88,56 +101,40 @@ int CIAO::DomainDataManager::update_domain (
   return 0;
 }
 
-CIAO::DomainDataManager::
-DomainDataManager (CORBA::ORB_ptr orb,
-                   ::Deployment::TargetManager_ptr target)
-  : orb_ (CORBA::ORB::_duplicate (orb)),
-    deployment_config_ (orb_.in()),
-    target_mgr_ (::Deployment::TargetManager::_duplicate(target))
+::Deployment::Domain* DAnCE::DomainDataManager::get_current_domain ()
 {
-  CIAO::Config_Handlers::DD_Handler dd (domain_file_name);
-  ::Deployment::Domain* dmn = dd.domain_idl ();
+  DANCE_TRACE ("DAnCE::DomainDataManager::get_current_domain");
 
-  if (CIAO::debug_level () > 9)
-    ::Deployment::DnC_Dump::dump (*dmn);
-
-  current_domain_ = *dmn;
-  initial_domain_ = current_domain_;
-
-  // initialize the provisioning domain
-  provisioned_data_ = initial_domain_;
-
-  update_node_status ();
-
-  call_all_node_managers ();
-}
-
-::Deployment::Domain* CIAO::DomainDataManager::get_current_domain ()
-{
   return new ::Deployment::Domain (provisioned_data_);
 }
 
-::Deployment::Domain* CIAO::DomainDataManager::get_initial_domain ()
+::Deployment::Domain* DAnCE::DomainDataManager::get_initial_domain ()
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::get_initial_domain");
+
   return new ::Deployment::Domain (initial_domain_);
 }
 
-int CIAO::DomainDataManager::readin_domain_data ()
+int DAnCE::DomainDataManager::readin_domain_data ()
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::readin_domain_data");
+
   // here read in Domain data ...
   //
   return 0;
 }
 
-int CIAO::DomainDataManager::call_all_node_managers ()
+int DAnCE::DomainDataManager::call_all_node_managers ()
 {
-  if ( this->deployment_config_.init ("NodeDetails.dat") == -1 )
+  DANCE_TRACE ("DAnCE::DomainDataManager::call_all_node_managers");
+
+/*  if ( this->deployment_config_.init ("NodeDetails.dat") == -1 )
     {
-      ACE_ERROR ((LM_ERROR,
+      DANCE_ERROR (1, (LM_ERROR,
                   "TargetM (%P|%t) DomainDataManager.cpp -"
-                  "CIAO::DomainDataManager::call_all_node_managers -"
+                  "DAnCE::DomainDataManager::call_all_node_managers -"
                   "ERROR while trying to initialize after reading "
-                  "node details DAT file \n"));
+                  "node details DAT file\n"));
       return 0;
     }
 
@@ -156,7 +153,7 @@ int CIAO::DomainDataManager::call_all_node_managers ()
         }
       catch (CORBA::Exception&)
         {
-          ACE_ERROR ((LM_ERROR, "DANCE::TM (%P|%t) DomainDataManager.cpp: "
+          DANCE_ERROR (1, (LM_ERROR, "DANCE::TM (%P|%t) DomainDataManager.cpp: "
                       "Error trying to contact NodeManager %s\n",
                       initial_domain_.node[i].name.in ()));
           continue;
@@ -184,21 +181,24 @@ int CIAO::DomainDataManager::call_all_node_managers ()
             }
           catch (CORBA::Exception& ex)
             {
-              ACE_ERROR ((LM_ERROR , "TM::Error in calling Join Domain==\n"));
+              DANCE_ERROR (1, (LM_ERROR , "TM::Error in calling Join Domain==\n"));
               ex._tao_print_exception (
                 "Exception caught in ""DomainDataManager::joinDomain");
             }
         }
     }
+*/
   return 0;
 
 }
 
 
-void CIAO::DomainDataManager
-::commitResources (
-                   const ::Deployment::DeploymentPlan & plan)
+::Deployment::ResourceCommitmentManager_ptr DAnCE::DomainDataManager
+::commitResources (const ::Deployment::ResourceAllocations &)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::commitResources");
+
+/*
   // commit the resources
   // parse into the plan and commit resources ...
 
@@ -232,15 +232,18 @@ void CIAO::DomainDataManager
 
   // here commit the commitresources
   provisioned_data_ = temp_provisioned_data;
+  */
+  return 0;
 }
 
 
-void CIAO::DomainDataManager::
-releaseResources (
-                  const ::Deployment::DeploymentPlan& plan)
+void DAnCE::DomainDataManager::
+releaseResources (const ::Deployment::ResourceCommitmentManager_ptr)
 {
-  // release the resources
+  DANCE_TRACE ("DAnCE::DomainDataManager::releaseResources");
 
+  // release the resources
+/*
 
   // set the action value
   current_action_ = release;
@@ -259,16 +262,16 @@ releaseResources (
           }
         }
     }
-
+*/
 }
 
 
-void CIAO::DomainDataManager::
-match_requirement_resource (
+void DAnCE::DomainDataManager::match_requirement_resource (
       ::Deployment::InstanceResourceDeploymentDescriptions deployed,
-      ::Deployment::Resources & available
-         )
+      ::Deployment::Resources & available)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::match_requirement_resource");
+
   // here match the deployed to the available
 
   for (CORBA::ULong i = 0;i < deployed.length ();i++)
@@ -279,7 +282,6 @@ match_requirement_resource (
         {
           if (!ACE_OS::strcmp (deployed[i].requirementName, available[j].name))
             {
-              if (CIAO::debug_level () > 9)
               // search for the resourcename in the resourceType
               for (CORBA::ULong k = 0;k < available[j].resourceType.length ();k++)
                 {
@@ -303,11 +305,12 @@ match_requirement_resource (
 
 }
 
-void CIAO::DomainDataManager::
-match_properties (
+void DAnCE::DomainDataManager::match_properties (
       ::Deployment::Properties deployed,
       ::Deployment::SatisfierProperties & available)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::match_properties");
+
   bool property_found;
 
   for (CORBA::ULong i = 0;i < deployed.length ();i++)
@@ -344,22 +347,24 @@ match_properties (
     } // outside for ...
 }
 
-void CIAO::DomainDataManager::commit_release_resource (
+void DAnCE::DomainDataManager::commit_release_resource (
            ::Deployment::Property & deployed,
            ::Deployment::SatisfierProperty & available)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::commit_release_resource");
+
   if (current_action_ == commit)
     {
 
       CORBA::Long required_d;
 
       if ((deployed.value >>= required_d) == false)
-        ACE_ERROR ((LM_ERROR, "Failed to extract required amount\n"));
+        DANCE_ERROR (1, (LM_ERROR, "Failed to extract required amount\n"));
 
       CORBA::Long available_d;
 
       if ((available.value >>= available_d) == false)
-        ACE_ERROR ((LM_ERROR, "failed to extract available amount\n"));
+        DANCE_ERROR (1, (LM_ERROR, "failed to extract available amount\n"));
 
       if (available_d >= required_d)
         {
@@ -396,51 +401,11 @@ void CIAO::DomainDataManager::commit_release_resource (
     }
 }
 
-void CIAO::DomainDataManager::stop_monitors ()
-{
-
-  CORBA::ULong length = initial_domain_.node.length ();
-
-  for (CORBA::ULong i=0;i < length;i++)
-    {
-      ::Deployment::NodeManager_var node_manager;
-
-      try
-        {
-          node_manager =
-            deployment_config_.get_node_manager
-            (initial_domain_.node[i].name.in ());
-        }
-      catch (CORBA::Exception&)
-        {
-          ACE_ERROR ((LM_ERROR, "DANCE::TM (%P|%t) DomainDataManager.cpp: "
-                      "Error in get Node Manager from Deployment Config %s\n",
-                      initial_domain_.node[i].name.in ()));
-          continue;
-        }
-
-
-      if (!CORBA::is_nil (node_manager.in ()))
-        {
-          try
-            {
-              node_manager->leaveDomain ();
-            }
-          catch (CORBA::Exception& ex)
-            {
-              ACE_ERROR ((LM_ERROR , "TM::Error in calling Leave Domain\n"));
-              ex._tao_print_exception (
-                "Exception caught in ""DomainDataManager::leaveDomain");
-            }
-        }
-    }
-  return;
-
-}
-
-int CIAO::DomainDataManager::add_to_domain (
+int DAnCE::DomainDataManager::add_to_domain (
     const ::Deployment::Domain& domain)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::add_to_domain");
+
   // here add the domain to the Domain
   // right now use only a node
 
@@ -458,7 +423,7 @@ int CIAO::DomainDataManager::add_to_domain (
       ::Deployment::Node a_node;
 
       if (!this->find_in_initial_domain (domain.node[i].name.in (),
-                                        a_node))
+                                         a_node))
         continue; // dont know this node
 
       //check if already present
@@ -475,19 +440,20 @@ int CIAO::DomainDataManager::add_to_domain (
   return 0;
 }
 
-bool CIAO::DomainDataManager::
-find_in_initial_domain (const char* node_name,
+bool DAnCE::DomainDataManager::find_in_initial_domain (const char* node_name,
                         ::Deployment::Node& node)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::find_in_initial_domain");
+
   for (CORBA::ULong i =0;
       i < this->initial_domain_.node.length ();
       i++)
   {
     if (ACE_OS::strcmp (node_name, this->initial_domain_.node[i].name.in ()) == 0)
-    {
-      node = this->initial_domain_.node[i];
-      return true;
-    }
+      {
+        node = this->initial_domain_.node[i];
+        return true;
+      }
   }
 
   // not found the node , return a node with an empty name
@@ -495,28 +461,31 @@ find_in_initial_domain (const char* node_name,
 }
 
 
-bool CIAO::DomainDataManager::
-find_in_provisioned_domain (const char* node_name,
+bool DAnCE::DomainDataManager::find_in_provisioned_domain (const char* node_name,
                         ::Deployment::Node& node)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::find_in_provisioned_domain");
+
   for (CORBA::ULong i =0;
       i < this->provisioned_data_.node.length ();
       i++)
   {
     if (ACE_OS::strcmp (node_name, this->provisioned_data_.node[i].name.in ()) == 0)
-    {
-      node = this->provisioned_data_.node[i];
-      return true;
-    }
+      {
+        node = this->provisioned_data_.node[i];
+        return true;
+      }
   }
 
   // not found the node , return a node with an empty name
   return false;
 }
 
-int CIAO::DomainDataManager::delete_from_domain (
+int DAnCE::DomainDataManager::delete_from_domain (
     const ::Deployment::Domain& domain)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::delete_from_domain");
+
   // validate input
   if (domain.node.length () == 0)
     return 1;
@@ -567,9 +536,11 @@ int CIAO::DomainDataManager::delete_from_domain (
   return 1;
 }
 
-int CIAO::DomainDataManager::intimate_planner (
+int DAnCE::DomainDataManager::intimate_planner (
     const ::Deployment::Domain& domain)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::intimate_planner");
+
  // use the connection with the planner and get a reference to the planner
  // make a call top the planner
   Deployment::Domain d = domain;
@@ -577,15 +548,19 @@ int CIAO::DomainDataManager::intimate_planner (
 
 }
 
-bool CIAO::DomainDataManager::update_node_status ()
+bool DAnCE::DomainDataManager::update_node_status ()
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::update_node_status");
+
   // update the node status here ...
   return 0;
 }
 
-void CIAO::DomainDataManager::commitResourceAllocation (
+void DAnCE::DomainDataManager::commitResourceAllocation (
           const ::Deployment::ResourceAllocations & resources)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::commitResourceAllocation");
+
   // commit the resources
   // parse into the plan and commit resources ...
 
@@ -595,9 +570,11 @@ void CIAO::DomainDataManager::commitResourceAllocation (
   this->commit_release_RA (resources);
 }
 
-void CIAO::DomainDataManager::releaseResourceAllocation (
+void DAnCE::DomainDataManager::releaseResourceAllocation (
     const ::Deployment::ResourceAllocations & resources)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::releaseResourceAllocation");
+
   // set the action value
   current_action_ = release;
 
@@ -605,9 +582,10 @@ void CIAO::DomainDataManager::releaseResourceAllocation (
 }
 
 
-int CIAO::DomainDataManager::
-commit_release_RA (const ::Deployment::ResourceAllocations& resources)
+int DAnCE::DomainDataManager::commit_release_RA (const ::Deployment::ResourceAllocations& resources)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::commit_release_RA");
+
   // temporary used to guard against exceptions
   temp_provisioned_data_ = provisioned_data_;
 
@@ -623,7 +601,7 @@ commit_release_RA (const ::Deployment::ResourceAllocations& resources)
     catch (::Deployment::ResourceCommitmentFailure& ex)
     {
       // catch the exception and add parameters
-      ACE_ERROR ((LM_ERROR, "Caught the Exception in releaseResourceAllocation\n"));
+      DANCE_ERROR (1, (LM_ERROR, "Caught the Exception in releaseResourceAllocation\n"));
       ex.index = i;
       throw ex;
     }
@@ -636,9 +614,11 @@ commit_release_RA (const ::Deployment::ResourceAllocations& resources)
 }
 
 ::Deployment::Resource&
-CIAO::DomainDataManager::find_resource (
+DAnCE::DomainDataManager::find_resource (
     const ::Deployment::ResourceAllocation& resource)
 {
+  DANCE_TRACE ("DAnCE::DomainDataManager::find_resource");
+
   // for now search the resource in the Node sequence; Later need
   // to add it to the Bridges and Interconnects too according to the
   // spec
