@@ -1,19 +1,17 @@
-// $Id: DetailView.h 68081 2005-09-01 19:26:35Z wotte $
+// $Id: DetailView.h 84578 2009-02-23 16:07:12Z johnnyw $
 
 #ifndef __DETAILVIEW_H
 #define __DETAILVIEW_H
 
 
 #include "NavUnit.h"
-#include <qwidget.h>
-#include <qmovie.h>
-
+#include <Qt/qwidget.h>
+#include <Qt/qmovie.h>
+#include <Qt/q3table.h>
 
 class QLabel;
 class QLineEdit;
 class QSpinBox;
-class QTable;
-
 
 class DetailView : public QWidget
 {
@@ -36,10 +34,10 @@ private:
   QSpinBox *x_edit;
   QSpinBox *y_edit;
   QSpinBox *z_edit;
-  QTable *child_list;
-  QTable *parent_list;
+  Q3Table *child_list;
+  Q3Table *parent_list;
   QLabel *movielabel;
-  QMovie movie;
+  QMovie *movie;
   QLabel *separatorlabel;
   QMovie separator;
 
