@@ -1,4 +1,4 @@
-// $Id: MapView.cpp 79494 2007-08-24 14:24:03Z sowayaa $
+// $Id: MapView.cpp 84578 2009-02-23 16:07:12Z johnnyw $
 
 #include "MapView.h"
 #include <stdlib.h>
@@ -6,15 +6,15 @@
 #include "worldmap1.xpm"
 
 MapView::MapView(
-  QCanvas& c,
+  Q3Canvas& c,
   QWidget* parent,
   const char* name,
-  WFlags f)
+  Qt::WindowFlags f)
   :
-  QCanvasView(&c, parent, name, f),
+  Q3CanvasView(&c, parent, name, f),
   bg_pixmap_(worldmap1)
 {
-  viewport()->setBackgroundMode(NoBackground);
+  viewport()->setBackgroundMode(Qt::NoBackground);
   enableClipper(TRUE);
   if(!bg_pixmap_.isNull())
   {
