@@ -1,23 +1,21 @@
-// $Id: NodeItem.h 68081 2005-09-01 19:26:35Z wotte $
+// $Id: NodeItem.h 84578 2009-02-23 16:07:12Z johnnyw $
 
 #ifndef __NODEITEM_H
 #define __NODEITEM_H
 
 #include "NavUnit.h"
-#include <qcanvas.h>
-//#include <qlist.h>
-#include <qtimer.h>
-#include <qbrush.h>
-#include <qobject.h>
+#include <Qt/q3canvas.h>
+#include <Qt/qtimer.h>
+#include <Qt/qbrush.h>
+#include <Qt/qobject.h>
 
-
-
-class NodeItem: public QObject, public QCanvasEllipse
+class NodeItem: public QObject,
+                public Q3CanvasEllipse
 {
   Q_OBJECT
 
 public:
-  NodeItem(QCanvas *canvas, NavUnit &unit);
+  NodeItem(Q3Canvas *canvas, NavUnit &unit);
 
   ~NodeItem() {}
 
