@@ -1,8 +1,8 @@
-// $Id: UpdatePositionCmd.cpp 68081 2005-09-01 19:26:35Z wotte $
+// $Id: UpdatePositionCmd.cpp 84578 2009-02-23 16:07:12Z johnnyw $
 
 #include "RootPanel.h"
 #include "UpdatePositionCmd.h"
-#include <qlcdnumber.h>
+#include <Qt/qlcdnumber.h>
 #include "NavUnit.h"
 
 
