@@ -1,16 +1,16 @@
-//$Id: starter.cpp 79494 2007-08-24 14:24:03Z sowayaa $:
+//$Id: starter.cpp 86079 2009-07-16 11:47:57Z johnnyw $:
 
 #include "SenderC.h"
 #include "ace/Get_Opt.h"
 
 // IOR file of the Sender
-const char * ior = 0;
+const ACE_TCHAR * ior = 0;
 const char * message = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:m:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:m:"));
   int c = 0;
 
   while ((c = get_opts ()) != -1)
@@ -22,7 +22,7 @@ parse_args (int argc, char *argv[])
           break;
 
         case 'm':
-          message = get_opts.opt_arg ();
+          message = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
           break;
 
         case '?':  // display help for use of the server.
@@ -39,28 +39,26 @@ parse_args (int argc, char *argv[])
 
   if (ior  == 0)
     {
-      ior = "file://Sender.ior";
+      ior = ACE_TEXT("file://Sender.ior");
     }
 
   return 0;
 }
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
       // Initialize orb
-      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv,
-                                            "");
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
       if (parse_args (argc, argv) != 0)
         {
           return -1;
         }
 
-      CORBA::Object_var obj =
-        orb->string_to_object (ior);
+      CORBA::Object_var obj = orb->string_to_object (ior);
 
       Hello::Sender_var sender = Hello::Sender::_narrow (obj.in ());
 
@@ -72,9 +70,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
         }
 
       if (message)
-      {
-        sender->local_message (message);
-      }
+        {
+          sender->local_message (message);
+        }
 
       sender->start ();
 
@@ -82,7 +80,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     }
   catch (const CORBA::Exception& ex)
     {
-      ex._tao_print_exception ("Unknown exception \n");
+      ex._tao_print_exception ("Unknown exception\n");
       return -1;
     }
 
