@@ -1,4 +1,4 @@
-// $Id: RoundTripClient_exec.h 77023 2007-02-12 14:01:04Z johnnyw $
+// $Id: RoundTripClient_exec.h 84406 2009-02-11 14:59:08Z wotte $
 
 //============================================================
 /**
@@ -29,7 +29,7 @@ namespace MyImpl
 
   class ROUNDTRIPCLIENT_EXEC_Export RoundTripClient_exec_i :
     public virtual Benchmark::RoundTripClient_Exec,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
   {
 
   public:
@@ -42,12 +42,10 @@ namespace MyImpl
     // Operations from Components::SessionComponent
     virtual void set_session_context (Components::SessionContext_ptr ctx);
 
-    virtual void ciao_preactivate ();
+    virtual void configuration_complete ();
 
     virtual void ccm_activate ();
 
-    virtual void ciao_postactivate ();
-
     virtual void ccm_passivate ();
 
     virtual void ccm_remove ();
@@ -71,7 +69,7 @@ namespace MyImpl
    */
   class ROUNDTRIPCLIENT_EXEC_Export RoundTripClientHome_exec_i :
     public virtual Benchmark::CCM_RoundTripClientHome,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
   {
   public:
     /// Default ctor.
