@@ -1,4 +1,4 @@
-// $Id: client.cpp 79574 2007-09-04 14:30:05Z sowayaa $
+// $Id: client.cpp 82081 2008-06-19 14:11:16Z sma $
 
 //==============================================================
 /**
@@ -18,15 +18,13 @@
 const char *ior = "file://test.ior";
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
 
       // Initialize orb
-      CORBA::ORB_var orb = CORBA::ORB_init (argc,
-                                            argv,
-                                            "");
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
       // Resolve HomeFinder interface
       CORBA::Object_var obj
