@@ -2,7 +2,7 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# $Id: run_test_ior_cad.pl 78126 2007-04-19 18:30:52Z johnnyw $
+# $Id: run_test_ior_cad.pl 88130 2009-12-14 08:15:24Z msmit $
 # -*- perl -*-
 
 #
@@ -10,22 +10,20 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
 #
 
 use lib "$ENV{'ACE_ROOT'}/bin";
-use PerlACE::Run_Test;
+use PerlACE::TestTarget;
+
+$tg = PerlACE::TestTarget::create_target (1) || die "Create target for ns failed\n";
 
 $status = 0;
-$daemon_ior = PerlACE::LocalFile ("daemon.ior");
-$am_ior = PerlACE::LocalFile ("am.ior");
+$daemon_base = "daemon.ior";
+$am_base = "am.ior";
+$daemon_ior = $tg->LocalFile ("daemon.ior");
+$am_ior = $tg->LocalFile ("am.ior");
 
-$ACE_ROOT=$ENV{'ACE_ROOT'};
 $CIAO_ROOT=$ENV{'CIAO_ROOT'};
 
-if ($CIAO_ROOT eq "") {
-    $CIAO_ROOT="$ACE_ROOT/TAO/CIAO";
-}
-
-unlink $daemon_ior;
-unlink $am_ior;
-
+$tg->DeleteFile ($daemon_base);
+$tg->DeleteFile ($am_base);
 
 # CIAO Daemon command line arguments
 $daemon_args = "-c $CIAO_ROOT/performance-tests/Benchmark/RoundTrip/svc.conf -ORBEndpoint iiop://localhost:10000 -o $daemon_ior -i CIAO_Installation_Data.ini -n $CIAO_ROOT/tools/ComponentServer/ComponentServer";
@@ -35,44 +33,44 @@ $assembly_manager_args = "-o $am_ior -c test.dat";
 $ad_args = " -k file://$am_ior -a Test-IOR.cad";
 
 # CIAO daemon process definition
-$DS = new PerlACE::Process ("$CIAO_ROOT/tools/Daemon/CIAO_Daemon",
+$DS = $tg->CreateProcess ("$CIAO_ROOT/tools/Daemon/CIAO_Daemon",
                             "$daemon_args");
 
 ## Starting up the CIAO daemon
 $DS->Spawn ();
-if (PerlACE::waitforfile_timed ($daemon_ior, $PerlACE::wait_interval_for_process_creation) == -1) {
+if ($tg->WaitForFileTimed($daemon_base,
+                          $tg->ProcessStartWaitInterval ()) == -1) {
     print STDERR "ERROR: Could not find daemon ior file <$daemon_ior>\n";
     $DS->Kill ();
     exit 1;
 }
 
 
-$AM = new PerlACE::Process("$CIAO_ROOT/tools/Assembly_Deployer/Assembly_Manager",
+$AM = $tg->CreateProcess("$CIAO_ROOT/tools/Assembly_Deployer/Assembly_Manager",
                            $assembly_manager_args);
 $AM->Spawn ();
-if (PerlACE::waitforfile_timed ($am_ior, $PerlACE::wait_interval_for_process_creation) == -1) {
+if ($tg->WaitForFileTimed($am_base,
+                          $tg->ProcessStartWaitInterval ()) == -1) {
     print STDERR "ERROR: Could not find assembly ior file <$am_ior>\n";
     $AM->Kill ();
     exit 1;
 }
 
-$AD = new PerlACE::Process("$CIAO_ROOT/tools/Assembly_Deployer/Assembly_Deployer",
+$AD = $tg->CreateProcess("$CIAO_ROOT/tools/Assembly_Deployer/Assembly_Deployer",
                            $ad_args);
 $AD->Spawn ();
 
 sleep (5);
 
 #Start the client to send the trigger message
-$CL = new PerlACE::Process ("../RoundTripClient/client", "");
-$CL->SpawnWaitKill(60);
+$CL = $tg->CreateProcess ("../RoundTripClient/client", "");
+$CL->SpawnWaitKill($tg->ProcessStopWaitInterval ());
 
 $AM->Kill ();
 $AD->Kill ();
 $DS->Kill ();
-#$CL->Kill ();
 
-#unlink $daemon_ior;
-#unlink $am_ior;
-unlink rtserver.ior;
+$tg->DeleteFile ($daemon_base);
+$tg->DeleteFile ($am_base);
 
 exit $status;
