@@ -1,8 +1,8 @@
 //
-// $Id: LatencyTest.cpp 77023 2007-02-12 14:01:04Z johnnyw $
+// $Id: LatencyTest.cpp 88279 2009-12-21 18:31:39Z johnnyw $
 //
 #include "LatencyTest.h"
-#include "CIAO_common.h"
+#include "ciao/Logger/Log_Macros.h"
 
 LatencyTest_Impl::LatencyTest_Impl (CORBA::ORB_ptr orb)
   : orb_ (CORBA::ORB::_duplicate (orb))
@@ -13,8 +13,7 @@ LatencyTest_Impl::LatencyTest_Impl (CORBA::ORB_ptr orb)
 CORBA::Long
 LatencyTest_Impl::makeCall (CORBA::Long send_time)
 {
-  if (CIAO::debug_level () > 0)
-    ACE_DEBUG ((LM_DEBUG, "Sending Time back \n"));
+  ACE_DEBUG ((LM_DEBUG, CLINFO"Sending Time back\n"));
 
   return send_time;
 }
