@@ -1,4 +1,4 @@
-// $Id: Sender_exec.cpp 79823 2007-10-22 18:55:03Z parsons $
+// $Id: Sender_exec.cpp 86021 2009-07-14 12:14:35Z wotte $
 
 #include "tao/ORB_Constants.h"
 #include "tao/debug.h"
@@ -290,14 +290,14 @@ Worker::print_stats (void)
     {
       if (this->do_dump_history_)
         {
-          this->history_.dump_samples ("HISTORY", gsf);
+          this->history_.dump_samples (ACE_TEXT("HISTORY"), gsf);
         }
 
       ACE_Basic_Stats stats;
       this->history_.collect_basic_stats (stats);
-      stats.dump_results ("Total", gsf);
+      stats.dump_results (ACE_TEXT("Total"), gsf);
 
-      ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                              this->test_end_ - this->test_start_,
                                              this->iterations_);
     }
@@ -582,9 +582,7 @@ CIDL_SenderImpl::SenderExec_i::start (
   char **argv = 0;
 
   this->orb_ =
-    CORBA::ORB_init (argc,
-                     argv,
-                     "");
+    CORBA::ORB_init (argc, argv);
 
   CORBA::Object_var object =
     this->orb_->resolve_initial_references ("RTORB");
@@ -653,7 +651,7 @@ CIDL_SenderImpl::SenderExec_i::set_session_context (
   ACE_DEBUG ((LM_DEBUG, "CIDL_SenderImpl::SenderExec_i::set_session_context\n"));
 
   this->context_ =
-    CIDL_SenderImpl::SenderExec_Context::_narrow (ctx);
+    ::CIAO_Protocols_Sender_Impl::Sender_Exec_Context::_narrow (ctx);
 
   if (CORBA::is_nil (this->context_.in ()))
     throw CORBA::INTERNAL ();
@@ -679,15 +677,9 @@ CIDL_SenderImpl::SenderExec_i::ccm_remove (void)
 
 
 void
-CIDL_SenderImpl::SenderExec_i::ciao_preactivate (void)
+CIDL_SenderImpl::SenderExec_i::configuration_complete (void)
 {
-  ACE_DEBUG ((LM_DEBUG, "CIDL_SenderImpl::SenderExec_i::ccm_preactivate\n"));
-}
-
-void
-CIDL_SenderImpl::SenderExec_i::ciao_postactivate (void)
-{
-  ACE_DEBUG ((LM_DEBUG, "CIDL_SenderImpl::SenderExec_i::ccm_postactivate\n"));
+  ACE_DEBUG ((LM_DEBUG, "CIDL_SenderImpl::SenderExec_i::configuration_complete\n"));
 }
 
 ::Components::EnterpriseComponent_ptr
