@@ -1,5 +1,5 @@
 //
-//$Id: client.cc 52479 2003-09-30 14:53:14Z bala $
+//$Id: client.cc 82149 2008-06-24 12:23:39Z sma $
 //
 //FUZZ: disable check_for_missing_rir_env
 
@@ -30,7 +30,7 @@ int do_dump_history = 0;
 int niterations = 1000;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
   //parse arguments
   ACE_Get_Opt get_opts (argc, argv, "hxi:");
@@ -81,7 +81,7 @@ set_priority ()
 }
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
 
   CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
