@@ -1,5 +1,5 @@
 //
-//$Id: server.cc 52479 2003-09-30 14:53:14Z bala $
+//$Id: server.cc 82149 2008-06-24 12:23:39Z sma $
 //
 // FUZZ: disable check_for_missing_rir_env
 #include <CORBA.h>
@@ -13,7 +13,7 @@
 
 #include "RoundTrip_impl.h"
 int
-main (int argc, char *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
     CORBA::ORB_var orb = CORBA::ORB_init (argc, argv, "mico-local-orb");
 
