@@ -1,5 +1,5 @@
 /* -*- c++ -*- */
-// $Id: basic_visitor.cpp 79190 2007-08-03 07:22:10Z parsons $
+// $Id: basic_visitor.cpp 88834 2010-02-04 10:23:45Z johnnyw $
 
 #include "basic_visitor.h"
 #include "identifier_helper.h"
@@ -19,6 +19,7 @@
 #include "ast_sequence.h"
 #include "ast_string.h"
 #include "ast_structure_fwd.h"
+#include "ast_typedef.h"
 #include "ast_union.h"
 #include "ast_union_branch.h"
 #include "ast_union_fwd.h"
@@ -64,12 +65,16 @@ basic_visitor::visit_scope (UTL_Scope *node)
           continue;
         }
 
+      AST_Decl::NodeType nt = d->node_type ();
+
       // Want to skip the uses_xxxConnection structs added by uses
       // multiple ports.
       // @@@ (JP) This will go away when the visitor is finished, since
       // those uses_xxxConnection structs will not be added to the AST.
       if (ScopeAsDecl (node)->node_type () == AST_Decl::NT_component
-          && d->node_type () != AST_Decl::NT_attr)
+          && (nt == AST_Decl::NT_struct
+              || nt == AST_Decl::NT_sequence
+              || nt == AST_Decl::NT_typedef))
         {
           continue;
         }
@@ -181,7 +186,7 @@ basic_visitor::visit_valuetype (AST_ValueType *node)
       << IdentifierHelper::try_escape (node->original_local_name ()).c_str ();
 
   AST_Decl::NodeType nt = node->node_type ();
-  AST_Interface **parents = node->inherits ();
+  AST_Type **parents = node->inherits ();
   long ninherits = node->n_inherits ();
 
   long i = 0;
@@ -205,7 +210,7 @@ basic_visitor::visit_valuetype (AST_ValueType *node)
           << "Components::EventBase";
     }
 
-  AST_Interface **supports = node->supports ();
+  AST_Type **supports = node->supports ();
 
   for (i = 0; i < node->n_supports (); ++i)
     {
@@ -218,7 +223,14 @@ basic_visitor::visit_valuetype (AST_ValueType *node)
           *os << ", ";
         }
 
-      *os << IdentifierHelper::orig_sn (supports[i]->name ()).c_str ();
+      if (i == 0 && node->supports_concrete () != 0)
+        {
+          supports[i] = node->supports_concrete ();
+        }
+
+      AST_Type *supported = supports[i];
+
+      *os << IdentifierHelper::orig_sn (supported->name ()).c_str ();
     }
 
   *os << be_nl
@@ -265,14 +277,63 @@ basic_visitor::visit_valuetype_fwd (AST_ValueTypeFwd *node)
   return 0;
 }
 
+int
+basic_visitor::visit_template_module (AST_Template_Module *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_template_module_inst (AST_Template_Module_Inst *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_template_module_ref (AST_Template_Module_Ref *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_porttype (AST_PortType *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_provides (AST_Provides *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_uses (AST_Uses *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_publishes (AST_Publishes *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_emits (AST_Emits *)
+{
+  return 0;
+}
+
+int
+basic_visitor::visit_consumes (AST_Consumes *)
+{
+  return 0;
+}
+
 int
 basic_visitor::visit_factory  (AST_Factory *node)
 {
-  if (node->imported ())
-    {
-      return 0;
-    }
-
   *os << be_nl;
 
   *os << "factory "
@@ -398,7 +459,7 @@ basic_visitor::visit_enum (AST_Enum *node)
       *os << be_nl;
 
       AST_EnumVal *ev = AST_EnumVal::narrow_from_decl (i.item ());
-      
+
       *os << IdentifierHelper::try_escape (ev->original_local_name ()).c_str ();
 
       // Advance here so the check below will work.
@@ -506,7 +567,7 @@ basic_visitor::visit_union (AST_Union *node)
       << "union "
       << IdentifierHelper::try_escape (node->original_local_name ()).c_str ()
       << " switch (";
-      
+
   *os << this->type_name (node->disc_type ())
       << ")" << be_nl
       << "{" << be_idt;
@@ -770,6 +831,12 @@ basic_visitor::visit_native (AST_Native *node)
   return 0;
 }
 
+int
+basic_visitor::visit_param_holder (AST_Param_Holder *)
+{
+  return 0;
+}
+
 //========================================================
 
 void
@@ -983,24 +1050,24 @@ basic_visitor::gen_operation (AST_Operation *node)
 void
 basic_visitor::gen_attribute (AST_Attribute *node)
 {
-   bool rd_only = node->readonly ();
+  bool rd_only = node->readonly ();
 
-   // Keep output statements separate because of side effects.
-   // No need to check for anonymous array - anonymous types not
-   // accepted by parser for attributes.
-   *os << be_nl << be_nl
-       << (rd_only ? "readonly " : "") << "attribute ";
-   *os << this->type_name (node->field_type ());
-   *os << " "
-       << IdentifierHelper::try_escape (node->original_local_name ()).c_str ();
+  // Keep output statements separate because of side effects.
+  // No need to check for anonymous array - anonymous types not
+  // accepted by parser for attributes.
+  *os << be_nl << be_nl
+     << (rd_only ? "readonly " : "") << "attribute ";
+  *os << this->type_name (node->field_type ());
+  *os << " "
+     << IdentifierHelper::try_escape (node->original_local_name ()).c_str ();
 
-   this->gen_exception_list (node->get_get_exceptions (),
-                             rd_only ? "" : "get");
+  this->gen_exception_list (node->get_get_exceptions (),
+                           rd_only ? "" : "get");
 
-   this->gen_exception_list (node->get_set_exceptions (),
-                             "set");
+  this->gen_exception_list (node->get_set_exceptions (),
+                           "set");
 
-   *os << ";";
+  *os << ";";
 }
 
 void
@@ -1021,12 +1088,12 @@ basic_visitor::gen_label_value (AST_UnionLabel *node)
         {
           *os << IdentifierHelper::orig_sn (ScopeAsDecl (s)->name ()).c_str ()
               << "::";
-              
+
           Identifier *id =
             IdentifierHelper::original_local_name (val->n ()->last_component ());
 
           *os << IdentifierHelper::try_escape (id).c_str ();
-          
+
           id->destroy ();
           delete id;
           id = 0;
@@ -1057,7 +1124,7 @@ basic_visitor::gen_label_value (AST_UnionLabel *node)
       case AST_Expression::EV_ulonglong:
 #if ! defined (ACE_LACKS_LONGLONG_T)
         *os << "ACE_UINT64_LITERAL (";
-        this->os->print (ACE_UINT64_FORMAT_SPECIFIER, ev->u.ullval);
+        this->os->print (ACE_UINT64_FORMAT_SPECIFIER_ASCII, ev->u.ullval);
         *os << ")";
 #endif /* ! defined (ACE_LACKS_LONGLONG_T) */
         break;
@@ -1093,7 +1160,7 @@ basic_visitor::can_skip_module (AST_Module *m)
     {
       AST_Decl *d = si.item ();
       AST_Decl::NodeType nt = d->node_type ();
-      
+
       switch (nt)
         {
           case AST_Decl::NT_interface:
@@ -1107,20 +1174,20 @@ basic_visitor::can_skip_module (AST_Module *m)
               {
                 break;
               }
-              
+
             return false;
           case AST_Decl::NT_module:
             if (!this->can_skip_module (AST_Module::narrow_from_decl (d)))
               {
                 return false;
               }
-              
+
             break;
           default:
             break;
         }
     }
-    
+
   return true;
 }
 
@@ -1135,16 +1202,16 @@ basic_visitor::match_excluded_file (const char *raw_filename)
     {
       ACE_CString::size_type cursor = p;
       p = be_global->excluded_filenames ().find (' ', cursor);
-      
+
       ACE_CString one_filename =
         be_global->excluded_filenames ().substr (cursor, p - cursor);
-        
+
       if (one_filename == raw_filename)
         {
           return true;
         }
-        
-      // Skip the whitespace.  
+
+      // Skip the whitespace.
       if (p != ACE_CString::npos)
         {
           while (be_global->excluded_filenames ()[p] == ' ')
@@ -1153,6 +1220,6 @@ basic_visitor::match_excluded_file (const char *raw_filename)
             }
         }
     }
-    
+
   return false;
 }
