@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: be_extern.h 73108 2006-06-15 15:13:31Z parsons $
+// $Id: be_extern.h 83746 2008-11-14 14:00:59Z vzykov $
 /*
 
 COPYRIGHT
@@ -76,7 +76,7 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 extern TAO_IDL3_TO_IDL2_BE_Export BE_GlobalData *be_global;
 
-extern TAO_IDL3_TO_IDL2_BE_Export int BE_init (int &, char*[]);
+extern TAO_IDL3_TO_IDL2_BE_Export int BE_init (int &, ACE_TCHAR*[]);
 extern TAO_IDL3_TO_IDL2_BE_Export void BE_post_init (char *[], long);
 extern TAO_IDL3_TO_IDL2_BE_Export void BE_version (void);
 extern TAO_IDL3_TO_IDL2_BE_Export void BE_produce (void);
