@@ -1,5 +1,5 @@
 /* -*- c++ -*- */
-// $Id: be_global.h 78971 2007-07-20 12:15:15Z parsons $
+// $Id: be_global.h 86903 2009-10-02 18:35:46Z parsons $
 
 // ============================================================================
 //
@@ -51,10 +51,6 @@ public:
   //=======================================
 
   // Data accessors.
-
-  const char *filename (void) const;
-  void filename (char *fname);
-
   const char* output_dir (void) const;
   void output_dir (const char* s);
 
@@ -62,6 +58,8 @@ public:
 
   ACE_CString & excluded_filenames (void);
   
+  void set_excluded_filenames (const char *filenames);
+  
   bool gen_copyright (void) const;
 
   //=========================================
