@@ -1,4 +1,4 @@
-// $Id: be_init.cpp 78812 2007-07-06 12:53:13Z parsons $
+// $Id: be_init.cpp 83746 2008-11-14 14:00:59Z vzykov $
 
 #include "global_extern.h"
 #include "be_extern.h"
@@ -14,7 +14,7 @@ BE_version (void)
 }
 
 TAO_IDL3_TO_IDL2_BE_Export int
-BE_init (int & /* argc */, char * /*argv */ [])
+BE_init (int & /* argc */, ACE_TCHAR * /*argv */ [])
 {
   // Initialize BE global data object.
   ACE_NEW_RETURN (be_global,
