@@ -1,4 +1,4 @@
-// $Id: be_sunsoft.cpp 79190 2007-08-03 07:22:10Z parsons $
+// $Id: be_sunsoft.cpp 84767 2009-03-09 10:38:47Z johnnyw $
 
 #include "be_sunsoft.h"
 #include "identifier_helper.h"
@@ -14,7 +14,7 @@
 
 ACE_RCSID (be,
            be_sunsoft,
-           "$Id: be_sunsoft.cpp 79190 2007-08-03 07:22:10Z parsons $")
+           "$Id: be_sunsoft.cpp 84767 2009-03-09 10:38:47Z johnnyw $")
 
 TAO_SunSoft_OutStream::TAO_SunSoft_OutStream (void)
   : TAO_OutStream ()
@@ -30,7 +30,7 @@ TAO_SunSoft_OutStream::print (Identifier *id)
 {
   ACE_OS::fprintf (this->fp_,
                    id->get_string ());
-                   
+
   return *this;
 }
 
@@ -44,29 +44,31 @@ TAO_SunSoft_OutStream::print (AST_Expression *expr)
       switch (ev->et)
         {
         case AST_Expression::EV_short:
-          this->TAO_OutStream::print ("%hd", ev->u.sval);
+          this->TAO_OutStream::print (ACE_INT32_FORMAT_SPECIFIER_ASCII, ev->u.sval);
           break;
         case AST_Expression::EV_ushort:
-          this->TAO_OutStream::print ("%hu%c", ev->u.usval, 'U');
+          this->TAO_OutStream::print (ACE_INT32_FORMAT_SPECIFIER_ASCII "%c", ev->u.usval, 'U');
           break;
         case AST_Expression::EV_long:
-          this->TAO_OutStream::print ("%ld", ev->u.lval);
+          this->TAO_OutStream::print (ACE_INT32_FORMAT_SPECIFIER_ASCII, ev->u.lval);
           break;
         case AST_Expression::EV_ulong:
-          this->TAO_OutStream::print ("%u%c", ev->u.ulval, 'U');
+          this->TAO_OutStream::print (ACE_UINT32_FORMAT_SPECIFIER_ASCII "%c", ev->u.ulval, 'U');
           break;
+        // The ACE_LACKS_LONGLONG_T guards have been removed around
+        // the next 2 cases since the macros now used should work
+        // whether native 64-bit integers are defined or not.
         case AST_Expression::EV_longlong:
-#if ! defined (ACE_LACKS_LONGLONG_T)
-          this->TAO_OutStream::print ("%ld", ev->u.llval);
-#endif /* ! defined (ACE_LACKS_LONGLONG_T) */
+          this->TAO_OutStream::print ("ACE_INT64_LITERAL (");
+          this->TAO_OutStream::print (ACE_INT64_FORMAT_SPECIFIER_ASCII,
+                                      ev->u.llval);
+          this->TAO_OutStream::print (")");
           break;
         case AST_Expression::EV_ulonglong:
-#if ! defined (ACE_LACKS_LONGLONG_T)
           this->TAO_OutStream::print ("ACE_UINT64_LITERAL (");
-          this->TAO_OutStream::print (ACE_UINT64_FORMAT_SPECIFIER,
+          this->TAO_OutStream::print (ACE_UINT64_FORMAT_SPECIFIER_ASCII,
                                       ev->u.ullval);
           this->TAO_OutStream::print (")");
-#endif /* ! defined (ACE_LACKS_LONGLONG_T) */
           break;
         case AST_Expression::EV_float:
           this->TAO_OutStream::print ("%f%c", ev->u.fval, 'F');
