@@ -1,5 +1,5 @@
 /* -*- c++ -*- */
-// be_sunsoft.h,v 1.1 2004/08/16 00:19:16 parsons Exp
+// $Id: be_sunsoft.h 79190 2007-08-03 07:22:10Z parsons $
 
 // ============================================================================
 //
@@ -22,7 +22,7 @@
 
 #include "be_helper.h"
 
-class TAO_SunSoft_OutStream : public TAO_OutStream
+class TAO_IDL3_TO_IDL2_BE_Export TAO_SunSoft_OutStream : public TAO_OutStream
 {
   // =TITLE
   //  TAO_SunSoft_OutStream
@@ -38,10 +38,6 @@ public:
   virtual TAO_OutStream &print (Identifier *id);
   // output the SunSoft IDL Identifier Node
 
-  virtual TAO_OutStream &print (UTL_IdList *idl);
-  // output the SunSoft IDL UTL_IdList Node which is usually used to maintain a
-  // scoped name
-
   virtual TAO_OutStream &print (AST_Expression *expr);
   // output the contents of the AST_Expression node
 };
