@@ -1,24 +1,33 @@
 /* -*- c++ -*- */
-// $Id: idl3_to_idl2_visitor.cpp 79190 2007-08-03 07:22:10Z parsons $
+// $Id: idl3_to_idl2_visitor.cpp 89087 2010-02-19 15:45:52Z parsons $
 
 #include "idl3_to_idl2_visitor.h"
 #include "identifier_helper.h"
 #include "be_sunsoft.h"
 #include "be_extern.h"
 
+#include "ast_component.h"
 #include "ast_component_fwd.h"
+#include "ast_provides.h"
+#include "ast_uses.h"
+#include "ast_publishes.h"
+#include "ast_emits.h"
+#include "ast_consumes.h"
 #include "ast_eventtype.h"
 #include "ast_eventtype_fwd.h"
 #include "ast_home.h"
+#include "ast_finder.h"
 #include "ast_operation.h"
 #include "ast_root.h"
+
 #include "utl_exceptlist.h"
 #include "utl_identifier.h"
 #include "global_extern.h"
 #include "nr_extern.h"
 
 idl3_to_idl2_visitor::idl3_to_idl2_visitor (void)
-  : basic_visitor ()
+  : basic_visitor (),
+    home_ (0)
 {
 }
 
@@ -38,7 +47,7 @@ idl3_to_idl2_visitor::visit_module (AST_Module *node)
 
   ACE_CString name =
     IdentifierHelper::try_escape (node->original_local_name ());
-    
+
   *os << "module " << name.c_str () << be_nl
       << "{" << be_idt;
 
@@ -82,7 +91,7 @@ idl3_to_idl2_visitor::visit_interface (AST_Interface *node)
   *os << "interface "
       << IdentifierHelper::try_escape (node->original_local_name ()).c_str ();
 
-  AST_Interface **parents = node->inherits ();
+  AST_Type **parents = node->inherits ();
 
   for (long i = 0; i < node->n_inherits (); ++i)
     {
@@ -134,7 +143,7 @@ idl3_to_idl2_visitor::visit_component (AST_Component *node)
   long nsupports = node->n_supports ();
 
   *os << " : "
-      << (base != 0 
+      << (base != 0
             ? IdentifierHelper::orig_sn (base->name ()).c_str ()
             : "Components::CCMObject");
 
@@ -157,12 +166,6 @@ idl3_to_idl2_visitor::visit_component (AST_Component *node)
                         -1);
     }
 
-  this->gen_provides (node);
-  this->gen_uses (node);
-  this->gen_publishes (node);
-  this->gen_emits (node);
-  this->gen_consumes (node);
-
   *os << be_uidt_nl
       << "};";
 
@@ -185,6 +188,179 @@ idl3_to_idl2_visitor::visit_component_fwd (AST_ComponentFwd *node)
   return 0;
 }
 
+int
+idl3_to_idl2_visitor::visit_provides (AST_Provides *node)
+{
+  Identifier *orig_id =
+    IdentifierHelper::original_local_name (node->local_name ());
+
+  UTL_ScopedName *n = node->provides_type ()->name ();
+  ACE_CString impl_name =
+    IdentifierHelper::orig_sn (n);
+
+  *os << be_nl << be_nl
+      << impl_name.c_str () << " provide_" << orig_id << " ();";
+
+  orig_id->destroy ();
+  delete orig_id;
+  orig_id = 0;
+
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_uses (AST_Uses *node)
+{
+  *os << be_nl << be_nl;
+
+  Identifier *orig_id =
+    IdentifierHelper::original_local_name (node->local_name ());
+
+  UTL_ScopedName *n = node->uses_type ()->name ();
+  ACE_CString impl_name =
+    IdentifierHelper::orig_sn (n);
+
+  if (node->is_multiple ())
+    {
+      *os << "struct " << orig_id << "Connection" << be_nl
+          << "{" << be_idt_nl
+          << impl_name.c_str () << " objref;" << be_nl
+          << "Components::Cookie ck;" << be_uidt_nl
+          << "};" << be_nl << be_nl
+          << "typedef sequence<" << orig_id << "Connection> "
+          << orig_id << "Connections;"
+          << be_nl << be_nl
+          << "Components::Cookie connect_" << orig_id << " (in "
+          << impl_name.c_str () << " connection)" << be_idt_nl
+          << "raises (Components::ExceededConnectionLimit, "
+          << "Components::InvalidConnection);" << be_uidt_nl << be_nl
+          << impl_name.c_str () << " disconnect_" << orig_id
+          << " (in Components::Cookie ck)" << be_idt_nl
+          << "raises (Components::InvalidConnection);"
+          << be_uidt_nl << be_nl
+          << orig_id << "Connections get_connections_" << orig_id
+          << " ();";
+    }
+  else
+    {
+      *os << "void connect_" << orig_id << " (in "
+          << impl_name.c_str () << " conxn)" << be_idt_nl
+          << "raises (Components::AlreadyConnected, "
+          << "Components::InvalidConnection);" << be_uidt_nl << be_nl
+          << impl_name.c_str () << " disconnect_" << orig_id
+          << " ()" << be_idt_nl
+          << "raises (Components::NoConnection);" << be_uidt_nl << be_nl
+          << impl_name.c_str () << " get_connection_" << orig_id
+          << " ();";
+    }
+
+  orig_id->destroy ();
+  delete orig_id;
+  orig_id = 0;
+
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_publishes (AST_Publishes *node)
+{
+  Identifier *orig_id =
+    IdentifierHelper::original_local_name (node->local_name ());
+
+  UTL_ScopedName *n = node->publishes_type ()->name ();
+  ACE_CString impl_name =
+    IdentifierHelper::orig_sn (n, true);
+
+  *os << be_nl << be_nl
+      << "Components::Cookie subscribe_" << orig_id
+      << " (in "
+      << impl_name.c_str () << "Consumer consumer)"
+      << be_idt_nl
+      << "raises (Components::ExceededConnectionLimit);"
+      << be_uidt_nl << be_nl
+      << impl_name.c_str () << "Consumer unsubscribe_" << orig_id
+      << " (in Components::Cookie ck)" << be_idt_nl
+      << "raises (Components::InvalidConnection);" << be_uidt;
+
+  orig_id->destroy ();
+  delete orig_id;
+  orig_id = 0;
+
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_emits (AST_Emits *node)
+{
+  Identifier *orig_id =
+    IdentifierHelper::original_local_name (node->local_name ());
+
+  UTL_ScopedName *n = node->emits_type ()->name ();
+  ACE_CString impl_name =
+    IdentifierHelper::orig_sn (n, true);
+
+  *os << be_nl << be_nl
+      << "void connect_" << orig_id
+      << " (in "
+      << impl_name.c_str () << "Consumer consumer)" << be_idt_nl
+      << "raises (Components::AlreadyConnected);"
+      << be_uidt_nl << be_nl
+      << impl_name.c_str () << "Consumer disconnect_" << orig_id
+      << " ()" << be_idt_nl
+      << "raises (Components::NoConnection);" << be_uidt;
+
+  orig_id->destroy ();
+  delete orig_id;
+  orig_id = 0;
+
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_consumes (AST_Consumes *node)
+{
+  Identifier *orig_id =
+    IdentifierHelper::original_local_name (node->local_name ());
+
+  UTL_ScopedName *n = node->consumes_type ()->name ();
+  ACE_CString impl_name =
+    IdentifierHelper::orig_sn (n, true);
+
+  *os << be_nl << be_nl
+      << impl_name.c_str () << "Consumer get_consumer_" << orig_id
+      << " ();";
+
+  orig_id->destroy ();
+  delete orig_id;
+  orig_id = 0;
+
+ return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_extended_port (AST_Extended_Port *)
+{
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_mirror_port (AST_Mirror_Port *)
+{
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_connector (AST_Connector *)
+{
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_param_holder (AST_Param_Holder *)
+{
+  return 0;
+}
+
 int
 idl3_to_idl2_visitor::visit_eventtype (AST_EventType *node)
 {
@@ -204,7 +380,7 @@ idl3_to_idl2_visitor::visit_eventtype (AST_EventType *node)
   *os << be_nl << be_nl
       << "interface " << node->original_local_name () << "Consumer : ";
 
-  AST_Interface *parent = 0;
+  AST_Type *parent = 0;
   AST_Decl::NodeType nt = AST_Decl::NT_native;
 
   if (node->n_inherits () > 0)
@@ -264,6 +440,8 @@ idl3_to_idl2_visitor::visit_home (AST_Home *node)
     {
       return 0;
     }
+    
+  this->home_ = node;
 
   ACE_CString explicit_name = node->original_local_name ()->get_string ();
   explicit_name += "Explicit";
@@ -308,9 +486,6 @@ idl3_to_idl2_visitor::visit_home (AST_Home *node)
   // Reset the home's decls to be defined in the explicit home interface.
   this->tranfer_scope_elements (node, xplicit);
 
-  this->gen_factories (node, xplicit);
-  this->gen_finders (node, xplicit);
-
   *os << be_uidt_nl
       << "};" << be_nl << be_nl;
 
@@ -319,7 +494,7 @@ idl3_to_idl2_visitor::visit_home (AST_Home *node)
   delete sn;
   sn = 0;
 
-  AST_ValueType *key = node->primary_key ();
+  AST_Type *key = node->primary_key ();
   ACE_CString mng_name =
     IdentifierHelper::orig_sn (node->managed_component ()->name ());
   ACE_CString key_name;
@@ -334,7 +509,7 @@ idl3_to_idl2_visitor::visit_home (AST_Home *node)
     {
       key_name =
         IdentifierHelper::orig_sn (key->name ());
-        
+
       *os << "in " << key_name.c_str () << " key";
     }
 
@@ -383,6 +558,45 @@ idl3_to_idl2_visitor::visit_home (AST_Home *node)
   return 0;
 }
 
+int
+idl3_to_idl2_visitor::visit_factory (AST_Factory *node)
+{
+  Identifier *id = node->original_local_name ();
+  
+  *os << be_nl << be_nl;
+  
+  if (this->home_ == 0)
+    {
+      *os << "factory ";
+    }
+  else
+    {
+      AST_Component *c = this->home_->managed_component ();
+      
+      *os << IdentifierHelper::orig_sn (c->name ()).c_str ()
+          << " ";
+    }
+    
+  *os << IdentifierHelper::try_escape (id).c_str ()
+      << " (";
+      
+  this->gen_params (node, node->argument_count ());
+  
+  *os << ")";
+  
+  this->gen_exception_list (node->exceptions ());
+  
+  *os << ";";
+          
+  return 0;
+}
+
+int
+idl3_to_idl2_visitor::visit_finder (AST_Finder *node)
+{
+  return this->visit_factory (node);
+}
+
 int
 idl3_to_idl2_visitor::visit_root (AST_Root *node)
 {
@@ -391,7 +605,7 @@ idl3_to_idl2_visitor::visit_root (AST_Root *node)
                                         "_IDL2.idl",
                                         "_TAO_IDL_",
                                         "_IDL_");
-                                            
+
   if (status == -1)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
@@ -409,7 +623,7 @@ idl3_to_idl2_visitor::visit_root (AST_Root *node)
           *os << be_nl;
         }
 
-      ACE_CString raw_filename = idl_global->included_idl_files ()[i];    
+      ACE_CString raw_filename = idl_global->included_idl_files ()[i];
       bool excluded_file_found =
         this->match_excluded_file (raw_filename.c_str ());
 
@@ -452,187 +666,6 @@ idl3_to_idl2_visitor::visit_root (AST_Root *node)
   return 0;
 }
 
-void
-idl3_to_idl2_visitor::gen_provides (AST_Component *node)
-{
-  ACE_Unbounded_Queue<AST_Component::port_description> &s =
-    node->provides ();
-  AST_Component::port_description *pd = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Component::port_description> iter (s);
-       ! iter.done ();
-       iter.advance ())
-    {
-      iter.next (pd);
-      
-      Identifier *orig_id = IdentifierHelper::original_local_name (pd->id);
-
-      *os << be_nl << be_nl
-          << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-          << " provide_" << orig_id << " ();";
-          
-      orig_id->destroy ();
-      delete orig_id;
-      orig_id = 0;
-    }
-}
-
-void
-idl3_to_idl2_visitor::gen_uses (AST_Component *node)
-{
-  ACE_Unbounded_Queue<AST_Component::port_description> &s =
-    node->uses ();
-  AST_Component::port_description *pd = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Component::port_description> iter (s);
-       ! iter.done ();
-       iter.advance ())
-    {
-      iter.next (pd);
-
-      *os << be_nl << be_nl;
-      
-      Identifier *orig_id = IdentifierHelper::original_local_name (pd->id);
-
-      if (pd->is_multiple)
-        {
-          *os << "struct " << orig_id << "Connection" << be_nl
-              << "{" << be_idt_nl
-              << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-              << " objref;" << be_nl
-              << "Components::Cookie ck;" << be_uidt_nl
-              << "};" << be_nl << be_nl
-              << "typedef sequence<" << orig_id << "Connection> "
-              << orig_id << "Connections;"
-              << be_nl << be_nl
-              << "Components::Cookie connect_" << orig_id << " (in "
-              << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-              << " connection)" << be_idt_nl
-              << "raises (Components::ExceededConnectionLimit, "
-              << "Components::InvalidConnection);" << be_uidt_nl << be_nl
-              << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-              << " disconnect_" << orig_id
-              << " (in Components::Cookie ck)" << be_idt_nl
-              << "raises (Components::InvalidConnection);"
-              << be_uidt_nl << be_nl
-              << orig_id << "Connections get_connections_" << orig_id
-              << " ();";
-        }
-      else
-        {
-          *os << "void connect_" << orig_id << " (in "
-              << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-              << " conxn)" << be_idt_nl
-              << "raises (Components::AlreadyConnected, "
-              << "Components::InvalidConnection);" << be_uidt_nl << be_nl
-              << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-              << " disconnect_" << orig_id
-              << " ()" << be_idt_nl
-              << "raises (Components::NoConnection);" << be_uidt_nl << be_nl
-              << IdentifierHelper::orig_sn (pd->impl->name ()).c_str ()
-              << " get_connection_" << orig_id
-              << " ();";
-        }
-        
-      orig_id->destroy ();
-      delete orig_id;
-      orig_id = 0;
-    }
-}
-
-void
-idl3_to_idl2_visitor::gen_publishes (AST_Component *node)
-{
-  ACE_Unbounded_Queue<AST_Component::port_description> &s =
-    node->publishes ();
-  AST_Component::port_description *pd = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Component::port_description> iter (s);
-       ! iter.done ();
-       iter.advance ())
-    {
-      iter.next (pd);
-      
-      Identifier *orig_id = IdentifierHelper::original_local_name (pd->id);
-
-      *os << be_nl << be_nl
-          << "Components::Cookie subscribe_" << orig_id
-          << " (in "
-          << IdentifierHelper::orig_sn (pd->impl->name (), true).c_str ()
-          << "Consumer consumer)"
-          << be_idt_nl
-          << "raises (Components::ExceededConnectionLimit);"
-          << be_uidt_nl << be_nl
-          << IdentifierHelper::orig_sn (pd->impl->name (), true).c_str ()
-          << "Consumer unsubscribe_" << orig_id
-          << " (in Components::Cookie ck)" << be_idt_nl
-          << "raises (Components::InvalidConnection);" << be_uidt;
-         
-      orig_id->destroy ();
-      delete orig_id;
-      orig_id = 0;
-   }
-}
-
-void
-idl3_to_idl2_visitor::gen_emits (AST_Component *node)
-{
-  ACE_Unbounded_Queue<AST_Component::port_description> &s =
-    node->emits ();
-  AST_Component::port_description *pd = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Component::port_description> iter (s);
-       ! iter.done ();
-       iter.advance ())
-    {
-      iter.next (pd);
-
-      Identifier *orig_id = IdentifierHelper::original_local_name (pd->id);
-
-      *os << be_nl << be_nl
-          << "void connect_" << orig_id
-          << " (in "
-          << IdentifierHelper::orig_sn (pd->impl->name (), true).c_str ()
-          << "Consumer consumer)" << be_idt_nl
-          << "raises (Components::AlreadyConnected);"
-          << be_uidt_nl << be_nl
-          << IdentifierHelper::orig_sn (pd->impl->name (), true).c_str ()
-          << "Consumer disconnect_" << orig_id
-          << " ()" << be_idt_nl
-          << "raises (Components::NoConnection);" << be_uidt;
-         
-      orig_id->destroy ();
-      delete orig_id;
-      orig_id = 0;
-    }
-}
-
-void
-idl3_to_idl2_visitor::gen_consumes (AST_Component *node)
-{
-  ACE_Unbounded_Queue<AST_Component::port_description> &s =
-    node->consumes ();
-  AST_Component::port_description *pd = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Component::port_description> iter (s);
-       ! iter.done ();
-       iter.advance ())
-    {
-      iter.next (pd);
-      
-      Identifier *orig_id = IdentifierHelper::original_local_name (pd->id);
-
-      *os << be_nl << be_nl
-          << IdentifierHelper::orig_sn (pd->impl->name (), true).c_str ()
-          << "Consumer get_consumer_" << orig_id
-          << " ();";
-         
-      orig_id->destroy ();
-      delete orig_id;
-      orig_id = 0;
-    }
-}
-
 UTL_ScopedName *
 idl3_to_idl2_visitor::create_scoped_name (const char *prefix,
                                           const char *local_name,
@@ -695,80 +728,3 @@ idl3_to_idl2_visitor::tranfer_scope_elements (AST_Home *src,
         }
     }
 }
-
-void
-idl3_to_idl2_visitor::gen_factories (AST_Home *node,
-                                     AST_Interface &)
-{
-  AST_Operation **item = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Operation *> i (node->factories ());
-       ! i.done ();
-       i.advance ())
-    {
-      i.next (item);
-
-      *os << be_nl << be_nl
-          << IdentifierHelper::orig_sn (node->managed_component ()->name ()).c_str ()
-          << " "
-          << IdentifierHelper::try_escape ((*item)->original_local_name ()).c_str ()
-          << " (";
-
-      this->gen_params (*item, (*item)->argument_count ());
-
-      *os << ")";
-
-      UTL_ExceptList *exceps = (*item)->exceptions ();
-
-      if (exceps != 0 && exceps->length () > 0)
-        {
-          this->gen_exception_list (exceps, "", false);
-        }
-      else
-        {
-          *os << be_idt_nl
-              << "raises (";
-        }
-
-      *os << "Components::CreateFailure);" << be_uidt;
-    }
-}
-
-void
-idl3_to_idl2_visitor::gen_finders (AST_Home *node,
-                                   AST_Interface &)
-{
-  AST_Operation **item = 0;
-
-  for (ACE_Unbounded_Queue_Iterator<AST_Operation *> i (node->finders ());
-       ! i.done ();
-       i.advance ())
-    {
-      i.next (item);
-
-      *os << be_nl << be_nl
-          << IdentifierHelper::orig_sn (node->managed_component ()->name ()).c_str ()
-          << " "
-          << IdentifierHelper::try_escape( (*item)->original_local_name ()).c_str ()
-          << " (";
-
-      this->gen_params (*item, (*item)->argument_count ());
-
-      *os << ")";
-
-      UTL_ExceptList *exceps = (*item)->exceptions ();
-
-      if (exceps != 0 && exceps->length () > 0)
-        {
-          this->gen_exception_list (exceps, "", false);
-        }
-      else
-        {
-          *os << be_idt_nl
-              << "raises (";
-        }
-
-      *os << "Components::FinderFailure);" << be_uidt;
-    }
-}
-
