@@ -1,4 +1,4 @@
-// $Id: ast_argument.cpp 79376 2007-08-16 23:46:36Z sowayaa $
+// $Id: ast_argument.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -73,10 +73,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_argument.h"
 #include "ast_visitor.h"
 
-ACE_RCSID (ast,
-           ast_argument,
-           "$Id: ast_argument.cpp 79376 2007-08-16 23:46:36Z sowayaa $")
-
 // Static functions.
 
 // Convert an enum Direction value to a char *.
@@ -96,13 +92,8 @@ direction_to_string (AST_Argument::Direction d)
   return 0;
 }
 
-AST_Argument::AST_Argument (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Field (),
-    pd_direction (dir_IN)
-{
-}
+AST_Decl::NodeType const
+AST_Argument::NT = AST_Decl::NT_argument;
 
 AST_Argument::AST_Argument (Direction d,
                             AST_Type *ft,
@@ -145,6 +136,4 @@ AST_Argument::direction (void)
   return this->pd_direction;
 }
 
-
-
 IMPL_NARROW_FROM_DECL(AST_Argument)
