@@ -1,4 +1,4 @@
-// $Id: ast_check.cpp 76635 2007-01-26 17:07:54Z parsons $
+// $Id: ast_check.cpp 89086 2010-02-19 15:20:19Z parsons $
 
 /*
 
@@ -70,9 +70,7 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "global_extern.h"
 #include "utl_err.h"
 
-ACE_RCSID (ast,
-           ast_check,
-           "$Id: ast_check.cpp 76635 2007-01-26 17:07:54Z parsons $")
+#include "utl_scope.h"
 
 // Static storage for remembering nodes.
 static AST_Type  **ast_fwds = 0;
