@@ -1,20 +1,11 @@
-// $Id: ast_component_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_component_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 #include "ast_component_fwd.h"
 #include "ast_visitor.h"
 #include "utl_identifier.h"
 
-ACE_RCSID( ast,
-           ast_component_fwd,
-           "$Id: ast_component_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_ComponentFwd::AST_ComponentFwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_InterfaceFwd ()
-{
-}
+AST_Decl::NodeType const
+AST_ComponentFwd::NT = AST_Decl::NT_component_fwd;
 
 AST_ComponentFwd::AST_ComponentFwd (AST_Interface *dummy,
                                     UTL_ScopedName *n)
