@@ -1,4 +1,4 @@
-// $Id: ast_concrete_type.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_concrete_type.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -69,18 +69,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "ast_concrete_type.h"
 
-ACE_RCSID (ast, 
-           ast_concrete_type, 
-           "$Id: ast_concrete_type.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-// Constructor(s) and destructor.
-AST_ConcreteType::AST_ConcreteType (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type ()
-{
-}
-
 AST_ConcreteType::AST_ConcreteType (AST_Decl::NodeType nt,
                                     UTL_ScopedName *n)
   : COMMON_Base (),
@@ -101,6 +89,4 @@ AST_ConcreteType::destroy (void)
   this->AST_Type::destroy ();
 }
 
-
-
 IMPL_NARROW_FROM_DECL(AST_ConcreteType)
