@@ -1,4 +1,4 @@
-// $Id: ast_constant.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_constant.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -77,10 +77,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_generator.h"
 #include "nr_extern.h"
 
-ACE_RCSID (ast,
-           ast_constant,
-           "$Id: ast_constant.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
 // Static functions.
 
 // Convert a value from the enum AST_Expression::ExprType to a char *.
@@ -126,17 +122,8 @@ AST_Constant::exprtype_to_string (AST_Expression::ExprType et)
   return 0;
 }
 
-// Constructor(s) and destructor.
-
-// Default constructor.
-AST_Constant::AST_Constant (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    pd_constant_value (0),
-    pd_et (AST_Expression::EV_none),
-    ifr_added_ (0)
-{
-}
+AST_Decl::NodeType const
+AST_Constant::NT = AST_Decl::NT_const;
 
 // Used in constructing AST_EnumVal nodes.
 AST_Constant::AST_Constant (AST_Expression::ExprType t,
@@ -313,6 +300,4 @@ AST_Constant::enum_full_name (void)
     }
 }
 
-
-
 IMPL_NARROW_FROM_DECL(AST_Constant)
