@@ -1,4 +1,4 @@
-// $Id: ast_decl.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_decl.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -94,10 +94,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 // FUZZ: disable check_for_streams_include
 #include "ace/streams.h"
 
-ACE_RCSID (ast,
-           ast_decl,
-           "$Id: ast_decl.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
 COMMON_Base::COMMON_Base (bool local,
                           bool abstract)
   : is_local_ (local),
@@ -134,31 +130,6 @@ COMMON_Base::destroy (void)
 {
 }
 
-// Constructor(s) and destructor.
-
-AST_Decl::AST_Decl (void)
-  : COMMON_Base (),
-    repoID_ (0),
-    flat_name_ (0),
-    contains_wstring_ (-1),
-    pd_imported (false),
-    pd_in_main_file (false),
-    pd_defined_in (0),
-    pd_node_type (NT_module),
-    pd_line (-1),
-    pd_local_name (0),
-    pd_original_local_name (0),
-    pd_added (false),
-    full_name_ (0),
-    prefix_ (0),
-    version_ (0),
-    anonymous_ (false),
-    typeid_set_ (false),
-    last_referenced_as_ (0),
-    prefix_scope_ (0)
-{
-}
-
 AST_Decl::AST_Decl (NodeType nt,
                     UTL_ScopedName *n,
                     bool anonymous)
@@ -176,7 +147,6 @@ AST_Decl::AST_Decl (NodeType nt,
     pd_name (0),
     pd_local_name (n == 0 ? 0 : n->last_component ()->copy ()),
     pd_original_local_name (0),
-    pd_added (false),
     full_name_ (0),
     prefix_ (0),
     version_ (0),
@@ -656,8 +626,11 @@ AST_Decl::compute_flat_name (void)
               first = second = false;
             }
 
-          // Print the identifier.
-          item_name = i.item ()->get_string ();
+          // Print the identifier, leaving out
+          // _cxx_ prefix, if any.
+          Identifier *tmp = i.item ()->copy ();
+          idl_global->original_local_name (tmp);
+          item_name = tmp->get_string ();
           namelen += ACE_OS::strlen (item_name);
 
           if (first)
@@ -672,6 +645,10 @@ AST_Decl::compute_flat_name (void)
                   second = true;
                 }
             }
+            
+          tmp->destroy ();
+          delete tmp;
+          tmp = 0;
         }
 
       ACE_NEW (this->flat_name_,
@@ -694,8 +671,11 @@ AST_Decl::compute_flat_name (void)
               first = second = false;
             }
 
-          // Print the identifier.
-          item_name = j.item ()->get_string ();
+          // Print the identifier, leaving out
+          // _cxx_ prefix, if any.
+          Identifier *tmp = j.item ()->copy ();
+          idl_global->original_local_name (tmp);
+          item_name = tmp->get_string ();
           ACE_OS::strcat (this->flat_name_, item_name);
 
           if (first)
@@ -710,10 +690,94 @@ AST_Decl::compute_flat_name (void)
                   second = true;
                 }
             }
+
+          tmp->destroy ();
+          delete tmp;
+          tmp = 0;
         }
     }
 }
 
+const char *
+AST_Decl::node_type_to_string (NodeType nt)
+{
+  switch (nt)
+    {
+      case NT_module:
+        return "module";
+      case NT_interface:
+      case NT_interface_fwd:
+        return "interface";
+      case NT_valuetype:
+      case NT_valuetype_fwd:
+      case NT_valuebox:
+        return "valuetype";
+      case NT_const:
+        return "const";
+      case NT_except:
+        return "exception";
+      case NT_attr:
+        return "attribute";
+      case NT_union:
+      case NT_union_fwd:
+        return "union";
+      case NT_struct:
+      case NT_struct_fwd:
+        return "struct";
+      case NT_enum:
+        return "enum";
+      case NT_string:
+        return "string";
+      case NT_wstring:
+        return "wstring";
+      case NT_array:
+        return "array";
+      case NT_sequence:
+        return "sequence";
+      case NT_typedef:
+        return "typedef";
+      case NT_pre_defined:
+        return "primitive";
+      case NT_native:
+        return "native";
+      case NT_factory:
+        return "factory";
+      case NT_component:
+      case NT_component_fwd:
+        return "component";
+      case NT_home:
+        return "home";
+      case NT_eventtype:
+      case NT_eventtype_fwd:
+        return "eventtype";
+      case NT_type:
+        return "typename";
+      case NT_fixed:
+        return "fixed";
+      case NT_porttype:
+        return "porttype";
+      case NT_provides:
+        return "provides";
+      case NT_uses:
+        return "uses";
+      case NT_publishes:
+        return "publishes";
+      case NT_emits:
+        return "emits";
+      case NT_consumes:
+        return "consumes";
+      // No useful output for these.
+      case NT_enum_val:
+      case NT_field:
+      case NT_union_branch:
+      case NT_op:
+      case NT_argument:
+      case NT_root:
+      default:
+        return "";
+    }
+}
+
 // Return TRUE if one of my ancestor scopes is "s"
 // and FALSE otherwise.
 bool
@@ -1107,18 +1171,6 @@ AST_Decl::set_in_main_file (bool is_it)
   this->pd_in_main_file = is_it;
 }
 
-bool
-AST_Decl::added (void)
-{
-  return this->pd_added;
-}
-
-void
-AST_Decl::set_added (bool is_it)
-{
-  this->pd_added = is_it;
-}
-
 UTL_Scope *
 AST_Decl::defined_in (void)
 {
@@ -1345,7 +1397,7 @@ AST_Decl::original_local_name (Identifier *local_name)
                       "_cxx_")
         == local_name->get_string ())
     {
-      // CSting class is good to do this stuff.
+      // AACE_CString class is good to do this stuff.
       ACE_CString name_str (local_name->get_string ());
 
       // Remove _cxx_.
