@@ -1,4 +1,4 @@
-// $Id: ast_enum.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_enum.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -72,21 +72,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "utl_err.h"
 #include "utl_indenter.h"
 
-ACE_RCSID (ast,
-           ast_enum,
-           "$Id: ast_enum.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_Enum::AST_Enum (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    UTL_Scope (),
-    pd_enum_counter (0),
-    member_count_ (-1)
-{
-  this->size_type (AST_Type::FIXED);
-}
+AST_Decl::NodeType const
+AST_Enum::NT = AST_Decl::NT_enum;
 
 AST_Enum::AST_Enum (UTL_ScopedName *n,
                     bool local,
@@ -249,7 +236,6 @@ AST_Enum::compute_member_count (void)
   return 0;
 }
 
-// Add an AST_EnumVal node to this scope.
 AST_EnumVal *
 AST_Enum::fe_add_enum_val (AST_EnumVal *t)
 {
@@ -280,7 +266,7 @@ AST_Enum::fe_add_enum_val (AST_EnumVal *t)
     }
       
   // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
+  if ((d = this->lookup_for_add (t)) != 0)
     {
       if (!can_be_redefined (d))
         {
@@ -317,7 +303,10 @@ AST_Enum::fe_add_enum_val (AST_EnumVal *t)
                            t->local_name ());
 
   if (t1 == 0)
-    return 0;  // Prevent dereferencing null pointer in nested calls.
+    {
+      // Prevent dereferencing null pointer in nested calls.
+      return 0;
+    }
 
   // Add it to enclosing scope.
   idl_global->scopes ().next_to_top ()->fe_add_enum_val (t1);
