@@ -1,22 +1,12 @@
-// $Id: ast_eventtype_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_eventtype_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 #include "ast_eventtype_fwd.h"
 #include "ast_interface.h"
 #include "ast_visitor.h"
 #include "utl_identifier.h"
 
-ACE_RCSID( ast,
-           ast_eventtype_fwd,
-           "$Id: ast_eventtype_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_EventTypeFwd::AST_EventTypeFwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_InterfaceFwd (),
-    AST_ValueTypeFwd ()
-{
-}
+AST_Decl::NodeType const
+AST_EventTypeFwd::NT = AST_Decl::NT_eventtype_fwd;
 
 AST_EventTypeFwd::AST_EventTypeFwd (AST_Interface *dummy,
                                     UTL_ScopedName *n)
