@@ -1,4 +1,4 @@
-// $Id: ast_expression.cpp 80444 2008-01-16 19:36:00Z parsons $
+// $Id: ast_expression.cpp 88545 2010-01-14 10:42:20Z johnnyw $
 
 /*
 
@@ -68,20 +68,21 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "ast_expression.h"
 #include "ast_constant.h"
+#include "ast_typedef.h"
+#include "ast_param_holder.h"
 #include "ast_visitor.h"
-#include "global_extern.h"
+#include "ast_generator.h"
+
 #include "utl_err.h"
 #include "utl_scope.h"
 #include "utl_string.h"
+
 #include "nr_extern.h"
+#include "global_extern.h"
 
 // FUZZ: disable check_for_streams_include
 #include "ace/streams.h"
 
-ACE_RCSID (ast,
-           ast_expression,
-           "$Id: ast_expression.cpp 80444 2008-01-16 19:36:00Z parsons $")
-
 // Helper function to fill out the details of where this expression
 // is defined.
 void
@@ -94,8 +95,6 @@ AST_Expression::fill_definition_details (void)
   this->pd_file_name = idl_global->filename ();
 }
 
-// Constructor(s) and destructor.
-
 // An AST_Expression denoting a symbolic name.
 AST_Expression::AST_Expression (UTL_ScopedName *nm)
   : pd_ec (EC_symbol),
@@ -103,9 +102,20 @@ AST_Expression::AST_Expression (UTL_ScopedName *nm)
     pd_v1 (0),
     pd_v2 (0),
     pd_n (nm),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
+  
+  AST_Decl *d =
+    idl_global->scopes ().top_non_null ()->lookup_by_name (nm,
+                                                           true);
+  
+  if (d->node_type () == AST_Decl::NT_param_holder)
+    {
+      this->param_holder_ =
+        AST_Param_Holder::narrow_from_decl (d);
+    }
 }
 
 // An AST_Expression denoting a type coercion from another AST_Expression.
@@ -116,10 +126,12 @@ AST_Expression::AST_Expression (AST_Expression *v,
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
+  AST_Param_Holder *ph = v->param_holder_;
   this->fill_definition_details ();
-  
+
   // If we are here because one string constant has
   // another one as its rhs, we must copy the UTL_String
   // so both can be destroyed at cleanup.
@@ -127,7 +139,7 @@ AST_Expression::AST_Expression (AST_Expression *v,
     {
       ACE_NEW (this->pd_ev,
               AST_ExprValue);
-               
+
       ACE_NEW (this->pd_ev->u.strval,
                UTL_String (v->pd_ev->u.strval));
 
@@ -137,20 +149,31 @@ AST_Expression::AST_Expression (AST_Expression *v,
     {
       ACE_NEW (this->pd_ev,
               AST_ExprValue);
-               
+
       this->pd_ev->u.wstrval = ACE::strnew (v->pd_ev->u.wstrval);
       this->pd_ev->et = EV_string;
     }
   else
     {
-      this->pd_ev = v->coerce (t);
-
-      if (this->pd_ev == 0)
+      if (ph == 0)
         {
-          idl_global->err ()->coercion_error (v,
-                                              t);
+          this->pd_ev = v->coerce (t);
+
+          if (this->pd_ev == 0)
+            {
+              idl_global->err ()->coercion_error (v, t);
+            }
         }
-        
+      else
+        {
+          // The param info member isn't managed by this type,
+          // so we can just pass the pointer to the new expr.
+          this->param_holder_ =
+            idl_global->gen ()->create_param_holder (
+              ph->name (),
+              const_cast<FE_Utils::T_Param_Info *> (ph->info ()));
+        }
+
       if (0 != v->pd_n)
         {
           this->pd_n =
@@ -169,19 +192,21 @@ AST_Expression::AST_Expression (ExprComb c,
     pd_v1 (ev1),
     pd_v2 (ev2),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 }
 
 // An AST_Expression denoting a short integer.
-AST_Expression::AST_Expression (short sv)
+AST_Expression::AST_Expression (ACE_CDR::Short sv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -193,13 +218,14 @@ AST_Expression::AST_Expression (short sv)
 }
 
 // An AST_Expression denoting an unsigned short integer.
-AST_Expression::AST_Expression (unsigned short usv)
+AST_Expression::AST_Expression (ACE_CDR::UShort usv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -211,13 +237,14 @@ AST_Expression::AST_Expression (unsigned short usv)
 }
 
 // An AST_Expression denoting a long integer.
-AST_Expression::AST_Expression (long lv)
+AST_Expression::AST_Expression (ACE_CDR::Long lv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -229,13 +256,14 @@ AST_Expression::AST_Expression (long lv)
 }
 
 // An AST_Expression denoting a boolean.
-AST_Expression::AST_Expression (bool b)
+AST_Expression::AST_Expression (ACE_CDR::Boolean b)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -247,13 +275,14 @@ AST_Expression::AST_Expression (bool b)
 }
 
 // An AST_Expression denoting an unsigned long integer.
-AST_Expression::AST_Expression (unsigned long ulv)
+AST_Expression::AST_Expression (ACE_CDR::ULong ulv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -265,14 +294,15 @@ AST_Expression::AST_Expression (unsigned long ulv)
 }
 
 // An AST_Expression denoting an unsigned long integer.
-AST_Expression::AST_Expression (idl_uns_long ulv,
+AST_Expression::AST_Expression (ACE_CDR::ULong ulv,
                                 ExprType t)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -288,13 +318,14 @@ AST_Expression::AST_Expression (idl_uns_long ulv,
 }
 
 // An AST_Expression denoting a 32-bit floating point number.
-AST_Expression::AST_Expression (float fv)
+AST_Expression::AST_Expression (ACE_CDR::Float fv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -306,13 +337,14 @@ AST_Expression::AST_Expression (float fv)
 }
 
 // An AST_Expression denoting a 64-bit floating point number.
-AST_Expression::AST_Expression (double dv)
+AST_Expression::AST_Expression (ACE_CDR::Double dv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -324,13 +356,14 @@ AST_Expression::AST_Expression (double dv)
 }
 
 // An AST_Expression denoting a character.
-AST_Expression::AST_Expression (char cv)
+AST_Expression::AST_Expression (ACE_CDR::Char cv)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -348,7 +381,8 @@ AST_Expression::AST_Expression (ACE_OutputCDR::from_wchar wcv)
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -360,13 +394,14 @@ AST_Expression::AST_Expression (ACE_OutputCDR::from_wchar wcv)
 }
 
 // An AST_Expression denoting an octet (unsigned char).
-AST_Expression::AST_Expression (unsigned char ov)
+AST_Expression::AST_Expression (ACE_CDR::Octet ov)
   : pd_ec (EC_none),
     pd_ev (0),
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -384,13 +419,14 @@ AST_Expression::AST_Expression (UTL_String *sv)
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
   ACE_NEW (this->pd_ev,
            AST_ExprValue);
-           
+
   UTL_String *new_str = 0;
   ACE_NEW (new_str,
            UTL_String (sv));
@@ -406,7 +442,8 @@ AST_Expression::AST_Expression (char *sv)
     pd_v1 (0),
     pd_v2 (0),
     pd_n (0),
-    tdef (0)
+    tdef (0),
+    param_holder_ (0)
 {
   this->fill_definition_details ();
 
@@ -2479,6 +2516,14 @@ AST_Expression::eval_symbol (AST_Expression::EvalKind ek)
       idl_global->err ()->lookup_error (this->pd_n);
       return 0;
     }
+    
+  // If we are a template parameter placeholder, just skip the
+  // rest - nothing needs to be evaluated until instantiation
+  // time.  
+  if (this->param_holder_ != 0)
+    {
+      return 0;
+    }
 
   // Do lookup.
   d = s->lookup_by_name (this->pd_n,
@@ -2712,8 +2757,7 @@ AST_Expression::coerce (AST_Expression::ExprType t)
     }
   else
     {
-      return coerce_value (copy,
-                           t);
+      return coerce_value (copy, t);
     }
 }
 
@@ -2776,6 +2820,15 @@ AST_Expression::evaluate (EvalKind ek)
   AST_ExprValue *tmp = eval_kind (this->pd_ev, ek);
   delete this->pd_ev;
   this->pd_ev = tmp;
+  
+  // Artifact of expressions doing double duty for all template
+  // args. At this point, we have knowledge that we must be an
+  // enum constant, so we set the expression type here, rather
+  // than at the point of creation.
+  if (ek == AST_Expression::EK_const && this->pd_n != 0)
+    {
+      this->pd_ev->et = AST_Expression::EV_enum;
+    }
 }
 
 // Expression equality comparison operator.
@@ -2965,6 +3018,12 @@ AST_Expression::get_tdef (void) const
   return this->tdef;
 }
 
+AST_Param_Holder *
+AST_Expression::param_holder (void) const
+{
+  return this->param_holder_;
+}
+
 // Helper functions for expression dumpers.
 
 // Dump this binary AST_Expression node to the ostream o.
@@ -3200,14 +3259,21 @@ AST_Expression::destroy (void)
 
   delete this->pd_v2;
   this->pd_v2 = 0;
-  
+
   if (this->pd_n != 0)
     {
       this->pd_n->destroy ();
     }
-    
+
   delete this->pd_n;
   this->pd_n = 0;
+  
+  if (this->param_holder_ != 0)
+    {
+      this->param_holder_->destroy ();
+      delete this->param_holder_;
+      this->param_holder_ = 0;
+    }
 }
 
 // Data accessors.
