@@ -1,4 +1,4 @@
-// $Id: ast_factory.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_factory.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -64,7 +64,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 */
 
-// AST_Factory nodes denote OBV factory construct declarations
+// AST_Factory nodes denote OBV or component home factory
+// construct declarations.
 // AST_Factory is a subclass of AST_Decl (it is not a type!)
 // and of UTL_Scope (the arguments are managed in a scope).
 
@@ -78,24 +79,12 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "utl_exceptlist.h"
 #include "utl_namelist.h"
 
-ACE_RCSID (ast,
-           ast_factory,
-           "$Id: ast_factory.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_Factory::AST_Factory (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    UTL_Scope (),
-    pd_exceptions (0),
-    pd_n_exceptions (0),
-    argument_count_ (-1),
-    has_native_ (0)
-{
-}
+AST_Decl::NodeType const
+AST_Factory::NT = AST_Decl::NT_factory;
 
 AST_Factory::AST_Factory (UTL_ScopedName *n)
-  : COMMON_Base (1,
-                 0), //@@ Always local, never abstract
+  : COMMON_Base (true,
+                 false), //@@ Always local, never abstract
     AST_Decl (AST_Decl::NT_factory,
               n),
     UTL_Scope (AST_Decl::NT_factory),
@@ -155,6 +144,23 @@ AST_Factory::destroy (void)
   this->UTL_Scope::destroy ();
 }
 
+UTL_ExceptList *
+AST_Factory::be_add_exceptions (UTL_ExceptList *t)
+{
+  if (this->pd_exceptions != 0)
+    {
+      idl_global->err ()->error1 (UTL_Error::EIDL_ILLEGAL_RAISES,
+                                  this);
+    }
+  else
+    {
+      this->pd_exceptions = t;
+      this->pd_n_exceptions = (t == 0 ? 0 : t->length ());
+    }
+
+  return this->pd_exceptions;
+}
+
 // Private operations.
 
 // Compute total number of members.
@@ -201,99 +207,60 @@ AST_Factory::compute_argument_attr (void)
   return 0;
 }
 
-// Add this AST_Argument node (an factory argument declaration)
-// to this scope.
 AST_Argument *
 AST_Factory::fe_add_argument (AST_Argument *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = lookup_by_name_local (t->local_name(), 0)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to scope.
-  this->add_to_scope (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_Argument::narrow_from_decl (
+      this->fe_add_ref_decl (t));
 }
 
 UTL_NameList *
 AST_Factory::fe_add_exceptions (UTL_NameList *t)
 {
   UTL_ScopedName *nl_n = 0;
-  AST_Exception *fe = 0;
+  AST_Type *fe = 0;
   AST_Decl *d = 0;
 
   this->pd_exceptions = 0;
 
-  for (UTL_NamelistActiveIterator nl_i (t); !nl_i.is_done (); nl_i.next ())
+  for (UTL_NamelistActiveIterator nl_i (t);
+       !nl_i.is_done ();
+       nl_i.next ())
     {
       nl_n = nl_i.item ();
 
-      d = this->lookup_by_name (nl_n,
-                                true);
+      d = this->defined_in ()->lookup_by_name (nl_n, true);
 
-      if (d == 0 || d->node_type() != AST_Decl::NT_except)
+      if (d == 0)
         {
           idl_global->err ()->lookup_error (nl_n);
           return 0;
         }
+        
+      AST_Decl::NodeType nt = d->node_type ();
 
-      fe = AST_Exception::narrow_from_decl (d);
-
-      if (fe == 0)
+      if (nt != AST_Decl::NT_except
+          && nt != AST_Decl::NT_param_holder)
         {
           idl_global->err ()->error1 (UTL_Error::EIDL_ILLEGAL_RAISES,
                                       this);
           return 0;
         }
 
+      fe = AST_Type::narrow_from_decl (d);
+
+      UTL_ExceptList *el = 0;
+      ACE_NEW_RETURN (el,
+                      UTL_ExceptList (fe, 0),
+                      0);
+
       if (this->pd_exceptions == 0)
         {
-          ACE_NEW_RETURN (this->pd_exceptions,
-                          UTL_ExceptList (fe,
-                                          0),
-                          0);
+          this->pd_exceptions = el;
         }
       else
         {
-          UTL_ExceptList *el = 0;
-          ACE_NEW_RETURN (el,
-                          UTL_ExceptList (fe,
-                                          0),
-                          0);
-
           this->pd_exceptions->nconc (el);
         }
 
@@ -306,10 +273,11 @@ AST_Factory::fe_add_exceptions (UTL_NameList *t)
   t->destroy ();
   delete t;
   t = 0;
+  
   return t;
 }
 
-// Dump this AST_Factory node (an OBV factory construct) to the ostream o.
+// Dump this AST_Factory node to the ostream o.
 void
 AST_Factory::dump (ACE_OSTREAM_TYPE &o)
 {
@@ -321,7 +289,7 @@ AST_Factory::dump (ACE_OSTREAM_TYPE &o)
 
   // Iterator must be explicitly advanced inside the loop.
   for (UTL_ScopeActiveIterator i (this, IK_decls);
-       !i.is_done();)
+       !i.is_done ();)
     {
       d = i.item ();
       d->dump (o);
@@ -334,7 +302,6 @@ AST_Factory::dump (ACE_OSTREAM_TYPE &o)
     }
 
   this->dump_i (o, ")");
-
 }
 
 int
@@ -343,9 +310,6 @@ AST_Factory::ast_accept (ast_visitor *visitor)
   return visitor->visit_factory (this);
 }
 
-// Data accessors
-
-
-
 IMPL_NARROW_FROM_DECL(AST_Factory)
 IMPL_NARROW_FROM_SCOPE(AST_Factory)
+
