@@ -1,4 +1,4 @@
-// $Id: ast_generator.cpp 73110 2006-06-15 18:56:10Z parsons $
+// $Id: ast_generator.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 
 /*
 
@@ -79,6 +79,17 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_component.h"
 #include "ast_component_fwd.h"
 #include "ast_home.h"
+#include "ast_mirror_port.h"
+#include "ast_connector.h"
+#include "ast_template_module.h"
+#include "ast_template_module_inst.h"
+#include "ast_template_module_ref.h"
+#include "ast_param_holder.h"
+#include "ast_provides.h"
+#include "ast_uses.h"
+#include "ast_publishes.h"
+#include "ast_emits.h"
+#include "ast_consumes.h"
 #include "ast_exception.h"
 #include "ast_enum.h"
 #include "ast_attribute.h"
@@ -90,18 +101,18 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_sequence.h"
 #include "ast_string.h"
 #include "ast_structure_fwd.h"
+#include "ast_typedef.h"
 #include "ast_native.h"
 #include "ast_factory.h"
+#include "ast_finder.h"
+
 #include "utl_identifier.h"
+
 #include "nr_extern.h"
 #include "ace/OS_NS_wchar.h"
 
 #include "ast_generator.h"
 
-ACE_RCSID (ast,
-           ast_generator,
-           "$Id: ast_generator.cpp 73110 2006-06-15 18:56:10Z parsons $")
-
 AST_PredefinedType *
 AST_Generator::create_predefined_type (AST_PredefinedType::PredefinedType t,
                                        UTL_ScopedName *n)
@@ -119,7 +130,7 @@ AST_Module *
 AST_Generator::create_module (UTL_Scope *s,
                               UTL_ScopedName *n)
 {
- // We create this first so if we find a module with the
+  // We create this first so if we find a module with the
   // same name from an included file, we can add its
   // members to the new module's scope.
   AST_Module *retval = 0;
@@ -127,57 +138,59 @@ AST_Generator::create_module (UTL_Scope *s,
                   AST_Module (n),
                   0);
 
-  AST_Decl *d = 0;
   AST_Module *m = 0;
 
-  UTL_ScopeActiveIterator iter (s,
-                                UTL_Scope::IK_decls);
-
   // Check for another module of the same name in this scope.
-  while (!iter.is_done ())
+  for (UTL_ScopeActiveIterator iter (s, UTL_Scope::IK_decls);
+       !iter.is_done ();
+       iter.next ())
     {
-      d = iter.item ();
+      // Can't just check node type here, since it could be a
+      // template module or template module instantiation.
+      m = AST_Module::narrow_from_decl (iter.item ());
 
-      if (d->node_type () == AST_Decl::NT_module)
+      if (m != 0)
         {
           // Does it have the same name as the one we're
           // supposed to create.
-          if (d->local_name ()->compare (n->last_component ()))
+          if (m->local_name ()->compare (n->last_component ()))
             {
-              m = AST_Module::narrow_from_decl (d);
-
               // Get m's previous_ member, plus all it's decls,
               // into the new modules's previous_ member.
               retval->add_to_previous (m);
+              retval->prefix (const_cast<char *> (m->prefix ()));
             }
         }
-
-      iter.next ();
     }
 
   // If this scope is itself a module, and has been previously
   // opened, the previous opening may contain a previous opening
   // of the module we're creating.
-  d = ScopeAsDecl (s);
+  AST_Decl *d = ScopeAsDecl (s);
   AST_Decl::NodeType nt = d->node_type ();
 
   if (nt == AST_Decl::NT_module || nt == AST_Decl::NT_root)
     {
+      // Also check this to week out a template module or its
+      // instantiation.
       m = AST_Module::narrow_from_decl (d);
 
-      // AST_Module::previous_ is a set, so it contains each
-      // entry only once, but previous_ will contain the decls
-      // from all previous openings. See comment in
-      // AST_Module::add_to_previous() body.
-      d = m->look_in_previous (n->last_component ());
-
-      if (d != 0)
+      if (m != 0)
         {
-          if (d->node_type () == AST_Decl::NT_module)
-            {
-              m = AST_Module::narrow_from_decl (d);
+          // AST_Module::previous_ is a set, so it contains each
+          // entry only once, but previous_ will contain the decls
+          // from all previous openings. See comment in
+          // AST_Module::add_to_previous() body.
+          d = m->look_in_previous (n->last_component ());
 
-              retval->add_to_previous (m);
+          if (d != 0)
+            {
+              if (d->node_type () == AST_Decl::NT_module)
+                {
+                  m = AST_Module::narrow_from_decl (d);
+
+                  retval->add_to_previous (m);
+                }
             }
         }
     }
@@ -198,7 +211,7 @@ AST_Generator::create_root (UTL_ScopedName *n)
 
 AST_Interface *
 AST_Generator::create_interface (UTL_ScopedName *n,
-                                 AST_Interface **inherits,
+                                 AST_Type **inherits,
                                  long n_inherits,
                                  AST_Interface **inherits_flat,
                                  long n_inherits_flat,
@@ -244,14 +257,14 @@ AST_Generator::create_interface_fwd (UTL_ScopedName *n,
 
 AST_ValueType *
 AST_Generator::create_valuetype (UTL_ScopedName *n,
-                                 AST_Interface **inherits,
+                                 AST_Type **inherits,
                                  long n_inherits,
-                                 AST_ValueType *inherits_concrete,
+                                 AST_Type *inherits_concrete,
                                  AST_Interface **inherits_flat,
                                  long n_inherits_flat,
-                                 AST_Interface **supports_list,
+                                 AST_Type **supports_list,
                                  long n_supports,
-                                 AST_Interface *supports_concrete,
+                                 AST_Type *supports_concrete,
                                  bool is_abstract,
                                  bool is_truncatable,
                                  bool is_custom)
@@ -312,14 +325,14 @@ AST_Generator::create_valuetype_fwd (UTL_ScopedName *n,
 
 AST_EventType *
 AST_Generator::create_eventtype (UTL_ScopedName *n,
-                                 AST_Interface **inherits,
+                                 AST_Type **inherits,
                                  long n_inherits,
-                                 AST_ValueType *inherits_concrete,
+                                 AST_Type *inherits_concrete,
                                  AST_Interface **inherits_flat,
                                  long n_inherits_flat,
-                                 AST_Interface **supports_list,
+                                 AST_Type **supports_list,
                                  long n_supports,
-                                 AST_Interface *supports_concrete,
+                                 AST_Type *supports_concrete,
                                  bool is_abstract,
                                  bool is_truncatable,
                                  bool is_custom)
@@ -381,7 +394,7 @@ AST_Generator::create_eventtype_fwd (UTL_ScopedName *n,
 AST_Component *
 AST_Generator::create_component (UTL_ScopedName *n,
                                  AST_Component *base_component,
-                                 AST_Interface **supports_list,
+                                 AST_Type **supports_list,
                                  long n_supports,
                                  AST_Interface **supports_flat,
                                  long n_supports_flat)
@@ -423,8 +436,8 @@ AST_Home *
 AST_Generator::create_home (UTL_ScopedName *n,
                             AST_Home *base_home,
                             AST_Component *managed_component,
-                            AST_ValueType *primary_key,
-                            AST_Interface **supports_list,
+                            AST_Type *primary_key,
+                            AST_Type **supports_list,
                             long n_supports,
                             AST_Interface **supports_flat,
                             long n_supports_flat)
@@ -690,7 +703,7 @@ AST_Generator::create_expr (AST_Expression::ExprComb c,
 }
 
 AST_Expression *
-AST_Generator::create_expr (long v)
+AST_Generator::create_expr (ACE_CDR::Long v)
 {
   AST_Expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -701,7 +714,7 @@ AST_Generator::create_expr (long v)
 }
 
 AST_Expression *
-AST_Generator::create_expr (bool b)
+AST_Generator::create_expr (ACE_CDR::Boolean b)
 {
   AST_Expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -712,7 +725,7 @@ AST_Generator::create_expr (bool b)
 }
 
 AST_Expression *
-AST_Generator::create_expr (idl_uns_long v,
+AST_Generator::create_expr (ACE_CDR::ULong v,
                             AST_Expression::ExprType t)
 {
   AST_Expression *retval = 0;
@@ -736,7 +749,7 @@ AST_Generator::create_expr (UTL_String *s)
 }
 
 AST_Expression *
-AST_Generator::create_expr (char c)
+AST_Generator::create_expr (ACE_CDR::Char c)
 {
   AST_Expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -769,7 +782,7 @@ AST_Generator::create_expr (char *s)
 }
 
 AST_Expression *
-AST_Generator::create_expr (double d)
+AST_Generator::create_expr (ACE_CDR::Double d)
 {
   AST_Expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -780,7 +793,7 @@ AST_Generator::create_expr (double d)
 }
 
 AST_EnumVal *
-AST_Generator::create_enum_val (unsigned long v,
+AST_Generator::create_enum_val (ACE_CDR::ULong v,
                                 UTL_ScopedName *n)
 {
   AST_EnumVal *retval = 0;
@@ -794,7 +807,7 @@ AST_Generator::create_enum_val (unsigned long v,
 
 AST_Array *
 AST_Generator::create_array (UTL_ScopedName *n,
-                             unsigned long ndims,
+                             ACE_CDR::ULong ndims,
                              UTL_ExprList *dims,
                              bool is_local,
                              bool is_abstract)
@@ -909,6 +922,17 @@ AST_Generator::create_factory (UTL_ScopedName *n)
   return retval;
 }
 
+AST_Finder *
+AST_Generator::create_finder (UTL_ScopedName *n)
+{
+  AST_Finder *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Finder (n),
+                  0);
+
+  return retval;
+}
+
 AST_ValueBox *
 AST_Generator::create_valuebox (UTL_ScopedName *n,
                                 AST_Type *boxed_type)
@@ -920,3 +944,183 @@ AST_Generator::create_valuebox (UTL_ScopedName *n,
 
   return retval;
 }
+
+AST_PortType *
+AST_Generator::create_porttype (UTL_ScopedName *n)
+{
+  AST_PortType *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_PortType (n),
+                  0);
+
+  return retval;
+}
+
+AST_Provides *
+AST_Generator::create_provides (UTL_ScopedName *n,
+                                AST_Type *provides_type)
+{
+  AST_Provides *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Provides (n,
+                                provides_type),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Uses *
+AST_Generator::create_uses (UTL_ScopedName *n,
+                            AST_Type *uses_type,
+                            bool is_multiple)
+{
+  AST_Uses *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Uses (n,
+                            uses_type,
+                            is_multiple),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Publishes *
+AST_Generator::create_publishes (UTL_ScopedName *n,
+                                 AST_Type *publishes_type)
+{
+  AST_Publishes *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Publishes (n,
+                                 publishes_type),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Emits *
+AST_Generator::create_emits (UTL_ScopedName *n,
+                             AST_Type *emits_type)
+{
+  AST_Emits *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Emits (n,
+                             emits_type),
+                  0);
+                  
+  return retval;              
+}
+AST_Consumes *
+AST_Generator::create_consumes (UTL_ScopedName *n,
+                                AST_Type *consumes_type)
+{
+  AST_Consumes *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Consumes (n,
+                                consumes_type),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Extended_Port *
+AST_Generator::create_extended_port (
+  UTL_ScopedName *n,
+  AST_PortType *porttype_ref)
+{
+  AST_Extended_Port *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Extended_Port (n,
+                                     porttype_ref),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Mirror_Port *
+AST_Generator::create_mirror_port (
+  UTL_ScopedName *n,
+  AST_PortType *porttype_ref)
+{
+  AST_Mirror_Port *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Mirror_Port (n,
+                                   porttype_ref),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Connector *
+AST_Generator::create_connector (
+  UTL_ScopedName *n,
+  AST_Connector *base_connector)
+{
+  AST_Connector *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Connector (n,
+                                 base_connector),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Template_Module *
+AST_Generator::create_template_module (
+  UTL_ScopedName *n,
+  FE_Utils::T_PARAMLIST_INFO *template_params)
+{
+  AST_Template_Module *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Template_Module (n,
+                                       template_params),
+                  0);
+                  
+  return retval;
+}
+  
+AST_Template_Module_Inst *
+AST_Generator::create_template_module_inst (
+  UTL_ScopedName *n,
+  AST_Template_Module *ref,
+  FE_Utils::T_ARGLIST *template_args)
+{
+  AST_Template_Module_Inst *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Template_Module_Inst (n,
+                                            ref,
+                                            template_args),
+                  0);
+                  
+  return retval;
+}
+  
+AST_Template_Module_Ref *
+AST_Generator::create_template_module_ref (
+  UTL_ScopedName *n,
+  AST_Template_Module *ref,
+  UTL_StrList *param_refs)
+{
+  AST_Template_Module_Ref *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Template_Module_Ref (n,
+                                           ref,
+                                           param_refs),
+                  0);
+                  
+  return retval;
+}
+    
+AST_Param_Holder *
+AST_Generator::create_param_holder (
+  UTL_ScopedName *parameter_name,
+  FE_Utils::T_Param_Info *info)
+{
+  AST_Param_Holder *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  AST_Param_Holder (parameter_name,
+                                    info),
+                  0);
+                  
+  return retval;
+}
+
