@@ -1,4 +1,4 @@
-// $Id: ast_interface_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_interface_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -75,18 +75,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_visitor.h"
 #include "utl_identifier.h"
 
-ACE_RCSID( ast,
-           ast_interface_fwd,
-           "$Id: ast_interface_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_InterfaceFwd::AST_InterfaceFwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    pd_full_definition (0),
-    is_defined_ (false)
-{
-}
+AST_Decl::NodeType const
+AST_InterfaceFwd::NT = AST_Decl::NT_interface_fwd;
 
 AST_InterfaceFwd::AST_InterfaceFwd (AST_Interface *dummy,
                                     UTL_ScopedName *n)
@@ -249,7 +239,7 @@ AST_InterfaceFwd::is_defined (void)
               // is a sufficient way to tell if our full
               // definition has already gone through the
               // add_to_scope process.
-              if (0 != fwd && fwd->full_definition ()->added ())
+              if (0 != fwd && fwd->is_defined ())
                 {
                   this->is_defined_ = true;
                 }
