@@ -1,4 +1,4 @@
-// $Id: ast_predefined_type.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_predefined_type.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -78,18 +78,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ace/Log_Msg.h"
 #include "ace/OS_NS_stdio.h"
 
-ACE_RCSID (ast,
-           ast_predefined_type,
-           "$Id: ast_predefined_type.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_PredefinedType::AST_PredefinedType (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    pd_pt (PT_long)
-{
-}
+AST_Decl::NodeType const
+AST_PredefinedType::NT = AST_Decl::NT_pre_defined;
 
 AST_PredefinedType::AST_PredefinedType (PredefinedType t,
                                         UTL_ScopedName *n)
