@@ -1,4 +1,4 @@
-// $Id: ast_string.cpp 79376 2007-08-16 23:46:36Z sowayaa $
+// $Id: ast_string.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -78,21 +78,9 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "idl_defines.h"
 #include "global_extern.h"
 
-ACE_RCSID (ast,
-           ast_string,
-           "$Id: ast_string.cpp 79376 2007-08-16 23:46:36Z sowayaa $")
-
-AST_String::AST_String (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    pd_max_size (0),
-    pd_width (sizeof (char))
-{
-  // Always the case.
-  this->size_type (AST_Type::VARIABLE);
-}
+// Note we are overlooking the wstring case here.
+AST_Decl::NodeType const
+AST_String::NT = AST_Decl::NT_string;
 
 AST_String::AST_String (AST_Decl::NodeType nt,
                         UTL_ScopedName *n,
@@ -111,20 +99,28 @@ AST_String::AST_String (AST_Decl::NodeType nt,
   Identifier *id = 0;
   UTL_ScopedName *new_name = 0;
   UTL_ScopedName *conc_name = 0;
+  bool narrow = this->width () == sizeof (char);
 
   ACE_NEW (id,
-           Identifier (this->width () == 1 ? "Char *" : "WChar *"));
+           Identifier (narrow ? "char *" : "WChar *"));
 
   ACE_NEW (conc_name,
            UTL_ScopedName (id,
                            0));
 
-  ACE_NEW (id,
-           Identifier ("CORBA"));
+  if (narrow)
+    {
+      new_name = conc_name;
+    }
+  else
+    {
+      ACE_NEW (id,
+               Identifier ("CORBA"));
 
-  ACE_NEW (new_name,
-           UTL_ScopedName (id,
-                           conc_name));
+      ACE_NEW (new_name,
+               UTL_ScopedName (id,
+                               conc_name));
+    }
 
   this->set_name (new_name);
 
