@@ -1,4 +1,4 @@
-// $Id: ast_structure.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_structure.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -73,27 +73,13 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_field.h"
 #include "ast_enum.h"
 #include "ast_enum_val.h"
+#include "ast_typedef.h"
 #include "ast_visitor.h"
+
 #include "utl_string.h"
 #include "utl_err.h"
 #include "utl_indenter.h"
 
-ACE_RCSID (ast,
-           ast_structure,
-           "$Id: ast_structure.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_Structure::AST_Structure (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    UTL_Scope (),
-    member_count_ (-1),
-    local_struct_ (-1),
-    fwd_decl_ (0)
-{
-}
-
 AST_Structure::AST_Structure (UTL_ScopedName *n,
                               bool local,
                               bool abstract)
@@ -198,7 +184,6 @@ AST_Structure::in_recursion (ACE_Unbounded_Queue<AST_Type *> &list)
   return this->in_recursion_;
 }
 
-// Return the member count.
 int
 AST_Structure::member_count (void)
 {
@@ -210,7 +195,7 @@ AST_Structure::member_count (void)
   return this->member_count_;
 }
 
-size_t
+ACE_CDR::ULong
 AST_Structure::nfields (void) const
 {
   return this->fields_.size ();
@@ -218,10 +203,9 @@ AST_Structure::nfields (void) const
 
 int
 AST_Structure::field (AST_Field **&result,
-                      size_t slot) const
+                      ACE_CDR::ULong slot) const
 {
-  return this->fields_.get (result,
-                            slot);
+  return this->fields_.get (result, slot);
 }
 
 bool
@@ -326,202 +310,40 @@ AST_Structure::fwd_decl (AST_StructureFwd *node)
   this->fwd_decl_ = node;
 }
 
+ACE_Unbounded_Queue<AST_Field *> &
+AST_Structure::fields (void)
+{
+  return this->fields_;
+}
+
 // Private operations.
 
-// Add this AST_Field node (a field declaration) to this scope.
 AST_Field *
 AST_Structure::fe_add_field (AST_Field *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to scope.
-  this->add_to_scope (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  AST_Type *ft = t->field_type ();
-  UTL_ScopedName *mru = ft->last_referenced_as ();
-
-  if (mru != 0)
-    {
-      this->add_to_referenced (ft,
-                               false,
-                               mru->first_component ());
-    }
-
-  this->fields_.enqueue_tail (t);
-
-  return t;
+  return this->fe_add_ref_decl (t);
 }
 
-// Add an AST_Structure node (a manifest struct type) to this scope.
 AST_Structure *
 AST_Structure::fe_add_structure (AST_Structure *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to local types.
-  this->add_to_local_types (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return this->fe_add_full_struct_type (t);
 }
 
-// Add an AST_Union node (a manifest union type) to this scope.
 AST_Union *
 AST_Structure::fe_add_union (AST_Union *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to local types.
-  this->add_to_local_types (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_Union::narrow_from_decl (
+      this->fe_add_full_struct_type (t));
 }
 
-// Add this AST_Enum node (a manifest enum declaration) to this scope.
 AST_Enum *
 AST_Structure::fe_add_enum (AST_Enum *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to local types.
-  this->add_to_local_types (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_Enum::narrow_from_decl (
+      this->fe_add_decl (t));
 }
 
 // Add this AST_EnumVal node (an enumerator declaration) to this scope.
@@ -531,46 +353,9 @@ AST_Structure::fe_add_enum (AST_Enum *t)
 AST_EnumVal *
 AST_Structure::fe_add_enum_val (AST_EnumVal *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to scope.
-  this->add_to_scope (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_EnumVal::narrow_from_decl (
+      this->fe_add_decl (t));
 }
 
 // Compute total number of members.
@@ -784,8 +569,6 @@ AST_Structure::destroy (void)
   this->UTL_Scope::destroy ();
 }
 
-
-
 IMPL_NARROW_FROM_DECL(AST_Structure)
 IMPL_NARROW_FROM_SCOPE(AST_Structure)
 
