@@ -1,4 +1,4 @@
-// $Id: ast_structure_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_structure_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 // AST_StructureFwd nodes denote forward declarations of IDL structs.
 // AST_StructureFwd nodes have a field containing the full declaration
@@ -10,18 +10,8 @@
 #include "ast_visitor.h"
 #include "utl_identifier.h"
 
-ACE_RCSID( ast,
-           ast_structure_fwd,
-           "$Id: ast_structure_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_StructureFwd::AST_StructureFwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    pd_full_definition (0),
-    is_defined_ (false)
-{
-}
+AST_Decl::NodeType const
+AST_StructureFwd::NT = AST_Decl::NT_struct_fwd;
 
 AST_StructureFwd::AST_StructureFwd (AST_Structure *full_defn,
                                     UTL_ScopedName *n)
