@@ -1,4 +1,4 @@
-// $Id: ast_typedef.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_typedef.cpp 89075 2010-02-18 20:37:07Z parsons $
 
 /*
 
@@ -76,18 +76,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (ast,
-           ast_typedef,
-           "$Id: ast_typedef.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_Typedef::AST_Typedef (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    pd_base_type (0),
-    owns_base_type_ (false)
-{
-}
+AST_Decl::NodeType const
+AST_Typedef::NT = AST_Decl::NT_typedef;
 
 AST_Typedef::AST_Typedef (AST_Type *bt,
                           UTL_ScopedName *n,
@@ -99,16 +89,10 @@ AST_Typedef::AST_Typedef (AST_Type *bt,
               n),
     AST_Type (AST_Decl::NT_typedef,
               n),
-    pd_base_type (bt),
-    owns_base_type_ (false)
+    AST_Field (AST_Decl::NT_typedef,
+               bt,
+               n)
 {
-  AST_Decl::NodeType nt = bt->node_type ();
-
-  if (AST_Decl::NT_array == nt || AST_Decl::NT_sequence == nt)
-    {
-      this->owns_base_type_ = true;
-      bt->anonymous (false);
-    }
 }
 
 AST_Typedef::~AST_Typedef (void)
@@ -137,7 +121,7 @@ AST_Typedef::primitive_base_type (void) const
 AST_Type *
 AST_Typedef::base_type (void) const
 {
-  return this->pd_base_type;
+  return this->ref_type_;
 }
 
 bool
@@ -149,7 +133,7 @@ AST_Typedef::legal_for_primary_key (void) const
 bool
 AST_Typedef::is_local (void)
 {
-  return this->pd_base_type->is_local ();
+  return this->ref_type_->is_local ();
 }
 
 bool
@@ -168,17 +152,8 @@ AST_Typedef::owns_base_type (bool val)
 void
 AST_Typedef::dump (ACE_OSTREAM_TYPE&o)
 {
-  if (this->is_local ())
-    {
-      this->dump_i (o, "(local) ");
-    }
-  else
-    {
-      this->dump_i (o, "(abstract) ");
-    }
-
   this->dump_i (o, "typedef ");
-  this->pd_base_type->dump (o);
+  this->ref_type_->dump (o);
   this->dump_i (o, " ");
   this->local_name ()->dump (o);
 }
@@ -187,7 +162,7 @@ AST_Typedef::dump (ACE_OSTREAM_TYPE&o)
 int
 AST_Typedef::compute_size_type (void)
 {
-  AST_Type *type = this->base_type ();
+  AST_Type *type = this->ref_type_;
 
   if (type == 0)
     {
@@ -215,18 +190,8 @@ AST_Typedef::ast_accept (ast_visitor *visitor)
 void
 AST_Typedef::destroy (void)
 {
-  if (this->owns_base_type_)
-    {
-      this->pd_base_type->destroy ();
-      delete this->pd_base_type;
-      this->pd_base_type = 0;
-    }
-
+  this->AST_Field::destroy ();
   this->AST_Type::destroy ();
 }
 
-// Data accessors.
-
-
-
 IMPL_NARROW_FROM_DECL(AST_Typedef)
