@@ -1,4 +1,4 @@
-// $Id: ast_union.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_union.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 /*
 
@@ -80,6 +80,7 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_predefined_type.h"
 #include "ast_enum.h"
 #include "ast_enum_val.h"
+#include "ast_typedef.h"
 #include "ast_visitor.h"
 #include "utl_err.h"
 #include "utl_identifier.h"
@@ -89,21 +90,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 // FUZZ: disable check_for_streams_include
 #include "ace/streams.h"
 
-ACE_RCSID (ast,
-           ast_union,
-           "$Id: ast_union.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_Union::AST_Union (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    UTL_Scope (),
-    AST_Structure (),
-    default_index_ (-2)
-{
-}
-
 AST_Union::AST_Union (AST_ConcreteType *dt,
                       UTL_ScopedName *n,
                       bool local,
@@ -157,6 +143,12 @@ AST_Union::AST_Union (AST_ConcreteType *dt,
         case AST_PredefinedType::PT_ulong:
           this->pd_udisc_type = AST_Expression::EV_ulong;
           break;
+        case AST_PredefinedType::PT_longlong:
+          this->pd_udisc_type = AST_Expression::EV_longlong;
+          break;
+        case AST_PredefinedType::PT_ulonglong:
+          this->pd_udisc_type = AST_Expression::EV_ulonglong;
+          break;
         case AST_PredefinedType::PT_short:
           this->pd_udisc_type = AST_Expression::EV_short;
           break;
@@ -523,7 +515,12 @@ AST_Union::compute_default_value (void)
   // values of the discriminant type are covered by the cases.
 
   // Compute the total true "case" labels i.e., exclude the "default" case.
-  int total_case_members = 0;
+  ACE_UINT64 total_case_members = 0;
+
+  // In the case of a (unsigned) long long discriminant being fully used
+  // the total case count would actually overflow back to zero.
+  // This is 'end of days' programming but what the heck. We're here now.
+  bool first_case_found = false;
 
   // Instantiate a scope iterator.
   for (UTL_ScopeActiveIterator si (this, UTL_Scope::IK_decls);
@@ -542,6 +539,7 @@ AST_Union::compute_default_value (void)
               if (ub->label (i)->label_kind () == AST_UnionLabel::UL_label)
                 {
                   ++total_case_members;
+                  first_case_found = true;
                 }
             }
         }
@@ -558,7 +556,7 @@ AST_Union::compute_default_value (void)
     {
     case AST_Expression::EV_short:
     case AST_Expression::EV_ushort:
-      if (total_case_members == ACE_UINT16_MAX + 1)
+      if (total_case_members > ACE_UINT16_MAX)
         {
           this->default_value_.computed_ = 0;
         }
@@ -566,7 +564,11 @@ AST_Union::compute_default_value (void)
       break;
     case AST_Expression::EV_long:
     case AST_Expression::EV_ulong:
-      if ((unsigned int) total_case_members > ACE_UINT32_MAX)
+    case AST_Expression::EV_enum:
+      // Enums in CORBA are always 32bits in size, so unless
+      // there are that many enum labels in the set, it is
+      // incomplete (reguardless as to the actual member_count).
+      if (total_case_members > ACE_UINT32_MAX)
         {
           this->default_value_.computed_ = 0;
         }
@@ -574,19 +576,17 @@ AST_Union::compute_default_value (void)
       break;
     case AST_Expression::EV_longlong:
     case AST_Expression::EV_ulonglong:
-      // Error for now.
-      this->default_value_.computed_ = -1;
-      ACE_ERROR_RETURN ((
-          LM_ERROR,
-          ACE_TEXT ("(%N:%l) AST_Union::compute_default_value ")
-          ACE_TEXT ("- unimplemented discriminant type ")
-          ACE_TEXT ("(longlong or ulonglong)\n")
-        ),
-        -1
-      );
-      ACE_NOTREACHED (break;)
+      // We would wrap to 0 here - we are using a 64 bit count
+      if (first_case_found && total_case_members == 0)
+        {
+          // If anyone ever produces a "default clause is invalid here" error
+          // after passing through here I will buy them a a house.
+          this->default_value_.computed_ = 0;
+        }
+
+      break;
     case AST_Expression::EV_char:
-      if (total_case_members == ACE_OCTET_MAX + 1)
+      if (total_case_members > ACE_OCTET_MAX)
         {
           this->default_value_.computed_ = 0;
         }
@@ -605,38 +605,6 @@ AST_Union::compute_default_value (void)
           this->default_value_.computed_ = 0;
         }
 
-      break;
-    case AST_Expression::EV_enum:
-      // Has to be enum.
-      {
-        AST_Decl *d = AST_Decl::narrow_from_decl (this->disc_type ());
-
-        if (d->node_type () == AST_Decl::NT_typedef)
-          {
-            AST_Typedef *bt = AST_Typedef::narrow_from_decl (d);
-            d = bt->primitive_base_type ();
-          }
-
-        AST_Enum *en = AST_Enum::narrow_from_decl (d);
-
-        if (en != 0)
-          {
-            if (total_case_members == en->member_count ())
-              {
-                this->default_value_.computed_ = 0;
-              }
-          }
-        else
-          {
-            // Error.
-            this->default_value_.computed_ = -1;
-            ACE_ERROR_RETURN ((LM_ERROR,
-                               ACE_TEXT ("(%N:%l) AST_Union::")
-                               ACE_TEXT ("compute_default_value ")
-                               ACE_TEXT ("- disc type not an ENUM\n")),
-                              -1);
-          }
-      }
       break;
     default:
       // Error.
@@ -706,8 +674,11 @@ AST_Union::compute_default_value (void)
       this->default_value_.u.enum_val = 0;
       break;
     case AST_Expression::EV_longlong:
+      this->default_value_.u.longlong_val = 0;
+      break;
     case AST_Expression::EV_ulonglong:
-      // Unimplemented.
+      this->default_value_.u.ulonglong_val = 0;
+      break;
     default:
       // Error caught earlier.
       break;
@@ -833,8 +804,27 @@ AST_Union::compute_default_value (void)
 
                           break;
                         case AST_Expression::EV_longlong:
+#if ! defined (ACE_LACKS_LONGLONG_T)
+                          if (this->default_value_.u.longlong_val
+                                == expr->ev ()->u.llval)
+                            {
+                              this->default_value_.u.longlong_val++;
+                              break_loop = 1;
+                            }
+
+                          break;
+#endif
                         case AST_Expression::EV_ulonglong:
-                          // Unimplemented. right now - flag as error.
+#if ! defined (ACE_LACKS_LONGLONG_T)
+                          if (this->default_value_.u.ulonglong_val
+                                == expr->ev ()->u.ullval)
+                            {
+                              this->default_value_.u.ulonglong_val++;
+                              break_loop = 1;
+                            }
+
+                          break;
+#endif
                         default:
                           // Error.
                           break;
@@ -916,228 +906,34 @@ AST_Union::compute_default_index (void)
 
 // Redefinition of inherited virtual operations
 
-// Add this AST_UnionBranch node (a node representing one branch in a
-// union declaration) to this scope
 AST_UnionBranch *
 AST_Union::fe_add_union_branch (AST_UnionBranch *t)
 {
-  AST_Decl *d = 0;
-
-  // If this is a malformed branch, don't do anything with it.
-  if (t == 0 || t->label() == 0)
-    {
-      return 0;
-    }
-
-  // If branch with that label already exists, complain.
-  if (lookup_branch (t) != 0)
-    {
-      idl_global->err ()->error2 (UTL_Error::EIDL_MULTIPLE_BRANCH,
-                                  this,
-                                  t);
-      return 0;
-    }
-
-  // If branch with same field name exists, complain.
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to scope.
-  this->add_to_scope (t);
-
-  // If we have an enum discriminator, add the label names to
-  // the name_referenced list before we add the union branch,
-  // so a branch name clash with a label name will be caught.
-  if (this->pd_udisc_type == AST_Expression::EV_enum)
-    {
-      t->add_labels (this);
-    }
-  else
-    {
-      t->coerce_labels (this);
-    }
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  AST_Type *ft = t->field_type ();
-  UTL_ScopedName *mru = ft->last_referenced_as ();
-
-  if (mru != 0)
-    {
-      this->add_to_referenced (ft,
-                               false,
-                               mru->first_component ());
-    }
-
-  this->fields_.enqueue_tail (t);
-
-  return t;
+  return
+    AST_UnionBranch::narrow_from_decl (
+      this->fe_add_ref_decl (t));
 }
 
-// Add this AST_Union (manifest union type) to this scope.
 AST_Union *
 AST_Union::fe_add_union (AST_Union *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to local types.
-  this->add_to_local_types (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_Union::narrow_from_decl (
+      this->fe_add_full_struct_type (t));
 }
 
-// Add this AST_Structure node (manifest struct type) to this scope.
 AST_Structure *
 AST_Union::fe_add_structure (AST_Structure *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to local types.
-  this->add_to_local_types (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return this->fe_add_full_struct_type (t);
 }
 
-// Add this AST_Enum node (manifest enum type) to this scope.
 AST_Enum *
 AST_Union::fe_add_enum (AST_Enum *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to local types.
-  this->add_to_local_types (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_Enum::narrow_from_decl (
+      this->fe_add_decl (t));
 }
 
 // Add this AST_EnumVal node (enumerator declaration) to this scope.
@@ -1147,46 +943,9 @@ AST_Union::fe_add_enum (AST_Enum *t)
 AST_EnumVal *
 AST_Union::fe_add_enum_val (AST_EnumVal *t)
 {
-  AST_Decl *d = 0;
-
-  // Already defined and cannot be redefined? Or already used?
-  if ((d = this->lookup_for_add (t, false)) != 0)
-    {
-      if (!can_be_redefined (d))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_REDEF,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (this->referenced (d, t->local_name ()))
-        {
-          idl_global->err ()->error3 (UTL_Error::EIDL_DEF_USE,
-                                      t,
-                                      this,
-                                      d);
-          return 0;
-        }
-
-      if (t->has_ancestor (d))
-        {
-          idl_global->err ()->redefinition_in_scope (t,
-                                                     d);
-          return 0;
-        }
-    }
-
-  // Add it to scope.
-  this->add_to_scope (t);
-
-  // Add it to set of locally referenced symbols.
-  this->add_to_referenced (t,
-                           false,
-                           t->local_name ());
-
-  return t;
+  return
+    AST_EnumVal::narrow_from_decl (
+      this->fe_add_decl (t));
 }
 
 // Dump this AST_Union node to the ostream o.
@@ -1261,7 +1020,5 @@ AST_Union::udisc_type (void)
   return this->pd_udisc_type;
 }
 
-
-
 IMPL_NARROW_FROM_DECL(AST_Union)
 IMPL_NARROW_FROM_SCOPE(AST_Union)
