@@ -1,20 +1,11 @@
-// $Id: ast_valuebox.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_valuebox.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 #include "ast_valuebox.h"
 #include "ast_visitor.h"
 #include "utl_identifier.h"
 
-ACE_RCSID (ast, 
-           ast_valuebox, 
-           "ast_valuebox.cpp,v 1.0  Exp")
-
-AST_ValueBox::AST_ValueBox (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType () 
-{
-}
+AST_Decl::NodeType const
+AST_ValueBox::NT = AST_Decl::NT_valuebox;
 
 AST_ValueBox::AST_ValueBox (UTL_ScopedName *n,
                             AST_Type       *boxed_type)
@@ -61,8 +52,6 @@ AST_ValueBox::destroy (void)
   this->AST_ConcreteType::destroy ();
 }
 
-
-
 IMPL_NARROW_FROM_DECL(AST_ValueBox)
 
 
