@@ -1,21 +1,12 @@
-// $Id: ast_valuetype_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_valuetype_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
 
 #include "ast_valuetype_fwd.h"
 #include "ast_interface.h"
 #include "ast_visitor.h"
 #include "utl_identifier.h"
 
-ACE_RCSID( ast,
-           ast_valuetype_fwd,
-           "$Id: ast_valuetype_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-AST_ValueTypeFwd::AST_ValueTypeFwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_InterfaceFwd ()
-{
-}
+AST_Decl::NodeType const
+AST_ValueTypeFwd::NT = AST_Decl::NT_valuetype_fwd;
 
 AST_ValueTypeFwd::AST_ValueTypeFwd (AST_Interface *dummy,
                                     UTL_ScopedName *n)
