@@ -1,23 +1,18 @@
-// $Id: be_decl.cpp 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_decl.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_Decl that provides additional means for C++
-//    mapping.
-//
-// = AUTHOR
-//    Copyright 1994-1995 by Sun Microsystems, Inc.
-//    and
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_decl.cpp
+ *
+ *  $Id: be_decl.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_Decl that provides additional means for C++
+ *  mapping.
+ *
+ *
+ *  @author Copyright 1994-1995 by Sun Microsystems
+ *  @author Inc. and Aniruddha Gokhale
+ */
+//=============================================================================
 
 #include "be_decl.h"
 #include "be_scope.h"
@@ -35,70 +30,20 @@
 #include "be_enum.h"
 #include "be_operation.h"
 #include "be_factory.h"
+#include "be_finder.h"
 #include "be_sequence.h"
 #include "be_visitor.h"
+
 #include "ast_structure_fwd.h"
+#include "ast_typedef.h"
 #include "ast_string.h"
+
 #include "utl_identifier.h"
+
 #include "global_extern.h"
 #include "ace/Log_Msg.h"
 #include "ace/String_Base.h"
 
-ACE_RCSID (be,
-           be_decl,
-           "$Id: be_decl.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-// Default Constructor
-be_decl::be_decl (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    cli_hdr_gen_ (false),
-    cli_stub_gen_ (false),
-    cli_inline_gen_ (false),
-    srv_hdr_gen_ (false),
-    impl_hdr_gen_ (false),
-    srv_skel_gen_ (false),
-    impl_skel_gen_ (false),
-    srv_inline_gen_ (false),
-    tie_skel_gen_ (false),
-    cli_hdr_any_op_gen_ (false),
-    cli_stub_any_op_gen_ (false),
-    cli_hdr_cdr_op_gen_ (false),
-    cli_stub_cdr_op_gen_ (false),
-    cli_inline_cdr_op_gen_ (false),
-    cli_inline_cdr_decl_gen_ (false),
-    cli_hdr_serializer_op_gen_ (false),
-    cli_stub_serializer_op_gen_ (false),
-    cli_inline_serializer_op_gen_ (false),
-    cli_inline_serializer_decl_gen_ (false),
-    cli_traits_gen_ (false),
-    cli_arg_traits_gen_ (false),
-    srv_arg_traits_gen_ (false),
-    srv_sarg_traits_gen_ (false),
-    cli_pragma_inst_gen_ (false),
-    cli_inarg_tmpl_class_gen_ (false),
-    cli_inarg_pragma_inst_gen_ (false),
-    cli_inoutarg_tmpl_class_gen_ (false),
-    cli_inoutarg_pragma_inst_gen_ (false),
-    cli_outarg_tmpl_class_gen_ (false),
-    cli_outarg_pragma_inst_gen_ (false),
-    cli_retarg_tmpl_class_gen_ (false),
-    cli_retarg_pragma_inst_gen_ (false),
-    srv_tmpl_class_gen_ (false),
-    srv_pragma_inst_gen_ (false),
-    srv_inarg_tmpl_class_gen_ (false),
-    srv_inarg_pragma_inst_gen_ (false),
-    srv_inoutarg_tmpl_class_gen_ (false),
-    srv_inoutarg_pragma_inst_gen_ (false),
-    srv_outarg_tmpl_class_gen_ (false),
-    srv_outarg_pragma_inst_gen_ (false),
-    srv_retarg_tmpl_class_gen_ (false),
-    srv_retarg_pragma_inst_gen_ (false),
-    ccm_pre_proc_gen_ (false)
-{
-}
-
-// Constructor
 be_decl::be_decl (AST_Decl::NodeType type,
                   UTL_ScopedName *n)
   : COMMON_Base (),
@@ -146,11 +91,15 @@ be_decl::be_decl (AST_Decl::NodeType type,
     srv_outarg_pragma_inst_gen_ (false),
     srv_retarg_tmpl_class_gen_ (false),
     srv_retarg_pragma_inst_gen_ (false),
-    ccm_pre_proc_gen_ (false)
+    ccm_pre_proc_gen_ (false),
+    ex_idl_facet_gen_ (false),
+    svnt_hdr_facet_gen_ (false),
+    svnt_src_facet_gen_ (false),
+    exec_hdr_facet_gen_ (false),
+    exec_src_facet_gen_ (false)
 {
 }
 
-// Destructor
 be_decl::~be_decl (void)
 {
 }
@@ -244,8 +193,10 @@ be_decl::compute_flat_name  (const char *prefix,
       // Prefix.
       result_str = prefix_str;
 
-      // Local name.
-      result_str += ACE_CString (this->local_name ()->get_string ());
+      // Local name. Leave out _cxx_ prefix, if any.
+      result_str +=
+        ACE_CString (
+          this->original_local_name ()->get_string ());
 
       // Suffix.
       result_str += suffix_str;
@@ -275,8 +226,10 @@ be_decl::compute_flat_name  (const char *prefix,
       // Prefix.
       result_str += prefix_str;
 
-      // Local name.
-      result_str += ACE_CString (this->local_name ()->get_string ());
+      // Local name. Leave out _cxx_ prefix, if any.
+      result_str +=
+        ACE_CString (
+          this->original_local_name ()->get_string ());
 
       // Suffix.
       result_str += suffix_str;
@@ -302,47 +255,49 @@ be_decl::scope (void)
 {
   be_decl *d = this;
 
-   switch (this->node_type ())
-   {
-     case AST_Decl::NT_interface_fwd:
-        // Resolve forward declared interface by looking at full_definition()
-        // field and iterating.
-        d =
-          be_interface::narrow_from_decl (
-              (be_interface_fwd::narrow_from_decl (this))->full_definition ()
-            );
-     // Fall through
-     case AST_Decl::NT_interface:
-        return be_interface::narrow_from_decl (d);
-     case AST_Decl::NT_module:
-        return be_module::narrow_from_decl (d);
-     case AST_Decl::NT_root:
-        return be_root::narrow_from_decl (d);
-     case AST_Decl::NT_except:
-        return be_exception::narrow_from_decl (d);
-     case AST_Decl::NT_union:
-        return be_union::narrow_from_decl (d);
-     case AST_Decl::NT_struct:
-        return be_structure::narrow_from_decl (d);
-     case AST_Decl::NT_enum:
-        return be_enum::narrow_from_decl (d);
-     case AST_Decl::NT_op:
-        return be_operation::narrow_from_decl (d);
-     case AST_Decl::NT_factory:
-        return be_factory::narrow_from_decl (d);
-     case AST_Decl::NT_sequence:
-        return be_sequence::narrow_from_decl (d);
-     case AST_Decl::NT_valuetype:
-        return be_valuetype::narrow_from_decl (d);
-     case AST_Decl::NT_component:
-        return be_component::narrow_from_decl (d);
-     case AST_Decl::NT_eventtype:
-        return be_eventtype::narrow_from_decl (d);
-     case AST_Decl::NT_home:
-        return be_home::narrow_from_decl (d);
-     default:
-        return (be_scope *)0;
-   }
+  switch (this->node_type ())
+  {
+    case AST_Decl::NT_interface_fwd:
+      // Resolve forward declared interface by looking at full_definition()
+      // field and iterating.
+      d =
+        be_interface::narrow_from_decl (
+            (be_interface_fwd::narrow_from_decl (this))->full_definition ()
+          );
+    // Fall through
+    case AST_Decl::NT_interface:
+      return be_interface::narrow_from_decl (d);
+    case AST_Decl::NT_module:
+      return be_module::narrow_from_decl (d);
+    case AST_Decl::NT_root:
+      return be_root::narrow_from_decl (d);
+    case AST_Decl::NT_except:
+      return be_exception::narrow_from_decl (d);
+    case AST_Decl::NT_union:
+      return be_union::narrow_from_decl (d);
+    case AST_Decl::NT_struct:
+      return be_structure::narrow_from_decl (d);
+    case AST_Decl::NT_enum:
+      return be_enum::narrow_from_decl (d);
+    case AST_Decl::NT_op:
+      return be_operation::narrow_from_decl (d);
+    case AST_Decl::NT_factory:
+      return be_factory::narrow_from_decl (d);
+    case AST_Decl::NT_finder:
+      return be_finder::narrow_from_decl (d);
+    case AST_Decl::NT_sequence:
+      return be_sequence::narrow_from_decl (d);
+    case AST_Decl::NT_valuetype:
+      return be_valuetype::narrow_from_decl (d);
+    case AST_Decl::NT_component:
+      return be_component::narrow_from_decl (d);
+    case AST_Decl::NT_eventtype:
+      return be_eventtype::narrow_from_decl (d);
+    case AST_Decl::NT_home:
+      return be_home::narrow_from_decl (d);
+    default:
+      return (be_scope *)0;
+  }
 }
 
 // Boolean methods to test if code was already generated.
@@ -604,6 +559,36 @@ be_decl::ccm_pre_proc_gen (void)
   return this->ccm_pre_proc_gen_;
 }
 
+bool
+be_decl::ex_idl_facet_gen (void)
+{
+  return this->ex_idl_facet_gen_;
+}
+
+bool
+be_decl::svnt_hdr_facet_gen (void)
+{
+  return this->svnt_hdr_facet_gen_;
+}
+
+bool
+be_decl::svnt_src_facet_gen (void)
+{
+  return this->svnt_src_facet_gen_;
+}
+
+bool
+be_decl::exec_hdr_facet_gen (void)
+{
+  return this->exec_hdr_facet_gen_;
+}
+
+bool
+be_decl::exec_src_facet_gen (void)
+{
+  return this->exec_src_facet_gen_;
+}
+
 // Set the flag indicating that code generation is done.
 void
 be_decl::cli_hdr_gen (bool val)
@@ -858,6 +843,36 @@ be_decl::ccm_pre_proc_gen (bool val)
   this->ccm_pre_proc_gen_ = val;
 }
 
+void
+be_decl::ex_idl_facet_gen (bool val)
+{
+  this->ex_idl_facet_gen_ = val;
+}
+
+void
+be_decl::svnt_hdr_facet_gen (bool val)
+{
+  this->svnt_hdr_facet_gen_ = val;
+}
+
+void
+be_decl::svnt_src_facet_gen (bool val)
+{
+  this->svnt_src_facet_gen_ = val;
+}
+
+void
+be_decl::exec_hdr_facet_gen (bool val)
+{
+  this->exec_hdr_facet_gen_ = val;
+}
+
+void
+be_decl::exec_src_facet_gen (bool val)
+{
+  this->exec_src_facet_gen_ = val;
+}
+
 //==========================================
 
 int
