@@ -1,44 +1,24 @@
-// $Id: be_eventtype_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
-
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_eventtype_fwd.h
-//
-// = DESCRIPTION
-//    Extension of class be_valuetype_fwd that provides additional
-//    means for C++ mapping of an eventtype.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
 
+//=============================================================================
+/**
+ *  @file    be_eventtype_fwd.cpp
+ *
+ *  $Id: be_eventtype_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class be_valuetype_fwd that provides additional
+ *  means for C++ mapping of an eventtype.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 #include "be_eventtype_fwd.h"
 #include "be_visitor.h"
+
 #include "ast_interface.h"
 
-ACE_RCSID (be, 
-           be_eventtype_fwd, 
-           "$Id: be_eventtype_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-be_eventtype_fwd::be_eventtype_fwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_InterfaceFwd (),
-    be_decl (),
-    be_type (),
-    be_interface_fwd (),
-    AST_ValueTypeFwd (),
-    be_valuetype_fwd (),
-    AST_EventTypeFwd ()
-{
-}
+#include "global_extern.h"
 
 be_eventtype_fwd::be_eventtype_fwd (AST_Interface *dummy,
                                     UTL_ScopedName *n)
@@ -72,7 +52,9 @@ be_eventtype_fwd::~be_eventtype_fwd (void)
 int
 be_eventtype_fwd::accept (be_visitor *visitor)
 {
-  return visitor->visit_eventtype_fwd (this);
+  return (idl_global->ignore_idl3 ()
+            ? 0
+            : visitor->visit_eventtype_fwd (this));
 }
 
 void
