@@ -1,4 +1,4 @@
-// $Id: be_generator.cpp 73110 2006-06-15 18:56:10Z parsons $
+// $Id: be_generator.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 
 /*
 
@@ -81,6 +81,18 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "be_component.h"
 #include "be_component_fwd.h"
 #include "be_home.h"
+#include "be_porttype.h"
+#include "be_mirror_port.h"
+#include "be_connector.h"
+#include "be_template_module.h"
+#include "be_template_module_inst.h"
+#include "be_template_module_ref.h"
+#include "be_param_holder.h"
+#include "be_provides.h"
+#include "be_uses.h"
+#include "be_publishes.h"
+#include "be_emits.h"
+#include "be_consumes.h"
 #include "be_union.h"
 #include "be_union_fwd.h"
 #include "be_structure.h"
@@ -102,14 +114,11 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "be_typedef.h"
 #include "be_native.h"
 #include "be_factory.h"
+#include "be_finder.h"
 #include "utl_identifier.h"
 #include "nr_extern.h"
 #include "ace/config-all.h"
 
-ACE_RCSID (be,
-           be_generator,
-           "$Id: be_generator.cpp 73110 2006-06-15 18:56:10Z parsons $")
-
 AST_Root *
 be_generator::create_root (UTL_ScopedName *n)
 {
@@ -146,22 +155,23 @@ be_generator::create_module (UTL_Scope *s,
                   be_module (n),
                   0);
 
+  AST_Module *m = 0;
 
   // Check for another module of the same name in this scope.
   for (UTL_ScopeActiveIterator iter (s, UTL_Scope::IK_decls);
        !iter.is_done ();
        iter.next ())
     {
-      AST_Decl *d = iter.item ();
+      // Can't just check node type here, since it could be a
+      // template module or template module instantiation.
+      m = AST_Module::narrow_from_decl (iter.item ());
 
-      if (d->node_type () == AST_Decl::NT_module)
+      if (m != 0)
         {
           // Does it have the same name as the one we're
           // supposed to create.
-          if (d->local_name ()->compare (n->last_component ()))
+          if (m->local_name ()->compare (n->last_component ()))
             {
-              AST_Module *m = AST_Module::narrow_from_decl (d);
-
               // Get m's previous_ member, plus all it's decls,
               // into the new modules's previous_ member.
               retval->add_to_previous (m);
@@ -178,21 +188,26 @@ be_generator::create_module (UTL_Scope *s,
 
   if (nt == AST_Decl::NT_module || nt == AST_Decl::NT_root)
     {
-      AST_Module *m = AST_Module::narrow_from_decl (d);
+      // Also check this to week out a template module or its
+      // instantiation.
+      m = AST_Module::narrow_from_decl (d);
 
-      // AST_Module::previous_ is a set, so it contains each
-      // entry only once, but previous_ will contain the decls
-      // from all previous openings. See comment in
-      // AST_Module::add_to_previous() body.
-      d = m->look_in_previous (n->last_component ());
-
-      if (d != 0)
+      if (m != 0)
         {
-          if (d->node_type () == AST_Decl::NT_module)
-            {
-              m = AST_Module::narrow_from_decl (d);
+          // AST_Module::previous_ is a set, so it contains each
+          // entry only once, but previous_ will contain the decls
+          // from all previous openings. See comment in
+          // AST_Module::add_to_previous() body.
+          d = m->look_in_previous (n->last_component ());
 
-              retval->add_to_previous (m);
+          if (d != 0)
+            {
+              if (d->node_type () == AST_Decl::NT_module)
+                {
+                  m = AST_Module::narrow_from_decl (d);
+
+                  retval->add_to_previous (m);
+                }
             }
         }
     }
@@ -202,7 +217,7 @@ be_generator::create_module (UTL_Scope *s,
 
 AST_Interface *
 be_generator::create_interface (UTL_ScopedName *n,
-                                AST_Interface **ih,
+                                AST_Type **ih,
                                 long nih,
                                 AST_Interface **ih_flat,
                                 long nih_flat,
@@ -261,14 +276,14 @@ be_generator::create_valuebox (UTL_ScopedName *n,
 
 AST_ValueType *
 be_generator::create_valuetype (UTL_ScopedName *n,
-                                AST_Interface **inherits,
+                                AST_Type **inherits,
                                 long n_inherits,
-                                AST_ValueType *inherits_concrete,
+                                AST_Type *inherits_concrete,
                                 AST_Interface **inherits_flat,
                                 long n_inherits_flat,
-                                AST_Interface **supports_list,
+                                AST_Type **supports_list,
                                 long n_supports,
-                                AST_Interface *supports_concrete,
+                                AST_Type *supports_concrete,
                                 bool is_abstract,
                                 bool is_truncatable,
                                 bool is_custom)
@@ -321,14 +336,14 @@ be_generator::create_valuetype_fwd (UTL_ScopedName *n,
 
 AST_EventType *
 be_generator::create_eventtype (UTL_ScopedName *n,
-                                AST_Interface **inherits,
+                                AST_Type **inherits,
                                 long n_inherits,
-                                AST_ValueType *inherits_concrete,
+                                AST_Type *inherits_concrete,
                                 AST_Interface **inherits_flat,
                                 long n_inherits_flat,
-                                AST_Interface **supports_list,
+                                AST_Type **supports_list,
                                 long n_supports,
-                                AST_Interface *supports_concrete,
+                                AST_Type *supports_concrete,
                                 bool is_abstract,
                                 bool is_truncatable,
                                 bool is_custom)
@@ -382,7 +397,7 @@ be_generator::create_eventtype_fwd (UTL_ScopedName *n,
 AST_Component *
 be_generator::create_component (UTL_ScopedName *n,
                                 AST_Component *base_component,
-                                AST_Interface **supports_list,
+                                AST_Type **supports_list,
                                 long n_supports,
                                 AST_Interface **supports_flat,
                                 long n_supports_flat)
@@ -424,8 +439,8 @@ AST_Home *
 be_generator::create_home (UTL_ScopedName *n,
                            AST_Home *base_home,
                            AST_Component *managed_component,
-                           AST_ValueType *primary_key,
-                           AST_Interface **supports_list,
+                           AST_Type *primary_key,
+                           AST_Type **supports_list,
                            long n_supports,
                            AST_Interface **supports_flat,
                            long n_supports_flat)
@@ -692,7 +707,7 @@ be_generator::create_expr (AST_Expression::ExprComb c,
 }
 
 AST_Expression *
-be_generator::create_expr (long l)
+be_generator::create_expr (ACE_CDR::Long l)
 {
   be_expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -703,7 +718,7 @@ be_generator::create_expr (long l)
 }
 
 AST_Expression *
-be_generator::create_expr (bool b)
+be_generator::create_expr (ACE_CDR::Boolean b)
 {
   be_expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -714,7 +729,7 @@ be_generator::create_expr (bool b)
 }
 
 AST_Expression *
-be_generator::create_expr (idl_uns_long l,
+be_generator::create_expr (ACE_CDR::ULong l,
                            AST_Expression::ExprType t)
 {
   be_expression *retval = 0;
@@ -738,7 +753,7 @@ be_generator::create_expr (UTL_String *s)
 }
 
 AST_Expression *
-be_generator::create_expr(char c)
+be_generator::create_expr (ACE_CDR::Char c)
 {
   be_expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -771,7 +786,7 @@ be_generator::create_expr (char *s)
 }
 
 AST_Expression *
-be_generator::create_expr (double d)
+be_generator::create_expr (ACE_CDR::Double d)
 {
   be_expression *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -782,7 +797,7 @@ be_generator::create_expr (double d)
 }
 
 AST_EnumVal *
-be_generator::create_enum_val (unsigned long v,
+be_generator::create_enum_val (ACE_CDR::ULong v,
                                UTL_ScopedName *n)
 {
   be_enum_val *retval = 0;
@@ -796,7 +811,7 @@ be_generator::create_enum_val (unsigned long v,
 
 AST_Array *
 be_generator::create_array (UTL_ScopedName *n,
-                            unsigned long ndims,
+                            ACE_CDR::ULong ndims,
                             UTL_ExprList *dims,
                             bool is_local,
                             bool is_abstract)
@@ -911,3 +926,194 @@ be_generator::create_factory (UTL_ScopedName *n)
 
   return retval;
 }
+
+AST_Finder *
+be_generator::create_finder (UTL_ScopedName *n)
+{
+  be_finder *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_finder (n),
+                  0);
+
+  return retval;
+}
+
+AST_PortType *
+be_generator::create_porttype (UTL_ScopedName *n)
+{
+  be_porttype *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_porttype (n),
+                  0);
+
+  return retval;
+}
+
+AST_Provides *
+be_generator::create_provides (UTL_ScopedName *n,
+                               AST_Type *provides_type)
+{
+  be_provides *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_provides (n,
+                               provides_type),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Uses *
+be_generator::create_uses (UTL_ScopedName *n,
+                           AST_Type *uses_type,
+                           bool is_multiple)
+{
+  be_uses *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_uses (n,
+                           uses_type,
+                           is_multiple),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Publishes *
+be_generator::create_publishes (UTL_ScopedName *n,
+                                AST_Type *publishes_type)
+{
+  be_publishes *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_publishes (n,
+                                publishes_type),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Emits *
+be_generator::create_emits (UTL_ScopedName *n,
+                            AST_Type *emits_type)
+{
+  be_emits *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_emits (n,
+                            emits_type),
+                  0);
+                  
+  return retval;              
+}
+AST_Consumes *
+be_generator::create_consumes (UTL_ScopedName *n,
+                               AST_Type *consumes_type)
+{
+  be_consumes *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_consumes (n,
+                               consumes_type),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Extended_Port *
+be_generator::create_extended_port (
+  UTL_ScopedName *n,
+  AST_PortType *porttype_ref)
+{
+  be_extended_port *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_extended_port (n,
+                                    porttype_ref),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Mirror_Port *
+be_generator::create_mirror_port (
+  UTL_ScopedName *n,
+  AST_PortType *porttype_ref)
+{
+  be_mirror_port *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_mirror_port (n,
+                                  porttype_ref),
+                  0);
+                  
+  return retval;              
+}
+
+AST_Connector *
+be_generator::create_connector (
+  UTL_ScopedName *n,
+  AST_Connector *base_connector)
+{
+  be_connector *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_connector (n,
+                                base_connector),
+                  0);
+                  
+  return retval;
+}
+
+AST_Template_Module *
+be_generator::create_template_module (
+  UTL_ScopedName *n,
+  FE_Utils::T_PARAMLIST_INFO *template_params)
+{
+  be_template_module *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_template_module (n,
+                                      template_params),
+                  0);
+                  
+  return retval;
+}
+  
+AST_Template_Module_Inst *
+be_generator::create_template_module_inst (
+  UTL_ScopedName *n,
+  AST_Template_Module *ref,
+  FE_Utils::T_ARGLIST *template_args)
+{
+  be_template_module_inst *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_template_module_inst (n,
+                                           ref,
+                                           template_args),
+                  0);
+                  
+  return retval;
+}
+  
+AST_Template_Module_Ref *
+be_generator::create_template_module_ref (
+  UTL_ScopedName *n,
+  AST_Template_Module *ref,
+  UTL_StrList *param_refs)
+{
+  be_template_module_ref *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_template_module_ref (n,
+                                          ref,
+                                          param_refs),
+                  0);
+                  
+  return retval;
+}
+    
+AST_Param_Holder *
+be_generator::create_param_holder (
+  UTL_ScopedName *parameter_name,
+  FE_Utils::T_Param_Info *info)
+{
+  be_param_holder *retval = 0;
+  ACE_NEW_RETURN (retval,
+                  be_param_holder (parameter_name,
+                                   info),
+                  0);
+                  
+  return retval;
+}
+
