@@ -1,38 +1,38 @@
-// $Id: be_interface.cpp 80398 2008-01-08 21:58:57Z wotte $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_interface.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_Interface that provides additional means for C++
-//    mapping of an interface.
-//
-// = AUTHOR
-//    Copyright 1994-1995 by Sun Microsystems, Inc.
-//    and
-//    Aniruddha Gokhale,
-//    Michael Kircher
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_interface.cpp
+ *
+ *  $Id: be_interface.cpp 89274 2010-03-02 09:57:21Z johnnyw $
+ *
+ *  Extension of class AST_Interface that provides additional means for C++
+ *  mapping of an interface.
+ *
+ *
+ *  @author Copyright 1994-1995 by Sun Microsystems
+ *  @author Inc. and Aniruddha Gokhale
+ *  @author Michael Kircher
+ */
+//=============================================================================
 
 #include "be_interface.h"
 #include "be_interface_strategy.h"
+#include "be_component.h"
+#include "be_connector.h"
 #include "be_attribute.h"
 #include "be_operation.h"
 #include "be_exception.h"
 #include "be_visitor.h"
 #include "be_helper.h"
-#include "be_stream_factory.h"
+#include "be_identifier_helper.h"
 #include "be_extern.h"
+#include "be_visitor_operation.h"
+#include "be_visitor_attribute.h"
+#include "be_visitor_context.h"
 #include "utl_identifier.h"
 #include "utl_exceptlist.h"
 #include "ast_generator.h"
-#include "ast_component.h"
+#include "ast_home.h"
 #include "global_extern.h"
 #include "idl_defines.h"
 #include "nr_extern.h"
@@ -42,34 +42,8 @@
 #include "ace/OS_NS_unistd.h"
 #include "ace/OS_NS_fcntl.h"
 
-ACE_RCSID (be,
-           be_interface,
-           "$Id: be_interface.cpp 80398 2008-01-08 21:58:57Z wotte $")
-
-// Default constructor.
-be_interface::be_interface (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    UTL_Scope (),
-    AST_Interface (),
-    be_scope (),
-    be_type (),
-    var_out_seq_decls_gen_ (0),
-    skel_count_ (0),
-    in_mult_inheritance_ (-1),
-    strategy_ (0),
-    original_interface_ (0),
-    has_mixed_parentage_ (-1),
-    session_component_child_ (-1)
-{
-  ACE_NEW (this->strategy_,
-           be_interface_default_strategy (this));
-}
-
-// Constructor used to build the AST.
 be_interface::be_interface (UTL_ScopedName *n,
-                            AST_Interface **ih,
+                            AST_Type **ih,
                             long nih,
                             AST_Interface **ih_flat,
                             long nih_flat,
@@ -90,6 +64,8 @@ be_interface::be_interface (UTL_ScopedName *n,
                    local,
                    abstract),
     be_scope (AST_Decl::NT_interface),
+    be_decl (AST_Decl::NT_interface,
+             n),
     be_type (AST_Decl::NT_interface,
              n),
     var_out_seq_decls_gen_ (0),
@@ -158,7 +134,6 @@ be_interface::set_strategy (be_interface_strategy *new_strategy)
   return old;
 }
 
-
 const char *
 be_interface::local_name (void) const
 {
@@ -214,7 +189,6 @@ be_interface::relative_skel_name (const char *skel_name)
   return this->strategy_->relative_skel_name (skel_name);
 }
 
-
 void
 be_interface::compute_full_skel_name (const char *prefix,
                                       char *&skelname)
@@ -571,12 +545,11 @@ be_interface::gen_stub_ctor (TAO_OutStream *os)
                   << ")" << be_uidt;
             }
 
-          int status =
+          int const status =
             this->traverse_inheritance_graph (
                       be_interface::gen_abstract_init_helper,
                       os,
-                      true
-                    );
+                      true);
 
           if (status == -1)
             {
@@ -601,13 +574,20 @@ be_interface::gen_stub_ctor (TAO_OutStream *os)
           *os << "::CORBA::Object (objref, _tao_collocated, servant, oc)";
         }
 
-      *os << "," << be_nl
-          << "the"<< this->base_proxy_broker_name () << "_ (0)"
-          << be_uidt << be_uidt;
+      if (be_global->gen_direct_collocation() || be_global->gen_thru_poa_collocation ())
+        {
+          *os << "," << be_nl
+              << "the"<< this->base_proxy_broker_name () << "_ (0)"
+              << be_uidt << be_uidt;
+        }
 
-      *os << be_nl << "{" << be_idt_nl
-          << "this->" << this->flat_name ()
-          << "_setup_collocation ();";
+      *os << be_nl << "{" << be_idt_nl;
+
+      if (be_global->gen_direct_collocation() || be_global->gen_thru_poa_collocation ())
+        {
+          *os << "this->" << this->flat_name ()
+              << "_setup_collocation ();";
+        }
 
       if (this->is_abstract ())
         {
@@ -665,8 +645,7 @@ be_interface:: gen_var_out_seq_decls (void)
 // ****************************************************************
 
 TAO_IDL_Inheritance_Hierarchy_Worker::~TAO_IDL_Inheritance_Hierarchy_Worker (
-    void
-  )
+    void)
 {
 }
 
@@ -722,9 +701,7 @@ private:
   be_visitor *visitor_;
 };
 
-Pure_Virtual_Regenerator::Pure_Virtual_Regenerator (
-    be_visitor *visitor
-  )
+Pure_Virtual_Regenerator::Pure_Virtual_Regenerator (be_visitor *visitor)
   : visitor_ (visitor)
 {
 }
@@ -903,6 +880,7 @@ be_interface::gen_operation_table (const char *flat_name,
                         char [ACE_OS::strlen (idl_global->temp_dir ())
                               + 11 // The number of possible digits in
                                    // a 32-bit number plus a dot
+                              + 11 // for process id
                               + ACE_OS::strlen (flat_name)
                               + ACE_OS::strlen (".gperf")
                               + 1],
@@ -916,15 +894,16 @@ be_interface::gen_operation_table (const char *flat_name,
           (static_cast<ACE_RANDR_TYPE> (ACE_OS::time())
            + static_cast<ACE_RANDR_TYPE> (ACE_OS::getpid ()));
         ACE_OS::sprintf (temp_file,
-                         "%s%d.%s.gperf",
+                         "%s%d.%d.%s.gperf",
                          idl_global->temp_dir (),
                          ACE_OS::rand_r (seed),
+                         ACE_OS::getpid (),
                          flat_name);
 
         // QNX can't handle individual file names (path components)
         // longer than 48 characters.
 #if defined(__QNX__)
-        size_t temp_dir_len = ACE_OS::strlen (idl_global->temp_dir ());
+        size_t const temp_dir_len = ACE_OS::strlen (idl_global->temp_dir ());
 
         if (ACE_OS::strlen (temp_file) > temp_dir_len + 47)
           {
@@ -937,13 +916,8 @@ be_interface::gen_operation_table (const char *flat_name,
 
         // Make a new outstream to hold the gperf_temp_file for this
         // interface.
-
-        // Retrieve the singleton instance to the outstream factory.
-        TAO_OutStream_Factory *factory =
-          TAO_OUTSTREAM_FACTORY::instance ();
-
-        // Get a new instance for the temp file.
-        TAO_OutStream *os = factory->make_outstream ();
+        TAO_OutStream *os = 0;
+        ACE_NEW_RETURN (os, TAO_OutStream, -1);
 
         if (os == 0)
           {
@@ -1341,7 +1315,8 @@ be_interface::gen_collocated_skel_body (be_interface *derived,
 }
 
 void
-be_interface::gen_ostream_operator (TAO_OutStream *os)
+be_interface::gen_ostream_operator (TAO_OutStream *os,
+                                    bool /* use_underscore */)
 {
   *os << be_nl
       << "std::ostream& operator<< (" << be_idt << be_idt_nl
@@ -1359,6 +1334,7 @@ be_interface::gen_ostream_operator (TAO_OutStream *os)
 void
 be_interface::gen_member_ostream_operator (TAO_OutStream *os,
                                            const char *instance_name,
+                                           bool /* use_underscore */,
                                            bool accessor)
 {
   *os << instance_name << (accessor ? " ()" : ".in ()");
@@ -1379,7 +1355,14 @@ be_interface::analyze_parentage (void)
       be_interface *parent =
         be_interface::narrow_from_decl (this->pd_inherits[i]);
 
-      if (parent->is_abstract () || parent->has_mixed_parentage ())
+      if (parent == 0)
+        {
+          // The item is a template param holder.
+          continue;
+        }
+
+      if (parent->is_abstract ()
+          || parent->has_mixed_parentage ())
         {
           this->has_mixed_parentage_ = 1;
           break;
@@ -1389,9 +1372,13 @@ be_interface::analyze_parentage (void)
   AST_Decl::NodeType nt = this->node_type ();
   bool can_be_mixed = nt == AST_Decl::NT_interface
                           || nt == AST_Decl::NT_component
-                          || nt == AST_Decl::NT_home;
+                          || nt == AST_Decl::NT_home
+                          || nt == AST_Decl::NT_connector;
 
-  if (this->has_mixed_parentage_ == 1 && can_be_mixed && this->is_defined ())
+  if (this->has_mixed_parentage_ == 1
+      && can_be_mixed
+      && this->is_defined ()
+      && !this->imported ())
     {
       be_global->mixed_parentage_interfaces.enqueue_tail (this);
     }
@@ -1399,8 +1386,8 @@ be_interface::analyze_parentage (void)
 
 // ****************************************************************
 
-be_code_emitter_wrapper::
-be_code_emitter_wrapper (be_interface::tao_code_emitter emitter)
+be_code_emitter_wrapper::be_code_emitter_wrapper (
+      be_interface::tao_code_emitter emitter)
   : emitter_ (emitter)
 {
 }
@@ -1415,13 +1402,17 @@ be_code_emitter_wrapper::emit (be_interface *derived_interface,
                          output_stream);
 }
 
+// ****************************************************************
+
 // Template method that traverses the inheritance graph in a breadth-first
 // style. The actual work on each element in the inheritance graph is carried
 // out by the function passed as argument.
 int
-be_interface::traverse_inheritance_graph (be_interface::tao_code_emitter gen,
-                                          TAO_OutStream *os,
-                                          bool abstract_paths_only)
+be_interface::traverse_inheritance_graph (
+  be_interface::tao_code_emitter gen,
+  TAO_OutStream *os,
+  bool abstract_paths_only,
+  bool add_ccm_object)
 {
   // Make sure the queues are empty.
   this->insert_queue.reset ();
@@ -1439,24 +1430,26 @@ be_interface::traverse_inheritance_graph (be_interface::tao_code_emitter gen,
 
   be_code_emitter_wrapper wrapper (gen);
 
-  return this->traverse_inheritance_graph (wrapper,
-                                           os,
-                                           abstract_paths_only);
+  return
+    this->traverse_inheritance_graph (wrapper,
+                                      os,
+                                      abstract_paths_only,
+                                      add_ccm_object);
 }
 
 int
 be_interface::traverse_inheritance_graph (
-    TAO_IDL_Inheritance_Hierarchy_Worker &worker,
-    TAO_OutStream *os,
-    bool abstract_paths_only
-  )
+  TAO_IDL_Inheritance_Hierarchy_Worker &worker,
+  TAO_OutStream *os,
+  bool abstract_paths_only,
+  bool add_ccm_object)
 {
-  AST_Interface *intf = 0;  // element inside the queue
+  AST_Type *intf = 0;  // element inside the queue
 
   if (!this->insert_queue.is_empty ())
     {
       // Dequeue the element at the head of the queue.
-      if (this->insert_queue.dequeue_head (intf))
+      if (this->insert_queue.dequeue_head (intf) != 0)
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_interface::traverse_graph - "
@@ -1464,27 +1457,25 @@ be_interface::traverse_inheritance_graph (
                             -1);
         }
 
-      // If we are doing a component, we check for a parent.
-      if (intf->node_type () == AST_Decl::NT_component)
+      AST_Decl::NodeType nt = intf->node_type ();
+
+      // If we are doing a home, we check for a parent.
+      if (nt == AST_Decl::NT_home)
         {
-          (void) this->insert_non_dup (be_global->ccmobject ());
+          this->enqueue_base_home_r (
+            AST_Home::narrow_from_decl (intf));
+        }
 
-          AST_Component *base =
-            AST_Component::narrow_from_decl (intf)->base_component ();
-
-          if (base != 0)
+      // If we are doing a component, we check for a parent.
+      if (nt == AST_Decl::NT_component || nt == AST_Decl::NT_connector)
+        {
+          if (add_ccm_object)
             {
-              (void) this->insert_non_dup (base);
-
-              long const n_supports = base->n_supports ();
-              AST_Interface **supports = base->supports ();
-
-              for (long j = 0; j < n_supports; ++j)
-                {
-                  (void) this->insert_non_dup (supports[j],
-                                               abstract_paths_only);
-                }
+              (void) this->insert_non_dup (be_global->ccmobject ());
             }
+
+          this->enqueue_base_component_r (
+            AST_Component::narrow_from_decl (intf));
         }
 
       (void) this->insert_non_dup (intf, abstract_paths_only);
@@ -1705,6 +1696,8 @@ be_interface::gen_gperf_lookup_methods (const char *flat_name)
                          "fclose"),
                         -1);
     }
+  // And reset file to 0 because otherwise there is a problem during destruction of stream.
+  tao_cg->gperf_input_stream ()->file () = 0;
 
   // Open the temp file.
 #if defined (ACE_OPENVMS)
@@ -1716,16 +1709,16 @@ be_interface::gen_gperf_lookup_methods (const char *flat_name)
                              "fop=dfw");
   //FUZZ: enable check_for_lack_ACE_OS
 #else
-  ACE_HANDLE input = ACE::open_temp_file (tao_cg->gperf_input_filename (),
+  ACE_HANDLE input = ACE::open_temp_file (ACE_TEXT_CHAR_TO_TCHAR (tao_cg->gperf_input_filename ()),
                                           O_RDONLY);
 #endif
 
   if (input == ACE_INVALID_HANDLE)
     {
-      ACE_ERROR_RETURN ((LM_ERROR,
-                         "Error:%p:File open failed on gperf's temp input file\n",
-                         "open_temp_file"),
-                        -1);
+      ACE_ERROR ((LM_ERROR, "Error:%p:File open failed on gperf's temp input file %s\n",
+                  "open_temp_file",
+                  tao_cg->gperf_input_filename ()));
+      return -1;
     }
 
 #ifndef ACE_OPENVMS
@@ -1783,67 +1776,67 @@ be_interface::gen_gperf_lookup_methods (const char *flat_name)
   {
       // Perfect Hashing.
     case BE_GlobalData::TAO_PERFECT_HASH:
-      process_options.command_line ("%s"
-                                    " "
-                                    "-m -M -J -c -C"
-                                    " "
-                                    "-D -E -T -f 0"
-                                    " "
-                                    "-F 0,0"
-                                    " "
-                                    "-a -o -t -p -K"
-                                    " "
-                                    "opname -L C++"
-                                    " "
-                                    "-Z TAO_%s_Perfect_Hash_OpTable"
-                                    " "
-                                    "-N lookup",
+      process_options.command_line (ACE_TEXT ("%s")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-m -M -J -c -C")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-D -E -T -f 0")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-F 0,0")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-a -o -t -p -K")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("opname -L C++")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-Z TAO_%s_Perfect_Hash_OpTable")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-N lookup"),
                                     idl_global->gperf_path (),
                                     flat_name);
       break;
 
       // Binary search methods from GPERF. Everythis and the -B flag.
     case BE_GlobalData::TAO_BINARY_SEARCH:
-      process_options.command_line ("%s"
-                                    " "
-                                    "-B"
-                                    "  "
-                                    "-m -M -J -c -C"
-                                    " "
-                                    "-D -E -T -f 0"
-                                    " "
-                                    "-F 0,0,0"
-                                    " "
-                                    "-a -o -t -p -K"
-                                    " "
-                                    "opname -L C++"
-                                    " "
-                                    "-Z TAO_%s_Binary_Search_OpTable"
-                                    " "
-                                    "-N lookup",
+      process_options.command_line (ACE_TEXT ("%s")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-B")
+                                    ACE_TEXT ("  ")
+                                    ACE_TEXT ("-m -M -J -c -C")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-D -E -T -f 0")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-F 0,0,0")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-a -o -t -p -K")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("opname -L C++")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-Z TAO_%s_Binary_Search_OpTable")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-N lookup"),
                                     idl_global->gperf_path (),
                                     flat_name);
       break;
 
       // Linear search methods from GPERF. Everything and the -Z flag.
     case BE_GlobalData::TAO_LINEAR_SEARCH:
-      process_options.command_line ("%s"
-                                    " "
-                                    "-b"
-                                    "  "
-                                    "-m -M -J -c -C"
-                                    " "
-                                    "-D -E -T -f 0"
-                                    " "
-                                    "-F 0,0"
-                                    " "
-                                    "-a -o -t -p -K"
-                                    " "
-                                    "opname -L C++"
-                                    " "
-                                    "-Z TAO_%s_Linear_Search_OpTable"
-                                    " "
-                                    "-N lookup",
+      process_options.command_line (ACE_TEXT ("%s")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-b")
+                                    ACE_TEXT ("  ")
+                                    ACE_TEXT ("-m -M -J -c -C")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-D -E -T -f 0")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-F 0,0")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-a -o -t -p -K")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("opname -L C++")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-Z TAO_%s_Linear_Search_OpTable")
+                                    ACE_TEXT (" ")
+                                    ACE_TEXT ("-N lookup"),
                                     idl_global->gperf_path (),
                                     flat_name);
       break;
@@ -1859,7 +1852,7 @@ be_interface::gen_gperf_lookup_methods (const char *flat_name)
   if (result != -1)
     {
       result = process.spawn (process_options);
-      
+
       // Spawn a process for gperf.
       if (result == -1)
         {
@@ -1873,7 +1866,7 @@ be_interface::gen_gperf_lookup_methods (const char *flat_name)
         {
           ACE_exitcode exitcode;
           result = process.wait (&exitcode);
-          
+
           if (result == -1)
             {
               ACE_ERROR ((LM_ERROR,
@@ -1899,8 +1892,7 @@ be_interface::gen_gperf_lookup_methods (const char *flat_name)
 
   if (result != -1)
     {
-      FILE* gperfOutputFile;
-      gperfOutputFile = ACE_OS::fopen (gperfOutput, "r");
+      FILE* gperfOutputFile = ACE_OS::fopen (gperfOutput, "r");
 
       if (gperfOutputFile == 0)
         {
@@ -2217,11 +2209,10 @@ be_interface::gen_colloc_op_decl_helper (be_interface *derived,
 
           // Generate the static method corresponding to this method.
           *os << "static void" << be_nl
-              << d->local_name () << " (" << be_idt << be_idt_nl
-              << "TAO_Abstract_ServantBase *servant, " << be_nl
-              << "TAO::Argument ** args," << be_nl
-              << "int num_args" << be_uidt_nl
-              << ");";
+              << d->local_name () << " (" << be_idt_nl
+              << "TAO_Abstract_ServantBase *servant, "
+              << "TAO::Argument **args, "
+              << "int num_args);" << be_uidt_nl;
         }
       else if (d->node_type () == AST_Decl::NT_attr)
         {
@@ -2234,11 +2225,10 @@ be_interface::gen_colloc_op_decl_helper (be_interface *derived,
 
           // Generate the static method corresponding to this method.
           *os << "static void" << be_nl
-              << "_get_" << d->local_name () << " (" << be_idt << be_idt_nl
-              << "TAO_Abstract_ServantBase *servant, " << be_nl
-              << "TAO::Argument ** args," << be_nl
-              << "int num_args" << be_uidt_nl
-              << ");";
+              << "_get_" << d->local_name () << " (" << be_idt_nl
+              << "TAO_Abstract_ServantBase *servant, "
+              << "TAO::Argument **args, "
+              << "int num_args);" << be_uidt_nl;
 
           if (!attr->readonly ())
             {
@@ -2248,11 +2238,10 @@ be_interface::gen_colloc_op_decl_helper (be_interface *derived,
               // this method.
               *os << "static void" << be_nl
                   << "_set_" << d->local_name () << " ("
-                  << be_idt << be_idt_nl
-                  << "TAO_Abstract_ServantBase *servant, " << be_nl
-                  << "TAO::Argument ** args," << be_nl
-                  << "int num_args" << be_uidt_nl
-                  << ");";
+                  << be_idt_nl
+                  << "TAO_Abstract_ServantBase *servant, "
+                  << "TAO::Argument **args, "
+                  << "int num_args);" << be_uidt_nl;
             }
         }
     }
@@ -2373,7 +2362,7 @@ be_interface::copy_ctor_helper (be_interface *derived,
     }
   else if (base->is_nested ())
     {
-      be_decl *scope;
+      be_decl *scope = 0;
       scope = be_scope::narrow_from_scope (base->defined_in ())->decl ();
 
       *os << "POA_" << scope->name () << "::"
@@ -2456,6 +2445,50 @@ be_interface::gen_abstract_init_helper (be_interface *node,
   return 0;
 }
 
+int
+be_interface::op_attr_decl_helper (be_interface * /*derived */,
+                                   be_interface *ancestor,
+                                   TAO_OutStream *os)
+{
+  if (be_component::narrow_from_decl (ancestor) != 0)
+    {
+      return 0;
+    }
+
+  be_visitor_context ctx;
+  ctx.stream (os);
+  ctx.state (TAO_CodeGen::TAO_ROOT_SVH);
+
+  for (UTL_ScopeActiveIterator si (ancestor, UTL_Scope::IK_decls);
+       !si.is_done ();
+       si.next ())
+    {
+      // Get the next AST decl node
+      AST_Decl *d = si.item ();
+
+      if (d->node_type () == AST_Decl::NT_op)
+        {
+          be_operation *op = be_operation::narrow_from_decl (d);
+          be_visitor_operation_ch v (&ctx);
+
+          if (v.visit_operation (op) == -1)
+            {
+            }
+        }
+      else if (d->node_type () == AST_Decl::NT_attr)
+        {
+          be_attribute *attr = be_attribute::narrow_from_decl (d);
+          be_visitor_attribute v (&ctx);
+
+          if (v.visit_attribute (attr) == -1)
+            {
+            }
+        }
+    }
+
+  return 0;
+}
+
 void
 be_interface::destroy (void)
 {
@@ -2484,13 +2517,11 @@ TAO_CodeGen::CG_STATE
 be_interface::next_state (TAO_CodeGen::CG_STATE current_state,
                           int is_extra_state)
 {
-  return this->strategy_->next_state (current_state,
-                                      is_extra_state);
+  return this->strategy_->next_state (current_state, is_extra_state);
 }
 
 int
-be_interface::has_extra_code_generation (
-  TAO_CodeGen::CG_STATE current_state)
+be_interface::has_extra_code_generation (TAO_CodeGen::CG_STATE current_state)
 {
   return this->strategy_->has_extra_code_generation (current_state);
 }
@@ -2502,7 +2533,7 @@ be_interface::original_interface (be_interface *original_interface)
 }
 
 be_interface *
-be_interface::original_interface ()
+be_interface::original_interface (void)
 {
   return this->original_interface_;
 }
@@ -2523,7 +2554,9 @@ be_interface::has_mixed_parentage (void)
 
   AST_Decl::NodeType nt = this->node_type ();
 
-  if (AST_Decl::NT_component == nt || AST_Decl::NT_home == nt)
+  if (AST_Decl::NT_component == nt
+      || AST_Decl::NT_home == nt
+      || AST_Decl::NT_connector == nt)
     {
       return 0;
     }
@@ -2554,8 +2587,7 @@ be_interface::session_component_child (void)
       UTL_ScopedName sn (&head_id, &tail);
 
       AST_Decl *session_component =
-        const_cast<be_interface*> (this)->scope ()->lookup_by_name (&sn,
-                                                                    true);
+        const_cast<be_interface*> (this)->scope ()->lookup_by_name (&sn, true);
 
       tail_id.destroy ();
       head_id.destroy ();
@@ -2594,6 +2626,449 @@ be_interface::is_event_consumer (void)
                        "Components::EventConsumerBase") == 0;
 }
 
+void
+be_interface::gen_facet_idl (TAO_OutStream &os)
+{
+  if (this->ex_idl_facet_gen ())
+    {
+      return;
+    }
+
+  this->gen_nesting_open (os);
+
+  os << be_nl
+     << "local interface CCM_"
+     << this->original_local_name ()->get_string ()
+     << " : ::"
+     << IdentifierHelper::orig_sn (this->name ()).c_str ()
+     << be_nl
+     << "{" << be_idt;
+
+  os << be_uidt_nl
+     << "};";
+
+  if (be_global->ami4ccm_call_back ())
+    {
+      ACE_CString reply_handler_local_name;
+      reply_handler_local_name += "AMI_";
+      reply_handler_local_name += this->name ()->last_component ()->get_string();
+      UTL_ScopedName *reply_handler_name =
+        static_cast<UTL_ScopedName *> (this->name ()->copy ());
+      reply_handler_name->last_component ()->replace_string (
+                                             reply_handler_local_name.c_str ()
+                                           );
+      os << be_nl << be_nl
+         << "local interface AMI_"
+         << this->original_local_name ()->get_string ()
+         << "Callback : ::CCM_AMI::ReplyHandler"
+         << be_nl
+         << "{" << be_idt_nl
+         << "void foo (in long ami_return_val, in string answer);" << be_nl
+         << "void foo_excep (in CCM_AMI::ExceptionHolder excep_holder);" << be_nl
+         << "void hello (in long ami_return_val);" << be_nl
+         << "void hello_excep (in CCM_AMI::ExceptionHolder excep_holder);" << be_nl
+         << "void get_rw_attrib (in short ami_return_val);" << be_nl
+         << "void get_rw_attrib_excep (in CCM_AMI::ExceptionHolder excep_holder);" << be_nl
+         << "void set_rw_attrib ();" << be_nl
+         << "void set_rw_attrib_excep (in CCM_AMI::ExceptionHolder excep_holder);" << be_nl
+         << "void get_ro_attrib (in short ami_return_val);" << be_nl
+         << "void get_ro_attrib_excep (in CCM_AMI::ExceptionHolder excep_holder);" << be_uidt_nl
+         << "};"
+         << be_nl;
+
+      os << be_nl
+         << "local interface CCM_AMI_"
+         << this->original_local_name ()->get_string ()
+         << "Callback : AMI_"
+         << this->original_local_name ()->get_string ()
+         << "Callback"
+         << be_nl
+         << "{"
+         << "};"
+         << be_nl;
+
+      os << be_nl << "local interface AMI_"
+         << this->original_local_name ()->get_string ()
+         << be_nl
+         << "{" << be_idt_nl
+         << "void sendc_foo (in AMI_MyFooCallback ami_handler, in string in_str);" << be_nl
+         << "void sendc_hello (in AMI_MyFooCallback ami_handler);" << be_nl
+         << "void sendc_get_rw_attrib (in AMI_MyFooCallback ami_handler);" << be_nl
+         << "void sendc_set_rw_attrib (in AMI_MyFooCallback ami_handler, in short rw_attrib);" << be_nl
+         << "void sendc_get_ro_attrib (in AMI_MyFooCallback ami_handler);" << be_uidt_nl
+         << "};"
+         << be_nl;
+
+      os << be_nl
+         << "local interface CCM_AMI_"
+         << this->original_local_name ()->get_string ()
+         << " : ::"
+         << IdentifierHelper::orig_sn (reply_handler_name).c_str ()
+         << be_nl
+         << "{" << be_idt;
+
+      os << be_uidt_nl
+         << "};";
+
+/*
+         os << be_nl << be_nl
+  << "local interface CCM_AMI_CONN_MyFoo" << be_nl
+  << "  : ::Components::EnterpriseComponent" << be_nl
+  << "{" << be_nl
+  << "  ::Hello::CCM_AMI_MyFoo get_provides_MyFoo ();" << be_nl
+  << "};" << be_nl
+  << be_nl
+  << "local interface CCM_AMI_CONN_MyFoo_Context" << be_nl
+  << "  : ::Components::SessionContext" << be_nl
+  << "{" << be_nl
+  << "  ::Hello::MyFoo get_connection_uses_MyFoo ();" << be_nl
+  << "  ::Hello::AMI_MyFoo get_connection_provides_MyFoo ();" << be_nl
+  << "};";*/
+    }
+
+  this->gen_nesting_close (os);
+
+  this->ex_idl_facet_gen (true);
+}
+
+void
+be_interface::enqueue_base_component_r (AST_Component *node)
+{
+  AST_Component *base = node->base_component ();
+
+  if (base == 0)
+    {
+      return;
+    }
+
+  this->enqueue_base_component_r (base);
+
+  (void) this->insert_non_dup (base);
+
+  long const n_supports = base->n_supports ();
+  AST_Type **supports = base->supports ();
+
+  for (long j = 0; j < n_supports; ++j)
+    {
+      (void) this->insert_non_dup (supports[j]);
+    }
+}
+
+void
+be_interface::enqueue_base_home_r (AST_Home *node)
+{
+  AST_Home *base = node->base_home ();
+
+  if (base == 0)
+    {
+      return;
+    }
+
+  this->enqueue_base_home_r (base);
+
+  (void) this->insert_non_dup (base);
+
+  long const n_supports = base->n_supports ();
+  AST_Type **supports = base->supports ();
+
+  for (long j = 0; j < n_supports; ++j)
+    {
+      (void) this->insert_non_dup (supports[j]);
+    }
+}
+
+// =================================================================
+
+class Facet_Op_Attr_Helper
+  : public TAO_IDL_Inheritance_Hierarchy_Worker
+{
+public:
+  Facet_Op_Attr_Helper (be_visitor *visitor);
+
+  virtual int emit (be_interface *derived_interface,
+                    TAO_OutStream *os,
+                    be_interface *base_interface);
+
+private:
+  be_visitor *visitor_;
+};
+
+Facet_Op_Attr_Helper::Facet_Op_Attr_Helper (
+    be_visitor *visitor)
+  : visitor_ (visitor)
+{
+}
+
+int
+Facet_Op_Attr_Helper::emit (be_interface * /*derived_interface */,
+                            TAO_OutStream *,
+                            be_interface *base_interface)
+{
+  AST_Decl::NodeType nt = base_interface->node_type ();
+
+  if (nt == AST_Decl::NT_component || nt == AST_Decl::NT_connector)
+    {
+      return 0;
+    }
+
+  return visitor_->visit_scope (base_interface);
+}
+
+// ================================================================
+
+int
+be_interface::gen_facet_svnt_hdr (be_visitor *visitor,
+                                  TAO_OutStream &os)
+{
+  // No '_cxx_' prefix>
+  const char *lname =
+    this->original_local_name ()->get_string ();
+
+  be_decl *scope =
+    be_scope::narrow_from_scope (this->defined_in ())->decl ();
+  ACE_CString suffix (scope->flat_name ());
+
+  ACE_CString export_macro (be_global->svnt_export_macro ());
+
+  if (export_macro == "")
+    {
+      export_macro = be_global->skel_export_macro ();
+    }
+
+  if (suffix != "")
+    {
+      suffix = ACE_CString ("_") + suffix;
+    }
+
+  os << be_nl << be_nl
+     << "namespace CIAO_FACET" << suffix.c_str () << be_nl
+     << "{" << be_idt_nl;
+
+  os << "class " << export_macro.c_str () <<  " " << lname << "_Servant" << be_idt_nl
+     << ": public virtual " << this->full_skel_name () << be_uidt_nl
+     << "{" << be_nl
+     << "public:" << be_idt_nl;
+
+  AST_Decl *s = ScopeAsDecl (this->defined_in ());
+  ACE_CString sname_str (s->full_name ());
+  const char *sname = sname_str.c_str ();
+  const char *global = (sname_str == "" ? "" : "::");
+
+  os << lname << "_Servant (" << be_idt_nl
+     << global << sname << "::CCM_"
+     << lname << "_ptr executor," << be_nl
+     << "::Components::CCMContext_ptr ctx);" << be_uidt_nl << be_nl;
+
+  os << "virtual ~" << lname << "_Servant (void);";
+
+  this->insert_queue.reset ();
+  this->del_queue.reset ();
+  this->insert_queue.enqueue_tail (this);
+
+  Facet_Op_Attr_Helper helper (visitor);
+
+  int status =
+    this->traverse_inheritance_graph (helper,
+                                      &os,
+                                      false,
+                                      false);
+
+  if (status == -1)
+    {
+      ACE_ERROR_RETURN ((LM_ERROR,
+                         ACE_TEXT ("be_interface::")
+                         ACE_TEXT ("gen_facet_svnt_hdr - ")
+                         ACE_TEXT ("traverse_inheritance_graph() ")
+                         ACE_TEXT ("failed\n")),
+                        -1);
+    }
+
+  os << be_nl << be_nl << "// Get component implementation." << be_nl
+     << "virtual CORBA::Object_ptr _get_component (void);"
+     << be_uidt_nl << be_nl;
+
+  os << "protected:" << be_idt_nl;
+
+  os << "// Facet executor." << be_nl
+     << global << sname << "::CCM_"
+     << lname << "_var executor_;" << be_nl << be_nl;
+
+  os << "// Context object." << be_nl
+     << "::Components::CCMContext_var ctx_;" << be_uidt_nl;
+
+  os << "};" << be_nl << be_nl;
+
+  os << be_uidt_nl
+     << "}";
+
+  return 0;
+}
+
+int
+be_interface::gen_facet_svnt_src (be_visitor *visitor,
+                                  TAO_OutStream &os)
+{
+  // No '_cxx_' prefix.
+  const char *lname =
+    this->original_local_name ()->get_string ();
+
+  be_decl *scope =
+    be_scope::narrow_from_scope (this->defined_in ())->decl ();
+
+  ACE_CString sname_str (scope->full_name ());
+
+  const char *sname = sname_str.c_str ();
+  const char *global = (sname_str == "" ? "" : "::");
+
+  ACE_CString suffix (scope->flat_name ());
+
+  if (suffix != "")
+    {
+      suffix = ACE_CString ("_") + suffix;
+    }
+
+  os << be_nl << be_nl
+     << "namespace CIAO_FACET" << suffix.c_str () << be_nl
+     << "{" << be_idt_nl;
+
+  os << lname << "_Servant::"
+     << lname << "_Servant (" << be_idt << be_idt_nl
+     << global << sname << "::CCM_"
+     << lname << "_ptr executor," << be_nl
+     << "::Components::CCMContext_ptr ctx)" << be_uidt_nl
+     << ": executor_ ( " << global << sname
+     << "::CCM_" << lname
+     << "::_duplicate (executor))," << be_idt_nl
+     << "ctx_ ( ::Components::CCMContext::_duplicate (ctx))"
+     << be_uidt << be_uidt_nl
+     << "{" << be_nl
+     << "}";
+
+  os << be_nl << be_nl
+     << lname << "_Servant::~"
+     << lname << "_Servant (void)" << be_nl
+     << "{" << be_nl
+     << "}";
+
+  os << be_nl << be_nl
+     << "// All facet operations and attributes.";
+
+  /// The overload of traverse_inheritance_graph() used here
+  /// doesn't automatically prime the queues.
+  this->insert_queue.reset ();
+  this->del_queue.reset ();
+  this->insert_queue.enqueue_tail (this);
+
+  Facet_Op_Attr_Helper op_attr_gen (visitor);
+
+  int status =
+    this->traverse_inheritance_graph (op_attr_gen,
+                                      &os,
+                                      false,
+                                      false);
+
+  if (status == -1)
+    {
+      ACE_ERROR_RETURN ((LM_ERROR,
+                         ACE_TEXT ("be_interface::")
+                         ACE_TEXT ("gen_facet_svnt_src - ")
+                         ACE_TEXT ("traverse_inheritance_graph() ")
+                         ACE_TEXT ("failed\n")),
+                        -1);
+    }
+
+  os << be_nl << be_nl
+     << "::CORBA::Object_ptr" << be_nl
+     << lname << "_Servant::_get_component (void)"
+     << be_nl
+     << "{" << be_idt_nl
+     << "::Components::SessionContext_var sc =" << be_idt_nl
+     << "::Components::SessionContext::_narrow (this->ctx_.in ());"
+     << be_uidt_nl << be_nl
+     << "if (! ::CORBA::is_nil (sc.in ()))" << be_idt_nl
+     << "{" << be_idt_nl
+     << "return sc->get_CCM_object ();" << be_uidt_nl
+     << "}" << be_uidt_nl << be_nl
+     << "::Components::EntityContext_var ec =" << be_idt_nl
+     << "::Components::EntityContext::_narrow (this->ctx_.in ());"
+     << be_uidt_nl << be_nl
+     << "if (! ::CORBA::is_nil (ec.in ()))" << be_idt_nl
+     << "{" << be_idt_nl
+     << "return ec->get_CCM_object ();" << be_uidt_nl
+     << "}" << be_uidt_nl << be_nl
+     << "throw ::CORBA::INTERNAL ();" << be_uidt_nl
+     << "}";
+
+  os << be_uidt_nl
+     << "}";
+
+  return 0;
+}
+
+void
+be_interface::gen_nesting_open (TAO_OutStream &os)
+{
+  os << be_nl;
+
+  for (UTL_IdListActiveIterator i (this->name ()); ! i.is_done () ;)
+    {
+      UTL_ScopedName tmp (i.item (), 0);
+      AST_Decl *scope =
+        this->defined_in ()->lookup_by_name (&tmp, true);
+
+      if (scope == 0)
+        {
+          i.next ();
+          continue;
+        }
+
+      ACE_CString module_name =
+        IdentifierHelper::try_escape (scope->original_local_name ());
+
+      if (module_name == "")
+        {
+          i.next ();
+          continue;
+        }
+
+      i.next ();
+
+      if (i.is_done ())
+        {
+          break;
+        }
+
+      os << be_nl
+         << "module " << module_name.c_str () << be_nl
+         << "{" << be_idt;
+    }
+}
+
+void
+be_interface::gen_nesting_close (TAO_OutStream &os)
+{
+  for (UTL_IdListActiveIterator i (this->name ()); ! i.is_done () ;)
+    {
+      ACE_CString module_name (i.item ()->get_string ());
+
+      if (module_name == "")
+        {
+          i.next ();
+          continue;
+        }
+
+      i.next ();
+
+      if (i.is_done ())
+        {
+          break;
+        }
+
+      os << be_uidt_nl
+         << "};";
+    }
+}
+
 const char *
 be_interface::base_proxy_impl_name (void)
 {
@@ -2687,8 +3162,5 @@ be_interface::server_enclosing_scope (void)
   return this->strategy_->server_scope ();
 }
 
-
-
-
 IMPL_NARROW_FROM_DECL (be_interface)
 IMPL_NARROW_FROM_SCOPE (be_interface)
