@@ -1,32 +1,23 @@
-// $Id: be_interface_strategy.cpp 77405 2007-02-26 23:35:31Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_interface_strategy.cpp
-//
-// = DESCRIPTION
-//    A strategy to cover the differences between various variants
-//    of an interface
-//
-// = AUTHOR
-//    Michael Kircher
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_interface_strategy.cpp
+ *
+ *  $Id: be_interface_strategy.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  A strategy to cover the differences between various variants
+ *  of an interface
+ *
+ *
+ *  @author Michael Kircher
+ */
+//=============================================================================
 
 #include "be_interface_strategy.h"
 #include "be_interface.h"
 #include "be_extern.h"
 #include "utl_identifier.h"
 
-ACE_RCSID (be,
-           be_interface_strategy,
-           "$Id: be_interface_strategy.cpp 77405 2007-02-26 23:35:31Z ossama $")
-
-
 be_interface_strategy::be_interface_strategy (be_interface *node,
                                               Strategy_Kind strategy_type)
   : local_name_(0),
@@ -593,7 +584,8 @@ be_interface_default_strategy::flat_client_scope (void)
     }
 
   const char *full_name = this->flat_name ();
-  const char *name = this->local_name ();
+  const char *name =
+    this->node_->original_local_name ()->get_string ();
 
   size_t offset = ACE_OS::strlen (name);
   size_t length = ACE_OS::strlen (full_name) - offset;
