@@ -1,30 +1,21 @@
-// $Id: be_operation_strategy.cpp 79376 2007-08-16 23:46:36Z sowayaa $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_operation_strategy.cpp
-//
-// = DESCRIPTION
-//    A strategy to cover the differences between various variants
-//    of an operations, e.g. AMI sendc_, AMI raise_
-//
-// = AUTHOR
-//    Michael Kircher
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_operation_strategy.cpp
+ *
+ *  $Id: be_operation_strategy.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  A strategy to cover the differences between various variants
+ *  of an operations, e.g. AMI sendc_, AMI raise_
+ *
+ *
+ *  @author Michael Kircher
+ */
+//=============================================================================
 
 #include "be_operation_strategy.h"
 #include "be_operation.h"
 
-ACE_RCSID (be,
-           be_operation_strategy,
-           "$Id: be_operation_strategy.cpp 79376 2007-08-16 23:46:36Z sowayaa $")
-
-
 be_operation_strategy::be_operation_strategy (be_operation *node,
                                               Strategy_Kind strategy_type)
   : node_ (node),
