@@ -1,23 +1,18 @@
-// $Id: be_sequence.cpp 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_sequence.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_Sequence that provides additional means for C++
-//    mapping.
-//
-// = AUTHOR
-//    Copyright 1994-1995 by Sun Microsystems, Inc.
-//    and
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_sequence.cpp
+ *
+ *  $Id: be_sequence.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_Sequence that provides additional means for C++
+ *  mapping.
+ *
+ *
+ *  @author Copyright 1994-1995 by Sun Microsystems
+ *  @author Inc. and Aniruddha Gokhale
+ */
+//=============================================================================
 
 #include "be_sequence.h"
 #include "be_typedef.h"
@@ -27,6 +22,7 @@
 #include "be_field.h"
 #include "be_visitor.h"
 #include "be_helper.h"
+#include "be_string.h"
 
 #include "utl_identifier.h"
 #include "idl_defines.h"
@@ -35,27 +31,6 @@
 
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (be,
-           be_sequence,
-           "$Id: be_sequence.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-be_sequence::be_sequence (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    AST_Sequence (),
-    UTL_Scope (),
-    be_scope (),
-    be_decl (),
-    be_type (),
-    mt_ (be_sequence::MNG_UNKNOWN),
-    field_node_ (0)
-{
-  // Always the case.
-  this->has_constructor (true);
-}
-
 be_sequence::be_sequence (AST_Expression *v,
                           AST_Type *t,
                           UTL_ScopedName *n,
@@ -148,6 +123,14 @@ be_sequence::be_sequence (AST_Expression *v,
     }
 }
 
+be_type *
+be_sequence::base_type (void) const
+{
+  return
+    be_type::narrow_from_decl (
+      this->AST_Sequence::base_type ());
+}
+
 // Helper to create_name.
 char *
 be_sequence::gen_name (void)
@@ -200,7 +183,6 @@ be_sequence::gen_name (void)
       // template and non-template implementations of IDL sequences.
       UTL_Scope *parent = this->defined_in ();
       seq->set_defined_in (parent);
-      parent->add_sequence (seq);
       char *seq_name = seq->gen_name ();
 
       ACE_OS::sprintf (namebuf,
@@ -329,6 +311,7 @@ be_sequence::managed_type (void)
           case AST_Decl::NT_interface_fwd:
           case AST_Decl::NT_component:
           case AST_Decl::NT_component_fwd:
+          case AST_Decl::NT_connector:
             this->mt_ = be_sequence::MNG_OBJREF;
             break;
           case AST_Decl::NT_valuebox:
@@ -404,7 +387,8 @@ be_sequence::decl (void)
 
 // Overridden method
 void
-be_sequence::gen_ostream_operator (TAO_OutStream *os)
+be_sequence::gen_ostream_operator (TAO_OutStream *os,
+                                   bool /* use_underscore */)
 {
   *os << be_nl
       << "std::ostream& operator<< (" << be_idt << be_idt_nl
@@ -624,27 +608,121 @@ be_sequence::gen_base_class_name (TAO_OutStream *os,
 
       break;
     case be_sequence::MNG_STRING:
-      if (this->unbounded ())
-        {
-          *os << "TAO::unbounded_basic_string_sequence<char>";
-        }
-      else
-        {
-          *os << "TAO::bounded_basic_string_sequence<char, "
-              << this->max_size ()->ev ()->u.ulval << ">";
-        }
+      {
+        be_type *prim_type = 0;
+        if (elem->node_type () == AST_Decl::NT_typedef)
+          {
+            // Get the primitive base type of this typedef node.
+            be_typedef *t = be_typedef::narrow_from_decl (elem);
+            prim_type = t->primitive_base_type ();
+          }
+        else
+          {
+            prim_type = elem;
+          }
+
+        if (prim_type->node_type () == AST_Decl::NT_string)
+          {
+            be_string *str =
+              be_string::narrow_from_decl (prim_type);
+            if (!str)
+              {
+                ACE_ERROR_RETURN ((LM_ERROR,
+                                   "(%N:%l) be_sequence::"
+                                   "gen_base_class_name - "
+                                   "bad string node\n"),
+                                  -1);
+              }
+
+            // We need to make a distinction between bounded and
+            // unbounded strings.
+            if (str->max_size ()->ev ()->u.ulval != 0)
+              {
+                if (this->unbounded ())
+                  {
+                    *os << "TAO::unbounded_bd_string_sequence<char, "
+                        << str->max_size ()->ev ()->u.ulval << ">";
+                  }
+                else
+                  {
+                    *os << "TAO::bounded_bd_string_sequence<char, "
+                        << this->max_size ()->ev ()->u.ulval << ", "
+                        << str->max_size ()->ev ()->u.ulval << ">";
+                  }
+              }
+            else
+              {
+                if (this->unbounded ())
+                  {
+                    *os << "TAO::unbounded_basic_string_sequence<char>";
+                  }
+                else
+                  {
+                    *os << "TAO::bounded_basic_string_sequence<char, "
+                        << this->max_size ()->ev ()->u.ulval << ">";
+                  }
+              }
+          }
+      }
 
       break;
     case be_sequence::MNG_WSTRING:
-      if (this->unbounded ())
-        {
-          *os << "TAO::unbounded_basic_string_sequence<CORBA::WChar>";
-        }
-      else
-        {
-          *os << "TAO::bounded_basic_string_sequence<CORBA::WChar, "
-              << this->max_size ()->ev ()->u.ulval << ">";
-        }
+      {
+        be_type *prim_type = 0;
+        if (elem->node_type () == AST_Decl::NT_typedef)
+          {
+            // Get the primitive base type of this typedef node.
+            be_typedef *t = be_typedef::narrow_from_decl (elem);
+            prim_type = t->primitive_base_type ();
+          }
+        else
+          {
+            prim_type = elem;
+          }
+
+        if (prim_type->node_type () == AST_Decl::NT_wstring)
+          {
+            be_string *str =
+              be_string::narrow_from_decl (prim_type);
+            if (!str)
+              {
+                ACE_ERROR_RETURN ((LM_ERROR,
+                                   "(%N:%l) be_sequence::"
+                                   "gen_base_class_name - "
+                                   "bad string node\n"),
+                                  -1);
+              }
+
+            // We need to make a distinction between bounded and
+            // unbounded strings.
+            if (str->max_size ()->ev ()->u.ulval != 0)
+              {
+                if (this->unbounded ())
+                  {
+                    *os << "TAO::unbounded_bd_string_sequence<CORBA::WChar, "
+                        << str->max_size ()->ev ()->u.ulval << ">";
+                  }
+                else
+                  {
+                    *os << "TAO::bounded_bd_string_sequence<CORBA::WChar, "
+                        << this->max_size ()->ev ()->u.ulval << ", "
+                        << str->max_size ()->ev ()->u.ulval << ">";
+                  }
+              }
+            else
+              {
+                if (this->unbounded ())
+                  {
+                    *os << "TAO::unbounded_basic_string_sequence<CORBA::WChar>";
+                  }
+                else
+                  {
+                    *os << "TAO::bounded_basic_string_sequence<CORBA::WChar, "
+                        << this->max_size ()->ev ()->u.ulval << ">";
+                  }
+              }
+          }
+      }
 
       break;
     default: // Not a managed type.
