@@ -1,7 +1,6 @@
-// $Id: be_tmplinst.cpp 68471 2005-10-04 11:38:20Z jwillemsen $
+// $Id: be_tmplinst.cpp 86020 2009-07-14 12:13:54Z wotte $
 
 #include "be_visitor_typecode/typecode_defn.h"
-#include "be_stream_factory.h"
 #include "be_visitor_factory.h"
 #include "ast_interface.h"
 #include "ace/Singleton.h"
@@ -10,6 +9,5 @@
 
 #if defined (ACE_HAS_EXPLICIT_STATIC_TEMPLATE_MEMBER_INSTANTIATION)
 template class ACE_Singleton<TAO_CodeGen, ACE_SYNCH_RECURSIVE_MUTEX>;
-template class ACE_Singleton<TAO_OutStream_Factory,ACE_SYNCH_RECURSIVE_MUTEX>;
 template class ACE_Singleton<TAO_Visitor_Factory,ACE_SYNCH_RECURSIVE_MUTEX>;
 #endif /* ACE_HAS_EXPLICIT_STATIC_TEMPLATE_MEMBER_INSTANTIATION */
