@@ -1,23 +1,18 @@
-// $Id: be_type.cpp 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_type.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_Type that provides additional means for C++
-//    mapping.
-//
-// = AUTHOR
-//    Copyright 1994-1995 by Sun Microsystems, Inc.
-//    and
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_type.cpp
+ *
+ *  $Id: be_type.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_Type that provides additional means for C++
+ *  mapping.
+ *
+ *
+ *  @author Copyright 1994-1995 by Sun Microsystems
+ *  @author Inc. and Aniruddha Gokhale
+ */
+//=============================================================================
 
 #include "be_type.h"
 #include "be_scope.h"
@@ -28,22 +23,6 @@
 #include "idl_defines.h"
 #include "nr_extern.h"
 
-ACE_RCSID (be,
-           be_type,
-           "$Id: be_type.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-be_type::be_type (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    be_decl (),
-    tc_name_ (0),
-    common_varout_gen_ (false),
-    seen_in_sequence_ (false),
-    seen_in_operation_ (false)
-{
-}
-
 be_type::be_type (AST_Decl::NodeType nt,
                   UTL_ScopedName *n)
   : COMMON_Base (),
@@ -233,13 +212,15 @@ be_type::gen_fwd_helper_name (void)
 }
 
 void
-be_type::gen_ostream_operator (TAO_OutStream *)
+be_type::gen_ostream_operator (TAO_OutStream *,
+                               bool /* use_underscore */)
 {
 }
 
 void
 be_type::gen_member_ostream_operator (TAO_OutStream *os,
                                       const char *instance_name,
+                                      bool /* use_underscore */,
                                       bool accessor)
 {
   *os << instance_name << (accessor ? " ()" : "");
