@@ -1,42 +1,22 @@
-// $Id: be_union_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_union_fwd.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_UnionFwd that provides additional means for C++
-//    mapping of a union.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_union_fwd.cpp
+ *
+ *  $Id: be_union_fwd.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_UnionFwd that provides additional means for C++
+ *  mapping of a union.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 #include "be_union_fwd.h"
 #include "be_visitor.h"
 #include "ast_union.h"
 
-ACE_RCSID (be, 
-           be_union_fwd, 
-           "$Id: be_union_fwd.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-be_union_fwd::be_union_fwd (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_StructureFwd (),
-    AST_UnionFwd (),
-    be_decl (),
-    be_type (),
-    be_structure_fwd ()
-{
-}
-
 be_union_fwd::be_union_fwd (AST_Union *dummy,
                             UTL_ScopedName *n)
   : COMMON_Base (),
