@@ -1,19 +1,10 @@
 //
-// $Id: be_union_label.cpp 79376 2007-08-16 23:46:36Z sowayaa $
+// $Id: be_union_label.cpp 89076 2010-02-18 22:54:36Z parsons $
 //
 
 #include "be_union_label.h"
 #include "be_visitor.h"
 
-ACE_RCSID (be,
-           be_union_label,
-           "$Id: be_union_label.cpp 79376 2007-08-16 23:46:36Z sowayaa $")
-
-be_union_label::be_union_label (void)
-  : AST_UnionLabel ()
-{
-}
-
 be_union_label::be_union_label (AST_UnionLabel::UnionLabel ul,
                                 AST_Expression *v)
   : AST_UnionLabel (ul, v)
