@@ -1,53 +1,23 @@
-// $Id: be_valuebox.cpp 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_valuebox.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_Valuebox that provides additional means for C++
-//    mapping.
-//
-// = AUTHOR
-//    Gary Maxey
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_valuebox.cpp
+ *
+ *  $Id: be_valuebox.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_Valuebox that provides additional means for C++
+ *  mapping.
+ *
+ *
+ *  @author Gary Maxey
+ */
+//=============================================================================
 
 #include "be_valuebox.h"
 #include "be_type.h"
 #include "be_visitor.h"
 #include "global_extern.h"
 
-ACE_RCSID (be,
-           be_valuebox,
-           "be_valuebox.cpp Exp")
-
-// Default constructor.
-be_valuebox::be_valuebox (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    AST_ConcreteType (),
-    AST_ValueBox (),
-    be_decl (),
-    be_type ()
-{
-  // Always the case (according to C++ mapping specification).
-  this->size_type (AST_Type::VARIABLE);
-
-  // Set the flag  that says we have a valuetype in this IDL file.
-  // This allows the correct #include to be generated (see be_codegen.cpp).
-  idl_global->valuebase_seen_ = true;
-
-  // Set the flag that says we have a valuetype in this IDL file.
-  // This allows the correct #include to be generated (see be_codegen.cpp).
-  idl_global->valuetype_seen_ = true;
-}
-
 be_valuebox::be_valuebox (AST_Type *boxed_type,
                           UTL_ScopedName *n)
   : COMMON_Base (),
