@@ -1,22 +1,17 @@
-// $Id: be_valuetype.cpp 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_valuetype.cpp
-//
-// = DESCRIPTION
-//    Extension of class AST_Interface and be_interface that provides
-//    additional means for C++ mapping of an valuetype.
-//
-// = AUTHOR
-//    Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de>
-//    derived from be_interface.cpp
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_valuetype.cpp
+ *
+ *  $Id: be_valuetype.cpp 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_Interface and be_interface that provides
+ *  additional means for C++ mapping of an valuetype.
+ *
+ *
+ *  @author Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de>
+ */
+//=============================================================================
 
 #include "be_valuetype.h"
 #include "be_visitor.h"
@@ -29,48 +24,15 @@
 #include "global_extern.h"
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (be,
-           be_valuetype,
-           "$Id: be_valuetype.cpp 78883 2007-07-13 17:55:30Z ossama $")
-
-// Default constructor.
-be_valuetype::be_valuetype (void)
-  : COMMON_Base (),
-    AST_Decl (),
-    AST_Type (),
-    UTL_Scope (),
-    AST_Interface (),
-    be_scope (),
-    be_decl (),
-    be_type (),
-    be_interface (),
-    AST_ValueType (),
-    full_obv_skel_name_ (0)
-{
-  // Always the case.
-  this->size_type (AST_Type::VARIABLE);
-
-  AST_Module *m = AST_Module::narrow_from_scope (this->defined_in ());
-
-  if (m != 0)
-    {
-      m->set_has_nested_valuetype ();
-    }
-
-  // Always the case.
-  this->has_constructor (true);
-}
-
-// Constructor used to build the AST.
 be_valuetype::be_valuetype (UTL_ScopedName *n,
-                            AST_Interface **inherits,
+                            AST_Type **inherits,
                             long n_inherits,
-                            AST_ValueType *inherits_concrete,
+                            AST_Type *inherits_concrete,
                             AST_Interface **inherits_flat,
                             long n_inherits_flat,
-                            AST_Interface **supports,
+                            AST_Type **supports,
                             long n_supports,
-                            AST_Interface *supports_concrete,
+                            AST_Type *supports_concrete,
                             bool abstract,
                             bool truncatable,
                             bool custom)
@@ -135,6 +97,12 @@ be_valuetype::be_valuetype (UTL_ScopedName *n,
     {
       be_interface *intf =
         be_interface::narrow_from_decl (this->pd_supports[i]);
+        
+      if (intf == 0)
+        {
+          // The item is a temploate param holder.
+          continue;
+        }
 
       if (intf->is_abstract () || intf->has_mixed_parentage ())
         {
@@ -318,7 +286,7 @@ be_valuetype::have_operation (void)
       // Now traverse inheritance tree.
       long i;  // loop index
       long n_inherits = this->n_inherits ();
-      AST_Interface **inherits = this->inherits ();
+      AST_Type **inherits = this->inherits ();
 
       for (i = 0; i < n_inherits; ++i)
         {
@@ -335,15 +303,17 @@ be_valuetype::have_operation (void)
   if (! have_operation)
     {
       // Check for operations on supported interfaces
-      AST_Interface * supported = this->supports_concrete ();
+      AST_Type * supported = this->supports_concrete ();
 
       if (supported != 0)
         {
-          be_interface *intf = be_interface::narrow_from_decl (supported);
+          be_interface *intf =
+            be_interface::narrow_from_decl (supported);
 
           if (intf != 0)
             {
-                    have_operation = be_valuetype::have_supported_op (intf);
+              have_operation =
+                be_valuetype::have_supported_op (intf);
             }
         }
     }
@@ -393,14 +363,17 @@ be_valuetype::have_supported_op (be_interface * node)
       // Now traverse inheritance tree.
       long i;  // loop index
       long n_inherits = node->n_inherits ();
-      AST_Interface **inherits = node->inherits ();
+      AST_Type **inherits = node->inherits ();
+      
       for (i = 0; i < n_inherits; ++i)
         {
-          be_interface * intf = be_interface::narrow_from_decl (inherits[i]);
+          be_interface * intf =
+            be_interface::narrow_from_decl (inherits[i]);
 
           if (intf != 0)
             {
-              have_supported_op = be_valuetype::have_supported_op (intf);
+              have_supported_op =
+                be_valuetype::have_supported_op (intf);
 
               if (have_supported_op)
                 {
@@ -424,7 +397,7 @@ be_valuetype::will_have_factory (void)
 bool
 be_valuetype::has_member (void)
 {
-  AST_ValueType *parent = this->pd_inherits_concrete;
+  AST_Type *parent = this->pd_inherits_concrete;
 
   // We're looking for inherited members too.
   if (parent != 0)
@@ -538,7 +511,8 @@ be_valuetype::gen_helper_stubs (char *, char *)
 }
 
 void
-be_valuetype::gen_ostream_operator (TAO_OutStream *os)
+be_valuetype::gen_ostream_operator (TAO_OutStream *os,
+                                    bool /* use_underscore */)
 {
   *os << be_nl
       << "std::ostream& operator<< (" << be_idt << be_idt_nl
@@ -742,14 +716,15 @@ int
 be_valuetype::traverse_concrete_inheritance_graph (tao_code_emitter gen,
                                                    TAO_OutStream *os)
 {
-  AST_Interface *supported = this->supports_concrete ();
+  AST_Type *supported = this->supports_concrete ();
 
   if (supported == 0)
     {
       return 0;
     }
 
-  be_interface *concrete = be_interface::narrow_from_decl (supported);
+  be_interface *concrete =
+    be_interface::narrow_from_decl (supported);
 
   // Make sure the queues are empty.
   this->insert_queue.reset ();
