@@ -1,7 +1,7 @@
 /**
  *  @file   be_visitor_amh_pre_proc.cpp
  *
- *  $Id: be_visitor_amh_pre_proc.cpp 77405 2007-02-26 23:35:31Z ossama $
+ *  $Id: be_visitor_amh_pre_proc.cpp 88827 2010-02-04 08:42:41Z johnnyw $
  *
  *  This visitor creates for AMH implied IDL constructs the appropriate AST
  *  (Abstract Syntax Tree) node, sets the corresponding interface or operation
@@ -29,10 +29,6 @@
 #include "global_extern.h"
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (be,
-           be_visitor_amh_pre_proc,
-           "$Id: be_visitor_amh_pre_proc.cpp 77405 2007-02-26 23:35:31Z ossama $")
-
 be_visitor_amh_pre_proc::be_visitor_amh_pre_proc (be_visitor_context *ctx)
   : be_visitor_scope (ctx)
 {
@@ -602,7 +598,7 @@ be_visitor_amh_pre_proc::create_exception_holder (be_interface *node)
   idl_global->valuefactory_seen_ = true;
 
   const int inherit_count = 0;
-  AST_Interface **p_intf = 0;
+  AST_Type **p_intf = 0;
 
   UTL_ScopedName *excep_holder_name =
     node->compute_name ("AMH_",
