@@ -1,26 +1,21 @@
-//
-// $Id: be_visitor_ami_pre_proc.cpp 79765 2007-10-10 20:34:09Z parsons $
-//
 
 /* -*- c++ -*- */
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_ami_pre_proc.cpp
-//
-// = DESCRIPTION
-//    This visitor creates for AMI implied IDL constructs
-//    the appropriate AST (Abstract Syntax Tree) node,
-//    sets the corresponding interface or operation strategy
-//    on it and enteres the nodes into the AST.
-//
-// = AUTHOR
-//    Michael Kircher <Michael.Kircher@mchp.siemens.de>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_ami_pre_proc.cpp
+ *
+ *  $Id: be_visitor_ami_pre_proc.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  This visitor creates for AMI implied IDL constructs
+ *  the appropriate AST (Abstract Syntax Tree) node,
+ *  sets the corresponding interface or operation strategy
+ *  on it and enteres the nodes into the AST.
+ *
+ *
+ *  @author Michael Kircher <Michael.Kircher@mchp.siemens.de>
+ */
+//=============================================================================
+
 
 #include "be_visitor_ami_pre_proc.h"
 #include "be_visitor_context.h"
@@ -42,11 +37,6 @@
 #include "global_extern.h"
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (be,
-           be_visitor_ami_pre_proc,
-           "$Id: be_visitor_ami_pre_proc.cpp 79765 2007-10-10 20:34:09Z parsons $")
-
-
 be_visitor_ami_pre_proc::be_visitor_ami_pre_proc (be_visitor_context *ctx)
   : be_visitor_scope (ctx)
 {
@@ -152,9 +142,7 @@ be_visitor_ami_pre_proc::visit_interface (be_interface *node)
                         -1);
     }
 
-  be_valuetype *excep_holder = this->create_exception_holder (node);
-  be_interface *reply_handler = this->create_reply_handler (node,
-                                                            excep_holder);
+  be_interface *reply_handler = this->create_reply_handler (node);
   if (reply_handler)
     {
       reply_handler->set_defined_in (node->defined_in ());
@@ -261,7 +249,7 @@ be_visitor_ami_pre_proc::visit_operation (be_operation *node)
 int
 be_visitor_ami_pre_proc::visit_attribute (be_attribute *node)
 {
-  // Temporerily generate the set operation.
+  // Temporarily generate the set operation.
   be_operation *set_operation =
     this->generate_set_operation (node);
 
@@ -294,7 +282,7 @@ be_visitor_ami_pre_proc::visit_attribute (be_attribute *node)
         }
     }
 
-  // Temporerily generate the get operation.
+  // Temporarily generate the get operation.
   be_operation *get_operation =
     this->generate_get_operation (node);
 
@@ -329,15 +317,8 @@ be_visitor_ami_pre_proc::visit_attribute (be_attribute *node)
   return 0;
 }
 
-be_valuetype *
-be_visitor_ami_pre_proc::create_exception_holder (be_interface *)
-{
-  return be_global->messaging_exceptionholder ();
-}
-
 be_interface *
-be_visitor_ami_pre_proc::create_reply_handler (be_interface *node,
-                                               be_valuetype *excep_holder)
+be_visitor_ami_pre_proc::create_reply_handler (be_interface *node)
 {
   // We're at global scope here so we need to fool the scope stack
   // for a minute so the correct repo id can be calculated at
@@ -359,7 +340,16 @@ be_visitor_ami_pre_proc::create_reply_handler (be_interface *node,
                                            );
 
   long n_parents = 0;
-  AST_Interface **p_intf = this->create_inheritance_list (node, n_parents);
+  AST_Type **p_intf =
+    this->create_inheritance_list (node, n_parents);
+
+  if (!p_intf)
+    {
+      ACE_ERROR_RETURN ((LM_ERROR,
+                        "(%N:%l) be_visitor_ami_pre_proc::visit_interface - "
+                        "bad inheritance list\n"),
+                        0);
+    }
 
   be_interface *reply_handler = 0;
   ACE_NEW_RETURN (reply_handler,
@@ -377,14 +367,14 @@ be_visitor_ami_pre_proc::create_reply_handler (be_interface *node,
 
   reply_handler->set_name (reply_handler_name);
   reply_handler->set_defined_in (s);
-  
+
   // Set repo id to 0, so it will be recomputed on the next access,
   // and set the prefix to the node's prefix. All this is
   // necessary in case the node's prefix was modified after
   // its declaration.
   reply_handler->AST_Decl::repoID (0);
   reply_handler->prefix (const_cast<char*> (node->prefix ()));
-  
+
   reply_handler->gen_fwd_helper_name ();
 
   // Now our customized reply handler is created, we have to
@@ -411,47 +401,46 @@ be_visitor_ami_pre_proc::create_reply_handler (be_interface *node,
                                  "(%N:%l) be_visitor_ami_pre_proc::visit_interface - "
                                  "bad node in this scope\n"),
                                 0);
-
+              ACE_ERROR_RETURN ((LM_ERROR,
+                                 "(%N:%l) be_visitor_ami_pre_proc::visit_interface - "
+                                 "bad node in this scope\n"),
+                                0);
             }
 
           if (d->node_type () == AST_Decl::NT_attr)
             {
               be_attribute *attribute = be_attribute::narrow_from_decl (d);
 
-              if (attribute == 0)
+              if (attribute)
                 {
-                  return 0;
-                }
+                  be_operation *get_operation =
+                    this->generate_get_operation (attribute);
 
-              be_operation *get_operation =
-                this->generate_get_operation (attribute);
-
-              this->create_reply_handler_operation (get_operation,
-                                                    reply_handler);
-
-              this->create_excep_operation (get_operation,
-                                            reply_handler,
-                                            excep_holder);
-
-              get_operation->destroy ();
-              delete get_operation;
-              get_operation = 0;
-
-              if (!attribute->readonly ())
-                {
-                  be_operation *set_operation =
-                    this->generate_set_operation (attribute);
-
-                  this->create_reply_handler_operation (set_operation,
+                  this->create_reply_handler_operation (get_operation,
                                                         reply_handler);
 
-                  this->create_excep_operation (set_operation,
-                                                reply_handler,
-                                                excep_holder);
+                  this->create_excep_operation (get_operation,
+                                                reply_handler);
 
-                  set_operation->destroy ();
-                  delete set_operation;
-                  set_operation = 0;
+                  get_operation->destroy ();
+                  delete get_operation;
+                  get_operation = 0;
+
+                  if (!attribute->readonly ())
+                    {
+                      be_operation *set_operation =
+                        this->generate_set_operation (attribute);
+
+                      this->create_reply_handler_operation (set_operation,
+                                                            reply_handler);
+
+                      this->create_excep_operation (set_operation,
+                                                    reply_handler);
+
+                      set_operation->destroy ();
+                      delete set_operation;
+                      set_operation = 0;
+                    }
                 }
             }
           else
@@ -464,8 +453,7 @@ be_visitor_ami_pre_proc::create_reply_handler (be_interface *node,
                                                         reply_handler);
 
                   this->create_excep_operation (operation,
-                                                reply_handler,
-                                                excep_holder);
+                                                reply_handler);
                 }
             }
         } // end of while loop
@@ -477,7 +465,6 @@ be_visitor_ami_pre_proc::create_reply_handler (be_interface *node,
 int
 be_visitor_ami_pre_proc::create_raise_operation (
     be_decl *node,
-    be_valuetype *excep_holder,
     Operation_Kind operation_kind
   )
 {
@@ -516,6 +503,8 @@ be_visitor_ami_pre_proc::create_raise_operation (
                                       sn),
                   -1);
 
+  be_valuetype *excep_holder = be_global->messaging_exceptionholder ();
+
   // Name the operation properly
   UTL_ScopedName *op_name =
     static_cast<UTL_ScopedName *> (excep_holder->name ()->copy ());
@@ -549,8 +538,8 @@ be_visitor_ami_pre_proc::create_raise_operation (
                   be_operation (rt,
                                 AST_Operation::OP_noflags,
                                 op_name,
-                                0,
-                                0),
+                                false,
+                                false),
                   -1);
 
   operation->set_name (op_name);
@@ -627,8 +616,8 @@ be_visitor_ami_pre_proc::create_sendc_operation (be_operation *node,
                   be_operation (be_global->void_type (),
                                 AST_Operation::OP_noflags,
                                 op_name,
-                                0,
-                                0),
+                                false,
+                                false),
                   0);
 
   op->set_name (op_name);
@@ -916,8 +905,7 @@ be_visitor_ami_pre_proc::create_reply_handler_operation (
 
 int
 be_visitor_ami_pre_proc::create_excep_operation (be_operation *node,
-                                                 be_interface *reply_handler,
-                                                 be_valuetype *excep_holder)
+                                                 be_interface *reply_handler)
 {
   if (!node)
     {
@@ -944,6 +932,7 @@ be_visitor_ami_pre_proc::create_excep_operation (be_operation *node,
                                   0),
                   -1);
 
+  be_valuetype *excep_holder = be_global->messaging_exceptionholder ();
   be_argument *arg = 0;
   ACE_NEW_RETURN (arg,
                   be_argument (AST_Argument::dir_IN,
@@ -984,8 +973,8 @@ be_visitor_ami_pre_proc::create_excep_operation (be_operation *node,
                   be_operation (rt,
                                 AST_Operation::OP_noflags,
                                 op_name,
-                                0,
-                                0),
+                                false,
+                                false),
                   -1);
 
   operation->set_name (op_name);
@@ -1036,7 +1025,7 @@ be_visitor_ami_pre_proc::visit_scope (be_scope *node)
           }
       }
 
-      AST_Decl **elements;
+      AST_Decl **elements = 0;
       ACE_NEW_RETURN (elements,
                       AST_Decl *[number_of_elements],
                       -1);
@@ -1076,7 +1065,7 @@ be_visitor_ami_pre_proc::visit_scope (be_scope *node)
           // Set the scope node as "node" in which the code is being
           // generated so that elements in the node's scope can use it
           // for code generation.
-          this->ctx_->scope (node->decl ());
+          this->ctx_->scope (node);
 
           // Set the node to be visited.
           this->ctx_->node (bd);
@@ -1133,13 +1122,22 @@ be_visitor_ami_pre_proc::generate_get_operation (be_attribute *node)
                   be_operation (node->field_type (),
                                 AST_Operation::OP_noflags,
                                 get_name,
-                                0,
-                                0),
+                                false,
+                                false),
                   0);
 
   operation->set_name (get_name);
   operation->set_defined_in (node->defined_in ());
 
+  // Copy the exceptions since the user exception information may
+  // be needed when collocation is disabled.
+  UTL_ExceptList *exceptions = node->get_get_exceptions ();
+
+  if (0 != exceptions)
+    {
+      operation->be_add_exceptions (exceptions->copy ());
+    }
+
   return operation;
 }
 
@@ -1171,26 +1169,35 @@ be_visitor_ami_pre_proc::generate_set_operation (be_attribute *node)
                   be_operation (be_global->void_type (),
                                 AST_Operation::OP_noflags,
                                 set_name,
-                                0,
-                                0),
+                                false,
+                                false),
                   0);
 
   operation->set_name (set_name);
   operation->set_defined_in (node->defined_in ());
   operation->be_add_argument (arg);
 
+  // Copy the exceptions since the user exception information may
+  // be needed when collocation is disabled.
+  UTL_ExceptList *exceptions = node->get_set_exceptions ();
+
+  if (0 != exceptions)
+    {
+      operation->be_add_exceptions (exceptions->copy ());
+    }
+
   return operation;
 }
 
-AST_Interface **
+AST_Type **
 be_visitor_ami_pre_proc::create_inheritance_list (be_interface *node,
                                                   long &n_rh_parents)
 {
-  AST_Interface **retval = 0;
+  AST_Type **retval = 0;
 
-  long n_parents = node->n_inherits ();
-  AST_Interface **parents = node->inherits ();
-  AST_Interface *parent = 0;
+  long const n_parents = node->n_inherits ();
+  AST_Type **parents = node->inherits ();
+  AST_Type *parent = 0;
 
   for (long i = 0; i < n_parents; ++i)
     {
@@ -1209,7 +1216,7 @@ be_visitor_ami_pre_proc::create_inheritance_list (be_interface *node,
       be_interface *inherit_intf = be_global->messaging_replyhandler ();
 
       ACE_NEW_RETURN (retval,
-                      AST_Interface *[1],
+                      AST_Type *[1],
                       0);
 
       retval[0] = inherit_intf;
@@ -1218,7 +1225,7 @@ be_visitor_ami_pre_proc::create_inheritance_list (be_interface *node,
   else
     {
       ACE_NEW_RETURN (retval,
-                      AST_Interface *[n_rh_parents],
+                      AST_Type *[n_rh_parents],
                       0);
 
       ACE_CString prefix ("AMI_");
