@@ -1,22 +1,17 @@
-//
-// $Id: be_visitor_argument.cpp 66547 2005-06-21 20:31:32Z gmaxey $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_args.cpp
-//
-// = DESCRIPTION
-//    Visitors for generation of code for Argument
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_argument.cpp
+ *
+ *  $Id: be_visitor_argument.cpp 88845 2010-02-04 12:43:28Z johnnyw $
+ *
+ *  Visitors for generation of code for Argument
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_argument.h"
 #include "be_visitor_context.h"
@@ -56,6 +51,3 @@
 #include "be_visitor_argument/invoke_cs.cpp"
 #include "be_visitor_argument/paramlist.cpp"
 
-ACE_RCSID (be,
-           be_visitor_argument,
-           "$Id: be_visitor_argument.cpp 66547 2005-06-21 20:31:32Z gmaxey $")
