@@ -1,26 +1,17 @@
-//
-// $Id: argument.cpp 57961 2004-05-23 19:03:07Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    argument.cpp
-//
-// = DESCRIPTION
-//    generic visitor for Argument node
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    argument.cpp
+ *
+ *  $Id: argument.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  generic visitor for Argument node
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_argument, 
-           argument, 
-           "$Id: argument.cpp 57961 2004-05-23 19:03:07Z parsons $")
 
 be_visitor_args::be_visitor_args (be_visitor_context *ctx)
   : be_visitor_decl (ctx),
@@ -37,19 +28,19 @@ int be_visitor_args::visit_argument (be_argument *)
   return -1;
 }
 
-// helper that returns the type name either as a nested type name (for header
+// Helper that returns the type name either as a nested type name (for header
 // files) or as a fully scoped name. In addition, we make sure that if the type
-// is an alias, we use that name
+// is an alias, we use that name.
 const char *
 be_visitor_args::type_name (be_type *node,
                             const char *suffix)
 {
   static char namebuf [NAMEBUFSIZE];
-  ACE_OS::memset (namebuf, 
-                  '\0', 
+  ACE_OS::memset (namebuf,
+                  '\0',
                   NAMEBUFSIZE);
 
-  be_type *bt;
+  be_type *bt = 0;
 
   // Use the typedefed name if that is the one used in the IDL defn.
   if (this->ctx_->alias ())
@@ -74,7 +65,7 @@ be_visitor_args::type_name (be_type *node,
   return namebuf;
 }
 
-// helper that returns the direction type of the argument
+// Helper that returns the direction type of the argument
 AST_Argument::Direction
 be_visitor_args::direction (void)
 {
@@ -83,11 +74,11 @@ be_visitor_args::direction (void)
       return AST_Argument::Direction (this->fixed_direction_);
     }
 
-  // grab the argument node. We know that our context has stored the right
-  // argument node
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  // Grab the argument node. We know that our context has stored the right
+  // argument node.
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
-  ACE_ASSERT (arg != 0);
   return arg->direction ();
 }
 
