@@ -1,27 +1,17 @@
-//
-// $Id: marshal_ss.cpp 67714 2005-08-19 08:02:52Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    marshal_ss.cpp
-//
-// = DESCRIPTION
-//    Visitor that generates code that passes the argument variable to the
-//    marshal operations.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_argument,
-           marshal_ss,
-           "$Id: marshal_ss.cpp 67714 2005-08-19 08:02:52Z jwillemsen $")
+//=============================================================================
+/**
+ *  @file    marshal_ss.cpp
+ *
+ *  $Id: marshal_ss.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor that generates code that passes the argument variable to the
+ *  marshal operations.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 
 // ************************************************************************
@@ -140,7 +130,8 @@ int be_visitor_args_marshal_ss::visit_argument (be_argument *node)
 int be_visitor_args_marshal_ss::visit_array (be_array *)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
@@ -185,7 +176,8 @@ int be_visitor_args_marshal_ss::visit_array (be_array *)
 int be_visitor_args_marshal_ss::visit_enum (be_enum *)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
@@ -253,7 +245,8 @@ int be_visitor_args_marshal_ss::visit_predefined_type (
   )
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
@@ -411,7 +404,8 @@ int be_visitor_args_marshal_ss::visit_predefined_type (
 int be_visitor_args_marshal_ss::visit_sequence (be_sequence *)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
@@ -454,7 +448,8 @@ int be_visitor_args_marshal_ss::visit_sequence (be_sequence *)
 int be_visitor_args_marshal_ss::visit_string (be_string *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
@@ -607,10 +602,11 @@ be_visitor_args_marshal_ss::visit_home (
 }
 
 int
-be_visitor_args_marshal_ss::emit_common ()
+be_visitor_args_marshal_ss::emit_common (void)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
@@ -652,7 +648,8 @@ int
 be_visitor_args_marshal_ss::emit_common2 (be_type *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (this->ctx_->sub_state () == TAO_CodeGen::TAO_CDR_INPUT)
     {
