@@ -1,27 +1,18 @@
-//
-// $Id: post_upcall_ss.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    post_upcall_ss.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code to do post-processing of arguments following an
-//    upcall.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    post_upcall_ss.cpp
+ *
+ *  $Id: post_upcall_ss.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code to do post-processing of arguments following an
+ *  upcall.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_argument, 
-           post_upcall_ss, 
-           "$Id: post_upcall_ss.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ************************************************************************
 //  visitor for doing any post-processing after the upcall is made
@@ -78,7 +69,8 @@ int be_visitor_args_post_upcall_ss::visit_argument (be_argument *node)
 int be_visitor_args_post_upcall_ss::visit_array (be_array *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_argument *arg = this->ctx_->be_node_as_argument ();
+  be_argument *arg =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   // if the current type is an alias, use that
   be_type *bt = node;
