@@ -1,22 +1,17 @@
-//
-// $Id: be_visitor_array.cpp 66547 2005-06-21 20:31:32Z gmaxey $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_array.cpp
-//
-// = DESCRIPTION
-//    Visitors for generation of code for Array
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_array.cpp
+ *
+ *  $Id: be_visitor_array.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitors for generation of code for Array
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_enum.h"
 #include "be_type.h"
@@ -55,6 +50,3 @@
 #include "be_visitor_array/serializer_op_ch.cpp"
 #include "be_visitor_array/serializer_op_cs.cpp"
 
-ACE_RCSID (be, 
-           be_visitor_array, 
-           "$Id: be_visitor_array.cpp 66547 2005-06-21 20:31:32Z gmaxey $")
