@@ -1,30 +1,21 @@
-//
-// $Id: cdr_op_ch.cpp 78602 2007-06-27 09:21:28Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor for code generation of Arrays for the Cdr operators in the client
-//    header.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_ch.cpp
+ *
+ *  $Id: cdr_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor for code generation of Arrays for the Cdr operators in the client
+ *  header.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_sequence/cdr_op_ch.h"
 
-ACE_RCSID (be_visitor_array,
-           cdr_op_ch,
-           "$Id: cdr_op_ch.cpp 78602 2007-06-27 09:21:28Z parsons $")
-
 // ***************************************************************************
 // Array visitor for generating CDR operator declarations in the client header
 // ***************************************************************************
@@ -73,7 +64,7 @@ be_visitor_array_cdr_op_ch::visit_array (be_array *node)
   // is a declaration (not a reference), we must generate code for
   // the declaration.
   if (this->ctx_->alias () == 0 && // Not a typedef.
-      bt->is_child (this->ctx_->scope ()))
+      bt->is_child (this->ctx_->scope ()->decl ()))
     {
       int status = 0;
       be_visitor_context ctx (*this->ctx_);
