@@ -1,27 +1,18 @@
-//
-// $Id: cdr_op_cs.cpp 78602 2007-06-27 09:21:28Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor for code generation of Arrays for the CDR operators in the client
-//    stubs.
-//
-// = AUTHOR
-//    Jeff Parsons <parsons@cs.wustl.edu>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_cs.cpp
+ *
+ *  $Id: cdr_op_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor for code generation of Arrays for the CDR operators in the client
+ *  stubs.
+ *
+ *
+ *  @author Jeff Parsons <parsons@cs.wustl.edu>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_array,
-           cdr_op_cs,
-           "$Id: cdr_op_cs.cpp 78602 2007-06-27 09:21:28Z parsons $")
 
 // ***************************************************************************
 // Array visitor for generating CDR operator declarations in the client
@@ -92,7 +83,7 @@ be_visitor_array_cdr_op_cs::visit_array (be_array *node)
   // is a declaration (not a reference), we must generate code for
   // the declaration.
   if (this->ctx_->alias () == 0 // Not a typedef.
-      && bt->is_child (this->ctx_->scope ()))
+      && bt->is_child (this->ctx_->scope ()->decl ()))
     {
       int status = 0;
       be_visitor_context ctx (*this->ctx_);
@@ -140,8 +131,10 @@ be_visitor_array_cdr_op_cs::visit_array (be_array *node)
   ACE_OS::memset (fname,
                   '\0',
                   NAMEBUFSIZE);
+                  
+  bool use_underscore = (this->ctx_->tdef () == 0);
 
-  if (this->ctx_->tdef ())
+  if (!use_underscore)
     {
       ACE_OS::sprintf (fname, "%s", node->full_name ());
     }
@@ -218,12 +211,12 @@ be_visitor_array_cdr_op_cs::visit_array (be_array *node)
 
   if (be_global->gen_ostream_operators ())
     {
-      node->gen_ostream_operator (os);
+      node->gen_ostream_operator (os, use_underscore);
     }
 
   *os << be_global->core_versioning_end () << be_nl;
 
-  node->cli_stub_cdr_op_gen (1);
+  node->cli_stub_cdr_op_gen (true);
   return 0;
 }
 
@@ -266,7 +259,8 @@ be_visitor_array_cdr_op_cs::visit_valuetype_fwd (be_valuetype_fwd *node)
 }
 
 int
-be_visitor_array_cdr_op_cs::visit_predefined_type (be_predefined_type *node)
+be_visitor_array_cdr_op_cs::visit_predefined_type (
+  be_predefined_type *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
@@ -299,9 +293,10 @@ be_visitor_array_cdr_op_cs::visit_predefined_type (be_predefined_type *node)
   unsigned long i;
 
   // Grab the array node.
-  be_array *array = this->ctx_->be_node_as_array ();
+  be_array *array =
+    be_array::narrow_from_decl (this->ctx_->node ());
 
-  if (!node)
+  if (array == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_array_cdr_op_cs::"
@@ -564,11 +559,12 @@ int
 be_visitor_array_cdr_op_cs::visit_node (be_type *bt)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  unsigned long i;
-  be_array *node = this->ctx_->be_node_as_array ();
+  ACE_CDR::ULong i;
+  be_array *node =
+    be_array::narrow_from_decl (this->ctx_->node ());
   AST_Decl::NodeType nt = bt->node_type ();
 
-  if (!node)
+  if (node == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_array_cdr_op_cs::"
@@ -580,7 +576,7 @@ be_visitor_array_cdr_op_cs::visit_node (be_type *bt)
   // Initialize a boolean variable.
   *os << "CORBA::Boolean _tao_marshal_flag = true;" << be_nl;
 
-  unsigned long ndims = node->n_dims ();
+  ACE_CDR::ULong ndims = node->n_dims ();
 
   // We get here if the "type" of individual elements of the array is not a
   // primitive type. In this case, we are left with no other alternative but to
@@ -645,8 +641,37 @@ be_visitor_array_cdr_op_cs::visit_node (be_type *bt)
         }
       else
         {
+          be_string *str = 0;
+          if (bt->node_type () == AST_Decl::NT_string ||
+              bt->node_type () == AST_Decl::NT_wstring)
+            {
+              str = be_string::narrow_from_decl (bt);
+              if (!str)
+                {
+                  ACE_ERROR_RETURN ((LM_ERROR,
+                                     "(%N:%l) be_visitor_array_cdr_op_cs::"
+                                     "visit_node - "
+                                     "bad string node\n"),
+                                    -1);
+                }
+            }
+
           *os << "_tao_marshal_flag = (strm >> ";
-          *os << "_tao_array ";
+          if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+            {
+              if (str->width () == (long) sizeof (char))
+                {
+                  *os << "ACE_InputCDR::to_string (_tao_array ";
+                }
+              else
+                {
+                  *os << "ACE_InputCDR::to_wstring (_tao_array ";
+                }
+            }
+          else
+            {
+              *os << "_tao_array ";
+            }
 
           for (i = 0; i < ndims; ++i)
             {
@@ -659,6 +684,16 @@ be_visitor_array_cdr_op_cs::visit_node (be_type *bt)
               // handled in a special way.
               case AST_Decl::NT_string:
               case AST_Decl::NT_wstring:
+                if (str->max_size ()->ev ()->u.ulval != 0)
+                  {
+                    *os << ".out (), "
+                        << str->max_size ()->ev ()->u.ulval << ")";
+                  }
+                else
+                  {
+                    *os << ".out ()";
+                  }
+                break;
               case AST_Decl::NT_valuetype:
               case AST_Decl::NT_valuetype_fwd:
               case AST_Decl::NT_eventtype:
@@ -733,8 +768,37 @@ be_visitor_array_cdr_op_cs::visit_node (be_type *bt)
         }
       else
         {
+          be_string *str = 0;
+          if (bt->node_type () == AST_Decl::NT_string ||
+              bt->node_type () == AST_Decl::NT_wstring)
+            {
+              str = be_string::narrow_from_decl (bt);
+              if (!str)
+                {
+                  ACE_ERROR_RETURN ((LM_ERROR,
+                                     "(%N:%l) be_visitor_array_cdr_op_cs::"
+                                     "visit_node - "
+                                     "bad string node\n"),
+                                    -1);
+                }
+            }
+
           *os << "_tao_marshal_flag = (strm << ";
-          *os << "_tao_array ";
+          if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+            {
+              if (str->width () == (long) sizeof (char))
+                {
+                  *os << "ACE_OutputCDR::from_string (_tao_array ";
+                }
+              else
+                {
+                  *os << "ACE_OutputCDR::from_wstring (_tao_array ";
+                }
+            }
+          else
+            {
+              *os << "_tao_array ";
+            }
 
           for (i = 0; i < ndims; ++i)
             {
@@ -747,6 +811,16 @@ be_visitor_array_cdr_op_cs::visit_node (be_type *bt)
               // handled in a special way.
               case AST_Decl::NT_string:
               case AST_Decl::NT_wstring:
+                if (str->max_size ()->ev ()->u.ulval != 0)
+                  {
+                    *os << ".in (), "
+                        << str->max_size ()->ev ()->u.ulval << ")";
+                  }
+                else
+                  {
+                    *os << ".in ()";
+                  }
+                break;
               case AST_Decl::NT_valuetype:
               case AST_Decl::NT_valuetype_fwd:
               case AST_Decl::NT_eventtype:
