@@ -1,30 +1,21 @@
-//
-// $Id: serializer_op_ch.cpp 67596 2005-08-12 22:13:31Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    serializer_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor for code generation of Arrays for the 
-//    TAO::DCPS::Serializer operators in the client header.
-//
-// = AUTHOR
-//    Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    serializer_op_ch.cpp
+ *
+ *  $Id: serializer_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor for code generation of Arrays for the 
+ *  TAO::DCPS::Serializer operators in the client header.
+ *
+ *
+ *  @author Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_sequence/serializer_op_ch.h"
 
-ACE_RCSID (be_visitor_array, 
-           serializer_op_ch, 
-           "$Id: serializer_op_ch.cpp 67596 2005-08-12 22:13:31Z parsons $")
-
 // ***************************************************************************
 // Array visitor for generating Serializer operator declarations in the client header
 // ***************************************************************************
@@ -94,7 +85,7 @@ be_visitor_array_serializer_op_ch::visit_array (be_array *node)
   // is a declaration (not a reference), we must generate code for
   // the declaration.
   if (this->ctx_->alias () == 0 // Not a typedef.
-      && bt->is_child (this->ctx_->scope ()))
+      && bt->is_child (this->ctx_->scope ()->decl ()))
     {
       int status = 0;
       be_visitor_context ctx (*this->ctx_);
