@@ -1,28 +1,18 @@
-//
-// $Id: serializer_op_cs.cpp 77405 2007-02-26 23:35:31Z ossama $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    serializer_op_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor for code generation of Arrays for the
-//    TAO::DCPS::Serializer operators in the client stubs.
-//
-// = AUTHOR
-//    Scott Harris <harris_s@ociweb.com> based on code by
-//    Jeff Parsons <parsons@cs.wustl.edu>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    serializer_op_cs.cpp
+ *
+ *  $Id: serializer_op_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor for code generation of Arrays for the
+ *  TAO::DCPS::Serializer operators in the client stubs.
+ *
+ *
+ *  @author Scott Harris <harris_s@ociweb.com> based on code by Jeff Parsons <parsons@cs.wustl.edu>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_array,
-           serializer_op_cs,
-           "$Id: serializer_op_cs.cpp 77405 2007-02-26 23:35:31Z ossama $")
 
 // ***************************************************************************
 // Array visitor for generating Serializer operator declarations in the client
@@ -93,7 +83,7 @@ be_visitor_array_serializer_op_cs::visit_array (be_array *node)
   // is a declaration (not a reference), we must generate code for
   // the declaration.
   if (this->ctx_->alias () == 0 // Not a typedef.
-      && bt->is_child (this->ctx_->scope ()))
+      && bt->is_child (this->ctx_->scope ()->decl ()))
     {
       int status = 0;
       be_visitor_context ctx (*this->ctx_);
@@ -284,9 +274,10 @@ be_visitor_array_serializer_op_cs::visit_enum (be_enum *node)
   unsigned long i;
 
   // Grab the array node.
-  be_array *array = this->ctx_->be_node_as_array ();
+  be_array *array =
+    be_array::narrow_from_decl (this->ctx_->node ());
 
-  if (!node)
+  if (array == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_array_serializer_op_cs::"
@@ -419,9 +410,10 @@ be_visitor_array_serializer_op_cs::visit_predefined_type (
   unsigned long i;
 
   // Grab the array node.
-  be_array *array = this->ctx_->be_node_as_array ();
+  be_array *array =
+    be_array::narrow_from_decl (this->ctx_->node ());
 
-  if (!node)
+  if (array == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_array_serializer_op_cs::"
@@ -752,11 +744,12 @@ int
 be_visitor_array_serializer_op_cs::visit_node (be_type *bt)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  unsigned long i;
-  be_array *node = this->ctx_->be_node_as_array ();
+  ACE_CDR::ULong i;
+  be_array *node =
+    be_array::narrow_from_decl (this->ctx_->node ());
   AST_Decl::NodeType nt = bt->node_type ();
 
-  if (!node)
+  if (node == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_array_serializer_op_cs::"
@@ -925,7 +918,7 @@ be_visitor_array_serializer_op_cs::visit_node (be_type *bt)
               *os << "::CORBA::Boolean _tao_marshal_flag = true;" << be_nl;
             }
 
-    unsigned long ndims = node->n_dims ();
+    ACE_CDR::ULong ndims = node->n_dims ();
 
     // We get here if the "type" of individual elements of the array is not a
     // primitive type. In this case, we are left with no other alternative but to
@@ -954,7 +947,9 @@ be_visitor_array_serializer_op_cs::visit_node (be_type *bt)
                 << expr->ev ()->u.ulval;
 
             if (TAO_CodeGen::TAO_FIND_SIZE != this->ctx_->sub_state ())
+              {
                 *os << " && _tao_marshal_flag";
+              }
 
             *os << "; i" << i
                 << "++)" << be_idt_nl
