@@ -1,27 +1,18 @@
-//
-// $Id: any_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    any_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Any operators for an Component in the client
-//    header.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    any_op_ch.cpp
+ *
+ *  $Id: any_op_ch.cpp 89037 2010-02-16 21:11:04Z parsons $
+ *
+ *  Visitor generating code for Any operators for an Component in the client
+ *  header.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_component, 
-           any_op_ch, 
-           "$Id: any_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // ***************************************************************************
 // Interface visitor for generating Any operator declarations in the client header
@@ -44,3 +35,9 @@ be_visitor_component_any_op_ch::visit_component (be_component *node)
   be_visitor_interface_any_op_ch visitor (&ctx);
   return visitor.visit_interface (node);
 }
+
+int
+be_visitor_component_any_op_ch::visit_connector (be_connector *node)
+{
+  return this->visit_component (node);
+}
