@@ -1,4 +1,4 @@
-// $id: any_op_cs.cpp,v 1.12 1998/10/30 19:46:55 levine Exp $
+// $Id: any_op_cs.cpp 89037 2010-02-16 21:11:04Z parsons $
 
 // ============================================================================
 //
@@ -17,10 +17,6 @@
 //
 // ============================================================================
 
-ACE_RCSID (be_visitor_component, 
-           any_op_cs, 
-           "$Id: any_op_cs.cpp 48780 2003-03-12 16:50:35Z parsons $")
-
 // ***************************************************************************
 // Interface visitor for generating Any operator declarations in the client
 // stubs file
@@ -44,3 +40,9 @@ be_visitor_component_any_op_cs::visit_component (be_component *node)
   be_visitor_interface_any_op_cs visitor (&ctx);
   return visitor.visit_interface (node);
 }
+
+int
+be_visitor_component_any_op_cs::visit_connector (be_connector *node)
+{
+  return this->visit_component (node);
+}
