@@ -1,27 +1,17 @@
-//
-// $Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for CDR operators for components. This uses
-//    compiled marshaling.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_component, 
-           cdr_op_ch, 
-           "$Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
+//=============================================================================
+/**
+ *  @file    cdr_op_ch.cpp
+ *
+ *  $Id: cdr_op_ch.cpp 89037 2010-02-16 21:11:04Z parsons $
+ *
+ *  Visitor generating code for CDR operators for components. This uses
+ *  compiled marshaling.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 // ***************************************************************************
 // Interface visitor for generating CDR operator declarations in the client header
@@ -45,3 +35,9 @@ be_visitor_component_cdr_op_ch::visit_component (be_component *node)
   be_visitor_interface_cdr_op_ch visitor (&ctx);
   return visitor.visit_interface (node);
 }
+
+int
+be_visitor_component_cdr_op_ch::visit_connector (be_connector *node)
+{
+  return this->visit_component (node);
+}
