@@ -1,27 +1,18 @@
-//
-// $Id: any_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    any_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Any operators for a forward declared 
-//    component in the client header.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    any_op_ch.cpp
+ *
+ *  $Id: any_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Any operators for a forward declared 
+ *  component in the client header.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_component_fwd, 
-           any_op_ch, 
-           "$Id: any_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // ***************************************************************************
 // Generates Any operator declarations in the client header
