@@ -1,27 +1,18 @@
-//
-// $Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for CDR operators for forward declared
-//    components. This uses compiled marshaling.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_ch.cpp
+ *
+ *  $Id: cdr_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for CDR operators for forward declared
+ *  components. This uses compiled marshaling.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_component_fwd, 
-           cdr_op_ch, 
-           "$Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // ***************************************************************************
 // Forward declared component visitor for generating CDR operator declarations
