@@ -1,23 +1,18 @@
-//
-// $Id: be_visitor_decl.cpp 73110 2006-06-15 18:56:10Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_decl.cpp
-//
-// = DESCRIPTION
-//    Visitor for the base be_decl node. This serves to maintain the current
-//    state (context) of code generation for the derived visitor.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_decl.cpp
+ *
+ *  $Id: be_visitor_decl.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor for the base be_decl node. This serves to maintain the current
+ *  state (context) of code generation for the derived visitor.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_decl.h"
 #include "be_visitor_sequence.h"
@@ -26,10 +21,6 @@
 #include "be_type.h"
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (be, 
-           be_visitor_decl, 
-           "$Id: be_visitor_decl.cpp 73110 2006-06-15 18:56:10Z parsons $")
-
 // Root visitor for client header
 be_visitor_decl::be_visitor_decl (be_visitor_context *ctx)
   : ctx_ (ctx)
