@@ -1,22 +1,17 @@
-//
-// $Id: be_visitor_exception.cpp 66547 2005-06-21 20:31:32Z gmaxey $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_exception.cpp
-//
-// = DESCRIPTION
-//    Visitors for generation of code for Exception
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_exception.cpp
+ *
+ *  $Id: be_visitor_exception.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitors for generation of code for Exception
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_field.h"
 #include "be_exception.h"
@@ -53,6 +48,3 @@
 #include "be_visitor_exception/cdr_op_ch.cpp"
 #include "be_visitor_exception/cdr_op_cs.cpp"
 
-ACE_RCSID (be,
-           be_visitor_exception,
-           "$Id: be_visitor_exception.cpp 66547 2005-06-21 20:31:32Z gmaxey $")
