@@ -1,26 +1,16 @@
-//
-// $Id: exception.cpp 56725 2004-04-09 17:30:13Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    .cpp
-//
-// = DESCRIPTION
-//    Generic visitor generating code for Exceptions.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_exception, 
-           exception, 
-           "$Id: exception.cpp 56725 2004-04-09 17:30:13Z parsons $")
+//=============================================================================
+/**
+ *  @file    exception.cpp
+ *
+ *  $Id: exception.cpp 88845 2010-02-04 12:43:28Z johnnyw $
+ *
+ *  Generic visitor generating code for Exceptions.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 
 // Generic exception visitor.
@@ -91,7 +81,7 @@ be_visitor_exception::visit_field (be_field *node)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "(%N:%l) be_visitor_exception::"
                            "visit_field - "
-                           "Bad context state\n"), 
+                           "Bad context state\n"),
                           -1);
       }
     }
@@ -101,7 +91,7 @@ be_visitor_exception::visit_field (be_field *node)
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_exception::"
                          "visit_field - "
-                         "failed to accept visitor\n"),  
+                         "failed to accept visitor\n"),
                         -1);
     }
 
