@@ -1,26 +1,16 @@
-//
-// $Id: exception_ci.cpp 70870 2006-02-09 16:44:15Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    exception_ci.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Exception in the inline file.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_exception, 
-           exception_ci, 
-           "$Id: exception_ci.cpp 70870 2006-02-09 16:44:15Z parsons $")
+//=============================================================================
+/**
+ *  @file    exception_ci.cpp
+ *
+ *  $Id: exception_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Exception in the inline file.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 
 // ******************************************************
