@@ -1,21 +1,16 @@
-//
-// $Id: be_visitor_field.cpp 66547 2005-06-21 20:31:32Z gmaxey $
-//
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_field.cpp
-//
-// = DESCRIPTION
-//    Concrete visitor for the base "BE_Field" node
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_field.cpp
+ *
+ *  $Id: be_visitor_field.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Concrete visitor for the base "BE_Field" node
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_type.h"
 #include "be_field.h"
@@ -54,6 +49,3 @@
 #include "be_visitor_field/serializer_op_ch.cpp"
 #include "be_visitor_field/serializer_op_cs.cpp"
 
-ACE_RCSID (be, 
-           be_visitor_field, 
-           "$Id: be_visitor_field.cpp 66547 2005-06-21 20:31:32Z gmaxey $")
