@@ -1,22 +1,17 @@
-//
-// $Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating CDR operator declarator for field in the client header
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_ch.cpp
+ *
+ *  $Id: cdr_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating CDR operator declarator for field in the client header
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_array/cdr_op_ch.h"
 #include "be_visitor_enum/cdr_op_ch.h"
@@ -26,11 +21,6 @@
 #include "be_visitor_union/union.h"
 #include "be_visitor_union/cdr_op_ch.h"
 
-ACE_RCSID (be_visitor_field, 
-           cdr_op_ch, 
-           "$Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
-
-
 // **********************************************
 //  Visitor for field in the client header file.
 // **********************************************
@@ -83,7 +73,7 @@ be_visitor_field_cdr_op_ch::visit_array (be_array *node)
   // If not a typedef and we are defined in the use scope, we must be defined.
 
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // This is the case for anonymous arrays.
 
@@ -113,7 +103,7 @@ be_visitor_field_cdr_op_ch::visit_enum (be_enum *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined
   if (!this->ctx_->alias () // not a typedef.
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
@@ -141,7 +131,7 @@ be_visitor_field_cdr_op_ch::visit_sequence (be_sequence *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
@@ -170,7 +160,7 @@ be_visitor_field_cdr_op_ch::visit_structure (be_structure *node)
   // if not a typedef and we are defined in the use scope, we must be defined
 
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting
@@ -224,7 +214,7 @@ be_visitor_field_cdr_op_ch::visit_union (be_union *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
