@@ -1,40 +1,29 @@
-//
-// $Id: cdr_op_cs.cpp 79374 2007-08-16 20:45:48Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_cdr_op_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Field in the client stubs file.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_cs.cpp
+ *
+ *  $Id: cdr_op_cs.cpp 88845 2010-02-04 12:43:28Z johnnyw $
+ *
+ *  Visitor generating code for Field in the client stubs file.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_array/cdr_op_cs.h"
 #include "be_visitor_sequence/cdr_op_cs.h"
 #include "be_visitor_structure/cdr_op_cs.h"
 #include "be_visitor_union/cdr_op_cs.h"
 
-ACE_RCSID (be_visitor_field,
-           cdr_op_cs,
-           "$Id: cdr_op_cs.cpp 79374 2007-08-16 20:45:48Z parsons $")
-
-
 // **********************************************
 //  visitor for field in the client stubs file
 // **********************************************
 
 be_visitor_field_cdr_op_cs::be_visitor_field_cdr_op_cs (
-    be_visitor_context *ctx
-  )
+      be_visitor_context *ctx)
   : be_visitor_decl (ctx)
 {
 }
@@ -77,7 +66,7 @@ be_visitor_field_cdr_op_cs::visit_array (be_array *node)
   // If the array is defined in this scope, we must generate
   // CDR stream operators for the array itself.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -97,7 +86,8 @@ be_visitor_field_cdr_op_cs::visit_array (be_array *node)
   // field.
 
   TAO_OutStream *os = this->ctx_->stream ();
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -119,7 +109,7 @@ be_visitor_field_cdr_op_cs::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (this->ctx_->alias () == 0 // Not a typedef.
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
       // we have to generate a name for us that has an underscore
@@ -184,7 +174,7 @@ be_visitor_field_cdr_op_cs::visit_enum (be_enum *node)
   // If we are defined inside this scope, we must generate the
   /// CDR stream operators for us here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -203,7 +193,8 @@ be_visitor_field_cdr_op_cs::visit_enum (be_enum *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -245,9 +236,10 @@ int
 be_visitor_field_cdr_op_cs::visit_interface (be_interface *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -318,7 +310,8 @@ be_visitor_field_cdr_op_cs::visit_interface_fwd (be_interface_fwd *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -420,9 +413,10 @@ int
 be_visitor_field_cdr_op_cs::emit_valuetype_common (void)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_field_cdr_op_cs::"
@@ -467,7 +461,8 @@ be_visitor_field_cdr_op_cs::visit_predefined_type (be_predefined_type *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -568,7 +563,7 @@ be_visitor_field_cdr_op_cs::visit_sequence (be_sequence *node)
   // If the sequence is defined in this scope, generate its
   // CDR stream operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -589,7 +584,8 @@ be_visitor_field_cdr_op_cs::visit_sequence (be_sequence *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -628,12 +624,13 @@ be_visitor_field_cdr_op_cs::visit_sequence (be_sequence *node)
 }
 
 int
-be_visitor_field_cdr_op_cs::visit_string (be_string *)
+be_visitor_field_cdr_op_cs::visit_string (be_string *str)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -649,11 +646,47 @@ be_visitor_field_cdr_op_cs::visit_string (be_string *)
   switch (this->ctx_->sub_state ())
     {
     case TAO_CodeGen::TAO_CDR_INPUT:
-      *os << "(strm >> _tao_aggregate." << f->local_name () << ".out ())";
+      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+        {
+          if (str->width () == (long) sizeof (char))
+            {
+              *os << "(strm >> ACE_InputCDR::to_string (_tao_aggregate."
+                  << f->local_name () << ".out (), "
+                  << str->max_size ()->ev ()->u.ulval << "))";
+            }
+          else
+            {
+              *os << "(strm >> ACE_InputCDR::to_wstring (_tao_aggregate."
+                  << f->local_name () << ".out (), "
+                  << str->max_size ()->ev ()->u.ulval << "))";
+            }
+        }
+      else
+        {
+          *os << "(strm >> _tao_aggregate." << f->local_name () << ".out ())";
+        }
 
       break;
     case TAO_CodeGen::TAO_CDR_OUTPUT:
-      *os << "(strm << _tao_aggregate." << f->local_name () << ".in ())";
+      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+        {
+          if (str->width () == (long) sizeof (char))
+            {
+              *os << "(strm << ACE_OutputCDR::from_string (_tao_aggregate."
+                  << f->local_name () << ".in (), "
+                  << str->max_size ()->ev ()->u.ulval << "))";
+            }
+          else
+            {
+              *os << "(strm << ACE_OutputCDR::from_wstring (_tao_aggregate."
+                  << f->local_name () << ".in (), "
+                  << str->max_size ()->ev ()->u.ulval << "))";
+            }
+        }
+      else
+        {
+          *os << "(strm << _tao_aggregate." << f->local_name () << ".in ())";
+        }
 
       break;
     case TAO_CodeGen::TAO_CDR_SCOPE:
@@ -677,7 +710,7 @@ be_visitor_field_cdr_op_cs::visit_structure (be_structure *node)
   // If the struct is defined in this scope, generate its CDR stream
   // operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -698,7 +731,8 @@ be_visitor_field_cdr_op_cs::visit_structure (be_structure *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -761,7 +795,7 @@ be_visitor_field_cdr_op_cs::visit_union (be_union *node)
   // If the union is defined in this scope, generate its CDR stream
   // operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -782,7 +816,8 @@ be_visitor_field_cdr_op_cs::visit_union (be_union *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -823,8 +858,7 @@ be_visitor_field_cdr_op_cs::visit_union (be_union *node)
 // ****************************************************************
 
 be_visitor_cdr_op_field_decl::be_visitor_cdr_op_field_decl (
-    be_visitor_context *ctx
-  )
+      be_visitor_context *ctx)
   : be_visitor_scope (ctx)
 {
 }
@@ -872,7 +906,8 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -892,7 +927,7 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (this->ctx_->alias () == 0 // Not a typedef.
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays,
       // we have to generate a name for us that has an underscope
@@ -930,8 +965,12 @@ be_visitor_cdr_op_field_decl::visit_array (be_array *node)
     case TAO_CodeGen::TAO_CDR_OUTPUT:
       *os << fname << "_forany "
           << "_tao_aggregate_" << f->local_name () << be_idt << be_idt_nl
+          << "#if defined __IBMCPP__ && __IBMCPP__ <= 800" << be_nl
+          << "((" << fname << "_slice*) (" << be_nl
+          << "#else" << be_nl
           << "(const_cast<" << be_idt << be_idt_nl
-          << fname << "_slice*> (" << be_nl
+          << fname << "_slice*> (" << be_uidt << be_uidt_nl
+          << "#endif" << be_idt << be_idt_nl
           << "_tao_aggregate." << f->local_name () << be_uidt_nl
           << ")" << be_uidt << be_uidt_nl
           << ");" << be_uidt_nl;
