@@ -1,32 +1,22 @@
-//
-// $Id: field_ci.cpp 56757 2004-04-12 16:09:02Z bala $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_ci.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Field in the client inline file
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    field_ci.cpp
+ *
+ *  $Id: field_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Field in the client inline file
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_array/array_ci.h"
 #include "be_visitor_structure/structure_ci.h"
 #include "be_visitor_union/union_ci.h"
 
-ACE_RCSID (be_visitor_field, 
-           field_ci, 
-           "$Id: field_ci.cpp 56757 2004-04-12 16:09:02Z bala $")
-
-
 be_visitor_field_ci::be_visitor_field_ci (be_visitor_context *ctx)
   : be_visitor_decl (ctx)
 {
@@ -71,7 +61,7 @@ int
 be_visitor_field_ci::visit_array (be_array *node)
 {
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -100,7 +90,7 @@ int
 be_visitor_field_ci::visit_structure (be_structure *node)
 {
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -142,7 +132,7 @@ int
 be_visitor_field_ci::visit_union (be_union *node)
 {
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
