@@ -1,22 +1,17 @@
-//
-// $Id: field_cs.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Field in the client stubs file.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    field_cs.cpp
+ *
+ *  $Id: field_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Field in the client stubs file.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_array/array_cs.h"
 #include "be_visitor_enum/enum_cs.h"
@@ -24,11 +19,6 @@
 #include "be_visitor_structure/structure_cs.h"
 #include "be_visitor_union/union_cs.h"
 
-ACE_RCSID (be_visitor_field, 
-           field_cs, 
-           "$Id: field_cs.cpp 48780 2003-03-12 16:50:35Z parsons $")
-
-
 // **********************************************
 //  Visitor for field in the client stubs file.
 // **********************************************
@@ -74,7 +64,7 @@ int
 be_visitor_field_cs::visit_array (be_array *node)
 {
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -97,7 +87,7 @@ int
 be_visitor_field_cs::visit_enum (be_enum *node)
 {
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -120,7 +110,7 @@ int
 be_visitor_field_cs::visit_sequence (be_sequence *node)
 {
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -143,7 +133,7 @@ int
 be_visitor_field_cs::visit_structure (be_structure *node)
 {
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -185,7 +175,7 @@ int
 be_visitor_field_cs::visit_union (be_union *node)
 {
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
