@@ -1,23 +1,18 @@
-//
-// $Id: serializer_op_ch.cpp 66459 2005-06-15 20:47:58Z fields_t $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    serializer_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating TAO::DCPS::Serializer operator declarator for field 
-//    in the client header
-//
-// = AUTHOR
-//    Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    serializer_op_ch.cpp
+ *
+ *  $Id: serializer_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating TAO::DCPS::Serializer operator declarator for field 
+ *  in the client header
+ *
+ *
+ *  @author Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_visitor_array/serializer_op_ch.h"
 #include "be_visitor_enum/serializer_op_ch.h"
@@ -27,11 +22,6 @@
 #include "be_visitor_union/union.h"
 #include "be_visitor_union/serializer_op_ch.h"
 
-ACE_RCSID (be_visitor_field, 
-           serializer_op_ch, 
-           "$Id: serializer_op_ch.cpp 66459 2005-06-15 20:47:58Z fields_t $")
-
-
 // **********************************************
 //  Visitor for field in the client header file.
 // **********************************************
@@ -84,7 +74,7 @@ be_visitor_field_serializer_op_ch::visit_array (be_array *node)
   // If not a typedef and we are defined in the use scope, we must be defined.
 
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // This is the case for anonymous arrays.
 
@@ -114,7 +104,7 @@ be_visitor_field_serializer_op_ch::visit_enum (be_enum *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined
   if (!this->ctx_->alias () // not a typedef.
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
@@ -142,7 +132,7 @@ be_visitor_field_serializer_op_ch::visit_sequence (be_sequence *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
@@ -171,7 +161,7 @@ be_visitor_field_serializer_op_ch::visit_structure (be_structure *node)
   // if not a typedef and we are defined in the use scope, we must be defined
 
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting
@@ -225,7 +215,7 @@ be_visitor_field_serializer_op_ch::visit_union (be_union *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
