@@ -1,26 +1,17 @@
-//
-// $Id: home_cs.cpp 70870 2006-02-09 16:44:15Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    home_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Component Home node in the client source.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    home_cs.cpp
+ *
+ *  $Id: home_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Component Home node in the client source.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_home, 
-           home_cs, 
-           "$Id: home_cs.cpp 70870 2006-02-09 16:44:15Z parsons $")
 
 be_visitor_home_cs::be_visitor_home_cs (
     be_visitor_context *ctx
