@@ -2,7 +2,7 @@
 /**
 *  @file   amh_ch.cpp
 *
-*  $Id: amh_ch.cpp 73128 2006-06-19 14:51:36Z parsons $
+*  $Id: amh_ch.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 *
 *  Specialized interface visitor for AMH-RH generates code that is
 *  specific to AMH interfaces.
@@ -11,10 +11,6 @@
 */
 //=============================================================================
 
-ACE_RCSID (be_visitor_interface,
-           amh_ch,
-           "$Id: amh_ch.cpp 73128 2006-06-19 14:51:36Z parsons $")
-
 be_visitor_amh_interface_ch::be_visitor_amh_interface_ch (
     be_visitor_context *ctx
   )
@@ -41,9 +37,6 @@ be_visitor_amh_interface_ch::visit_interface (be_interface *node)
 
   TAO_OutStream *os = this->ctx_->stream ();
 
-  // Now the interface definition itself.
-  os->gen_ifdef_macro (node->flat_name ());
-
   // Now generate the class definition.
   *os << "class " << be_global->stub_export_macro ()
       << " " << node->local_name () << be_idt_nl
