@@ -1,27 +1,18 @@
-//
-// $Id: ami_interface_ch.cpp 46434 2002-09-25 16:25:39Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    ami_interface_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for AMI Interfaces in the client header
-//
-// = AUTHOR
-//    Aniruddha Gokhale,
-//    Michael Kircher
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    ami_interface_ch.cpp
+ *
+ *  $Id: ami_interface_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for AMI Interfaces in the client header
+ *
+ *
+ *  @author Aniruddha Gokhale
+ *  @author Michael Kircher
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_interface, 
-           ami_interface_ch, 
-           "$Id: ami_interface_ch.cpp 46434 2002-09-25 16:25:39Z parsons $")
 
 // ******************************************************
 // Interface visitor for client header
@@ -51,7 +42,6 @@ be_visitor_ami_interface_ch::visit_interface (be_interface *node)
 
   // Grab the stream.
   TAO_OutStream *os = this->ctx_->stream ();
-  os->gen_ifdef_macro (node->replacement ()->flat_name (), "_ptr");
 
   // Forward declaration.
   *os << be_nl << be_nl 
@@ -62,6 +52,5 @@ be_visitor_ami_interface_ch::visit_interface (be_interface *node)
       << " *" << node->replacement ()->local_name ()
       << "_ptr;";
 
-  os->gen_endif ();
   return 0;
 }
