@@ -1,26 +1,17 @@
-//
-// $Id: interface.cpp 75259 2006-11-07 23:14:52Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    interface.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Interfaces. This is a generic visitor.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    interface.cpp
+ *
+ *  $Id: interface.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Interfaces. This is a generic visitor.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_interface,
-           interface,
-           "$Id: interface.cpp 75259 2006-11-07 23:14:52Z parsons $")
 
 // ******************************************************
 // Generic Interface visitor
@@ -518,7 +509,6 @@ be_visitor_interface::visit_operation (be_operation *node)
   // Change the state depending on the kind of node strategy.
   ctx.state (node->next_state (ctx.state ()));
 
-
   // Grab the appropriate visitor.
   be_visitor *visitor = tao_cg->make_visitor (&ctx);
 
