@@ -1,26 +1,17 @@
-//
-// $Id: interface_fwd_ch.cpp 70870 2006-02-09 16:44:15Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    interface_fwd_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Interface_Fwd node in the client header.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    interface_fwd_ch.cpp
+ *
+ *  $Id: interface_fwd_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Interface_Fwd node in the client header.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_interface_fwd, 
-           interface_fwd_ch, 
-           "$Id: interface_fwd_ch.cpp 70870 2006-02-09 16:44:15Z parsons $")
 
 // ********************************************************************
 // Visitor implementation for the Interface_Fwd type
