@@ -1,27 +1,18 @@
-//
-// $Id: any_op.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    any_op.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Any operators for elements in the scope of
-//    the Module.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    any_op.cpp
+ *
+ *  $Id: any_op.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Any operators for elements in the scope of
+ *  the Module.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_module, 
-           any_op, 
-           "$Id: any_op.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ***************************************************************************
 // Module visitor for generating Any operator declarations in the client header
