@@ -1,27 +1,18 @@
-//
-// $Id: cdr_op.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the CDR operators for types defined in Module's
-//    scope.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op.cpp
+ *
+ *  $Id: cdr_op.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the CDR operators for types defined in Module's
+ *  scope.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_module, 
-           cdr_op, 
-           "$Id: cdr_op.cpp,v 1.2 1999/05/28 02:16:43 coryan Exp ")
 
 // ***************************************************************************
 // Module visitor for generating CDR operator declarations in the client header
