@@ -1,26 +1,16 @@
-//
-// $Id: module.cpp 73637 2006-07-19 10:02:56Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    module.cpp
-//
-// = DESCRIPTION
-//    Generic visitor generating code for Module
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_module,
-           module,
-           "$Id: module.cpp 73637 2006-07-19 10:02:56Z jwillemsen $")
+//=============================================================================
+/**
+ *  @file    module.cpp
+ *
+ *  $Id: module.cpp 89018 2010-02-15 22:36:07Z parsons $
+ *
+ *  Generic visitor generating code for Module
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 
 // ******************************************************
@@ -359,10 +349,33 @@ be_visitor_module::visit_interface (be_interface *node)
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      {
+        be_visitor_interface_ex_idl visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVH:
+      {
+        be_visitor_interface_svh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      {
+        be_visitor_interface_svs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
     case TAO_CodeGen::TAO_ROOT_SERIALIZER_OP_CH:
     case TAO_CodeGen::TAO_ROOT_SERIALIZER_OP_CS:
+    case TAO_CodeGen::TAO_ROOT_EXH:
+    case TAO_CodeGen::TAO_ROOT_EXS:
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
       {
-        return 0; // nothing to be done for DCPS
+        // Nothing to be done for these cases.
+        return 0;
         break;
       }
     default:
@@ -809,18 +822,43 @@ be_visitor_module::visit_component (be_component *node)
         status = node->accept (&visitor);
         break;
       }
+    // Nothing for these with components, they have the executor.  
     case TAO_CodeGen::TAO_ROOT_IH:
-      {
-        be_visitor_component_ih visitor (&ctx);
-        status = node->accept (&visitor);
-        break;
-      }
     case TAO_CodeGen::TAO_ROOT_IS:
+      break;
+    case TAO_CodeGen::TAO_ROOT_SVH:
       {
-        be_visitor_component_is visitor (&ctx);
+        be_visitor_component_svh visitor (&ctx);
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      {
+        be_visitor_component_svs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXH:
+      {
+        be_visitor_component_exh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXS:
+      {
+        be_visitor_component_exs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      {
+        be_visitor_component_ex_idl visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+      break;
     default:
       {
         ACE_ERROR_RETURN ((LM_ERROR,
@@ -905,6 +943,39 @@ be_visitor_module::visit_home (be_home *node)
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_SVH:
+      {
+        be_visitor_home_svh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      {
+        be_visitor_home_svs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      {
+        be_visitor_home_ex_idl visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXH:
+      {
+        be_visitor_home_exh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXS:
+      {
+        be_visitor_home_exs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+      break;
     default:
       return 0; // nothing to be done
     }
@@ -921,6 +992,43 @@ be_visitor_module::visit_home (be_home *node)
   return 0;
 }
 
+int
+be_visitor_module::visit_connector (be_connector *node)
+{
+  // Instantiate a visitor context with a copy of our context. This info
+  // will be modified based on what type of node we are visiting.
+  be_visitor_context ctx (*this->ctx_);
+  ctx.node (node);
+  int status = 0;
+
+  switch (this->ctx_->state ())
+    {
+      case TAO_CodeGen::TAO_ROOT_CNH:
+        {
+          be_visitor_connector_dds_exh visitor (&ctx);
+          status = node->accept (&visitor);
+          break;
+        }
+      case TAO_CodeGen::TAO_ROOT_CNS:
+        {
+          be_visitor_connector_dds_exs visitor (&ctx);
+          status = node->accept (&visitor);
+          break;
+        }
+      // Skip these contexts, the connector impl is
+      // generated in a separate pass, using the states
+      // above.
+      case TAO_CodeGen::TAO_ROOT_EXH:
+      case TAO_CodeGen::TAO_ROOT_EXS:
+        break;
+      default:
+        // In all other cases, same as component.
+        return this->visit_component (node);
+    }
+    
+  return 0;
+}
+
 int
 be_visitor_module::visit_structure (be_structure *node)
 {
