@@ -1,24 +1,17 @@
-// $Id: module_ih.cpp 45401 2002-07-01 13:49:23Z parsons $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    module_ih.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Module in the implementation header
-//
-// = AUTHOR
-//    Yamuna Krishnamurthy (yamuna@cs.wustl.edu)
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    module_ih.cpp
+ *
+ *  $Id: module_ih.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Module in the implementation header
+ *
+ *
+ *  @author Yamuna Krishnamurthy (yamuna@cs.wustl.edu)
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_module, 
-           module_ih, 
-           "$Id: module_ih.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ************************************************************
 // Module visitor for server header
