@@ -1,28 +1,18 @@
-//
-// $Id: ami_handler_reply_stub_operation_ch.cpp 78149 2007-04-23 12:03:30Z johnnyw $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    ami_handler_reply_stub_operation_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for AMI Handler call back operation in
-//    the client header.
-//
-// = AUTHOR
-//    Aniruddha Gokhale and Alexander Babu Arulanthu
-//    <alex@cs.wustl.edu>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    ami_handler_reply_stub_operation_ch.cpp
+ *
+ *  $Id: ami_handler_reply_stub_operation_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for AMI Handler call back operation in
+ *  the client header.
+ *
+ *
+ *  @author Aniruddha Gokhale and Alexander Babu Arulanthu <alex@cs.wustl.edu>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation,
-           ami_handler_reply_stub_operation_ch,
-           "$Id: ami_handler_reply_stub_operation_ch.cpp 78149 2007-04-23 12:03:30Z johnnyw $")
 
 // ************************************************************
 // Operation visitor for server header
