@@ -1,26 +1,17 @@
-//
-// $Id: ami_handler_reply_stub_operation_cs.cpp 78185 2007-04-25 07:40:49Z johnnyw $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    ami_handler_reply_stub_operation_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Operation in the stubs file.
-//
-// = AUTHOR
-//    Alexander Babu Arulanthu <alex@cs.wustl.edu>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    ami_handler_reply_stub_operation_cs.cpp
+ *
+ *  $Id: ami_handler_reply_stub_operation_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Operation in the stubs file.
+ *
+ *
+ *  @author Alexander Babu Arulanthu <alex@cs.wustl.edu>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation,
-           ami_handler_reply_stub_operation_cs,
-           "$Id: ami_handler_reply_stub_operation_cs.cpp 78185 2007-04-25 07:40:49Z johnnyw $")
 
 // ************************************************************
 // Operation visitor for client stubs.
@@ -61,7 +52,7 @@ be_visitor_operation_ami_handler_reply_stub_operation_cs::visit_operation (
     be_operation *node
   )
 {
-  be_type *bt;
+  be_type *bt = 0;
   be_visitor_context ctx;
 
   TAO_OutStream *os = this->ctx_->stream ();
@@ -297,7 +288,7 @@ be_visitor_operation_ami_handler_reply_stub_operation_cs::visit_argument (
   )
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Retrieve the type for this argument.
   bt = be_type::narrow_from_decl (node->field_type ());
