@@ -1,26 +1,17 @@
-//
-// $Id: argument.cpp 76267 2007-01-02 12:45:41Z johnnyw $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    argument.cpp
-//
-// = DESCRIPTION
-//    Visitor that calls the visitor for arguments.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    argument.cpp
+ *
+ *  $Id: argument.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor that calls the visitor for arguments.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation,
-           argument,
-           "$Id: argument.cpp 76267 2007-01-02 12:45:41Z johnnyw $")
 
 // ************************************************************
 // Generic operation visitor to handle the pre/post
@@ -94,13 +85,14 @@ be_visitor_operation_argument::visit_argument (be_argument *node)
   // signature.
   be_visitor_context ctx (*this->ctx_);
 
-  // first grab the interface definition inside which this operation is
+  // First grab the interface definition inside which this operation is
   // defined. We need this since argument types may very well be declared
   // inside the scope of the interface node. In such cases, we would like to
   // generate the appropriate relative scoped names.
-  be_operation *op = this->ctx_->be_scope_as_operation ();
+  be_operation *op =
+    be_operation::narrow_from_scope (this->ctx_->scope ());
 
-  if (!op)
+  if (op == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_arglist::"
