@@ -1,28 +1,19 @@
-//
-// $Id: argument_invoke.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    argument_invoke.cpp
-//
-// = DESCRIPTION
-//    Visitor to pass arguments to the CDR operators. This one helps in
-//    generating the && and the , at the right place. This one is for the
-//    client stub side.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    argument_invoke.cpp
+ *
+ *  $Id: argument_invoke.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor to pass arguments to the CDR operators. This one helps in
+ *  generating the && and the , at the right place. This one is for the
+ *  client stub side.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation, 
-           argument_invoke, 
-           "$Id: argument_invoke.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ************************************************************
 // operation visitor to handle the passing of arguments to the CDR operators
