@@ -1,28 +1,19 @@
-//
-// $Id: argument_marshal.cpp 46434 2002-09-25 16:25:39Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    argument_marshal.cpp
-//
-// = DESCRIPTION
-//    Visitor to pass arguments to the CDR operators. This one helps in
-//    generating the && and the , at the right place. This one is for the
-//    skeleton side.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    argument_marshal.cpp
+ *
+ *  $Id: argument_marshal.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor to pass arguments to the CDR operators. This one helps in
+ *  generating the && and the , at the right place. This one is for the
+ *  skeleton side.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation, 
-           argument_marshal, 
-           "$Id: argument_marshal.cpp 46434 2002-09-25 16:25:39Z parsons $")
 
 // ************************************************************
 // operation visitor to handle the passing of arguments to the CDR operators
@@ -199,7 +190,8 @@ be_visitor_args_decl::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // retrieve the field node
-  be_argument *f = this->ctx_->be_node_as_argument ();
+  be_argument *f =
+    be_argument::narrow_from_decl (this->ctx_->node ());
 
   if (f == 0)
     {
@@ -219,7 +211,7 @@ be_visitor_args_decl::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
       // We have to generate a name for us that has an underscope
