@@ -1,27 +1,18 @@
-//
-// $Id: exceptlist_cs.cpp 67876 2005-08-26 09:52:55Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    exceptlist_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the list of exceptions that an operation
-//    raises.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    exceptlist_cs.cpp
+ *
+ *  $Id: exceptlist_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the list of exceptions that an operation
+ *  raises.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation,
-           exceptlist_cs,
-           "$Id: exceptlist_cs.cpp 67876 2005-08-26 09:52:55Z jwillemsen $")
 
 // ****************************************************************************
 // visitor to generate the exception list for operations
@@ -60,7 +51,8 @@ be_visitor_operation_exceptlist_cs::visit_operation (be_operation *node)
       for (UTL_ExceptlistActiveIterator ei (node->exceptions ());
            !ei.is_done ();)
         {
-          ex = be_exception::narrow_from_decl (ei.item ());
+          AST_Decl *d = ei.item ();
+          ex = be_exception::narrow_from_decl (d);
 
           *os << "{" << be_idt_nl
               << "\"" << ex->repoID () << "\"," << be_nl
