@@ -1,25 +1,18 @@
-// $Id: exceptlist_ss.cpp 70870 2006-02-09 16:44:15Z parsons $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    exceptlist_ss.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the list of exceptions that an operation
-//    raises (skeleton/server side).
-//
-// = AUTHOR
-//    Ossama Othman
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    exceptlist_ss.cpp
+ *
+ *  $Id: exceptlist_ss.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the list of exceptions that an operation
+ *  raises (skeleton/server side).
+ *
+ *
+ *  @author Ossama Othman
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation,
-           exceptlist_ss,
-           "$Id: exceptlist_ss.cpp 70870 2006-02-09 16:44:15Z parsons $")
 
 // ****************************************************************************
 // visitor to generate the exception list for operations (skeleton/server_side)
@@ -70,7 +63,7 @@ be_visitor_operation_exceptlist_ss::visit_operation (be_operation * node)
 
       *os << be_uidt_nl << "};" << be_uidt_nl
           << "static ::CORBA::ULong const nexceptions = "
-          << node->exceptions()->length () << ";";
+          << node->exceptions ()->length () << ";";
     }
   else
     {
