@@ -1,28 +1,18 @@
-//
-// $Id: operation_ss.cpp 76799 2007-01-31 14:44:26Z johnnyw $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    operation_ss.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Operation in the server skeleton
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    operation_ss.cpp
+ *
+ *  $Id: operation_ss.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Operation in the server skeleton
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 
-ACE_RCSID (be_visitor_operation,
-           operation_ss,
-           "$Id: operation_ss.cpp 76799 2007-01-31 14:44:26Z johnnyw $")
-
 // ************************************************************
 // Operation visitor for server skeletons
 // ************************************************************
