@@ -1,26 +1,17 @@
-//
-// $Id: smart_proxy_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    operation_smart_proxy_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Operation node in the client header.
-//
-// = AUTHOR
-//    Kirthika Parameswaran  <kirthika@cs.wustl.edu>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    smart_proxy_ch.cpp
+ *
+ *  $Id: smart_proxy_ch.cpp 88845 2010-02-04 12:43:28Z johnnyw $
+ *
+ *  Visitor generating code for Operation node in the client header.
+ *
+ *
+ *  @author Kirthika Parameswaran  <kirthika@cs.wustl.edu>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation, 
-           smart_proxy_ch, 
-           "$Id: smart_proxy_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // ******************************************************
 // Primary visitor for "operation" in client header.
