@@ -1,26 +1,17 @@
-//
-// $Id: smart_proxy_cs.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    operation_smart_proxy_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Operation in the stubs file.
-//
-// = AUTHOR
-//    Kirthika Parameswaran <kirthika@cs.wustl.edu>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    smart_proxy_cs.cpp
+ *
+ *  $Id: smart_proxy_cs.cpp 88845 2010-02-04 12:43:28Z johnnyw $
+ *
+ *  Visitor generating code for Operation in the stubs file.
+ *
+ *
+ *  @author Kirthika Parameswaran <kirthika@cs.wustl.edu>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_operation, 
-           operation_smart_proxy_cs, 
-           "$Id: smart_proxy_cs.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // ************************************************************
 // Operation visitor for client stubs
