@@ -1,27 +1,19 @@
-// $Id: upcall_command_ss.cpp 77405 2007-02-26 23:35:31Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    upcall_command_ss.cpp
-//
-// = DESCRIPTION
-//    Visitor that generates operation-specific TAO::Upcall_Command
-//    objects in skeletons.
-//
-// = AUTHOR
-//    Ossama Othman
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    upcall_command_ss.cpp
+ *
+ *  $Id: upcall_command_ss.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor that generates operation-specific TAO::Upcall_Command
+ *  objects in skeletons.
+ *
+ *
+ *  @author Ossama Othman
+ */
+//=============================================================================
 
 
-ACE_RCSID (be_visitor_operation,
-           upcall_command_ss,
-           "$Id: upcall_command_ss.cpp 77405 2007-02-26 23:35:31Z ossama $")
-
 be_visitor_operation_upcall_command_ss
 ::be_visitor_operation_upcall_command_ss (
     be_visitor_context *ctx)
@@ -418,8 +410,10 @@ be_visitor_operation_upcall_command_ss::gen_upcall (be_operation * node)
          << "dynamic_cast<TAO::ExceptionHolder *> (arg_" << index
          << ");" << be_uidt_nl
          << "if (tao_excepholder != 0)" << be_idt_nl
+         << "{" << be_idt_nl
          << "tao_excepholder->set_exception_data "
             "(_tao_" << op_name << "_exceptiondata, " << exceptions_count << ");" << be_uidt_nl
+         << "}" << be_uidt_nl
          << be_nl;
     }
 
