@@ -1,27 +1,18 @@
-//
-// $Id: any_op.cpp 67714 2005-08-19 08:02:52Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    any_op.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the Any operators for types defined in Root's
-//    scope.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    any_op.cpp
+ *
+ *  $Id: any_op.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the Any operators for types defined in Root's
+ *  scope.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           any_op, 
-           "$Id: any_op.cpp 67714 2005-08-19 08:02:52Z jwillemsen $")
 
 // ***************************************************************************
 // Root visitor for generating Any operator declarations in the client header
