@@ -1,27 +1,18 @@
-//
-// $Id: cdr_op.cpp 56725 2004-04-09 17:30:13Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the CDR operators for types defined
-//    in Root's scope.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op.cpp
+ *
+ *  $Id: cdr_op.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the CDR operators for types defined
+ *  in Root's scope.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           cdr_op, 
-           "$Id: cdr_op.cpp 56725 2004-04-09 17:30:13Z parsons $")
 
 // ***************************************************************************
 // Root visitor for generating CDR operator declarations in the client header
