@@ -1,3 +1,5 @@
+// $Id: root.cpp 88976 2010-02-12 22:09:05Z parsons $
+
 // ============================================================================
 //
 // = LIBRARY
@@ -13,9 +15,6 @@
 //    Aniruddha Gokhale
 //
 // ============================================================================
-ACE_RCSID (be_visitor_root,
-           root,
-           "$Id: root.cpp 78528 2007-05-30 20:10:04Z mitza $")
 
 // Generic Root visitor
 be_visitor_root::be_visitor_root (be_visitor_context *ctx)
@@ -143,15 +142,17 @@ int be_visitor_root::visit_root (be_root *node)
         {
           be_global->non_local_interfaces.dequeue_head (i);
 
-          *os << be_nl << be_nl
-              << "extern " << be_global->stub_export_macro () << be_nl
-              << "TAO::Collocation_Proxy_Broker *" << be_nl
-              << "(*" << i->flat_client_enclosing_scope ()
-              << i->base_proxy_broker_name ()
-              << "_Factory_function_pointer) ("
-              << be_idt << be_idt_nl
-              << "::CORBA::Object_ptr obj" << be_uidt_nl
-              << ");" << be_uidt;
+          if (be_global->gen_direct_collocation() || be_global->gen_thru_poa_collocation ())
+            {
+              *os << be_nl << be_nl
+                  << "extern " << be_global->stub_export_macro () << be_nl
+                  << "TAO::Collocation_Proxy_Broker *" << be_nl
+                  << "(*" << i->flat_client_enclosing_scope ()
+                  << i->base_proxy_broker_name ()
+                  << "_Factory_function_pointer) ("
+                  << be_idt << be_idt_nl
+                  << "::CORBA::Object_ptr obj);" << be_uidt << be_uidt;
+            }
         }
 
       size = be_global->non_defined_interfaces.size ();
@@ -230,7 +231,7 @@ int be_visitor_root::visit_root (be_root *node)
   // Make one more pass over the entire tree and generate the OBV_ namespaces
   // and OBV_ classes.
 
-  bool obv = 1;
+  bool obv = true;
   status = 0;
 
   switch (this->ctx_->state ())
@@ -249,7 +250,7 @@ int be_visitor_root::visit_root (be_root *node)
       break;
     }
 
-  if (obv == 1)
+  if (obv == true)
     {
       be_visitor_obv_module visitor (&ctx);
       status = visitor.visit_scope (node);
@@ -322,13 +323,13 @@ int be_visitor_root::visit_root (be_root *node)
             {
               be_visitor_root_any_op visitor (&ctx);
               status = node->accept (&visitor);
+            }
 
-              // Conditional switch to the *A.h stream is done
-              // in the visitor constructor.
-              if (be_global->gen_anyop_files ())
-                {
-                  (void) tao_cg->end_anyop_header ();
-                }
+          // Conditional switch to the *A.h stream is done
+          // in the visitor constructor.
+          if (be_global->gen_anyop_files ())
+            {
+              (void) tao_cg->end_anyop_header ();
             }
 
           break;
@@ -341,15 +342,16 @@ int be_visitor_root::visit_root (be_root *node)
             {
               be_visitor_root_any_op visitor (&ctx);
               status = node->accept (&visitor);
-
-              // Conditional switch to the *A.cpp stream is done
-              // in the visitor constructor.
-              if (be_global->gen_anyop_files ())
-                {
-                  (void) tao_cg->end_anyop_source ();
-                }
             }
 
+          // Conditional switch to the *A.cpp stream is done
+          // in the visitor constructor.
+          if (be_global->gen_anyop_files ())
+            {
+              (void) tao_cg->end_anyop_source ();
+            }
+
+
           break;
         }
       case TAO_CodeGen::TAO_ROOT_IH:
@@ -359,6 +361,13 @@ int be_visitor_root::visit_root (be_root *node)
       case TAO_CodeGen::TAO_ROOT_SI:
       case TAO_CodeGen::TAO_ROOT_SS:
       case TAO_CodeGen::TAO_ROOT_TIE_SH:
+      case TAO_CodeGen::TAO_ROOT_SVH:
+      case TAO_CodeGen::TAO_ROOT_SVS:
+      case TAO_CodeGen::TAO_ROOT_EXH:
+      case TAO_CodeGen::TAO_ROOT_EXS:
+      case TAO_CodeGen::TAO_ROOT_CNH:
+      case TAO_CodeGen::TAO_ROOT_CNS:
+      case TAO_CodeGen::TAO_ROOT_EX_IDL:
         break;
       default:
         {
@@ -399,6 +408,13 @@ int be_visitor_root::visit_root (be_root *node)
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_SVH:
+    case TAO_CodeGen::TAO_ROOT_SVS:
+    case TAO_CodeGen::TAO_ROOT_EXH:
+    case TAO_CodeGen::TAO_ROOT_EXS:
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
     case TAO_CodeGen::TAO_ROOT_CI:
     case TAO_CodeGen::TAO_ROOT_SH:
     case TAO_CodeGen::TAO_ROOT_IH:
@@ -447,6 +463,13 @@ int be_visitor_root::visit_root (be_root *node)
     case TAO_CodeGen::TAO_ROOT_SS:
     case TAO_CodeGen::TAO_ROOT_IS:
     case TAO_CodeGen::TAO_ROOT_TIE_SH:
+    case TAO_CodeGen::TAO_ROOT_SVH:
+    case TAO_CodeGen::TAO_ROOT_SVS:
+    case TAO_CodeGen::TAO_ROOT_EXH:
+    case TAO_CodeGen::TAO_ROOT_EXS:
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
       break; // nothing to be done
     default:
       {
@@ -475,10 +498,10 @@ int be_visitor_root::visit_root (be_root *node)
       (void) tao_cg->end_client_header ();
       break;
     case TAO_CodeGen::TAO_ROOT_CI:
-      tao_cg->end_client_inline ();
+      (void) tao_cg->end_client_inline ();
       break;
     case TAO_CodeGen::TAO_ROOT_CS:
-      tao_cg->end_client_stubs ();
+      (void) tao_cg->end_client_stubs ();
       break;
     case TAO_CodeGen::TAO_ROOT_SH:
       (void) tao_cg->end_server_header ();
@@ -491,7 +514,7 @@ int be_visitor_root::visit_root (be_root *node)
         );
       break;
     case TAO_CodeGen::TAO_ROOT_SI:
-      tao_cg->end_server_inline ();
+      (void) tao_cg->end_server_inline ();
       break;
     case TAO_CodeGen::TAO_ROOT_SS:
       if (be_global->gen_tie_classes ())
@@ -507,6 +530,27 @@ int be_visitor_root::visit_root (be_root *node)
           (void) tao_cg->end_server_template_header ();
         }
 
+      break;
+    case TAO_CodeGen::TAO_ROOT_SVH:
+      (void) tao_cg->end_ciao_svnt_header ();
+      break;
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      (void) tao_cg->end_ciao_svnt_source ();
+      break;
+    case TAO_CodeGen::TAO_ROOT_EXH:
+      (void) tao_cg->end_ciao_exec_header ();
+      break;
+    case TAO_CodeGen::TAO_ROOT_EXS:
+      (void) tao_cg->end_ciao_exec_source ();
+      break;
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      (void) tao_cg->end_ciao_exec_idl ();
+      break;
+    case TAO_CodeGen::TAO_ROOT_CNH:
+      (void) tao_cg->end_ciao_conn_header ();
+      break;
+    case TAO_CodeGen::TAO_ROOT_CNS:
+      (void) tao_cg->end_ciao_conn_source ();
       break;
     default:
       break;
@@ -562,7 +606,7 @@ be_visitor_root::visit_constant (be_constant *node)
 int
 be_visitor_root::visit_enum (be_enum *node)
 {
-  // Instantiate a visitor context with a copy of our context. This info
+ // Instantiate a visitor context with a copy of our context. This info
   // will be modified based on what type of node we are visiting.
   be_visitor_context ctx (*this->ctx_);
   ctx.node (node);
@@ -637,7 +681,7 @@ be_visitor_root::visit_enum (be_enum *node)
 int
 be_visitor_root::visit_exception (be_exception *node)
 {
-  // Instantiate a visitor context with a copy of our context. This info
+ // Instantiate a visitor context with a copy of our context. This info
   // will be modified based on what type of node we are visiting.
   be_visitor_context ctx (*this->ctx_);
   ctx.node (node);
@@ -790,10 +834,32 @@ be_visitor_root::visit_interface (be_interface *node)
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      {
+        be_visitor_interface_ex_idl visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVH:
+      {
+        be_visitor_interface_svh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      {
+        be_visitor_interface_svs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
     case TAO_CodeGen::TAO_ROOT_SERIALIZER_OP_CH:
     case TAO_CodeGen::TAO_ROOT_SERIALIZER_OP_CS:
+    case TAO_CodeGen::TAO_ROOT_EXH:
+    case TAO_CodeGen::TAO_ROOT_EXS:
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
       {
-        return 0; // nothing to be done for DCPS
+        return 0; // Nothing to be done.
         break;
       }
     default:
@@ -1240,6 +1306,39 @@ be_visitor_root::visit_component (be_component *node)
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_SVH:
+      {
+        be_visitor_component_svh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      {
+        be_visitor_component_svs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      {
+        be_visitor_component_ex_idl visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXH:
+      {
+        be_visitor_component_exh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXS:
+      {
+        be_visitor_component_exs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+      break;
     default:
       return 0;    // nothing to do.
     }
@@ -1329,6 +1428,39 @@ be_visitor_root::visit_home (be_home *node)
         status = node->accept (&visitor);
         break;
       }
+    case TAO_CodeGen::TAO_ROOT_SVH:
+      {
+        be_visitor_home_svh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_SVS:
+      {
+        be_visitor_home_svs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
+      {
+        be_visitor_home_ex_idl visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXH:
+      {
+        be_visitor_home_exh visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_EXS:
+      {
+        be_visitor_home_exs visitor (&ctx);
+        status = node->accept (&visitor);
+        break;
+      }
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+      break;
     default:
       return 0; // nothing to be done
     }
@@ -1345,6 +1477,52 @@ be_visitor_root::visit_home (be_home *node)
   return 0;
 }
 
+int
+be_visitor_root::visit_connector (be_connector *node)
+{
+  // Instantiate a visitor context with a copy of our context. This info
+  // will be modified based on what type of node we are visiting.
+  be_visitor_context ctx (*this->ctx_);
+  ctx.node (node);
+  int status = 0;
+
+  switch (this->ctx_->state ())
+    {
+      case TAO_CodeGen::TAO_ROOT_CNH:
+        {
+          be_visitor_connector_dds_exh visitor (&ctx);
+          status = node->accept (&visitor);
+          break;
+        }
+      case TAO_CodeGen::TAO_ROOT_CNS:
+        {
+          be_visitor_connector_dds_exs visitor (&ctx);
+          status = node->accept (&visitor);
+          break;
+        }
+      // Skip these contexts, the connector impl is
+      // generated in a separate pass, using the states
+      // above.
+      case TAO_CodeGen::TAO_ROOT_EXH:
+      case TAO_CodeGen::TAO_ROOT_EXS:
+        break;
+      default:
+        // In all other cases, same as component.
+        return this->visit_component (node);
+    }
+    
+  if (status == -1)
+    {
+      ACE_ERROR_RETURN ((LM_ERROR,
+                         ACE_TEXT ("be_visitor_root::")
+                         ACE_TEXT ("visit_connector - ")
+                         ACE_TEXT ("failed to accept visitor\n")),
+                        -1);
+    }
+    
+  return 0;
+}
+
 int
 be_visitor_root::visit_module (be_module *node)
 {
@@ -1363,12 +1541,17 @@ be_visitor_root::visit_module (be_module *node)
         break;
       }
     case TAO_CodeGen::TAO_ROOT_CI:
-      {
-        be_visitor_module visitor (&ctx);
-        status = node->accept (&visitor);
-        break;
-      }
+    case TAO_CodeGen::TAO_ROOT_SI:
+    case TAO_CodeGen::TAO_ROOT_SS:
+    case TAO_CodeGen::TAO_ROOT_IS:
     case TAO_CodeGen::TAO_ROOT_CS:
+    case TAO_CodeGen::TAO_ROOT_SVH:
+    case TAO_CodeGen::TAO_ROOT_SVS:
+    case TAO_CodeGen::TAO_ROOT_EXH:
+    case TAO_CodeGen::TAO_ROOT_EXS:
+    case TAO_CodeGen::TAO_ROOT_CNH:
+    case TAO_CodeGen::TAO_ROOT_CNS:
+    case TAO_CodeGen::TAO_ROOT_EX_IDL:
       {
         be_visitor_module visitor (&ctx);
         status = node->accept (&visitor);
@@ -1380,14 +1563,6 @@ be_visitor_root::visit_module (be_module *node)
         status = node->accept (&visitor);
         break;
       }
-    case TAO_CodeGen::TAO_ROOT_SI:
-    case TAO_CodeGen::TAO_ROOT_SS:
-    case TAO_CodeGen::TAO_ROOT_IS:
-      {
-        be_visitor_module visitor (&ctx);
-        status = node->accept (&visitor);
-        break;
-      }
     case TAO_CodeGen::TAO_ROOT_IH:
       {
         be_visitor_module_ih visitor (&ctx);
