@@ -1,26 +1,17 @@
-//
-// $Id: root_ci.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    root_ci.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the Root in the client inline
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    root_ci.cpp
+ *
+ *  $Id: root_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the Root in the client inline
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           root_ci, 
-           "$Id: root_ci.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // *********************************
 // Root visitor for client inline
