@@ -1,26 +1,17 @@
-//
-// $Id: root_cs.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    root_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Root in the client stubs file.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    root_cs.cpp
+ *
+ *  $Id: root_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Root in the client stubs file.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           root_cs, 
-           "$Id: root_cs.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ***********************************
 // Root visitor for client stubs
