@@ -1,24 +1,17 @@
-// $Id: root_ih.cpp 45401 2002-07-01 13:49:23Z parsons $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    root_ih.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Root in the server implementation header
-//
-// = AUTHOR
-//   Yamuna  Krishnamurthy (yamuna@cs.wustl.edu)
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    root_ih.cpp
+ *
+ *  $Id: root_ih.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Root in the server implementation header
+ *
+ *
+ *  @author Yamuna  Krishnamurthy (yamuna@cs.wustl.edu)
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           root_ih, 
-           "$Id: root_ih.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ***********************************
 // Root visitor for implementation header
