@@ -1,25 +1,16 @@
-//
-// $Id: root_is.cpp 45401 2002-07-01 13:49:23Z parsons $
-//
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    root_is.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the Root in the implementation skeletons file
-//
-// = AUTHOR
-//   Yamuna Krishnamurthy (yamuna@cs.wustl.edu)
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    root_is.cpp
+ *
+ *  $Id: root_is.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the Root in the implementation skeletons file
+ *
+ *
+ *  @author Yamuna Krishnamurthy (yamuna@cs.wustl.edu)
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           root_is, 
-           "$Id: root_is.cpp 45401 2002-07-01 13:49:23Z parsons $")
 
 // ******************************************************
 // Root visitor for implementation  skeletons
