@@ -1,26 +1,17 @@
-//
-// $Id: root_si.cpp 75259 2006-11-07 23:14:52Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    root_si.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the Root in the server inline file
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    root_si.cpp
+ *
+ *  $Id: root_si.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the Root in the server inline file
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root,
-           root_si,
-           "$Id: root_si.cpp 75259 2006-11-07 23:14:52Z parsons $")
 
 // ***********************************************
 // Root visitor for server inline
