@@ -1,26 +1,17 @@
-//
-// $Id: root_ss.cpp 75259 2006-11-07 23:14:52Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    root_ss.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the Root in the server skeletons file
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    root_ss.cpp
+ *
+ *  $Id: root_ss.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the Root in the server skeletons file
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root,
-           root_ss,
-           "$Id: root_ss.cpp 75259 2006-11-07 23:14:52Z parsons $")
 
 // ******************************************************
 // Root visitor for server skeletons
