@@ -1,27 +1,18 @@
-//
-// $Id: serializer_op.cpp 66459 2005-06-15 20:47:58Z fields_t $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    serializer_op.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the TAO::DCPS::Serializer operators 
-//    for types defined in Root's scope.
-//
-// = AUTHOR
-//    Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    serializer_op.cpp
+ *
+ *  $Id: serializer_op.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the TAO::DCPS::Serializer operators 
+ *  for types defined in Root's scope.
+ *
+ *
+ *  @author Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_root, 
-           serializer_op, 
-           "$Id: serializer_op.cpp 66459 2005-06-15 20:47:58Z fields_t $")
 
 // ***************************************************************************
 // Root visitor for generating Serializer operator declarations in the client header
