@@ -1,23 +1,18 @@
-//
-// $Id: be_visitor_scope.cpp 70870 2006-02-09 16:44:15Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_scope.cpp
-//
-// = DESCRIPTION
-//    Visitor for the base be_scope node. This serves to maintain the current
-//    state (context) of code generation for the derived visitor.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_scope.cpp
+ *
+ *  $Id: be_visitor_scope.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor for the base be_scope node. This serves to maintain the current
+ *  state (context) of code generation for the derived visitor.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_argument.h"
 #include "be_scope.h"
@@ -25,10 +20,6 @@
 #include "be_visitor_context.h"
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (be,
-           be_visitor_scope,
-           "$Id: be_visitor_scope.cpp 70870 2006-02-09 16:44:15Z parsons $")
-
 // ******************************************************
 //  Generic visitor for a scope.
 //  All elements that give rise to a scope inherit from
@@ -65,13 +56,13 @@ be_visitor_scope::visit_scope (be_scope *node)
                              "bad node in this scope\n"),
                             -1);
         }
-
+        
       be_decl *bd = be_decl::narrow_from_decl (d);
 
       // Set the scope node as "node" in which the code is being
       // generated so that elements in the node's scope can use it
       // for code generation.
-      this->ctx_->scope (node->decl ());
+      this->ctx_->scope (node);
 
       // Set the node to be visited.
       this->ctx_->node (bd);
@@ -132,7 +123,7 @@ int
 be_visitor_scope::next_elem (be_decl *elem,
                              be_decl *&successor)
 {
-  be_decl *ctx_scope = this->ctx_->scope ();
+  be_decl *ctx_scope = this->ctx_->scope ()->decl ();
   be_scope *node = 0;
 
   if (ctx_scope != 0)
@@ -203,14 +194,7 @@ be_visitor_scope::last_node (be_decl *bd)
   (void) this->next_elem (bd,
                           next);
 
-  if (next != 0)
-    {
-      // Not the last.
-      return 0;
-    }
-
-  // I am the last one.
-  return 1;
+  return (next == 0);
 }
 
 bool
