@@ -1,26 +1,17 @@
-//
-// $Id: sequence_ch.cpp 76929 2007-02-05 23:48:07Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    sequence_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Sequence in the client header
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    sequence_ch.cpp
+ *
+ *  $Id: sequence_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Sequence in the client header
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_sequence,
-           sequence_ch,
-           "$Id: sequence_ch.cpp 76929 2007-02-05 23:48:07Z parsons $")
 
 // Root visitor for client header.
 be_visitor_sequence_ch::be_visitor_sequence_ch (be_visitor_context *ctx)
@@ -37,7 +28,7 @@ int be_visitor_sequence_ch::visit_sequence (be_sequence *node)
   if (node->defined_in () == 0)
     {
       // The node is a nested sequence, and has had no scope defined.
-      node->set_defined_in (DeclAsScope (this->ctx_->scope ()));
+      node->set_defined_in (DeclAsScope (this->ctx_->scope ()->decl ()));
     }
 
   // First create a name for ourselves.
@@ -126,7 +117,7 @@ int be_visitor_sequence_ch::visit_sequence (be_sequence *node)
       << node->local_name () << be_idt_nl
       << ": public" << be_idt << be_idt_nl;
 
-  if (node->gen_base_class_name (os, "", this->ctx_->scope ()) == -1)
+  if (node->gen_base_class_name (os, "", this->ctx_->scope ()->decl ()) == -1)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_sequence_ch::"
@@ -151,7 +142,7 @@ int be_visitor_sequence_ch::visit_sequence (be_sequence *node)
     }
 
   *os << be_nl
-      << node->local_name () << " (" << be_idt << be_idt;
+      << node->local_name () << " (" << be_idt;
 
   if (node->unbounded ())
     {
@@ -177,8 +168,7 @@ int be_visitor_sequence_ch::visit_sequence (be_sequence *node)
     }
 
   *os << "* buffer, " << be_nl
-      << "::CORBA::Boolean release = false" << be_uidt_nl
-      << ");" << be_uidt_nl;
+      << "::CORBA::Boolean release = false);" << be_uidt_nl;
   *os << node->local_name () << " (const " << node->local_name ()
       << " &);" << be_nl;
   *os << "virtual ~" << node->local_name () << " (void);";
@@ -195,8 +185,7 @@ int be_visitor_sequence_ch::visit_sequence (be_sequence *node)
       *os << be_nl << be_nl
           << "typedef " << node->local_name () << "_var _var_type;"
           << be_nl
-          << "typedef " << node->local_name () << "_out _out_type;"
-          << be_nl << be_nl;
+          << "typedef " << node->local_name () << "_out _out_type;";
     }
 
   // TAO provides extensions for octet sequences, first find out if
@@ -225,14 +214,15 @@ int be_visitor_sequence_ch::visit_sequence (be_sequence *node)
   if (predef != 0 && predef->pt () == AST_PredefinedType::PT_octet
       && node->unbounded ())
     {
-      *os << "\n\n#if (TAO_NO_COPY_OCTET_SEQUENCES == 1)" << be_nl
-                << node->local_name () << " (" << be_idt << be_idt_nl
-                << "::CORBA::ULong length," << be_nl
-                << "const ACE_Message_Block* mb" << be_uidt_nl
-                << ")" << be_uidt_nl
-                << "  : TAO::unbounded_value_sequence< ::CORBA::Octet>"
-                << " (length, mb) {}" << "\n"
-                << "#endif /* TAO_NO_COPY_OCTET_SEQUENCE == 1 */";
+      *os << be_nl << be_nl
+          << "\n\n#if (TAO_NO_COPY_OCTET_SEQUENCES == 1)" << be_nl
+          << node->local_name () << " (" << be_idt << be_idt_nl
+          << "::CORBA::ULong length," << be_nl
+          << "const ACE_Message_Block* mb" << be_uidt_nl
+          << ")" << be_uidt_nl
+          << "  : TAO::unbounded_value_sequence< ::CORBA::Octet>"
+          << " (length, mb) {}" << "\n"
+          << "#endif /* TAO_NO_COPY_OCTET_SEQUENCE == 1 */";
     }
 
   *os << be_uidt_nl
