@@ -1,22 +1,17 @@
-//
-// $Id: be_visitor_structure.cpp 66457 2005-06-15 19:47:53Z fields_t $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_structure.cpp
-//
-// = DESCRIPTION
-//    Visitors for generation of code for Structure
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_structure.cpp
+ *
+ *  $Id: be_visitor_structure.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitors for generation of code for Structure
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_field.h"
 #include "be_structure.h"
@@ -40,6 +35,3 @@
 #include "be_visitor_structure/serializer_op_ch.cpp"
 #include "be_visitor_structure/serializer_op_cs.cpp"
 
-ACE_RCSID (be, 
-           be_visitor_structure, 
-           "$Id: be_visitor_structure.cpp 66457 2005-06-15 19:47:53Z fields_t $")
