@@ -1,26 +1,17 @@
-//
-// $Id: structure_fwd_ch.cpp 70870 2006-02-09 16:44:15Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    structure_fwd_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for be_structure_fwd node in the client header.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    structure_fwd_ch.cpp
+ *
+ *  $Id: structure_fwd_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for be_structure_fwd node in the client header.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_structure_fwd, 
-           structure_fwd_ch, 
-           "$Id: structure_fwd_ch.cpp 70870 2006-02-09 16:44:15Z parsons $")
 
 be_visitor_structure_fwd_ch::be_visitor_structure_fwd_ch (
     be_visitor_context *ctx
