@@ -1,22 +1,16 @@
-//
-// $Id: be_visitor_typecode.cpp 66547 2005-06-21 20:31:32Z gmaxey $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_typecode.cpp
-//
-// = DESCRIPTION
-//    Visitors for generation of code for TypeCodes for various types
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_typecode.cpp
+ *
+ *  $Id: be_visitor_typecode.cpp 89037 2010-02-16 21:11:04Z parsons $
+ *
+ *  Visitors for generation of code for TypeCodes for various types
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 #include "be_array.h"
 #include "be_enum.h"
@@ -24,7 +18,7 @@
 #include "be_exception.h"
 #include "be_field.h"
 #include "be_interface.h"
-#include "be_component.h"
+#include "be_connector.h"
 #include "be_home.h"
 #include "be_module.h"
 #include "be_predefined_type.h"
@@ -56,7 +50,3 @@
 #include "be_visitor_typecode/union_typecode.cpp"
 #include "be_visitor_typecode/value_typecode.cpp"
 
-
-ACE_RCSID (be,
-           be_visitor_typecode,
-           "$Id: be_visitor_typecode.cpp 66547 2005-06-21 20:31:32Z gmaxey $")
