@@ -1,26 +1,16 @@
-//
-// $Id: typecode_defn.cpp 77405 2007-02-26 23:35:31Z ossama $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    typecode_defn.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for TypeCode definitions for types.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_typecode,
-           typecode_defn,
-           "$Id: typecode_defn.cpp 77405 2007-02-26 23:35:31Z ossama $")
+//=============================================================================
+/**
+ *  @file    typecode_defn.cpp
+ *
+ *  $Id: typecode_defn.cpp 89037 2010-02-16 21:11:04Z parsons $
+ *
+ *  Visitor generating code for TypeCode definitions for types.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 #include "be_interface_fwd.h"
 
@@ -391,18 +381,18 @@ be_visitor_typecode_defn::visit_array (be_array *node)
   // Namespace begin.
   this->gen_begin_NS_for_anon ();
 
-  unsigned long const ndims = node->n_dims ();
+  ACE_CDR::ULong const ndims = node->n_dims ();
 
-  for (unsigned long i = 0; i < ndims; ++i)
+  for (ACE_CDR::ULong i = 0; i < ndims; ++i)
     {
       os << "TAO::TypeCode::Sequence< ::CORBA::TypeCode_ptr const *," << be_nl
          << "                        TAO::Null_RefCount_Policy>"
          << be_idt_nl
          << node->flat_name ();
 
-      unsigned long const inner_ndims = ndims - i - 1;
+      ACE_CDR::ULong const inner_ndims = ndims - i - 1;
 
-      for (unsigned long j = inner_ndims; j < ndims; ++j)
+      for (ACE_CDR::ULong j = inner_ndims; j < ndims; ++j)
         {
           os << "_" << node->dims ()[j]->ev ()->u.ulval;
         }
@@ -498,6 +488,12 @@ be_visitor_typecode_defn::visit_component (be_component *node)
   return this->visit_interface (node);
 }
 
+int
+be_visitor_typecode_defn::visit_connector (be_connector *node)
+{
+  return this->visit_interface (node);
+}
+
 int
 be_visitor_typecode_defn::visit_interface_fwd (be_interface_fwd * node)
 {
