@@ -1,26 +1,17 @@
-//
-// $Id: cdr_op_ch.cpp 73153 2006-06-20 07:42:07Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Cdr operators of a Typedef node
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_ch.cpp
+ *
+ *  $Id: cdr_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Cdr operators of a Typedef node
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_typedef,
-           cdr_op_ch,
-           "$Id: cdr_op_ch.cpp 73153 2006-06-20 07:42:07Z jwillemsen $")
 
 // ***************************************************************************
 // Typedef visitor for generating Cdr operator declarations in the client header
@@ -71,7 +62,7 @@ be_visitor_typedef_cdr_op_ch::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt; // base type
+  be_type *bt = 0; // base type
 
   if (this->ctx_->tdef ())
     {
@@ -144,7 +135,7 @@ be_visitor_typedef_cdr_op_ch::visit_typedef (be_typedef *node)
 int
 be_visitor_typedef_cdr_op_ch::visit_array (be_array *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ())
     {
@@ -164,7 +155,7 @@ be_visitor_typedef_cdr_op_ch::visit_array (be_array *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_cdr_op_ch::"
                              "visit_array - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -175,7 +166,7 @@ be_visitor_typedef_cdr_op_ch::visit_array (be_array *node)
 int
 be_visitor_typedef_cdr_op_ch::visit_enum (be_enum *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ())
     {
@@ -194,7 +185,7 @@ be_visitor_typedef_cdr_op_ch::visit_enum (be_enum *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_cdr_op_ch::"
                              "visit_enum - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -205,7 +196,7 @@ be_visitor_typedef_cdr_op_ch::visit_enum (be_enum *node)
 int
 be_visitor_typedef_cdr_op_ch::visit_sequence (be_sequence *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ())
     {
@@ -224,7 +215,7 @@ be_visitor_typedef_cdr_op_ch::visit_sequence (be_sequence *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_cdr_op_ch::"
                              "visit_sequence - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -235,7 +226,7 @@ be_visitor_typedef_cdr_op_ch::visit_sequence (be_sequence *node)
 int
 be_visitor_typedef_cdr_op_ch::visit_structure (be_structure *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ())
     {
@@ -254,7 +245,7 @@ be_visitor_typedef_cdr_op_ch::visit_structure (be_structure *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_cdr_op_ch::"
                              "visit_structure - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -265,7 +256,7 @@ be_visitor_typedef_cdr_op_ch::visit_structure (be_structure *node)
 int
 be_visitor_typedef_cdr_op_ch::visit_union (be_union *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ())
     {
@@ -284,7 +275,7 @@ be_visitor_typedef_cdr_op_ch::visit_union (be_union *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_op_ch::"
                              "visit_union - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
