@@ -1,27 +1,18 @@
-//
-// $Id: serializer_op_cs.cpp 66459 2005-06-15 20:47:58Z fields_t $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    serializer_op_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for TAO::DCPS::Serializer operators 
-//    in the client stubs
-//
-// = AUTHOR
-//    Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    serializer_op_cs.cpp
+ *
+ *  $Id: serializer_op_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for TAO::DCPS::Serializer operators
+ *  in the client stubs
+ *
+ *
+ *  @author Scott Harris <harris_s@ociweb.com> based on code by Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_typedef, 
-           serializer_op_cs, 
-           "$Id: serializer_op_cs.cpp 66459 2005-06-15 20:47:58Z fields_t $")
 
 // ***************************************************************************
 // Typedef visitor for generating Serializer operator declarations in the client
@@ -68,7 +59,7 @@ be_visitor_typedef_serializer_op_cs::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt; // base type
+  be_type *bt = 0; // base type
 
   if (this->ctx_->tdef ())
     {
@@ -87,7 +78,7 @@ be_visitor_typedef_serializer_op_cs::visit_typedef (be_typedef *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_typedef - "
-                             "bad primitive base type\n"),  
+                             "bad primitive base type\n"),
                             -1);
         }
 
@@ -97,7 +88,7 @@ be_visitor_typedef_serializer_op_cs::visit_typedef (be_typedef *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_typedef - "
-                             "failed to accept visitor\n"),  
+                             "failed to accept visitor\n"),
                             -1);
         }
 
@@ -117,7 +108,7 @@ be_visitor_typedef_serializer_op_cs::visit_typedef (be_typedef *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_typedef - "
-                             "bad base type\n"),  
+                             "bad base type\n"),
                             -1);
         }
 
@@ -127,7 +118,7 @@ be_visitor_typedef_serializer_op_cs::visit_typedef (be_typedef *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_typedef - "
-                             "failed to accept visitor\n"),  
+                             "failed to accept visitor\n"),
                             -1);
         }
 
@@ -141,7 +132,7 @@ be_visitor_typedef_serializer_op_cs::visit_typedef (be_typedef *node)
 int
 be_visitor_typedef_serializer_op_cs::visit_array (be_array *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -162,7 +153,7 @@ be_visitor_typedef_serializer_op_cs::visit_array (be_array *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_array - "
-                             "base class visitor failed \n"),  
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -173,7 +164,7 @@ be_visitor_typedef_serializer_op_cs::visit_array (be_array *node)
 int
 be_visitor_typedef_serializer_op_cs::visit_sequence (be_sequence *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -193,7 +184,7 @@ be_visitor_typedef_serializer_op_cs::visit_sequence (be_sequence *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_sequence - "
-                             "base class visitor failed \n"),  
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -204,7 +195,7 @@ be_visitor_typedef_serializer_op_cs::visit_sequence (be_sequence *node)
 int
 be_visitor_typedef_serializer_op_cs::visit_structure (be_structure *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -224,7 +215,7 @@ be_visitor_typedef_serializer_op_cs::visit_structure (be_structure *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_structure - "
-                             "base class visitor failed \n"),  
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -235,7 +226,7 @@ be_visitor_typedef_serializer_op_cs::visit_structure (be_structure *node)
 int
 be_visitor_typedef_serializer_op_cs::visit_union (be_union *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -255,7 +246,7 @@ be_visitor_typedef_serializer_op_cs::visit_union (be_union *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_serializer_op_cs::"
                              "visit_union - "
-                             "base class visitor failed \n"),  
+                             "base class visitor failed\n"),
                             -1);
         }
     }
