@@ -1,26 +1,17 @@
-//
-// $Id: typedef_ch.cpp 73210 2006-06-21 12:14:14Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    typedef_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Typedef in the client header
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    typedef_ch.cpp
+ *
+ *  $Id: typedef_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Typedef in the client header
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID(be_visitor_typedef,
-          typedef_ch,
-          "$Id: typedef_ch.cpp 73210 2006-06-21 12:14:14Z jwillemsen $")
 
 // ******************************************************
 // Typedef visitor for client header
@@ -59,7 +50,7 @@ be_visitor_typedef_ch::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->tdef ())
     {
@@ -149,8 +140,8 @@ be_visitor_typedef_ch::visit_array (be_array *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Is the base type an alias to an array node or an actual array node.
   if (this->ctx_->alias ())
@@ -177,7 +168,7 @@ be_visitor_typedef_ch::visit_array (be_array *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ch::"
                              "visit_array - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -269,8 +260,8 @@ be_visitor_typedef_ch::visit_enum (be_enum *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -290,7 +281,7 @@ be_visitor_typedef_ch::visit_enum (be_enum *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ch::"
                              "visit_enum - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -313,8 +304,8 @@ be_visitor_typedef_ch::visit_interface (be_interface *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -362,8 +353,8 @@ be_visitor_typedef_ch::visit_predefined_type (be_predefined_type *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -407,7 +398,7 @@ be_visitor_typedef_ch::visit_string (be_string *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
+  be_decl *scope = this->ctx_->scope ()->decl ();
 
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
@@ -441,8 +432,8 @@ be_visitor_typedef_ch::visit_sequence (be_sequence *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -462,7 +453,7 @@ be_visitor_typedef_ch::visit_sequence (be_sequence *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ch::"
                              "visit_sequence - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -489,8 +480,8 @@ be_visitor_typedef_ch::visit_structure (be_structure *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -510,7 +501,7 @@ be_visitor_typedef_ch::visit_structure (be_structure *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ch::"
                              "visit_structure - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -535,8 +526,8 @@ be_visitor_typedef_ch::visit_union (be_union *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -556,7 +547,7 @@ be_visitor_typedef_ch::visit_union (be_union *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ch::"
                              "visit_union - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -581,8 +572,8 @@ be_visitor_typedef_ch::visit_valuebox (be_valuebox *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
@@ -617,8 +608,8 @@ be_visitor_typedef_ch::visit_valuetype (be_valuetype *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
   be_typedef *tdef = this->ctx_->tdef ();
-  be_decl *scope = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *scope = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Typedef of a typedef?
   if (this->ctx_->alias ())
