@@ -1,26 +1,17 @@
-//
-// $Id: typedef_ci.cpp 73153 2006-06-20 07:42:07Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    typedef_ci.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Typedefs in the client inline file.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    typedef_ci.cpp
+ *
+ *  $Id: typedef_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Typedefs in the client inline file.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_typedef,
-           typedef_ci,
-           "$Id: typedef_ci.cpp 73153 2006-06-20 07:42:07Z jwillemsen $")
 
 // ******************************************************
 // Typedef visitor for client inline
@@ -59,7 +50,7 @@ be_visitor_typedef_ci::visit_typedef (be_typedef *node)
   // the type maybe. In the latter, we just need typedefs for the type and all
   // associated _var, _out, and other types.
 
-  be_type *bt; // base type
+  be_type *bt = 0; // base type
 
   if (this->ctx_->tdef ())
     {
@@ -133,7 +124,7 @@ be_visitor_typedef_ci::visit_array (be_array *node)
 {
   TAO_OutStream *os = this->ctx_->stream (); // output stream
   be_typedef *tdef = this->ctx_->tdef (); // typedef node
-  be_type *bt;
+  be_type *bt = 0;
 
   // This doesn't catch 'typedef of a typedef' if the node is
   // imported, so we check for that below before generating
@@ -163,7 +154,7 @@ be_visitor_typedef_ci::visit_array (be_array *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ci::"
                              "visit_array - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -227,7 +218,7 @@ be_visitor_typedef_ci::visit_array (be_array *node)
 int
 be_visitor_typedef_ci::visit_sequence (be_sequence *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -247,7 +238,7 @@ be_visitor_typedef_ci::visit_sequence (be_sequence *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ci::"
                              "visit_sequence - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -258,7 +249,7 @@ be_visitor_typedef_ci::visit_sequence (be_sequence *node)
 int
 be_visitor_typedef_ci::visit_structure (be_structure *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -278,7 +269,7 @@ be_visitor_typedef_ci::visit_structure (be_structure *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ci::"
                              "visit_structure - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
@@ -289,7 +280,7 @@ be_visitor_typedef_ci::visit_structure (be_structure *node)
 int
 be_visitor_typedef_ci::visit_union (be_union *node)
 {
-  be_type *bt;
+  be_type *bt = 0;
 
   if (this->ctx_->alias ()) // typedef of a typedef
     {
@@ -309,7 +300,7 @@ be_visitor_typedef_ci::visit_union (be_union *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_typedef_ci::"
                              "visit_union - "
-                             "base class visitor failed \n"),
+                             "base class visitor failed\n"),
                             -1);
         }
     }
