@@ -1,22 +1,17 @@
-//
-// $Id: be_visitor_union.cpp 66457 2005-06-15 19:47:53Z fields_t $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_union.cpp
-//
-// = DESCRIPTION
-//    Visitors for generation of code for Union
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_union.cpp
+ *
+ *  $Id: be_visitor_union.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitors for generation of code for Union
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
+
 
 #include "be_enum.h"
 #include "be_typedef.h"
@@ -49,6 +44,3 @@
 #include "be_visitor_union/serializer_op_ch.cpp"
 #include "be_visitor_union/serializer_op_cs.cpp"
 
-ACE_RCSID (be, 
-           be_visitor_union, 
-           "$Id: be_visitor_union.cpp 66457 2005-06-15 19:47:53Z fields_t $")
