@@ -1,26 +1,17 @@
-//
-// $Id: discriminant_cs.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    discriminant_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for discriminant of the union
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    discriminant_cs.cpp
+ *
+ *  $Id: discriminant_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for discriminant of the union
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_union, 
-           discriminant_cs, 
-           "$Id: discriminant_cs.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // *************************************************************************
 // Visitor for discriminant in client stubs.
@@ -41,8 +32,8 @@ int
 be_visitor_union_discriminant_cs::visit_enum (be_enum *node)
 {
   be_union *bu =
-    this->ctx_->be_node_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_decl (this->ctx_->node ());
+  be_type *bt = 0;
 
   if (this->ctx_->alias ())
     {
@@ -69,7 +60,7 @@ be_visitor_union_discriminant_cs::visit_enum (be_enum *node)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "(%N:%l) be_visitor_union_discriminant_cs::"
                              "visit_enum - "
-                             "codegen failed\n"), 
+                             "codegen failed\n"),
                             -1);
         }
     }
