@@ -1,27 +1,18 @@
 
-//
-// $Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    cdr_op_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating CDR operator declarator for union_branch in the client header
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    cdr_op_ch.cpp
+ *
+ *  $Id: cdr_op_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating CDR operator declarator for union_branch in the client header
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_union_branch, 
-           cdr_op_ch, 
-           "$Id: cdr_op_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // **********************************************
 //  Visitor for union_branch in the client header file.
@@ -74,7 +65,7 @@ be_visitor_union_branch_cdr_op_ch::visit_array (be_array *node)
   // If not a typedef and we are defined in the use scope, we must be defined.
 
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // This is the case for anonymous arrays.
 
@@ -101,7 +92,7 @@ be_visitor_union_branch_cdr_op_ch::visit_enum (be_enum *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -126,7 +117,7 @@ be_visitor_union_branch_cdr_op_ch::visit_sequence (be_sequence *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -150,7 +141,7 @@ be_visitor_union_branch_cdr_op_ch::visit_structure (be_structure *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -194,7 +185,7 @@ be_visitor_union_branch_cdr_op_ch::visit_union (be_union *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
