@@ -1,5 +1,5 @@
 //
-// $Id: cdr_op_cs.cpp 74462 2006-09-18 20:01:59Z parsons $
+// $Id: cdr_op_cs.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 //
 
 // ============================================================================
@@ -18,10 +18,6 @@
 //
 // ============================================================================
 
-ACE_RCSID (be_visitor_union_branch,
-           cdr_op_cs,
-           "$Id: cdr_op_cs.cpp 74462 2006-09-18 20:01:59Z parsons $")
-
 // **********************************************
 //  Visitor for union_branch in the client stubs file.
 // **********************************************
@@ -70,7 +66,7 @@ be_visitor_union_branch_cdr_op_cs::visit_array (be_array *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -89,9 +85,10 @@ be_visitor_union_branch_cdr_op_cs::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_cs::"
@@ -111,7 +108,7 @@ be_visitor_union_branch_cdr_op_cs::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
       // we have to generate a name for us that has an underscore
@@ -188,9 +185,10 @@ be_visitor_union_branch_cdr_op_cs::visit_enum (be_enum *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_cs::"
@@ -235,7 +233,7 @@ be_visitor_union_branch_cdr_op_cs::visit_enum (be_enum *node)
   // Not a typedef and node is defined inside the union. Otherwise the cdr
   // operator is generated elsewhere.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
@@ -262,9 +260,10 @@ be_visitor_union_branch_cdr_op_cs::visit_interface (be_interface *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_cs::"
@@ -341,9 +340,10 @@ be_visitor_union_branch_cdr_op_cs::visit_interface_fwd (be_interface_fwd *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_cs::"
@@ -425,9 +425,10 @@ be_visitor_union_branch_cdr_op_cs::emit_valuetype_common (be_type *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_cs::"
@@ -482,9 +483,10 @@ be_visitor_union_branch_cdr_op_cs::visit_predefined_type (
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_cs::"
@@ -646,7 +648,7 @@ be_visitor_union_branch_cdr_op_cs::visit_sequence (be_sequence *node)
   // If the sequence is defined in this scope, generate its CDR stream
   // operators heree.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Anonymous sequence
       be_visitor_context ctx (*this->ctx_);
@@ -669,8 +671,10 @@ be_visitor_union_branch_cdr_op_cs::visit_sequence (be_sequence *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
-  if (!f)
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+    
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_ci::"
@@ -737,9 +741,10 @@ be_visitor_union_branch_cdr_op_cs::visit_string (be_string *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_ci::"
@@ -762,8 +767,29 @@ be_visitor_union_branch_cdr_op_cs::visit_string (be_string *node)
           *os << "::CORBA::WString_var _tao_union_tmp;" << be_nl;
         }
 
-      *os << "result = strm >> _tao_union_tmp.out ();" << be_nl << be_nl
-          << "if (result)" << be_idt_nl
+      if (node->max_size ()->ev ()->u.ulval != 0)
+        {
+          if (node->width () == (long) sizeof (char))
+            {
+              *os << "result = strm >> ACE_InputCDR::to_string ("
+                  << "_tao_union_tmp.out (), "
+                  << node->max_size ()->ev ()->u.ulval << ");"
+                  << be_nl << be_nl;
+            }
+          else
+            {
+              *os << "result = strm >> ACE_InputCDR::to_wstring ("
+                  << "_tao_union_tmp.out (), "
+                  << node->max_size ()->ev ()->u.ulval << ");"
+                  << be_nl << be_nl;
+            }
+        }
+      else
+        {
+          *os << "result = strm >> _tao_union_tmp.out ();" << be_nl << be_nl;
+        }
+
+      *os << "if (result)" << be_idt_nl
           << "{" << be_idt_nl
           << "_tao_union."
           << f->local_name () << " (_tao_union_tmp);" << be_nl
@@ -773,8 +799,26 @@ be_visitor_union_branch_cdr_op_cs::visit_string (be_string *node)
       break;
 
     case TAO_CodeGen::TAO_CDR_OUTPUT:
-      *os << "result = strm << _tao_union."
-          << f->local_name () << " ();";
+      if (node->max_size ()->ev ()->u.ulval != 0)
+        {
+          if (node->width () == (long) sizeof (char))
+            {
+              *os << "result = strm << ACE_OutputCDR::from_string ("
+                  << "_tao_union." << f->local_name () << " (), "
+                  << node->max_size ()->ev ()->u.ulval << ");";
+            }
+          else
+            {
+              *os << "result = strm << ACE_OutputCDR::from_wstring ("
+                  << "_tao_union." << f->local_name () << " (), "
+                  << node->max_size ()->ev ()->u.ulval << ");";
+            }
+        }
+      else
+        {
+          *os << "result = strm << _tao_union."
+              << f->local_name () << " ();";
+        }
       break;
 
     case TAO_CodeGen::TAO_CDR_SCOPE:
@@ -798,7 +842,7 @@ be_visitor_union_branch_cdr_op_cs::visit_structure (be_structure *node)
   // If the structure is defined in this scope. generate its CDR
   // stream operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -820,9 +864,10 @@ be_visitor_union_branch_cdr_op_cs::visit_structure (be_structure *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_ci::"
@@ -894,7 +939,7 @@ be_visitor_union_branch_cdr_op_cs::visit_union (be_union *node)
   // If the union is defined in this scope, generate its CDR
   // stream operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -916,9 +961,10 @@ be_visitor_union_branch_cdr_op_cs::visit_union (be_union *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_cdr_op_ci::"
@@ -967,7 +1013,8 @@ be_visitor_union_branch_cdr_op_cs::visit_union (be_union *node)
 int
 be_visitor_union_branch_cdr_op_cs::explicit_default (void)
 {
-  be_union *bu = be_union::narrow_from_decl (this->ctx_->scope ());
+  be_union *bu =
+    be_union::narrow_from_decl (this->ctx_->scope ()->decl ());
   int def_index = bu->default_index ();
 
   if (def_index != -1)
