@@ -1,26 +1,17 @@
-//
-// $Id: public_assign_cs.cpp 72142 2006-04-19 10:24:02Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    public_assign_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Union Branch for the assignment operator
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    public_assign_cs.cpp
+ *
+ *  $Id: public_assign_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Union Branch for the assignment operator
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_union_branch,
-           public_assign_cs,
-           "$Id: public_assign_cs.cpp 72142 2006-04-19 10:24:02Z jwillemsen $")
 
 // **********************************************
 //  visitor for union_branch in the client stubs file generating the code for
@@ -109,10 +100,10 @@ int
 be_visitor_union_branch_public_assign_cs::visit_array (be_array *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -181,11 +172,11 @@ int
 be_visitor_union_branch_public_assign_cs::visit_enum (be_enum *)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
+    be_union::narrow_from_scope (this->ctx_->scope ());
 
-  if (!ub || !bu)
+  if (ub == 0 || bu == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_public_assign_cs::"
@@ -209,10 +200,10 @@ int
 be_visitor_union_branch_public_assign_cs::visit_interface (be_interface *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -306,10 +297,10 @@ be_visitor_union_branch_public_assign_cs::visit_interface_fwd (
   )
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -421,10 +412,10 @@ int
 be_visitor_union_branch_public_assign_cs::emit_valuetype_common (be_type *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -491,10 +482,10 @@ be_visitor_union_branch_public_assign_cs::visit_predefined_type (
   )
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -603,10 +594,10 @@ int
 be_visitor_union_branch_public_assign_cs::visit_sequence (be_sequence *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -668,11 +659,11 @@ int
 be_visitor_union_branch_public_assign_cs::visit_string (be_string *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
+    be_union::narrow_from_scope (this->ctx_->scope ());
 
-  if (!ub || !bu)
+  if (ub == 0 || bu == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_public_assign_cs::"
@@ -704,10 +695,10 @@ int
 be_visitor_union_branch_public_assign_cs::visit_structure (be_structure *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -799,10 +790,10 @@ int
 be_visitor_union_branch_public_assign_cs::visit_union (be_union *node)
 {
   be_union_branch *ub =
-    this->ctx_->be_node_as_union_branch (); // get union branch
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
   be_union *bu =
-    this->ctx_->be_scope_as_union ();  // get the enclosing union backend
-  be_type *bt;
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
