@@ -1,26 +1,17 @@
-//
-// $Id: public_ch.cpp 75202 2006-11-03 16:15:26Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    public_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Union_branch in the public part.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    public_ch.cpp
+ *
+ *  $Id: public_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Union_branch in the public part.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_union_branch,
-           public_ch,
-           "$Id: public_ch.cpp 75202 2006-11-03 16:15:26Z parsons $")
 
 // **********************************************
 //  Visitor for union_branch in the client header file.
@@ -72,8 +63,8 @@ int
 be_visitor_union_branch_public_ch::visit_array (be_array *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -154,8 +145,8 @@ int
 be_visitor_union_branch_public_ch::visit_enum (be_enum *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -216,8 +207,8 @@ int
 be_visitor_union_branch_public_ch::visit_interface (be_interface *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -259,8 +250,8 @@ int
 be_visitor_union_branch_public_ch::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -302,8 +293,8 @@ int
 be_visitor_union_branch_public_ch::visit_valuebox (be_valuebox *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -345,8 +336,8 @@ int
 be_visitor_union_branch_public_ch::visit_valuetype (be_valuetype *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -388,8 +379,8 @@ int
 be_visitor_union_branch_public_ch::visit_valuetype_fwd (be_valuetype_fwd *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -431,8 +422,8 @@ int
 be_visitor_union_branch_public_ch::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
   be_typedef *td = this->ctx_->alias ();
 
   // Check if we are visiting this via a visit to a typedef node.
@@ -503,8 +494,8 @@ int
 be_visitor_union_branch_public_ch::visit_sequence (be_sequence *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -574,7 +565,7 @@ int
 be_visitor_union_branch_public_ch::visit_string (be_string *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
+  be_decl *bu = this->ctx_->scope ()->decl ();
 
   if (!ub || !bu)
     {
@@ -621,8 +612,8 @@ int
 be_visitor_union_branch_public_ch::visit_structure (be_structure *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -703,8 +694,8 @@ int
 be_visitor_union_branch_public_ch::visit_union (be_union *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_decl *bu = this->ctx_->scope ();
-  be_type *bt;
+  be_decl *bu = this->ctx_->scope ()->decl ();
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
