@@ -1,26 +1,17 @@
-//
-// $Id: public_ci.cpp 74462 2006-09-18 20:01:59Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    public_ci.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Union Branch in the client inline file.
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    public_ci.cpp
+ *
+ *  $Id: public_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Union Branch in the client inline file.
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_union_branch,
-           public_ci,
-           "$Id: public_ci.cpp 74462 2006-09-18 20:01:59Z parsons $")
 
 // *****************************************************
 //  Visitor for union_branch in the client inline file.
@@ -73,9 +64,11 @@ be_visitor_union_branch_public_ci::visit_union_branch (be_union_branch *node)
 int
 be_visitor_union_branch_public_ci::visit_array (be_array *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -206,9 +199,11 @@ be_visitor_union_branch_public_ci::visit_array (be_array *node)
 int
 be_visitor_union_branch_public_ci::visit_enum (be_enum *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // heck if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -275,9 +270,11 @@ be_visitor_union_branch_public_ci::visit_enum (be_enum *node)
 int
 be_visitor_union_branch_public_ci::visit_interface (be_interface *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -363,9 +360,11 @@ be_visitor_union_branch_public_ci::visit_interface (be_interface *node)
 int
 be_visitor_union_branch_public_ci::visit_interface_fwd (be_interface_fwd *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -469,9 +468,11 @@ be_visitor_union_branch_public_ci::visit_valuetype_fwd (be_valuetype_fwd *node)
 int
 be_visitor_union_branch_public_ci::emit_valuetype_common  (be_type *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -546,9 +547,11 @@ be_visitor_union_branch_public_ci::visit_predefined_type (
     be_predefined_type *node
   )
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -756,9 +759,11 @@ be_visitor_union_branch_public_ci::visit_predefined_type (
 int
 be_visitor_union_branch_public_ci::visit_sequence (be_sequence *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -836,10 +841,12 @@ be_visitor_union_branch_public_ci::visit_sequence (be_sequence *node)
 int
 be_visitor_union_branch_public_ci::visit_string (be_string *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
 
-  if (!ub || !bu)
+  if (ub == 0 || bu == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_public_ci::"
@@ -1005,9 +1012,11 @@ be_visitor_union_branch_public_ci::visit_string (be_string *node)
 int
 be_visitor_union_branch_public_ci::visit_structure (be_structure *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -1161,9 +1170,11 @@ be_visitor_union_branch_public_ci::visit_typedef (be_typedef *node)
 int
 be_visitor_union_branch_public_ci::visit_union (be_union *node)
 {
-  be_union_branch *ub = this->ctx_->be_node_as_union_branch ();
-  be_union *bu = this->ctx_->be_scope_as_union ();
-  be_type *bt;
+  be_union_branch *ub =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+  be_union *bu =
+    be_union::narrow_from_scope (this->ctx_->scope ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
