@@ -1,26 +1,17 @@
-//
-// $Id: public_cs.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    public_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Union Branch in the client stubs
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    public_cs.cpp
+ *
+ *  $Id: public_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Union Branch in the client stubs
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_union_branch, 
-           public_cs, 
-           "$Id: public_cs.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // **********************************************
 //  Visitor for union_branch in the client stubs file.
@@ -71,7 +62,7 @@ be_visitor_union_branch_public_cs::visit_array (be_array *node)
   // If not a typedef and we are defined in the use scope, we must be
   // defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Anonymous array case.
       be_visitor_context ctx (*this->ctx_);
@@ -117,7 +108,7 @@ be_visitor_union_branch_public_cs::visit_sequence (be_sequence *node)
   // defined.
 
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Anonymous sequence case.
       be_visitor_context ctx (*this->ctx_);
