@@ -1,5 +1,5 @@
 //
-// $Id: serializer_op_cs.cpp 78529 2007-05-30 20:30:12Z dai_y $
+// $Id: serializer_op_cs.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 //
 
 // ============================================================================
@@ -18,10 +18,6 @@
 //
 // ============================================================================
 
-ACE_RCSID (be_visitor_union_branch,
-           serializer_op_cs,
-           "$Id: serializer_op_cs.cpp 78529 2007-05-30 20:30:12Z dai_y $")
-
 // **********************************************
 //  Visitor for union_branch in the client stubs file.
 // **********************************************
@@ -70,7 +66,7 @@ be_visitor_union_branch_serializer_op_cs::visit_array (be_array *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -89,9 +85,10 @@ be_visitor_union_branch_serializer_op_cs::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -111,7 +108,7 @@ be_visitor_union_branch_serializer_op_cs::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
       // we have to generate a name for us that has an underscore
@@ -229,9 +226,10 @@ be_visitor_union_branch_serializer_op_cs::visit_enum (be_enum *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -301,7 +299,7 @@ be_visitor_union_branch_serializer_op_cs::visit_enum (be_enum *node)
   // Not a typedef and node is defined inside the union. Otherwise the
   // Serializer operator is generated elsewhere.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Instantiate a visitor context with a copy of our context. This info
       // will be modified based on what type of node we are visiting.
@@ -328,9 +326,10 @@ be_visitor_union_branch_serializer_op_cs::visit_interface (be_interface *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -413,9 +412,10 @@ be_visitor_union_branch_serializer_op_cs::visit_interface_fwd (be_interface_fwd
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -475,9 +475,10 @@ be_visitor_union_branch_serializer_op_cs::visit_valuetype (be_valuetype *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -530,9 +531,10 @@ be_visitor_union_branch_serializer_op_cs::visit_valuetype_fwd (be_valuetype_fwd
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -585,9 +587,10 @@ be_visitor_union_branch_serializer_op_cs::visit_predefined_type (be_predefined_t
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -868,7 +871,7 @@ be_visitor_union_branch_serializer_op_cs::visit_sequence (be_sequence *node)
   // If the sequence is defined in this scope, generate its Serializer stream
   // operators heree.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // Anonymous sequence
       be_visitor_context ctx (*this->ctx_);
@@ -891,8 +894,10 @@ be_visitor_union_branch_serializer_op_cs::visit_sequence (be_sequence *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
-  if (!f)
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
+    
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -996,9 +1001,10 @@ be_visitor_union_branch_serializer_op_cs::visit_string (be_string *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -1084,7 +1090,7 @@ be_visitor_union_branch_serializer_op_cs::visit_structure (be_structure *node)
   // If the structure is defined in this scope. generate its Serializer
   // stream operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -1106,9 +1112,10 @@ be_visitor_union_branch_serializer_op_cs::visit_structure (be_structure *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -1217,7 +1224,7 @@ be_visitor_union_branch_serializer_op_cs::visit_union (be_union *node)
   // If the union is defined in this scope, generate its Serializer
   // stream operators here.
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -1239,9 +1246,10 @@ be_visitor_union_branch_serializer_op_cs::visit_union (be_union *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the union_branch node.
-  be_union_branch *f = this->ctx_->be_node_as_union_branch ();
+  be_union_branch *f =
+    be_union_branch::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_union_branch_serializer_op_cs::"
@@ -1290,7 +1298,8 @@ be_visitor_union_branch_serializer_op_cs::visit_union (be_union *node)
 int
 be_visitor_union_branch_serializer_op_cs::explicit_default (void)
 {
-  be_union *bu = be_union::narrow_from_decl (this->ctx_->scope ());
+  be_union *bu =
+    be_union::narrow_from_decl (this->ctx_->scope ()->decl ());
   int def_index = bu->default_index ();
 
   if (def_index != -1)
