@@ -1,33 +1,23 @@
-//
-// $Id: field_ch.cpp 67596 2005-08-12 22:13:31Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_ch.cpp
-//
-// = DESCRIPTION
-//     Visitor for the structure fields in valuebox class.
-//     This one generates code for access to strucuture members
-//     in the client header.
-//
-//     Based on be_visitor_union_branch/public_ch.  In general we
-//     generate the same method signatures as that visitor but cannot
-//     use it directly because a valuebox is not a scope and because
-//     the structure is visited prior to visiting the valuebox.
-//
-// = AUTHOR
-//    Gary Maxey
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_valuebox, 
-           field_ch, 
-           "$Id: field_ch.cpp 67596 2005-08-12 22:13:31Z parsons $")
+//=============================================================================
+/**
+ *  @file    field_ch.cpp
+ *
+ *  $Id: field_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *   Visitor for the structure fields in valuebox class.
+ *   This one generates code for access to strucuture members
+ *   in the client header.
+ *
+ *   Based on be_visitor_union_branch/public_ch.  In general we
+ *   generate the same method signatures as that visitor but cannot
+ *   use it directly because a valuebox is not a scope and because
+ *   the structure is visited prior to visiting the valuebox.
+ *
+ *
+ *  @author Gary Maxey
+ */
+//=============================================================================
 
 
 be_visitor_valuebox_field_ch::be_visitor_valuebox_field_ch (
@@ -76,7 +66,7 @@ int
 be_visitor_valuebox_field_ch::visit_array (be_array *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -101,8 +91,8 @@ be_visitor_valuebox_field_ch::visit_array (be_array *node)
 
 
   char fname [NAMEBUFSIZE];
-  ACE_OS::memset (fname, 
-                  '\0', 
+  ACE_OS::memset (fname,
+                  '\0',
                   NAMEBUFSIZE);
 
   if (bt->node_type () != AST_Decl::NT_typedef)
@@ -114,22 +104,22 @@ be_visitor_valuebox_field_ch::visit_array (be_array *node)
         {
           be_decl *parent =
                  be_scope::narrow_from_scope (bt->defined_in ())->decl ();
-          ACE_OS::sprintf (fname, 
-                           "%s::_%s", 
+          ACE_OS::sprintf (fname,
+                           "%s::_%s",
                            parent->full_name (),
                            bt->local_name ()->get_string ());
         }
       else
         {
-          ACE_OS::sprintf (fname, 
-                           "_%s", 
+          ACE_OS::sprintf (fname,
+                           "_%s",
                            bt->full_name ());
         }
     }
   else
     { // Typedefed node.
-      ACE_OS::sprintf (fname, 
-                       "%s", 
+      ACE_OS::sprintf (fname,
+                       "%s",
                        bt->full_name ());
     }
 
@@ -149,7 +139,7 @@ int
 be_visitor_valuebox_field_ch::visit_enum (be_enum *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -185,7 +175,7 @@ int
 be_visitor_valuebox_field_ch::visit_interface (be_interface *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -221,7 +211,7 @@ int
 be_visitor_valuebox_field_ch::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -271,7 +261,7 @@ int
 be_visitor_valuebox_field_ch::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -324,7 +314,7 @@ int
 be_visitor_valuebox_field_ch::visit_sequence (be_sequence *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -362,7 +352,7 @@ int
 be_visitor_valuebox_field_ch::visit_string (be_string *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -413,7 +403,7 @@ int
 be_visitor_valuebox_field_ch::visit_structure (be_structure *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -471,7 +461,7 @@ int
 be_visitor_valuebox_field_ch::visit_union (be_union *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this via a visit to a typedef node.
   if (this->ctx_->alias ())
