@@ -1,32 +1,24 @@
-//
-// $Id: field_ci.cpp 72142 2006-04-19 10:24:02Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_ci.cpp
-//
-// = DESCRIPTION
-//     Visitor for the Valuebox class.
-//     This one generates code for accessor and modifier functions of
-//    for valuebox struct members.
-//
-// = AUTHOR
-//    Gary Maxey
-//
-// ============================================================================
-ACE_RCSID (be_visitor_valuebox,
-           field_ci,
-           "$Id: field_ci.cpp 72142 2006-04-19 10:24:02Z jwillemsen $")
+//=============================================================================
+/**
+ *  @file    field_ci.cpp
+ *
+ *  $Id: field_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *   Visitor for the Valuebox class.
+ *   This one generates code for accessor and modifier functions of
+ *  for valuebox struct members.
+ *
+ *
+ *  @author Gary Maxey
+ */
+//=============================================================================
 
 be_visitor_valuebox_field_ci::be_visitor_valuebox_field_ci (
     be_visitor_context *ctx
   )
-  : be_visitor_decl (ctx)
+  : be_visitor_decl (ctx),
+    vb_node_ (0)
 {
 }
 
@@ -48,6 +40,10 @@ be_visitor_valuebox_field_ci::visit_field (be_field *node)
                         -1);
     }
 
+  // Store the valuebox in the visitor member, then replace the
+  // context value with the field node.
+  this->vb_node_ =
+    be_valuebox::narrow_from_decl (this->ctx_->node ());
   this->ctx_->node (node);
 
   if (bt->accept (this) == -1)
@@ -68,8 +64,7 @@ int
 be_visitor_valuebox_field_ci::visit_array (be_array *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -81,7 +76,7 @@ be_visitor_valuebox_field_ci::visit_array (be_array *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -132,7 +127,7 @@ be_visitor_valuebox_field_ci::visit_array (be_array *node)
   *os << "/// Modifier to set the member." << be_nl;
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (" << fname << " val)" << be_nl
       << "{" << be_idt_nl
       << fname << "_copy ("
@@ -143,7 +138,7 @@ be_visitor_valuebox_field_ci::visit_array (be_array *node)
   *os << "/// Accessor to retrieve the member." << be_nl;
 
   *os << "ACE_INLINE const " << fname << "_slice *" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (void) const" << be_nl
       << "{" << be_idt_nl
       << "return this->_pd_value->" << field->local_name ()
@@ -157,8 +152,7 @@ int
 be_visitor_valuebox_field_ci::visit_enum (be_enum *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -170,7 +164,7 @@ be_visitor_valuebox_field_ci::visit_enum (be_enum *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -185,8 +179,8 @@ be_visitor_valuebox_field_ci::visit_enum (be_enum *node)
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
 
-  this->emit_member_set (vb_node, field, bt, "", "");
-  this->emit_member_get (vb_node, field, bt, "", "", "const", "");
+  this->emit_member_set (field, bt, "", "");
+  this->emit_member_get (field, bt, "", "", "const", "");
 
   return 0;
 }
@@ -195,8 +189,7 @@ int
 be_visitor_valuebox_field_ci::visit_interface (be_interface *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -208,7 +201,7 @@ be_visitor_valuebox_field_ci::visit_interface (be_interface *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -225,7 +218,7 @@ be_visitor_valuebox_field_ci::visit_interface (be_interface *node)
   *os << "// Modifier to set the member." << be_nl;
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (" << bt->name () << "_ptr val)"
       << be_nl << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
@@ -233,7 +226,7 @@ be_visitor_valuebox_field_ci::visit_interface (be_interface *node)
       << ">::duplicate (val);" << be_uidt << be_uidt_nl
       << "}" << be_nl << be_nl;
 
-  this->emit_member_get (vb_node, field, bt, "", "_ptr", "const", ".in ()");
+  this->emit_member_get (field, bt, "", "_ptr", "const", ".in ()");
 
   return 0;
 }
@@ -242,8 +235,7 @@ int
 be_visitor_valuebox_field_ci::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -255,7 +247,7 @@ be_visitor_valuebox_field_ci::visit_interface_fwd (be_interface_fwd *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -272,7 +264,7 @@ be_visitor_valuebox_field_ci::visit_interface_fwd (be_interface_fwd *node)
   *os << "// Modifier to set the member." << be_nl;
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (" << bt->name () << "_ptr val)"
       << be_nl << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
@@ -280,7 +272,7 @@ be_visitor_valuebox_field_ci::visit_interface_fwd (be_interface_fwd *node)
       << ">::duplicate (val);" << be_uidt << be_uidt_nl
       << "}" << be_nl << be_nl;
 
-  this->emit_member_get (vb_node, field, bt, "", "_ptr", "const", ".in ()");
+  this->emit_member_get (field, bt, "", "_ptr", "const", ".in ()");
 
   return 0;
 }
@@ -317,8 +309,7 @@ int
 be_visitor_valuebox_field_ci::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -330,7 +321,7 @@ be_visitor_valuebox_field_ci::visit_predefined_type (be_predefined_type *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -351,26 +342,25 @@ be_visitor_valuebox_field_ci::visit_predefined_type (be_predefined_type *node)
       *os << "// Modifier to set the member." << be_nl;
 
       *os << "ACE_INLINE void" << be_nl
-          << vb_node->name () << "::" << field->local_name ()
+          << vb_node_->name () << "::" << field->local_name ()
           << " ( ::" << bt->name () << "_ptr val)"
           << be_nl << "{" << be_idt_nl
           << "this->_pd_value->" << field->local_name ()
           << " = ::" << bt->name() << "::_duplicate (val);" << be_uidt_nl
           << "}" << be_nl << be_nl;
 
-      this->emit_member_get (vb_node, field, bt, " ::", "_ptr", "const",
-                             ".in ()");
+      this->emit_member_get (field, bt, " ::", "_ptr", "const", ".in ()");
       break;
     case AST_PredefinedType::PT_any:
-      this->emit_member_set (vb_node, field, bt, "const ::", " &");
-      this->emit_member_get (vb_node, field, bt, "const ::", " &", "const", "");
-      this->emit_member_get (vb_node, field, bt, " ::", " &", "", "");
+      this->emit_member_set (field, bt, "const ::", " &");
+      this->emit_member_get (field, bt, "const ::", " &", "const", "");
+      this->emit_member_get (field, bt, " ::", " &", "", "");
       break;
     case AST_PredefinedType::PT_void:
       break;
     default:
-      this->emit_member_set (vb_node, field, bt, " ::", "");
-      this->emit_member_get (vb_node, field, bt, " ::", "", "const", "");
+      this->emit_member_set (field, bt, " ::", "");
+      this->emit_member_get (field, bt, " ::", "", "const", "");
       break;
   }
 
@@ -381,8 +371,7 @@ int
 be_visitor_valuebox_field_ci::visit_sequence (be_sequence *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -394,7 +383,7 @@ be_visitor_valuebox_field_ci::visit_sequence (be_sequence *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -408,9 +397,9 @@ be_visitor_valuebox_field_ci::visit_sequence (be_sequence *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "const ", " &");
-  this->emit_member_get (vb_node, field, bt, "const ", " &", "const", "");
-  this->emit_member_get (vb_node, field, bt, "", " &", "", "");
+  this->emit_member_set (field, bt, "const ", " &");
+  this->emit_member_get (field, bt, "const ", " &", "const", "");
+  this->emit_member_get (field, bt, "", " &", "", "");
 
   return 0;
 }
@@ -419,8 +408,7 @@ int
 be_visitor_valuebox_field_ci::visit_string (be_string *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -432,7 +420,7 @@ be_visitor_valuebox_field_ci::visit_string (be_string *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -446,8 +434,8 @@ be_visitor_valuebox_field_ci::visit_string (be_string *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "", "");
-  this->emit_member_set (vb_node, field, bt, "const ", "");
+  this->emit_member_set (field, bt, "", "");
+  this->emit_member_set (field, bt, "const ", "");
 
   *os << "// Modifier to set the member." << be_nl;
 
@@ -462,14 +450,14 @@ be_visitor_valuebox_field_ci::visit_string (be_string *node)
     }
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (const ::CORBA::" << string_type << "_var & val)"
       << be_nl << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
       << " = val;" << be_uidt_nl
       << "}" << be_nl << be_nl;
 
-  this->emit_member_get (vb_node, field, bt, "const ", "", "const", "");
+  this->emit_member_get (field, bt, "const ", "", "const", "");
 
   return 0;
 }
@@ -478,8 +466,7 @@ int
 be_visitor_valuebox_field_ci::visit_structure (be_structure *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -491,7 +478,7 @@ be_visitor_valuebox_field_ci::visit_structure (be_structure *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -505,9 +492,9 @@ be_visitor_valuebox_field_ci::visit_structure (be_structure *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "const ", " &");
-  this->emit_member_get (vb_node, field, bt, "const ", " &", "const", "");
-  this->emit_member_get (vb_node, field, bt, "", " &", "", "");
+  this->emit_member_set (field, bt, "const ", " &");
+  this->emit_member_get (field, bt, "const ", " &", "const", "");
+  this->emit_member_get (field, bt, "", " &", "", "");
 
   return 0;
 }
@@ -535,8 +522,7 @@ int
 be_visitor_valuebox_field_ci::visit_union (be_union *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -548,7 +534,7 @@ be_visitor_valuebox_field_ci::visit_union (be_union *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_field_ci::"
@@ -562,16 +548,15 @@ be_visitor_valuebox_field_ci::visit_union (be_union *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "const ", " &");
-  this->emit_member_get (vb_node, field, bt, "const ", " &", "const", "");
-  this->emit_member_get (vb_node, field, bt, "", " &", "", "");
+  this->emit_member_set (field, bt, "const ", " &");
+  this->emit_member_get (field, bt, "const ", " &", "const", "");
+  this->emit_member_get (field, bt, "", " &", "", "");
 
   return 0;
 }
 
 void
-be_visitor_valuebox_field_ci::emit_member_set (be_decl *vb_node,
-                                               be_decl *field,
+be_visitor_valuebox_field_ci::emit_member_set (be_decl *field,
                                                be_type *field_type,
                                                const char *const_arg,
                                                const char *arg_modifier)
@@ -581,7 +566,7 @@ be_visitor_valuebox_field_ci::emit_member_set (be_decl *vb_node,
   *os << "// Modifier to set the member." << be_nl;
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (" << const_arg << field_type->name () << arg_modifier << " val)"
       << be_nl << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
@@ -591,8 +576,7 @@ be_visitor_valuebox_field_ci::emit_member_set (be_decl *vb_node,
 }
 
 void
-be_visitor_valuebox_field_ci::emit_member_get (be_decl *vb_node,
-                                               be_decl *field,
+be_visitor_valuebox_field_ci::emit_member_get (be_decl *field,
                                                be_type *field_type,
                                                const char *const_prefix,
                                                const char *type_suffix,
@@ -605,7 +589,7 @@ be_visitor_valuebox_field_ci::emit_member_get (be_decl *vb_node,
 
   *os << "ACE_INLINE " << const_prefix << field_type->name () << type_suffix
       << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (void) " << const_method << be_nl
       << "{" << be_idt_nl
       << "return this->_pd_value->" << field->local_name () << access_modifier
