@@ -1,32 +1,24 @@
-//
-// $Id: union_member_ci.cpp 72142 2006-04-19 10:24:02Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    union_member_ci.cpp
-//
-// = DESCRIPTION
-//     Visitor for the Valuebox class.
-//     This one generates code for accessor and modifier functions of
-//     for valuebox union members.
-//
-// = AUTHOR
-//    Gary Maxey
-//
-// ============================================================================
-ACE_RCSID (be_visitor_valuebox,
-           union_member_ci,
-           "$Id: union_member_ci.cpp 72142 2006-04-19 10:24:02Z jwillemsen $")
+//=============================================================================
+/**
+ *  @file    union_member_ci.cpp
+ *
+ *  $Id: union_member_ci.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *   Visitor for the Valuebox class.
+ *   This one generates code for accessor and modifier functions of
+ *   for valuebox union members.
+ *
+ *
+ *  @author Gary Maxey
+ */
+//=============================================================================
 
 be_visitor_valuebox_union_member_ci::be_visitor_valuebox_union_member_ci (
     be_visitor_context *ctx
   )
-  : be_visitor_decl (ctx)
+  : be_visitor_decl (ctx),
+    vb_node_ (0)
 {
 }
 
@@ -48,6 +40,8 @@ be_visitor_valuebox_union_member_ci::visit_union_member (be_union_branch *node)
                         -1);
     }
 
+  this->vb_node_ =
+    be_valuebox::narrow_from_decl (this->ctx_->node ());
   this->ctx_->node (node);
 
   if (bt->accept (this) == -1)
@@ -68,8 +62,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -81,7 +74,7 @@ be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -132,7 +125,7 @@ be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
   *os << "/// Modifier to set the member." << be_nl;
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (" << fname << " val)" << be_nl
       << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
@@ -142,7 +135,7 @@ be_visitor_valuebox_union_member_ci::visit_array (be_array *node)
   *os << "/// Accessor to retrieve the member." << be_nl;
 
   *os << "ACE_INLINE const " << fname << "_slice *" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (void) const" << be_nl
       << "{" << be_idt_nl
       << "return this->_pd_value->" << field->local_name ()
@@ -156,8 +149,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_enum (be_enum *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -169,7 +161,7 @@ be_visitor_valuebox_union_member_ci::visit_enum (be_enum *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -184,8 +176,8 @@ be_visitor_valuebox_union_member_ci::visit_enum (be_enum *node)
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
 
-  this->emit_member_set (vb_node, field, bt, "", "");
-  this->emit_member_get (vb_node, field, bt, "", "", "const");
+  this->emit_member_set (field, bt, "", "");
+  this->emit_member_get (field, bt, "", "", "const");
 
   return 0;
 }
@@ -194,8 +186,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_interface (be_interface *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -207,7 +198,7 @@ be_visitor_valuebox_union_member_ci::visit_interface (be_interface *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -221,8 +212,8 @@ be_visitor_valuebox_union_member_ci::visit_interface (be_interface *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "", "_ptr");
-  this->emit_member_get (vb_node, field, bt, "", "_ptr", "const");
+  this->emit_member_set (field, bt, "", "_ptr");
+  this->emit_member_get (field, bt, "", "_ptr", "const");
 
   return 0;
 }
@@ -231,8 +222,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -244,7 +234,7 @@ be_visitor_valuebox_union_member_ci::visit_interface_fwd (be_interface_fwd *node
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -258,8 +248,8 @@ be_visitor_valuebox_union_member_ci::visit_interface_fwd (be_interface_fwd *node
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "", "_ptr");
-  this->emit_member_get (vb_node, field, bt, "", "_ptr", "const");
+  this->emit_member_set (field, bt, "", "_ptr");
+  this->emit_member_get (field, bt, "", "_ptr", "const");
 
   return 0;
 }
@@ -282,8 +272,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -295,7 +284,7 @@ be_visitor_valuebox_union_member_ci::visit_predefined_type (be_predefined_type *
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -313,19 +302,19 @@ be_visitor_valuebox_union_member_ci::visit_predefined_type (be_predefined_type *
   {
     case AST_PredefinedType::PT_pseudo:
     case AST_PredefinedType::PT_object:
-      this->emit_member_set (vb_node, field, bt, " ::", "_ptr");
-      this->emit_member_get (vb_node, field, bt, " ::", "_ptr", "const");
+      this->emit_member_set (field, bt, " ::", "_ptr");
+      this->emit_member_get (field, bt, " ::", "_ptr", "const");
       break;
     case AST_PredefinedType::PT_any:
-      this->emit_member_set (vb_node, field, bt, "const ::", " &");
-      this->emit_member_get (vb_node, field, bt, "const ::", " &", "const");
-      this->emit_member_get (vb_node, field, bt, "::", " &", "");
+      this->emit_member_set (field, bt, "const ::", " &");
+      this->emit_member_get (field, bt, "const ::", " &", "const");
+      this->emit_member_get (field, bt, "::", " &", "");
       break;
     case AST_PredefinedType::PT_void:
       break;
     default:
-      this->emit_member_set (vb_node, field, bt, " ::", "");
-      this->emit_member_get (vb_node, field, bt, " ::", "", "const");
+      this->emit_member_set (field, bt, " ::", "");
+      this->emit_member_get (field, bt, " ::", "", "const");
       break;
   }
 
@@ -336,8 +325,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_sequence (be_sequence *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -349,7 +337,7 @@ be_visitor_valuebox_union_member_ci::visit_sequence (be_sequence *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -363,9 +351,9 @@ be_visitor_valuebox_union_member_ci::visit_sequence (be_sequence *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "const ", " &");
-  this->emit_member_get (vb_node, field, bt, "const ", " &", "const");
-  this->emit_member_get (vb_node, field, bt, "", " &", "");
+  this->emit_member_set (field, bt, "const ", " &");
+  this->emit_member_get (field, bt, "const ", " &", "const");
+  this->emit_member_get (field, bt, "", " &", "");
 
   return 0;
 }
@@ -374,8 +362,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_string (be_string *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -387,7 +374,7 @@ be_visitor_valuebox_union_member_ci::visit_string (be_string *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -401,8 +388,8 @@ be_visitor_valuebox_union_member_ci::visit_string (be_string *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "", "");
-  this->emit_member_set (vb_node, field, bt, "const ", "");
+  this->emit_member_set (field, bt, "", "");
+  this->emit_member_set (field, bt, "const ", "");
 
   *os << "// Modifier to set the member." << be_nl;
 
@@ -417,14 +404,14 @@ be_visitor_valuebox_union_member_ci::visit_string (be_string *node)
     }
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (const ::CORBA::" << string_type << "_var & val)"
       << be_nl << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
       << " (val);" << be_uidt_nl
       << "}" << be_nl << be_nl;
 
-  this->emit_member_get (vb_node, field, bt, "const ", "", "const");
+  this->emit_member_get (field, bt, "const ", "", "const");
 
   return 0;
 }
@@ -433,8 +420,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_structure (be_structure *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -446,7 +432,7 @@ be_visitor_valuebox_union_member_ci::visit_structure (be_structure *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -460,9 +446,9 @@ be_visitor_valuebox_union_member_ci::visit_structure (be_structure *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "const ", " &");
-  this->emit_member_get (vb_node, field, bt, "const ", " &", "const");
-  this->emit_member_get (vb_node, field, bt, "", " &", "");
+  this->emit_member_set (field, bt, "const ", " &");
+  this->emit_member_get (field, bt, "const ", " &", "const");
+  this->emit_member_get (field, bt, "", " &", "");
 
   return 0;
 }
@@ -490,8 +476,7 @@ int
 be_visitor_valuebox_union_member_ci::visit_union (be_union *node)
 {
   be_decl *field = this->ctx_->node ();
-  be_valuebox *vb_node = be_valuebox::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -503,7 +488,7 @@ be_visitor_valuebox_union_member_ci::visit_union (be_union *node)
       bt = node;
     }
 
-  if (!field || !vb_node)
+  if (!field || !vb_node_)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuebox_union_member_ci::"
@@ -517,26 +502,26 @@ be_visitor_valuebox_union_member_ci::visit_union (be_union *node)
   *os << be_nl << be_nl << "// TAO_IDL - Generated from" << be_nl
       << "// " << __FILE__ << ":" << __LINE__ << be_nl << be_nl;
 
-  this->emit_member_set (vb_node, field, bt, "const ", " &");
-  this->emit_member_get (vb_node, field, bt, "const ", " &", "const");
-  this->emit_member_get (vb_node, field, bt, "", " &", "");
+  this->emit_member_set (field, bt, "const ", " &");
+  this->emit_member_get (field, bt, "const ", " &", "const");
+  this->emit_member_get (field, bt, "", " &", "");
 
   return 0;
 }
 
 void
-be_visitor_valuebox_union_member_ci::emit_member_set (be_decl *vb_node,
-                                               be_decl *field,
-                                               be_type *field_type,
-                                               const char *const_arg,
-                                               const char *arg_modifier)
+be_visitor_valuebox_union_member_ci::emit_member_set (
+  be_decl *field,
+  be_type *field_type,
+  const char *const_arg,
+  const char *arg_modifier)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
   *os << "// Modifier to set the member." << be_nl;
 
   *os << "ACE_INLINE void" << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (" << const_arg << field_type->name () << arg_modifier << " val)"
       << be_nl << "{" << be_idt_nl
       << "this->_pd_value->" << field->local_name ()
@@ -546,12 +531,12 @@ be_visitor_valuebox_union_member_ci::emit_member_set (be_decl *vb_node,
 }
 
 void
-be_visitor_valuebox_union_member_ci::emit_member_get (be_decl *vb_node,
-                                               be_decl *field,
-                                               be_type *field_type,
-                                               const char *const_prefix,
-                                               const char *type_suffix,
-                                               const char *const_method)
+be_visitor_valuebox_union_member_ci::emit_member_get (
+  be_decl *field,
+  be_type *field_type,
+  const char *const_prefix,
+  const char *type_suffix,
+  const char *const_method)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
@@ -559,7 +544,7 @@ be_visitor_valuebox_union_member_ci::emit_member_get (be_decl *vb_node,
 
   *os << "ACE_INLINE " << const_prefix << field_type->name () << type_suffix
       << be_nl
-      << vb_node->name () << "::" << field->local_name ()
+      << vb_node_->name () << "::" << field->local_name ()
       << " (void) " << const_method << be_nl
       << "{" << be_idt_nl
       << "return this->_pd_value->" << field->local_name ()
