@@ -1,26 +1,17 @@
-//
-// $Id: ami_exception_holder_ch.cpp 72142 2006-04-19 10:24:02Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    ami_exception_holder_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating exception holders for the AMI callback model.
-//
-// = AUTHOR
-//    Michael Kircher <Michael.Kircher@mchp.siemens.de>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    ami_exception_holder_ch.cpp
+ *
+ *  $Id: ami_exception_holder_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating exception holders for the AMI callback model.
+ *
+ *
+ *  @author Michael Kircher <Michael.Kircher@mchp.siemens.de>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype,
-           ami_exception_holder_ch,
-           "$Id: ami_exception_holder_ch.cpp 72142 2006-04-19 10:24:02Z jwillemsen $")
 
 // ******************************************************
 // Interface visitor for client header.
