@@ -1,26 +1,17 @@
-//
-// $Id: ami_exception_holder_cs.cpp 72142 2006-04-19 10:24:02Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    ami_exception_holder_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for excpetion holders.
-//
-// = AUTHOR
-//    Michael Kircher
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    ami_exception_holder_cs.cpp
+ *
+ *  $Id: ami_exception_holder_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for excpetion holders.
+ *
+ *
+ *  @author Michael Kircher
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype,
-           ami_exception_holder_cs,
-           "$Id: ami_exception_holder_cs.cpp 72142 2006-04-19 10:24:02Z jwillemsen $")
 
 // ************************************************************
 // Interface visitor for client stubs
