@@ -1,28 +1,18 @@
-//
-// $Id: arglist.cpp 76971 2007-02-08 19:28:22Z johnnyw $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    arglist.cpp
-//
-// = DESCRIPTION
-//    Visitor generating the parameter list of operations
-//    in the Valuetype class.
-//
-// = AUTHOR
-//    Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de>
-//    based on code from Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    arglist.cpp
+ *
+ *  $Id: arglist.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating the parameter list of operations
+ *  in the Valuetype class.
+ *
+ *
+ *  @author Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de> based on code from Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype,
-           arglist,
-           "$Id: arglist.cpp 76971 2007-02-08 19:28:22Z johnnyw $")
 
 // ************************************************************
 //   Operation visitor to generate the argument list.
@@ -132,9 +122,17 @@ be_visitor_obv_operation_arglist::visit_argument (be_argument *node)
   // defined. We need this since argument types may very well be declared
   // inside the scope of the interface node. In such cases, we would like to
   // generate the appropriate relative scoped names.
-  be_operation *op = this->ctx_->be_scope_as_operation ();
+  be_operation *op =
+    be_operation::narrow_from_decl (this->ctx_->node ());
 
-  if (!op)
+  // Sometimes the operation is stored in the context scope instead.
+  if (op == 0)
+    {
+      op =
+        be_operation::narrow_from_scope (this->ctx_->scope ());
+    }
+        
+  if (op == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_arglist::"
