@@ -1,26 +1,17 @@
-//
-// $Id: field_cdr_ch.cpp 48780 2003-03-12 16:50:35Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_cdr_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Field in the client header file.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    field_cdr_ch.cpp
+ *
+ *  $Id: field_cdr_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Field in the client header file.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype, 
-           field_cdr_op_ch, 
-           "$Id: field_cdr_ch.cpp 48780 2003-03-12 16:50:35Z parsons $")
 
 // **********************************************
 //  Visitor for field in the client header file.
@@ -74,7 +65,7 @@ be_visitor_valuetype_field_cdr_ch::visit_array (be_array *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // This is the case for anonymous arrays.
       be_visitor_context ctx (*this->ctx_);
@@ -99,7 +90,7 @@ be_visitor_valuetype_field_cdr_ch::visit_enum (be_enum *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -123,7 +114,7 @@ be_visitor_valuetype_field_cdr_ch::visit_sequence (be_sequence *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -147,7 +138,7 @@ be_visitor_valuetype_field_cdr_ch::visit_structure (be_structure *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -195,7 +186,7 @@ be_visitor_valuetype_field_cdr_ch::visit_union (be_union *node)
 {
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
