@@ -1,27 +1,17 @@
-//
-// $Id: field_cdr_cs.cpp 71573 2006-03-16 15:53:36Z sjiang $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_cdr_cs.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Field in the client stubs file.
-//
-// = AUTHOR
-//    Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de>
-//    derived from be_visitor_field/cdr_op_cs.cpp
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    field_cdr_cs.cpp
+ *
+ *  $Id: field_cdr_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Field in the client stubs file.
+ *
+ *
+ *  @author Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de> derived from be_visitor_field/cdr_op_cs.cpp
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype,
-           field_cdr_op_cs,
-           "$Id: field_cdr_cs.cpp 71573 2006-03-16 15:53:36Z sjiang $")
 
 // **********************************************
 //  Visitor for field in the client inline file.
@@ -74,9 +64,10 @@ be_visitor_valuetype_field_cdr_cs::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -93,7 +84,7 @@ be_visitor_valuetype_field_cdr_cs::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
       // We have to generate a name for us that has an underscore
@@ -152,7 +143,7 @@ be_visitor_valuetype_field_cdr_cs::visit_array (be_array *node)
 
   // If not a typedef and we are defined in the use scope, we must be defined.
   if (!this->ctx_->alias () // not a typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // This is the case for anonymous arrays.
       be_visitor_context ctx (*this->ctx_);
@@ -178,9 +169,10 @@ be_visitor_valuetype_field_cdr_cs::visit_enum (be_enum *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -214,7 +206,7 @@ be_visitor_valuetype_field_cdr_cs::visit_enum (be_enum *node)
     }
 
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -239,9 +231,10 @@ be_visitor_valuetype_field_cdr_cs::visit_interface (be_interface *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -288,9 +281,10 @@ be_visitor_valuetype_field_cdr_cs::visit_interface_fwd (be_interface_fwd *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -343,9 +337,10 @@ be_visitor_valuetype_field_cdr_cs::valuetype_common (be_type *)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -394,9 +389,10 @@ be_visitor_valuetype_field_cdr_cs::visit_valuetype_fwd (be_valuetype_fwd *)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -463,9 +459,10 @@ be_visitor_valuetype_field_cdr_cs::visit_predefined_type (be_predefined_type *no
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -567,9 +564,10 @@ be_visitor_valuetype_field_cdr_cs::visit_sequence (be_sequence *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -603,7 +601,7 @@ be_visitor_valuetype_field_cdr_cs::visit_sequence (be_sequence *node)
     }
 
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     // Not a typedef AND
     // node is defined inside the valuetype.
     {
@@ -626,14 +624,15 @@ be_visitor_valuetype_field_cdr_cs::visit_sequence (be_sequence *node)
 }
 
 int
-be_visitor_valuetype_field_cdr_cs::visit_string (be_string *)
+be_visitor_valuetype_field_cdr_cs::visit_string (be_string *str)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -647,12 +646,48 @@ be_visitor_valuetype_field_cdr_cs::visit_string (be_string *)
   switch (this->ctx_->sub_state ())
     {
     case TAO_CodeGen::TAO_CDR_INPUT:
-      *os << "(strm >> " << this->pre_ << f->local_name ()
-          << this->post_ << ".out ())";
+      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+        {
+          if (str->width () == (long) sizeof (char))
+            {
+              *os << "(strm >> ACE_InputCDR::to_string ("
+                  << this->pre_ << f->local_name () << this->post_
+                  << ".out (), " << str->max_size ()->ev ()->u.ulval << "))";
+            }
+          else
+            {
+              *os << "(strm >> ACE_InputCDR::to_wstring ("
+                  << this->pre_ << f->local_name () << this->post_
+                  << ".out (), " << str->max_size ()->ev ()->u.ulval << "))";
+            }
+        }
+      else
+        {
+          *os << "(strm >> " << this->pre_ << f->local_name ()
+              << this->post_ << ".out ())";
+        }
       break;
     case TAO_CodeGen::TAO_CDR_OUTPUT:
-      *os << "(strm << " << this->pre_ << f->local_name ()
-          << this->post_ << ".in ())";
+      if (str != 0 && str->max_size ()->ev ()->u.ulval != 0)
+        {
+          if (str->width () == (long) sizeof (char))
+            {
+              *os << "(strm << ACE_OutputCDR::from_string ("
+                  <<  this->pre_ << f->local_name () << this->post_
+                  << ".in (), " << str->max_size ()->ev ()->u.ulval << "))";
+            }
+          else
+            {
+              *os << "(strm << ACE_OutputCDR::from_wstring ("
+                  <<  this->pre_ << f->local_name () << this->post_
+                  << ".in (), " << str->max_size ()->ev ()->u.ulval << "))";
+            }
+        }
+      else
+        {
+          *os << "(strm << " << this->pre_ << f->local_name ()
+              << this->post_ << ".in ())";
+        }
       break;
     case TAO_CodeGen::TAO_CDR_SCOPE:
       // Nothing to be done.
@@ -670,14 +705,16 @@ be_visitor_valuetype_field_cdr_cs::visit_string (be_string *)
 }
 
 int
-be_visitor_valuetype_field_cdr_cs::visit_structure (be_structure *node)
+be_visitor_valuetype_field_cdr_cs::visit_structure (
+  be_structure *node)
 {
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -711,7 +748,7 @@ be_visitor_valuetype_field_cdr_cs::visit_structure (be_structure *node)
     }
 
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -757,9 +794,10 @@ be_visitor_valuetype_field_cdr_cs::visit_union (be_union *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_cs::"
@@ -793,7 +831,7 @@ be_visitor_valuetype_field_cdr_cs::visit_union (be_union *node)
     }
 
   if (node->node_type () != AST_Decl::NT_typedef
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       be_visitor_context ctx (*this->ctx_);
       ctx.node (node);
@@ -865,9 +903,10 @@ be_visitor_valuetype_field_cdr_decl::visit_array (be_array *node)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // Retrieve the field node.
-  be_field *f = this->ctx_->be_node_as_field ();
+  be_field *f =
+    be_field::narrow_from_decl (this->ctx_->node ());
 
-  if (!f)
+  if (f == 0)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "(%N:%l) be_visitor_valuetype_field_cdr_decl::"
@@ -877,7 +916,7 @@ be_visitor_valuetype_field_cdr_decl::visit_array (be_array *node)
     }
 
   // Retrieve the valuetype scope in which the code is generated.
-  be_decl *sc = this->ctx_->scope ();
+  be_decl *sc = this->ctx_->scope ()->decl ();
   be_valuetype *vt = be_valuetype::narrow_from_decl (sc);
 
   if (!vt)
@@ -897,7 +936,7 @@ be_visitor_valuetype_field_cdr_decl::visit_array (be_array *node)
                   NAMEBUFSIZE);
 
   if (!this->ctx_->alias ()
-      && node->is_child (this->ctx_->scope ()))
+      && node->is_child (this->ctx_->scope ()->decl ()))
     {
       // For anonymous arrays ...
       // We have to generate a name for us that has an underscope
