@@ -1,28 +1,19 @@
-//
-// $Id: field_cs.cpp 72142 2006-04-19 10:24:02Z jwillemsen $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    field_cs.cpp
-//
-// = DESCRIPTION
-//     Visitor for the Valuetype class.
-//     This one generates code for accessor and modifier functions of
-//     valuetype state members (in the stub file).
-//
-// = AUTHOR
-//    Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de>
-//    derived from be_visitor_union_branch/public_ci.cpp
-//
-// ============================================================================
-ACE_RCSID (be_visitor_valuetype,
-           field_cs,
-           "$Id: field_cs.cpp 72142 2006-04-19 10:24:02Z jwillemsen $")
+//=============================================================================
+/**
+ *  @file    field_cs.cpp
+ *
+ *  $Id: field_cs.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *   Visitor for the Valuetype class.
+ *   This one generates code for accessor and modifier functions of
+ *   valuetype state members (in the stub file).
+ *
+ *
+ *  @author Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de> derived from be_visitor_union_branch/public_ci.cpp
+ */
+//=============================================================================
+
 
 be_visitor_valuetype_field_cs::be_visitor_valuetype_field_cs (
     be_visitor_context *ctx
@@ -71,8 +62,9 @@ int
 be_visitor_valuetype_field_cs::visit_array (be_array *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -200,8 +192,9 @@ int
 be_visitor_valuetype_field_cs::visit_enum (be_enum *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -268,8 +261,9 @@ int
 be_visitor_valuetype_field_cs::visit_interface (be_interface *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -336,8 +330,9 @@ int
 be_visitor_valuetype_field_cs::visit_interface_fwd (be_interface_fwd *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -409,8 +404,9 @@ int
 be_visitor_valuetype_field_cs::valuetype_common (be_type *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -489,8 +485,9 @@ int
 be_visitor_valuetype_field_cs::visit_valuetype_fwd (be_valuetype_fwd *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -564,8 +561,9 @@ int
 be_visitor_valuetype_field_cs::visit_predefined_type (be_predefined_type *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -721,8 +719,9 @@ int
 be_visitor_valuetype_field_cs::visit_sequence (be_sequence *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -818,7 +817,8 @@ int
 be_visitor_valuetype_field_cs::visit_string (be_string *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
 
   if (!ub || !bu)
     {
@@ -960,8 +960,9 @@ int
 be_visitor_valuetype_field_cs::visit_structure (be_structure *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
@@ -1076,8 +1077,9 @@ int
 be_visitor_valuetype_field_cs::visit_union (be_union *node)
 {
   be_decl *ub = this->ctx_->node ();
-  be_valuetype *bu = be_valuetype::narrow_from_decl (this->ctx_->scope ());
-  be_type *bt;
+  be_valuetype *bu =
+    be_valuetype::narrow_from_decl (this->ctx_->scope ()->decl ());
+  be_type *bt = 0;
 
   // Check if we are visiting this node via a visit to a typedef node.
   if (this->ctx_->alias ())
