@@ -1,27 +1,17 @@
-//
-// $Id: valuetype.cpp 73110 2006-06-15 18:56:10Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    valuetype.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Valuetypes. This is a generic visitor.
-//
-// = AUTHOR
-//    Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de>
-//    based on interface.cpp from Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    valuetype.cpp
+ *
+ *  $Id: valuetype.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Valuetypes. This is a generic visitor.
+ *
+ *
+ *  @author Torsten Kuepper  <kuepper2@lfa.uni-wuppertal.de> based on interface.cpp from Aniruddha Gokhale
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype,
-           valuetype,
-           "$Id: valuetype.cpp 73110 2006-06-15 18:56:10Z parsons $")
 
 be_visitor_valuetype::be_visitor_valuetype (be_visitor_context *ctx)
   : be_visitor_scope (ctx)
@@ -56,7 +46,7 @@ be_visitor_valuetype::visit_valuetype_scope (be_valuetype *node)
       // generated so that elements in the node's scope can use it
       // for code generation.
 
-      this->ctx_->scope (node->decl ());
+      this->ctx_->scope (node);
       this->ctx_->node (bd);
       this->elem_number_++;
 
@@ -711,7 +701,7 @@ be_visitor_valuetype::gen_pd (be_valuetype *node)
       // Set the scope node as "node" in which the code is being
       // generated so that elements in the node's scope can use it
       // for code generation.
-      this->ctx_->scope (node->decl ());
+      this->ctx_->scope (node);
 
       // Set the node to be visited.
       this->ctx_->node (field);
@@ -778,7 +768,7 @@ be_visitor_valuetype::gen_obv_init_constructor_args (be_valuetype *node,
                                                      unsigned long &index)
 {
   TAO_OutStream *os = this->ctx_->stream ();
-  AST_ValueType *parent = node->inherits_concrete ();
+  AST_Type *parent = node->inherits_concrete ();
 
   // Generate for inherited members first.
   if (parent != 0)
