@@ -1,27 +1,18 @@
-//
-// $Id: valuetype_init_arglist_ch.cpp 76971 2007-02-08 19:28:22Z johnnyw $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    valuetype_init_arglist_ch.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for the parameter list of the OBV factory
-//    signature.
-//
-// = AUTHOR
-//    Boris Kolpackov <bosk@ipmce.ru>
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    valuetype_init_arglist_ch.cpp
+ *
+ *  $Id: valuetype_init_arglist_ch.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for the parameter list of the OBV factory
+ *  signature.
+ *
+ *
+ *  @author Boris Kolpackov <bosk@ipmce.ru>
+ */
+//=============================================================================
 
-ACE_RCSID (be_visitor_valuetype_init,
-           arglist_ch,
-           "$Id: valuetype_init_arglist_ch.cpp 76971 2007-02-08 19:28:22Z johnnyw $")
 
 be_visitor_valuetype_init_arglist_ch::be_visitor_valuetype_init_arglist_ch (
     be_visitor_context *ctx
@@ -31,8 +22,7 @@ be_visitor_valuetype_init_arglist_ch::be_visitor_valuetype_init_arglist_ch (
 }
 
 be_visitor_valuetype_init_arglist_ch::~be_visitor_valuetype_init_arglist_ch (
-    void
-  )
+  void)
 {
 }
 
@@ -45,7 +35,7 @@ be_visitor_valuetype_init_arglist_ch::visit_factory (be_factory *node)
 
   if (node->nmembers () > 0)
     {
-      os << be_idt << be_idt_nl;
+      os << be_idt_nl;
 
       // All we do is hand over code generation to our scope.
       if (this->visit_scope (node) == -1)
@@ -57,12 +47,11 @@ be_visitor_valuetype_init_arglist_ch::visit_factory (be_factory *node)
                             -1);
         }
 
-      os << be_uidt_nl
-         << ")";
+      os << ")" << be_uidt;
     }
   else
     {
-      os << "void)" << be_idt;
+      os << "void)";
     }
 
    return 0;
@@ -95,7 +84,7 @@ be_visitor_valuetype_init_arglist_ch::post_process (be_decl *bd)
   TAO_OutStream *os = this->ctx_->stream ();
 
   // If we are not the last node in the list of arguments, generate a comma.
-  if (!this->last_node (bd))
+  if (! this->last_node (bd))
     {
       *os << "," << be_nl;
     }
