@@ -1,26 +1,16 @@
-//
-// $Id: valuetype_si.cpp 63973 2005-02-15 05:07:04Z parsons $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    valuetype_si.cpp
-//
-// = DESCRIPTION
-//    Visitor generating code for Interfaces in the server inline file
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
-
-ACE_RCSID (be_visitor_valuetype,
-           valuetype_si,
-           "$Id: valuetype_si.cpp 63973 2005-02-15 05:07:04Z parsons $")
+//=============================================================================
+/**
+ *  @file    valuetype_si.cpp
+ *
+ *  $Id: valuetype_si.cpp 88829 2010-02-04 09:21:38Z johnnyw $
+ *
+ *  Visitor generating code for Interfaces in the server inline file
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 
 // ************************************************************************
