@@ -1,22 +1,19 @@
 /* -*- c++ -*- */
-// $Id: be_component.h 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_component.h
-//
-// = DESCRIPTION
-//    Extension of class AST_Component that provides additional means for C++
-//    mapping of an interface.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_component.h
+ *
+ *  $Id: be_component.h 89274 2010-03-02 09:57:21Z johnnyw $
+ *
+ *  Extension of class AST_Component that provides additional means for C++
+ *  mapping of an interface.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
+
 
 #ifndef TAO_BE_COMPONENT_H
 #define TAO_BE_COMPONENT_H
@@ -33,24 +30,26 @@ class be_component : public virtual AST_Component,
   // = DESCRIPTION
   //
 public:
-  be_component (void);
-
   be_component (UTL_ScopedName *n,
                 AST_Component *base_component,
-                AST_Interface **supports,
+                AST_Type **supports,
                 long n_supports,
                 AST_Interface **supports_flat,
                 long n_supports_flat);
 
   ~be_component (void);
+  
+  /// Override of the AST method to eliminate narrowing of
+  /// the return value. Non-virtual.
+  be_component *base_component (void) const;
 
+  /// Catch BE-specific members before delegating to the base class.
   virtual void redefine (AST_Interface *from);
-  // Catch BE-specific members before delegating to the base class.
 
-  // Cleanup function.
+  /// Cleanup function.
   virtual void destroy (void);
 
-  // Visiting.
+  /// Visiting.
   virtual int accept (be_visitor *visitor);
 
   // Need for public access to fe_add_structure and fe_add_typedef,
