@@ -1,19 +1,17 @@
 /* -*- c++ -*- */
-// $Id: be_eventtype.h 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_eventtype.h
-//
-// = DESCRIPTION
-//    Extension of class AST_EventType and be_valuetype that provides
-//    additional means for C++ mapping of an valuetype.
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_eventtype.h
+ *
+ *  $Id: be_eventtype.h 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_EventType and be_valuetype that provides
+ *  additional means for C++ mapping of an valuetype.
+ *
+ *
+ */
+//=============================================================================
 
 #ifndef TAO_BE_EVENTTYPE_H
 #define TAO_BE_EVENTTYPE_H
@@ -31,26 +29,20 @@ class be_eventtype : public virtual be_valuetype,
   //    Extends be_valuetype.
   //
 public:
-  be_eventtype (void);
-  // Default constructor.
-
   be_eventtype (UTL_ScopedName *n,
-                AST_Interface **inherits,
+                AST_Type **inherits,
                 long n_inherits,
-                AST_ValueType *inherits_concrete,
+                AST_Type *inherits_concrete,
                 AST_Interface **inherits_flat,
                 long n_inherits_flat,
-                AST_Interface **supports,
+                AST_Type **supports,
                 long n_supports,
-                AST_Interface *supports_concrete,
+                AST_Type *supports_concrete,
                 bool abstract,
                 bool truncatable,
                 bool custom);
-  // Constructor that sets its scoped name <n>, a list of inherited valuetypes
-  // and supported interfaces <ih>, and the number of inherited interfaces <nih>
 
   ~be_eventtype (void);
-  // Destructor.
 
   // Visiting.
   virtual int accept (be_visitor *visitor);
@@ -58,8 +50,7 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
- // Narrowing.
-
+  // Narrowing.
   DEF_NARROW_FROM_DECL (be_eventtype);
   DEF_NARROW_FROM_SCOPE (be_eventtype);
 };
