@@ -1,22 +1,18 @@
 /* -*- c++ -*- */
-// $Id: be_eventtype_fwd.h 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_eventtype_fwd.h
-//
-// = DESCRIPTION
-//    Extension of class AST_EventType_Fwd that provides additional
-//    means for C++ mapping of an eventtype.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_eventtype_fwd.h
+ *
+ *  $Id: be_eventtype_fwd.h 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_EventType_Fwd that provides additional
+ *  means for C++ mapping of an eventtype.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 #ifndef BE_EVENTTYPE_FWD_H
 #define BE_EVENTTYPE_FWD_H
@@ -33,15 +29,10 @@ class be_eventtype_fwd : public virtual be_valuetype_fwd,
   // =DESCRIPTION
   //   Extensions to the be_interface_fwd class
 public:
-  be_eventtype_fwd (void);
-  // Default constructor.
-
   be_eventtype_fwd (AST_Interface *dummy,
                     UTL_ScopedName *n);
-  // Constructor.
 
   virtual ~be_eventtype_fwd (void);
-  // Destructor.
 
   // Visiting.
   virtual int accept (be_visitor* visitor);
@@ -50,7 +41,6 @@ public:
   virtual void destroy (void);
 
   // Narrowing.
-
   DEF_NARROW_FROM_DECL (be_eventtype_fwd);
 };
 
