@@ -1,22 +1,18 @@
 /* -*- c++ -*- */
-// $Id: be_home.h 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_home.h
-//
-// = DESCRIPTION
-//    Extension of class AST_Home that provides additional
-//    means for C++ mapping of a component home.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_home.h
+ *
+ *  $Id: be_home.h 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_Home that provides additional
+ *  means for C++ mapping of a component home.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 #ifndef TAO_BE_HOME_H
 #define TAO_BE_HOME_H
@@ -33,13 +29,11 @@ class be_home : public virtual AST_Home,
   // =DESCRIPTION
   //   Extensions to the AST_Home class
 public:
-  be_home (void);
-
   be_home (UTL_ScopedName *n,
            AST_Home *base_home,
            AST_Component *managed_component,
-           AST_ValueType *primary_key,
-           AST_Interface **supports,
+           AST_Type *primary_key,
+           AST_Type **supports,
            long n_supports,
            AST_Interface **supports_flat,
            long n_supports_flat);
