@@ -1,22 +1,16 @@
-// $Id: be_native.h 78883 2007-07-13 17:55:30Z ossama $
-
-// Id
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_native.h
-//
-// = DESCRIPTION
-//    The native IDL type
-//
-// = AUTHOR
-//    Aniruddha Gokhale
-//
-// ============================================================================
 
+//=============================================================================
+/**
+ *  @file    be_native.h
+ *
+ *  $Id: be_native.h 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  The native IDL type
+ *
+ *
+ *  @author Aniruddha Gokhale
+ */
+//=============================================================================
 
 #ifndef BE_NATIVE_H
 #define BE_NATIVE_H
@@ -37,29 +31,23 @@ class be_native : public virtual AST_Native,
                   public virtual be_exception
 {
 public:
-  be_native (void);
-  // Default constructor.
-
   be_native (UTL_ScopedName *n);
-  // Constructor that initializes its scoped name.
 
   virtual ~be_native (void) {}
-  // Destructor
 
+  /// Generate the typecode description.
   virtual int gen_typecode (void);
-  // Generate the typecode description.
 
+  /// Return typecode size.
   virtual long tc_size (void);
-  // Return typecode size.
   
+  /// Cleanup.
   virtual void destroy (void);
-  // Cleanup.
 
   // Visiting.
   virtual int accept (be_visitor *visitor);
 
   // Narrowing.
-
   DEF_NARROW_FROM_DECL(be_native);
 };
 
