@@ -1,24 +1,19 @@
 /* -*- c++ -*- */
-// $Id: be_predefined_type.h 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_predefined_type.h
-//
-// = DESCRIPTION
-//    Extension of class AST_PredefinedType that provides additional means for C++
-//    mapping.
-//
-// = AUTHOR
-//    Copyright 1994-1995 by Sun Microsystems, Inc.
-//    and
-//    Aniruddha Gokhale
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_predefined_type.h
+ *
+ *  $Id: be_predefined_type.h 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_PredefinedType that provides additional means for C++
+ *  mapping.
+ *
+ *
+ *  @author Copyright 1994-1995 by Sun Microsystems
+ *  @author Inc. and Aniruddha Gokhale
+ */
+//=============================================================================
 
 #ifndef _BE_PREDEFINED_TYPE_H
 #define _BE_PREDEFINED_TYPE_H
@@ -32,14 +27,13 @@ class be_predefined_type : public virtual AST_PredefinedType,
                            public virtual be_type
 {
 public:
-  be_predefined_type (void);
-
   be_predefined_type (AST_PredefinedType::PredefinedType t,
                       UTL_ScopedName *n);
                       
   // Overridden from class be_type.
   virtual void gen_member_ostream_operator (TAO_OutStream *os,
                                             const char *instance_name,
+                                            bool use_underscore,
                                             bool accessor = false);
 
   // Visiting.
@@ -49,19 +43,20 @@ public:
   virtual void destroy (void);
 
   // Narrowing.
-
   DEF_NARROW_FROM_DECL (be_predefined_type);
 
 protected:
+  /// Overridden method.
   virtual void compute_tc_name (void);
-  // Overridden method.
 
   // Compute and return the value.
 
+  /**
+   * The object and TypeCode repository IDs have a mandatory omg.org
+   * prefix, but the default compute_repoID() uses the #pragma's to
+   * obtain prefixes.
+   */
   virtual void compute_repoID (void);
-  // The object and TypeCode repository IDs have a mandatory omg.org
-  // prefix, but the default compute_repoID() uses the #pragma's to
-  // obtain prefixes.
 };
 
 #endif
