@@ -1,22 +1,18 @@
 /* -*- c++ -*- */
-// $Id: be_union_fwd.h 78883 2007-07-13 17:55:30Z ossama $
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_union_fwd.h
-//
-// = DESCRIPTION
-//    Extension of class AST_UnionFwd that provides additional
-//    means for C++ mapping of a union.
-//
-// = AUTHOR
-//    Jeff Parsons
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_union_fwd.h
+ *
+ *  $Id: be_union_fwd.h 89076 2010-02-18 22:54:36Z parsons $
+ *
+ *  Extension of class AST_UnionFwd that provides additional
+ *  means for C++ mapping of a union.
+ *
+ *
+ *  @author Jeff Parsons
+ */
+//=============================================================================
 
 #ifndef BE_UNION_FWD_H
 #define BE_UNION_FWD_H
@@ -35,24 +31,18 @@ class be_union_fwd : public virtual AST_UnionFwd,
   // =DESCRIPTION
   //   Extensions to the AST_UnionFwd class
 public:
-  be_union_fwd (void);
-  // Default constructor.
-
   be_union_fwd (AST_Union *dummy,
                 UTL_ScopedName *n);
-  // Constructor.
 
   virtual ~be_union_fwd (void);
-  // Destructor.
 
+  /// Cleanup function.
   virtual void destroy (void);
-  // Cleanup function.
 
   // Visiting.
   virtual int accept (be_visitor* visitor);
 
   // Narrowing.
-
   DEF_NARROW_FROM_DECL (be_union_fwd);
 };
 
