@@ -1,4 +1,4 @@
-// $Id: be_union_label.h 73110 2006-06-15 18:56:10Z parsons $
+// $Id: be_union_label.h 89076 2010-02-18 22:54:36Z parsons $
 
 #ifndef BE_UNION_LABEL_H
 #define BE_UNION_LABEL_H
@@ -10,12 +10,8 @@ class be_visitor;
 class be_union_label : public virtual AST_UnionLabel
 {
 public:
-  be_union_label (void);
-  // Default constructor.
-
   be_union_label (AST_UnionLabel::UnionLabel ul,
                   AST_Expression *v);
-  // Constructor.
 
   // Visiting.
   virtual int accept (be_visitor *visitor);
