@@ -1,23 +1,18 @@
 /* -*- c++ -*- */
-//
-// $Id: be_visitor_root.h 66457 2005-06-15 19:47:53Z fields_t $
-//
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO IDL
-//
-// = FILENAME
-//    be_visitor_root.h
-//
-// = DESCRIPTION
-//    Concrete visitor for the Root class
-//
-// = AUTHOR
-//    Aniruddha Gokhale and Carlos O'Ryan
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    be_visitor_root.h
+ *
+ *  $Id: be_visitor_root.h 88919 2010-02-09 22:55:55Z parsons $
+ *
+ *  Concrete visitor for the Root class
+ *
+ *
+ *  @author Aniruddha Gokhale and Carlos O'Ryan
+ */
+//=============================================================================
+
 
 #ifndef TAO_BE_VISITOR_ROOT_H
 #define TAO_BE_VISITOR_ROOT_H
@@ -33,6 +28,13 @@
 #include "be_visitor_root/root_sth.h"
 #include "be_visitor_root/root_is.h"
 #include "be_visitor_root/root_ih.h"
+#include "be_visitor_root/root_svh.h"
+#include "be_visitor_root/root_svs.h"
+#include "be_visitor_root/root_ex_idl.h"
+#include "be_visitor_root/root_exh.h"
+#include "be_visitor_root/root_exs.h"
+#include "be_visitor_root/root_cnh.h"
+#include "be_visitor_root/root_cns.h"
 #include "be_visitor_root/any_op.h"
 #include "be_visitor_root/cdr_op.h"
 #include "be_visitor_root/serializer_op.h"
