@@ -1,4 +1,4 @@
-// $Id: drv_args.cpp 80525 2008-01-30 23:18:43Z parsons $
+// $Id: drv_args.cpp 87417 2009-11-09 15:04:38Z parsons $
 
 /*
 
@@ -76,10 +76,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ace/OS_NS_unistd.h"
 #include "ace/os_include/os_ctype.h"
 
-ACE_RCSID (driver,
-           drv_args,
-           "$Id: drv_args.cpp 80525 2008-01-30 23:18:43Z parsons $")
-
 extern long DRV_nfiles;
 extern char *DRV_files[];
 
@@ -122,11 +118,9 @@ void
 DRV_usage (void)
 {
   ACE_DEBUG ((LM_DEBUG,
-              ACE_TEXT ("%s%s%s%s"),
-              idl_global->prog_name (),
-              ACE_TEXT (": usage: "),
-              idl_global->prog_name (),
-              ACE_TEXT (" [flag | file]*\n")));
+              ACE_TEXT ("%s: usage: %s [flag | file]*\n"),
+              ACE_TEXT_CHAR_TO_TCHAR (idl_global->prog_name ()),
+              ACE_TEXT_CHAR_TO_TCHAR (idl_global->prog_name ())));
 
   ACE_DEBUG ((LM_DEBUG,
               ACE_TEXT ("Legal flags:\n")));
@@ -187,7 +181,7 @@ DRV_usage (void)
     ));
   ACE_DEBUG ((
       LM_DEBUG,
-      ACE_TEXT (" -Wp,<arg1,...,argn>\t\t\t\tpasses args to preprocessor\n")
+      ACE_TEXT (" -Wp,<arg1,...,argn>\tpasses args to preprocessor\n")
     ));
   ACE_DEBUG ((
       LM_DEBUG,
@@ -244,7 +238,7 @@ DRV_parse_args (long ac, char **av)
                           ACE_TEXT ("IDL: incorrect use of ")
                           ACE_TEXT ("the -A option\n")
                         ));
-                        
+
                       idl_global->set_compile_flags (
                                       idl_global->compile_flags ()
                                       | IDL_CF_ONLY_USAGE
@@ -274,15 +268,15 @@ DRV_parse_args (long ac, char **av)
                       LM_ERROR,
                       ACE_TEXT ("IDL: I don't understand")
                       ACE_TEXT (" the '%s' option\n"),
-                      av[i]
+                      ACE_TEXT_CHAR_TO_TCHAR (av[i])
                     ));
-                    
+
                   idl_global->set_compile_flags (
                                   idl_global->compile_flags ()
                                   | IDL_CF_ONLY_USAGE
                                 );
                 }
-                
+
               break;
             case 'D':
             case 'U':
@@ -302,7 +296,7 @@ DRV_parse_args (long ac, char **av)
                       arg += (has_space ? "\"" : "");
 
                       DRV_cpp_putarg (arg.c_str ());
-                      idl_global->add_include_path (arg.substr (2).c_str ());
+                      idl_global->add_include_path (arg.substr (2).c_str (), false);
                       ++i;
                     }
                   else
@@ -311,9 +305,9 @@ DRV_parse_args (long ac, char **av)
                           LM_ERROR,
                           ACE_TEXT ("IDL: I don't understand")
                           ACE_TEXT (" the '%s' option\n"),
-                          av[i]
+                          ACE_TEXT_CHAR_TO_TCHAR (av[i])
                         ));
-                        
+
                       idl_global->set_compile_flags (
                                       idl_global->compile_flags ()
                                       | IDL_CF_ONLY_USAGE
@@ -332,10 +326,10 @@ DRV_parse_args (long ac, char **av)
                   arg += av[i] + 2;
                   arg += (has_space? "\"" : "");
 
-                  idl_global->add_include_path (arg.substr (2).c_str ());
+                  idl_global->add_include_path (arg.substr (2).c_str (), false);
                   DRV_cpp_putarg (arg.c_str ());
                 }
-                
+
               break;
             case 'E':
               idl_global->set_compile_flags (idl_global->compile_flags () |
@@ -359,9 +353,9 @@ DRV_parse_args (long ac, char **av)
                           LM_ERROR,
                           ACE_TEXT ("IDL: I don't understand")
                           ACE_TEXT (" the '%s' option\n"),
-                          av[i]
+                          ACE_TEXT_CHAR_TO_TCHAR (av[i])
                         ));
-                        
+
                       idl_global->set_compile_flags (
                                       idl_global->compile_flags ()
                                       | IDL_CF_ONLY_USAGE
@@ -381,7 +375,7 @@ DRV_parse_args (long ac, char **av)
                       LM_ERROR,
                       ACE_TEXT ("IDL: Incorrect use of -W option\n")
                     ));
-                        
+
                   idl_global->set_compile_flags (
                                   idl_global->compile_flags ()
                                   | IDL_CF_ONLY_USAGE
@@ -392,17 +386,17 @@ DRV_parse_args (long ac, char **av)
                     {
                       DRV_prep_cpp_arg (s + 2);
                     }
-                    
+
                   break;
                 case 'b':
                   if (*(s + 1) == ',')
                     {
                       be_global->prep_be_arg (s + 2);
                     }
-                    
+
                   break;
                 }
-                
+
               break;
             case 'Y':
               if (av[i][2] == '\0')
@@ -418,9 +412,9 @@ DRV_parse_args (long ac, char **av)
                           LM_ERROR,
                           ACE_TEXT ("IDL: I don't understand")
                           ACE_TEXT (" the '%s' option\n"),
-                          av[i]
+                          ACE_TEXT_CHAR_TO_TCHAR (av[i])
                         ));
-                        
+
                       idl_global->set_compile_flags (
                                       idl_global->compile_flags ()
                                       | IDL_CF_ONLY_USAGE
@@ -448,22 +442,22 @@ DRV_parse_args (long ac, char **av)
                             ACE_TEXT ("IDL: I don't understand")
                             ACE_TEXT (" the '-Y' option\n")
                           ));
-                          
+
                         idl_global->set_compile_flags (
                                         idl_global->compile_flags ()
                                         | IDL_CF_ONLY_USAGE
                                       );
                       }
-                      
+
                     break;
                   default:
                     ACE_ERROR ((
                         LM_ERROR,
                         ACE_TEXT ("IDL: I dont' understand the use of")
                         ACE_TEXT (" %s with the '-Y' option\n"),
-                        s
+                        ACE_TEXT_CHAR_TO_TCHAR (s)
                       ));
-                    
+
                     idl_global->set_compile_flags (
                                     idl_global->compile_flags ()
                                     | IDL_CF_ONLY_USAGE
@@ -504,7 +498,7 @@ DRV_parse_args (long ac, char **av)
                   ACE_ERROR ((
                       LM_ERROR,
                       ACE_TEXT ("IDL: I don't understand the '%s' option\n"),
-                      av[i]
+                      ACE_TEXT_CHAR_TO_TCHAR (av[i])
                     ));
 
                   idl_global->set_compile_flags (
@@ -530,7 +524,7 @@ DRV_parse_args (long ac, char **av)
   // Make sure the output directory is valid.
   if (idl_global->temp_dir () == 0)
     {
-      char tmpdir[MAXPATHLEN + 1];
+      ACE_TCHAR tmpdir[MAXPATHLEN + 1];
 
       if (ACE::get_temp_dir (tmpdir, MAXPATHLEN) == -1)
         {
@@ -538,7 +532,7 @@ DRV_parse_args (long ac, char **av)
                       ACE_TEXT ("Temporary path too long, ")
                       ACE_TEXT ("defaulting to current directory\n")));
 
-          ACE_OS::strcpy (tmpdir, ".");
+          ACE_OS::strcpy (tmpdir, ACE_TEXT ("."));
         }
 
 #if defined(ACE_MVS)
@@ -551,13 +545,12 @@ DRV_parse_args (long ac, char **av)
         {
           ACE_ERROR ((
               LM_ERROR,
-              ACE_TEXT ("%s%s%s\n"),
-              ACE_TEXT ("Can't access temporary directory ("),
-              tmpdir,
-              ACE_TEXT ("), using current directory for temp files.")
+              ACE_TEXT ("Can't access temporary directory (%s),")
+              ACE_TEXT (" using current directory for temp files.\n"),
+              tmpdir
             ));
 
-          ACE_OS::strcpy (tmpdir, ".");
+          ACE_OS::strcpy (tmpdir, ACE_TEXT ("."));
 #if defined(ACE_MVS)
           if (ACE_OS::access (tmpdir, F_OK) == -1
               || ACE_OS::access (tmpdir, R_OK) == -1
@@ -567,16 +560,14 @@ DRV_parse_args (long ac, char **av)
 #endif /* ACE_MVS */
             {
               ACE_ERROR ((LM_ERROR,
-                          "%s%s\n",
-                          ACE_TEXT ("Error: Can't access ")
-                          ACE_TEXT ("temporary directory "),
+                          "Error: Can't access temporary directory %s\n",
                           tmpdir));
 
               throw Bailout ();
             }
         }
 
-      idl_global->temp_dir (tmpdir);
+      idl_global->temp_dir (ACE_TEXT_ALWAYS_CHAR (tmpdir));
     }
 
   DRV_cpp_post_init ();
