@@ -1,4 +1,4 @@
-// $Id: drv_preproc.cpp 80525 2008-01-30 23:18:43Z parsons $
+// $Id: drv_preproc.cpp 89219 2010-02-25 08:01:26Z johnnyw $
 
 /*
 
@@ -88,20 +88,23 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ace/OS_NS_unistd.h"
 #include "ace/OS_NS_fcntl.h"
 
-ACE_RCSID (driver,
-           drv_preproc,
-           "$Id: drv_preproc.cpp 80525 2008-01-30 23:18:43Z parsons $")
-
 // Storage for preprocessor args.
-unsigned long const DRV_MAX_ARGCOUNT = 128;
+unsigned long const DRV_MAX_ARGCOUNT = 1024;
 unsigned long DRV_argcount = 0;
-char const * DRV_arglist[DRV_MAX_ARGCOUNT] = { 0 };
+ACE_TCHAR const * DRV_arglist[DRV_MAX_ARGCOUNT] = { 0 };
 
 static char const * output_arg_format = 0;
 static long output_arg_index = 0;
 
+ACE_TCHAR const TCHAR_DIR_DOT[] = ACE_TEXT(".");
+
+#if defined (ACE_HAS_TCHAR_DIRENT)
+ACE_TCHAR const DIR_DOT[] = ACE_TEXT(".");
+ACE_TCHAR const DIR_DOT_DOT[] = ACE_TEXT("..");
+#else
 char const DIR_DOT[] = ".";
 char const DIR_DOT_DOT[] = "..";
+#endif /* ACE_HAS_TCHAR_DIRENT */
 
 // File names.
 static char tmp_file [MAXPATHLEN + 1] = { 0 };
@@ -116,8 +119,8 @@ static size_t drv_line_size = LINEBUF_SIZE + 1;
 void
 DRV_cpp_new_location (char const * new_loc)
 {
-  ACE::strdelete (const_cast<char *> (DRV_arglist[0]));
-  DRV_arglist[0] = ACE::strnew (new_loc);
+  ACE::strdelete (const_cast<ACE_TCHAR *> (DRV_arglist[0]));
+  DRV_arglist[0] = ACE::strnew (ACE_TEXT_CHAR_TO_TCHAR (new_loc));
 }
 
 // Push an argument into the DRV_arglist.
@@ -127,16 +130,14 @@ DRV_cpp_putarg (const char *str)
   if (DRV_argcount >= DRV_MAX_ARGCOUNT)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s%s %d %s\n",
+                  "%C: More than %d arguments to preprocessor\n",
                   idl_global->prog_name (),
-                  ": More than",
-                  DRV_MAX_ARGCOUNT,
-                  "arguments to preprocessor"));
+                  DRV_MAX_ARGCOUNT ));
 
       throw Bailout ();
     }
 
-  DRV_arglist[DRV_argcount++] = ACE::strnew (str);
+  DRV_arglist[DRV_argcount++] = ACE::strnew (ACE_TEXT_CHAR_TO_TCHAR (str));
 }
 
 // Expand the output argument with the given filename.
@@ -145,20 +146,17 @@ DRV_cpp_expand_output_arg (const char *filename)
 {
   if (output_arg_format != 0)
     {
-      ACE::strdelete (const_cast<char *> (DRV_arglist[output_arg_index]));
+      ACE::strdelete (const_cast<ACE_TCHAR *> (DRV_arglist[output_arg_index]));
       DRV_arglist[output_arg_index] = 0;
 
-      char *output_arg = 0;
-      ACE_NEW (output_arg,
-               char [ACE_OS::strlen (output_arg_format)
+      ACE_NEW (DRV_arglist[output_arg_index],
+               ACE_TCHAR [ACE_OS::strlen (output_arg_format)
                      + ACE_OS::strlen (filename)
                      + 1]);
 
-      ACE_OS::sprintf (output_arg,
-                       output_arg_format,
-                       filename);
-
-      DRV_arglist[output_arg_index] = output_arg;
+      ACE_OS::sprintf (const_cast<ACE_TCHAR *> (DRV_arglist[output_arg_index]),
+                       ACE_TEXT_CHAR_TO_TCHAR (output_arg_format),
+                       ACE_TEXT_CHAR_TO_TCHAR (filename));
     }
 }
 
@@ -166,58 +164,58 @@ DRV_cpp_expand_output_arg (const char *filename)
 static bool
 DRV_get_line (FILE *f)
 {
-    char *l = ACE_OS::fgets (drv_line,
-                             drv_line_size,
-                             f);
-
-    if (l == 0)
-      {
-        return false;
-      }
-
-    if (*l == '\0' && feof (f))
-      {
-        return false;
-      }
-
-    if (*l == '\0')
-      {
-        return true;
-      }
-
-    while (ACE_OS::strchr (drv_line, '\n') == 0)
-      {
-        // Haven't got to a newline yet.
-        // Create a bigger buffer and keep reading.
-        size_t temp_size;
-        temp_size = drv_line_size * 2;
-        char *temp = 0;
-        ACE_NEW_RETURN (temp,
-                        char[temp_size],
-                        false);
-        ACE_OS::strcpy (temp, drv_line);
-        delete [] drv_line;
-        drv_line = temp;
-        drv_line_size = temp_size;
-
-        l = ACE_OS::fgets (drv_line + ACE_OS::strlen (drv_line),
-                           drv_line_size - ACE_OS::strlen(drv_line),
+  char *l = ACE_OS::fgets (drv_line,
+                           drv_line_size,
                            f);
 
-        if (l == 0 || *l == '\0')
-          {
-            break;
-          }
-      }
+  if (l == 0)
+    {
+      return false;
+    }
 
-    size_t i = ACE_OS::strlen (drv_line) - 1;
+  if (*l == '\0' && feof (f))
+    {
+      return false;
+    }
 
-    if (drv_line[i] == '\n')
-      {
-        drv_line[i] = '\0';
-      }
+  if (*l == '\0')
+    {
+      return true;
+    }
 
-    return true;
+  while (ACE_OS::strchr (drv_line, '\n') == 0)
+    {
+      // Haven't got to a newline yet.
+      // Create a bigger buffer and keep reading.
+      size_t temp_size;
+      temp_size = drv_line_size * 2;
+      char *temp = 0;
+      ACE_NEW_RETURN (temp,
+                      char[temp_size],
+                      false);
+      ACE_OS::strcpy (temp, drv_line);
+      delete [] drv_line;
+      drv_line = temp;
+      drv_line_size = temp_size;
+
+      l = ACE_OS::fgets (drv_line + ACE_OS::strlen (drv_line),
+                         drv_line_size - ACE_OS::strlen(drv_line),
+                         f);
+
+      if (l == 0 || *l == '\0')
+        {
+          break;
+        }
+    }
+
+  size_t i = ACE_OS::strlen (drv_line) - 1;
+
+  if (drv_line[i] == '\n')
+    {
+      drv_line[i] = '\0';
+    }
+
+  return true;
 }
 
 // Initialize the cpp argument list.
@@ -268,12 +266,10 @@ DRV_cpp_init (void)
 
       char* TAO_ROOT = ACE_OS::getenv ("TAO_ROOT");
 
-      // When adding new dirs here don't forget to update
-      // IDL_GlobalData::validate_orb_include accordingly.
       if (TAO_ROOT != 0)
         {
-            DRV_add_include_path (include_path1, TAO_ROOT, 0);
-            DRV_add_include_path (include_path2, TAO_ROOT, "/tao");
+            DRV_add_include_path (include_path1, TAO_ROOT, 0, true);
+            DRV_add_include_path (include_path2, TAO_ROOT, "/tao", true);
         }
       else
         {
@@ -281,8 +277,8 @@ DRV_cpp_init (void)
 
           if (ACE_ROOT != 0)
             {
-              DRV_add_include_path (include_path1, ACE_ROOT, "/TAO");
-              DRV_add_include_path (include_path2, ACE_ROOT, "/TAO/tao");
+              DRV_add_include_path (include_path1, ACE_ROOT, "/TAO", true);
+              DRV_add_include_path (include_path2, ACE_ROOT, "/TAO/tao", true);
             }
           else
             {
@@ -290,10 +286,16 @@ DRV_cpp_init (void)
               // TAO_IDL_INCLUDE_DIR may be in quotes,
               // e.g. "/usr/local/include/tao"
               // We deal with a case like this below ...
-              DRV_add_include_path (include_path1, TAO_IDL_INCLUDE_DIR, 0);
-              DRV_add_include_path (include_path2, ".", 0);
+              DRV_add_include_path (include_path1,
+                                    TAO_IDL_INCLUDE_DIR,
+                                    0,
+                                    true);
+              DRV_add_include_path (include_path2,
+                                    TAO_IDL_INCLUDE_DIR,
+                                    "/tao",
+                                    true);
 #else
-              DRV_add_include_path (include_path1, ".", 0);
+              DRV_add_include_path (include_path1, ".", 0, true);
 #endif  /* TAO_IDL_INCLUDE_DIR */
             }
         }
@@ -302,21 +304,21 @@ DRV_cpp_init (void)
     }
 
   // Add any flags in platform_cpp_args to cpp's DRV_arglist.
-  ACE_ARGV platform_arglist (platform_cpp_args);
+  ACE_ARGV platform_arglist (ACE_TEXT_CHAR_TO_TCHAR (platform_cpp_args));
 
   for (int i = 0; i < platform_arglist.argc (); ++i)
     {
       // Check for an argument that specifies the preprocessor's output file.
-      if (ACE_OS::strstr (platform_arglist[i], "%s") != 0
+      if (ACE_OS::strstr (platform_arglist[i], ACE_TEXT ("%s")) != 0
           && output_arg_format == 0)
         {
-          output_arg_format = ACE::strnew (platform_arglist[i]);
+          output_arg_format = ACE::strnew (ACE_TEXT_ALWAYS_CHAR (platform_arglist[i]));
           output_arg_index = DRV_argcount;
           DRV_cpp_putarg (0);
         }
       else
         {
-          DRV_cpp_putarg (platform_arglist[i]);
+          DRV_cpp_putarg (ACE_TEXT_ALWAYS_CHAR (platform_arglist[i]));
         }
     }
 }
@@ -335,12 +337,12 @@ DRV_sweep_dirs (const char *rel_path,
   if (ACE_OS::chdir (rel_path) == -1)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
-                         "DRV_sweep_dirs: chdir %s failed\n",
+                         "DRV_sweep_dirs: chdir %C failed\n",
                          rel_path),
                         -1);
     }
 
-  ACE_Dirent dir (DIR_DOT);
+  ACE_Dirent dir (TCHAR_DIR_DOT);
   ACE_CString bname (base_path);
   bname += (bname.length () > 0 ? "/" : "");
   bname += rel_path;
@@ -348,16 +350,17 @@ DRV_sweep_dirs (const char *rel_path,
   char abspath[MAXPATHLEN] = "";
   char *full_path = 0;
 
-  for (dirent *dir_entry; (dir_entry = dir.read ()) != 0;)
+  for (ACE_DIRENT *dir_entry; (dir_entry = dir.read ()) != 0;)
     {
       // Skip the ".." and "." files in each directory.
-      if (ACE_OS::strcmp (dir_entry->d_name, DIR_DOT) == 0
-          || ACE_OS::strcmp (dir_entry->d_name, DIR_DOT_DOT) == 0)
-        {
-          continue;
-        }
+      if (ACE::isdotdir (dir_entry->d_name) == true)
+        continue;
 
+#if defined (ACE_HAS_TCHAR_DIRENT)
+      ACE_CString lname (ACE_TEXT_ALWAYS_CHAR (dir_entry->d_name));
+#else
       ACE_CString lname (dir_entry->d_name);
+#endif
       ACE_stat stat_buf;
 
       if (ACE_OS::lstat (lname.c_str (), &stat_buf) == -1)
@@ -387,7 +390,7 @@ DRV_sweep_dirs (const char *rel_path,
 
                   if (full_path != 0)
                     {
-                      idl_global->add_include_path (full_path);
+                      idl_global->add_include_path (full_path, false);
                     }
 
                   include_added = true;
@@ -413,7 +416,7 @@ DRV_sweep_dirs (const char *rel_path,
   if (ACE_OS::chdir (DIR_DOT_DOT) == -1)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
-                         "DRV_sweep_dirs: chdir .. (from %s) failed\n",
+                         "DRV_sweep_dirs: chdir .. (from %C) failed\n",
                          rel_path),
                         -1);
     }
@@ -422,56 +425,64 @@ DRV_sweep_dirs (const char *rel_path,
 }
 
 ACE_CString&
-DRV_add_include_path (ACE_CString& include_path, const char* p, const char* suffix)
+DRV_add_include_path (ACE_CString& include_path, const char *path,
+                      const char *suffix, bool is_system)
 {
-  if (p == 0) return include_path;
+  if (!path)
+    return include_path;
 
-  ACE_CString include_option ("-I");
+  const bool needToQuote= (('"' == *path) || ACE_OS::strchr (path, ' '));
+  const size_t pathLength= ACE_OS::strlen (path);
+  const char
+#if defined (ACE_WIN32)
+    nativeDir=  '\\',
+    foreignDir= '/';
+#else
+    nativeDir=  '/',
+    foreignDir= '\\';
+#endif
 
-  size_t len = ACE_OS::strlen (p);
+  // Eliminate possible enclosing quotes from the path, and since some compilers
+  // choke on double directory separators in paths, ensure that the path does not
+  // end with a directory slash.
+  include_path=
+    ACE_CString (path + ('"' == *path),     // Skip leading Quote
+                 pathLength
+                 - ('"' == *path)           // Don't count leading Quote
+                 - ( (1uL < pathLength) &&  // Don't count trailing Quote XOR directory
+                     ('"'        == path [pathLength - 1uL] ||
+                      nativeDir  == path [pathLength - 1uL] ||
+                      foreignDir == path [pathLength - 1uL]
+                   ) )
+                 - ( (2uL < pathLength) &&  // Don't count trailing Quote AND directory
+                     '"' == path [pathLength - 1uL] &&
+                     (nativeDir  == path [pathLength - 2uL] ||
+                      foreignDir == path [pathLength - 2uL]
+                   ) )
+                );
 
-  bool quote = !(p[0] == '"' || ACE_OS::strchr (p, ' ') == 0);
-
-  // Eliminate possible quotes from the path
-  if ('"' == p[0])
-  {
-    include_path = p + 1;
-    include_path[len - 2] = 0;
-  }
-  else
-  {
-    include_path = p;
-  }
-
-  // Some compilers choke on "//" separators.
-  if (p[len - 1] == '/' || p[len - 1] == '\\')
+  if (suffix)
     {
-      include_path[len - 1] = '\0';
+      if (!include_path.length () && ((nativeDir == *suffix) || (foreignDir == *suffix)))
+        ++suffix; // Path is empty, don't add the suffix's leading directory seporator
+
+      if (include_path.length () && *suffix && (nativeDir != *suffix) && (foreignDir != *suffix))
+        include_path+= nativeDir; // Force a directory seporator
+
+      // Add the suffix string to the path, ensuring that foreign directory slashes
+      // are added as the native type.
+      for ( ; *suffix; ++suffix)
+        include_path+= (foreignDir == *suffix) ? nativeDir : *suffix;
     }
 
-  for ( ; suffix != 0 && *suffix != 0; suffix++)
-  {
-#if defined (ACE_WIN32)
-    if (*suffix == '/')
-        include_path += '\\';
-#else
-    if (*suffix == '\\')
-        include_path += '/';
-#endif
-    else
-        include_path += *suffix;
-  }
-
-  if (quote)
-      include_option += '"';
-
-  include_option += include_path; //.c_str ();
-
-  if (quote)
-      include_option += '"';
+  // Build up the include string from the new path+suffix
+  ACE_CString include_option ("-I\"", 2 + needToQuote);
+  include_option+= include_path;
+  if (needToQuote)
+    include_option+= '"';
 
   DRV_cpp_putarg (include_option.c_str ());
-  idl_global->add_include_path (include_path.c_str ());
+  idl_global->add_include_path (include_path.c_str (), is_system);
 
   return include_path;
 }
@@ -481,7 +492,6 @@ DRV_add_include_path (ACE_CString& include_path, const char* p, const char* suff
 void
 DRV_cpp_post_init (void)
 {
-
   // Add include path for TAO_ROOT/orbsvcs.
   char* TAO_ROOT = ACE_OS::getenv ("TAO_ROOT");
 
@@ -491,7 +501,7 @@ DRV_cpp_post_init (void)
   // IDL_GlobalData::validate_orb_include accordingly.
   if (TAO_ROOT != 0)
     {
-      DRV_add_include_path (include_path3, TAO_ROOT, "/orbsvcs");
+      DRV_add_include_path (include_path3, TAO_ROOT, "/orbsvcs", true);
     }
   else
     {
@@ -500,29 +510,40 @@ DRV_cpp_post_init (void)
 
       if (ACE_ROOT != 0)
         {
-          DRV_add_include_path (include_path3, TAO_ROOT, "/TAO/orbsvcs");
+          DRV_add_include_path (include_path3, ACE_ROOT, "/TAO/orbsvcs", true);
         }
       else
         {
+#if defined (TAO_IDL_INCLUDE_DIR)
+          DRV_add_include_path (include_path3,
+                                TAO_IDL_INCLUDE_DIR,
+                                "/orbsvcs",
+                                true);
+#else
           // If ACE_ROOT isn't defined either, there will already
           // be a warning from DRV_preproc().
-          DRV_add_include_path (include_path3, ".", 0);
+          DRV_add_include_path (include_path3, ".", 0, true);
+#endif  /* TAO_IDL_INCLUDE_DIR */
         }
     }
 
   // Add include paths for CIAO_ROOT and CIAO_ROOT/ciao.
   char* CIAO_ROOT = ACE_OS::getenv ("CIAO_ROOT");
 
+  // When adding new dirs here don't forget to update
+  // IDL_GlobalData::validate_orb_include accordingly.
   if (CIAO_ROOT != 0)
     {
-      DRV_add_include_path (include_path4, CIAO_ROOT, 0);
-      DRV_add_include_path (include_path5, CIAO_ROOT, "/ciao");
+      DRV_add_include_path (include_path4, CIAO_ROOT, 0, true);
+      DRV_add_include_path (include_path5, CIAO_ROOT, "/ciao", true);
+      DRV_add_include_path (include_path5, CIAO_ROOT, "/ccm", true);
     }
   else if (TAO_ROOT != 0)
     {
       // If CIAO_ROOT hasn't been set, maybe it's nested under TAO_ROOT.
-      DRV_add_include_path (include_path4, TAO_ROOT, "/CIAO");
-      DRV_add_include_path (include_path5, TAO_ROOT, "/CIAO/ciao");
+      DRV_add_include_path (include_path4, TAO_ROOT, "/CIAO", true);
+      DRV_add_include_path (include_path5, TAO_ROOT, "/CIAO/ciao", true);
+      DRV_add_include_path (include_path5, TAO_ROOT, "/CIAO/ccm", true);
     }
   else
     {
@@ -531,15 +552,31 @@ DRV_cpp_post_init (void)
 
       if (ACE_ROOT != 0)
         {
-          DRV_add_include_path (include_path4, ACE_ROOT, "/TAO/CIAO");
-          DRV_add_include_path (include_path5, ACE_ROOT, "/TAO/CIAO/ciao");
+          DRV_add_include_path (include_path4, ACE_ROOT, "/TAO/CIAO", true);
+          DRV_add_include_path (include_path5, ACE_ROOT, "/TAO/CIAO/ciao", true);
+          DRV_add_include_path (include_path5, ACE_ROOT, "/TAO/CIAO/ccm", true);
         }
       else
         {
+#if defined (TAO_IDL_INCLUDE_DIR)
+          DRV_add_include_path (include_path4,
+                                TAO_IDL_INCLUDE_DIR,
+                                0,
+                                true);
+          DRV_add_include_path (include_path5,
+                                TAO_IDL_INCLUDE_DIR,
+                                "/ciao",
+                                true);
+          DRV_add_include_path (include_path5,
+                                TAO_IDL_INCLUDE_DIR,
+                                "/ccm",
+                                true);
+#else
           // If ACE_ROOT isn't defined either, there will already
           // be a warning from DRV_preproc().
-          DRV_add_include_path (include_path4, ACE_ROOT, ".");
-          DRV_add_include_path (include_path5, ACE_ROOT, ".");
+          DRV_add_include_path (include_path4, ACE_ROOT, ".", true);
+          DRV_add_include_path (include_path5, ACE_ROOT, ".", true);
+#endif  /* TAO_IDL_INCLUDE_DIR */
         }
     }
 
@@ -561,7 +598,7 @@ DRV_cpp_post_init (void)
   if (DRV_sweep_dirs (idl_global->recursion_start (), "") == -1)
     {
       ACE_ERROR ((LM_ERROR,
-                  "DRV_cpp_post_init: DRV_sweep_dirs (%s) failed\n",
+                  "DRV_cpp_post_init: DRV_sweep_dirs (%C) failed\n",
                   idl_global->recursion_start ()));
 
       throw Bailout ();
@@ -572,7 +609,7 @@ DRV_cpp_post_init (void)
   if (ACE_OS::chdir (cwd_path) == -1)
     {
       ACE_ERROR ((LM_ERROR,
-                  "DRV_cpp_post_init: ACE_OS::chdir (%s) failed\n",
+                  "DRV_cpp_post_init: ACE_OS::chdir (%C) failed\n",
                   cwd_path));
 
       throw Bailout ();
@@ -659,9 +696,7 @@ DRV_check_for_include (const char* buf)
   // We're not handling redirection from stdin.
   if (*h == '\0')
     {
-      ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT ("TAO_IDL: No input files\n")));
-
+      ACE_ERROR ((LM_ERROR, "TAO_IDL: No input files\n"));
 
       throw Bailout ();
     }
@@ -805,9 +840,7 @@ DRV_convert_includes (const char* buf)
   // We're not handling redirection from stdin.
   if (*r == '\0')
     {
-      ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT ("TAO_IDL: No input files\n")));
-
+      ACE_ERROR ((LM_ERROR, "TAO_IDL: No input files\n"));
 
       throw Bailout ();
     }
@@ -847,7 +880,7 @@ DRV_get_orb_idl_includes (void)
       if (fp == 0)
         {
           ACE_ERROR ((LM_ERROR,
-                      "TAO_IDL: cannot open or find file: %s\n",
+                      "TAO_IDL: cannot open or find file: %C\n",
                       orb_idl_path.c_str ()));
 
           throw Bailout ();
@@ -859,7 +892,7 @@ DRV_get_orb_idl_includes (void)
       // to the preprocessor.
       // This should go after user supplied include paths.
       ACE_CString include_path_arg;
-      DRV_add_include_path (include_path_arg, directory, "/tao");
+      DRV_add_include_path (include_path_arg, directory, "/tao", true);
     }
 
   while (DRV_get_line (fp))
@@ -882,9 +915,10 @@ DRV_copy_input (FILE *fin,
   if (f == 0)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: cannot open temp file \"%s\" for writing\n",
+                  "%C: cannot open temp file \"%C\" for copying from \"%C\": %p\n",
                   idl_global->prog_name (),
-                  fn));
+                  fn,
+                  orig_filename));
 
       throw Bailout ();
     }
@@ -892,9 +926,8 @@ DRV_copy_input (FILE *fin,
   if (fin == 0)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s%s",
-                  idl_global->prog_name (),
-                  ": cannot open input file\n"));
+                  "%C: cannot open input file\n",
+                  idl_global->prog_name ()));
 
       throw Bailout ();
     }
@@ -914,11 +947,11 @@ DRV_copy_input (FILE *fin,
       if (*s == '\\')
         {
           *d = '\\';
-          d++;
+          ++d;
         }
 
       *d = *s;
-      d++;
+      ++d;
     }
 
   *d = 0;
@@ -996,11 +1029,10 @@ DRV_pre_proc (const char *myfile)
       || tlen + sizeof (tao_idli_template) > sizeof (tmp_ifile))
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: temporary path/filename length is greater than "
+                  "%C: temporary path/filename length is greater than "
                   "length allowed by platform\n",
                   idl_global->prog_name ()));
 
-
       throw Bailout ();
     }
 
@@ -1012,14 +1044,23 @@ DRV_pre_proc (const char *myfile)
   ACE_OS::strcat (tmp_ifile, tao_idli_template);
 
   ACE_HANDLE const ti_fd = ACE_OS::mkstemp (tmp_ifile);
-  ACE_HANDLE const tf_fd = ACE_OS::mkstemp (tmp_file);
-
-  if (ti_fd == ACE_INVALID_HANDLE || tf_fd == ACE_INVALID_HANDLE)
+  if (ti_fd == ACE_INVALID_HANDLE)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: Unable to create temporary file: %m\n",
-                  idl_global->prog_name ()));
+                  "%C: Unable to create temporary file \"%C\": %p\n",
+                  idl_global->prog_name (),
+                  tmp_ifile));
 
+      throw Bailout ();
+    }
+
+  ACE_HANDLE const tf_fd = ACE_OS::mkstemp (tmp_file);
+  if (tf_fd == ACE_INVALID_HANDLE)
+    {
+      ACE_ERROR ((LM_ERROR,
+                  "%C: Unable to create temporary file \"%C\": %p\n",
+                  idl_global->prog_name (),
+                  tmp_file));
 
       throw Bailout ();
     }
@@ -1044,7 +1085,7 @@ DRV_pre_proc (const char *myfile)
 
   FILE * const file = ACE_OS::fopen (myfile, "r");
   DRV_copy_input (file,
-                  ACE_OS::fdopen (ti_fd, "w"),
+                  ACE_OS::fdopen (ti_fd, ACE_TEXT("w")),
                   tmp_ifile,
                   myfile);
   ACE_OS::fclose (file);
@@ -1075,7 +1116,7 @@ DRV_pre_proc (const char *myfile)
   ACE_Process process;
 
   // For complex builds, the default command line buffer size of 1024
-  // is sometimes not enough. We use 4096 here.
+  // is sometimes not enough. We use 8192 here.
   ACE_Process_Options cpp_options (1,       // Inherit environment.
                                    TAO_IDL_COMMAND_LINE_BUFFER_SIZE);
 
@@ -1083,17 +1124,36 @@ DRV_pre_proc (const char *myfile)
   DRV_cpp_putarg (t_ifile);
   DRV_cpp_putarg (0); // Null terminate the DRV_arglist.
 
-  cpp_options.command_line (DRV_arglist);
+  if (cpp_options.command_line (DRV_arglist) != 0)
+    {
+      ACE_ERROR ((LM_ERROR,
+                  "%C: command line processing \"%s\" failed\n",
+                  idl_global->prog_name (),
+                  DRV_arglist[0]));
+      throw Bailout ();
+    }
 
   // Rename temporary files so that they have extensions accepted
   // by the preprocessor.  Renaming is (supposed to be) an atomic
   // operation so we shouldn't be susceptible to attack.
-  if (ACE_OS::rename (tmp_file, t_file) != 0
-      || ACE_OS::rename (tmp_ifile, t_ifile) != 0)
+  if (ACE_OS::rename (tmp_file, t_file) != 0)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: Unable to rename temporary file: %m\n",
-                  idl_global->prog_name ()));
+                  "%C: Unable to rename temporary file \"%C\" to \"%C\": %p\n",
+                  idl_global->prog_name (),
+                  tmp_file,
+                  t_file));
+
+
+      throw Bailout ();
+    }
+  if (ACE_OS::rename (tmp_ifile, t_ifile) != 0)
+    {
+      ACE_ERROR ((LM_ERROR,
+                  "%C: Unable to rename temporary file \"%C\" to \"%C\": %p\n",
+                  idl_global->prog_name (),
+                  tmp_ifile,
+                  t_ifile));
 
 
       throw Bailout ();
@@ -1124,21 +1184,26 @@ DRV_pre_proc (const char *myfile)
       if (fd == ACE_INVALID_HANDLE)
         {
           ACE_ERROR ((LM_ERROR,
-                      "%s: cannot open temp file \"%s\" for writing\n",
+                      "%C: cannot open temp file \"%C\" for writing: %p\n",
                       idl_global->prog_name (),
                       t_file));
 
-
           throw Bailout ();
         }
 
       cpp_options.set_handles (ACE_INVALID_HANDLE, fd);
     }
 
+  if (idl_global->compile_flags () & IDL_CF_INFORMATIVE)
+    {
+      ACE_DEBUG ((LM_DEBUG, "%C: spawning: %s\n",
+                  idl_global->prog_name (),
+                  cpp_options.command_line_buf ()));
+    }
   if (process.spawn (cpp_options) == ACE_INVALID_PID)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: spawn of \"%s\" failed\n",
+                  "%C: spawn of \"%s\" failed\n",
                   idl_global->prog_name (),
                   DRV_arglist[0]));
 
@@ -1152,26 +1217,25 @@ DRV_pre_proc (const char *myfile)
       if (ACE_OS::close (fd) == -1)
         {
           ACE_ERROR ((LM_ERROR,
-                      "%s: cannot close temp file \"%s\" on parent\n",
+            "%C: cannot close temp file \"%C\" on parent: %p\n",
                       idl_global->prog_name (),
                       t_file));
 
-
           throw Bailout ();
         }
     }
 
   // Remove the null termination and the input file from the DRV_arglist,
   // the next file will the previous args.
-  ACE::strdelete (const_cast<char *> (DRV_arglist[DRV_argcount - 2]));
-
   DRV_argcount -= 2;
+  ACE::strdelete (const_cast<ACE_TCHAR *> (DRV_arglist[DRV_argcount]));
+  DRV_arglist[DRV_argcount] = 0;
   ACE_exitcode status = 0;
 
   if (process.wait (&status) == ACE_INVALID_PID)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: wait for child process failed\n",
+                  "%C: wait for child process failed\n",
                   idl_global->prog_name ()));
 
       throw Bailout ();
@@ -1185,7 +1249,7 @@ DRV_pre_proc (const char *myfile)
           errno = WEXITSTATUS ((status));
 
           ACE_ERROR ((LM_ERROR,
-                      "%s: preprocessor \"%s\" returned with an error\n",
+                      "%C: preprocessor \"%s\" returned with an error\n",
                       idl_global->prog_name (),
                       DRV_arglist[0]));
 
@@ -1198,7 +1262,7 @@ DRV_pre_proc (const char *myfile)
       errno = EINTR;
 
       ACE_ERROR ((LM_ERROR,
-                  "%s: preprocessor \"%s\" appears "
+                  "%C: preprocessor \"%s\" appears "
                   "to have been interrupted\n",
                   idl_global->prog_name (),
                   DRV_arglist[0]));
@@ -1218,7 +1282,7 @@ DRV_pre_proc (const char *myfile)
   if (yyin == 0)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: Could not open cpp output file: %p\n",
+                  "%C: Could not open cpp output file \"%C\": %p\n",
                   idl_global->prog_name (),
                   t_file));
 
@@ -1236,7 +1300,7 @@ DRV_pre_proc (const char *myfile)
       if (preproc == 0)
         {
           ACE_ERROR ((LM_ERROR,
-                      "%s: Could not open cpp output file: %p\n",
+                      "%C: Could not open cpp output file \"$C\": %p\n",
                       idl_global->prog_name (),
                       t_file));
 
@@ -1271,7 +1335,7 @@ DRV_pre_proc (const char *myfile)
   if (ACE_OS::unlink (t_ifile) == -1)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: Could not remove cpp input file: %p\n",
+                  "%C: Could not remove cpp input file \"%C\": %p\n",
                   idl_global->prog_name (),
                   t_ifile));
 
@@ -1281,7 +1345,7 @@ DRV_pre_proc (const char *myfile)
   if (ACE_OS::unlink (t_file) == -1)
     {
       ACE_ERROR ((LM_ERROR,
-                  "%s: Could not remove cpp output file: %p\n",
+                  "%C: Could not remove cpp output file \"%C\": %p\n",
                   idl_global->prog_name (),
                   t_file));
 
