@@ -1,4 +1,4 @@
-// $Id: fe_init.cpp 80525 2008-01-30 23:18:43Z parsons $
+// $Id: fe_init.cpp 89086 2010-02-19 15:20:19Z parsons $
 
 /*
 
@@ -64,20 +64,18 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 */
 
-#include "ast_module.h"
-#include "ast_predefined_type.h"
-#include "ast_generator.h"
-#include "ast_root.h"
+#include "ace/Env_Value_T.h"
+#include "ace/UUID.h"
+
 #include "utl_scoped_name.h"
 #include "utl_identifier.h"
 #include "global_extern.h"
 #include "fe_extern.h"
-#include "ace/Env_Value_T.h"
-#include "ace/UUID.h"
 
-ACE_RCSID (fe,
-           fe_init,
-           "$Id: fe_init.cpp 80525 2008-01-30 23:18:43Z parsons $")
+#include "ast_module.h"
+#include "ast_predefined_type.h"
+#include "ast_generator.h"
+#include "ast_root.h"
 
 const size_t LOCAL_ESCAPES_BUFFER_SIZE = 1024;
 
@@ -523,12 +521,14 @@ fe_populate_idl_keywords (void)
   static const char *keywords[] =
     {
       "ABSTRACT",
+      "ALIAS",
       "ANY",
       "ATTRIBUTE",
       "BOOLEAN",
       "CASE",
       "CHAR",
       "COMPONENT",
+      "CONNECTOR",
       "CONST",
       "CONSUMES",
       "CONTEXT",
@@ -552,6 +552,7 @@ fe_populate_idl_keywords (void)
       "INTERFACE",
       "LOCAL",
       "LONG",
+      "MIRRORPORT",
       "MODULE",
       "MULTIPLE",
       "NATIVE",
@@ -559,6 +560,8 @@ fe_populate_idl_keywords (void)
       "OCTET",
       "ONEWAY",
       "OUT",
+      "PORT",
+      "PORTTYPE",
       "PRIMARYKEY",
       "PRIVATE",
       "PROVIDES",
@@ -688,13 +691,10 @@ FE_populate (void)
   fe_populate_idl_keywords ();
 }
 
-// Store include paths from the environment variable, if any.
 void
-FE_store_env_include_paths (void)
+FE_extract_env_include_paths (ACE_Unbounded_Queue<ACE_CString> &list)
 {
-  // If this method have to change then don't forget to update
-  // util/utl_global.cpp:IDL_GlobalData::validate_orb_include (...).
-  ACE_Env_Value<char*> incl_paths ("INCLUDE",
+  ACE_Env_Value<char*> incl_paths (ACE_TEXT ("INCLUDE"),
                                    (char *) 0);
   const char *aggr_str = incl_paths;
 
@@ -712,19 +712,35 @@ FE_store_env_include_paths (void)
       do
         {
           pos = aggr_cstr.find (separator);
-          idl_global->add_include_path (aggr_cstr.substr (0, pos).fast_rep ());
+          list.enqueue_tail (aggr_cstr.substr (0, pos));
           aggr_cstr = aggr_cstr.substr (pos + 1);
         } while (pos != ACE_CString::npos);
     }
 }
 
+// Store include paths from the environment variable, if any.
+void
+FE_store_env_include_paths (void)
+{
+  ACE_Unbounded_Queue<ACE_CString> list;
+  FE_extract_env_include_paths (list);
+
+  ACE_CString *path_tmp = 0;
+  for (ACE_Unbounded_Queue_Iterator<ACE_CString>iter (list);
+       !iter.done (); iter.advance ())
+    {
+      iter.next (path_tmp);
+      idl_global->add_include_path (path_tmp->fast_rep (), false);
+    }
+}
+
 const char *
 FE_get_cpp_loc_from_env (void)
 {
   const char *cpp_loc = 0;
 
   // See if TAO_IDL_PREPROCESSOR is defined.
-  ACE_Env_Value<char*> preprocessor ("TAO_IDL_PREPROCESSOR",
+  ACE_Env_Value<char*> preprocessor (ACE_TEXT ("TAO_IDL_PREPROCESSOR"),
                                      (char *) 0);
 
   // Set cpp_loc to the built in location, unless it has been overriden by
@@ -736,7 +752,7 @@ FE_get_cpp_loc_from_env (void)
   else
     {
       // Check for the deprecated CPP_LOCATION environment variable
-      ACE_Env_Value<char*> cpp_path ("CPP_LOCATION",
+      ACE_Env_Value<char*> cpp_path (ACE_TEXT ("CPP_LOCATION"),
                                      (char *) 0);
 
       if (cpp_path != 0)
@@ -764,7 +780,7 @@ FE_get_cpp_args_from_env (void)
   const char *cpp_args = 0;
 
   // Added some customizable preprocessor options
-  ACE_Env_Value<char*> args1 ("TAO_IDL_PREPROCESSOR_ARGS",
+  ACE_Env_Value<char*> args1 (ACE_TEXT ("TAO_IDL_PREPROCESSOR_ARGS"),
                               (char *) 0);
 
   if (args1 != 0)
@@ -775,7 +791,7 @@ FE_get_cpp_args_from_env (void)
     {
       // Check for the deprecated TAO_IDL_DEFAULT_CPP_FLAGS environment
       // variable.
-      ACE_Env_Value<char*> args2 ("TAO_IDL_DEFAULT_CPP_FLAGS",
+      ACE_Env_Value<char*> args2 (ACE_TEXT ("TAO_IDL_DEFAULT_CPP_FLAGS"),
                                   (char *) 0);
 
       if (args2 != 0)
@@ -793,4 +809,3 @@ FE_get_cpp_args_from_env (void)
 
   return cpp_args;
 }
-
