@@ -1,4 +1,4 @@
-// $Id: fe_private.cpp 79376 2007-08-16 23:46:36Z sowayaa $
+// $Id: fe_private.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 
 /*
 
@@ -67,8 +67,4 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "fe_private.h"
 #include "utl_strlist.h"
 
-ACE_RCSID (fe, 
-           fe_private, 
-           "$Id: fe_private.cpp 79376 2007-08-16 23:46:36Z sowayaa $")
-
 UTL_StrList *DRV_global_pragmas = 0;
