@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_argument.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_argument.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -84,16 +84,10 @@ public:
       dir_INOUT = 0x04
     };
 
-  // Operations.
-
-  // Constructor(s).
-  AST_Argument (void);
-
   AST_Argument (Direction direction,
                 AST_Type *ft,
                 UTL_ScopedName *n);
 
-  // Destructor.
   virtual ~AST_Argument (void);
 
   // Data Accessors.
@@ -111,12 +105,12 @@ public:
   
   // Cleanup.
   virtual void destroy (void);
+  
+  static AST_Decl::NodeType const NT;
 
 private:
-  // Data.
-
   const Direction pd_direction;
-  // Argument direction
+  // Argument direction.
 };
 
 #endif           // _AST_ARGUMENT_AST_ARGUMENT_HH
