@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_array.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_array.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -67,6 +67,8 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #ifndef _AST_ARRAY_AST_ARRAY_HH
 #define _AST_ARRAY_AST_ARRAY_HH
 
+#include "ace/CDR_Base.h"
+
 #include "ast_concrete_type.h"
 
 class UTL_ExprList;
@@ -80,27 +82,21 @@ class ast_visitor;
 class TAO_IDL_FE_Export AST_Array : public virtual AST_ConcreteType
 {
 public:
-  // Operations.
-
-  // Constructor(s).
-  AST_Array (void);
-
   AST_Array (UTL_ScopedName *n,
-             unsigned long ndims,
+             ACE_CDR::ULong ndims,
              UTL_ExprList *dims,
              bool local,
              bool abstract);
 
-  // Destructor.
   virtual ~AST_Array (void);
 
   // Data Accessors.
 
-  unsigned long n_dims (void);
+  ACE_CDR::ULong n_dims (void);
 
   AST_Expression **dims (void);
   void set_dims (AST_Expression **,
-                 unsigned long);
+                 ACE_CDR::ULong);
 
   AST_Type *base_type (void) const;
   void set_base_type (AST_Type *nbt);
@@ -122,7 +118,9 @@ public:
 
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
-
+  
+  static AST_Decl::NodeType const NT;
+  
 protected:
   virtual int compute_size_type (void);
   // Compute the size type if it is unknown.
@@ -130,7 +128,7 @@ protected:
 private:
   // Data.
 
-  unsigned long pd_n_dims;
+  ACE_CDR::ULong pd_n_dims;
   // How many dimensions?
 
   AST_Expression **pd_dims;
@@ -147,7 +145,7 @@ private:
 
   // Compute how many dimensions.
   AST_Expression **compute_dims (UTL_ExprList *dims,
-                                 unsigned long ndims);
+                                 ACE_CDR::ULong ndims);
 };
 
 #endif           // _AST_ARRAY_AST_ARRAY_HH
