@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_attribute.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_attribute.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -76,18 +76,12 @@ class UTL_NameList;
 class TAO_IDL_FE_Export AST_Attribute : public virtual AST_Field
 {
 public:
-  // Operations.
-
-  // Constructor(s).
-  AST_Attribute (void);
-
   AST_Attribute (bool readonly,
                  AST_Type *ft,
                  UTL_ScopedName *n,
                  bool local,
                  bool abstract);
 
-  // Destructor.
   virtual ~AST_Attribute (void);
 
   // Data Accessors.
@@ -113,6 +107,8 @@ public:
   UTL_ExceptList *be_add_get_exceptions (UTL_ExceptList *t);
   UTL_ExceptList *be_add_set_exceptions (UTL_ExceptList *t);
 
+  static AST_Decl::NodeType const NT;
+  
 private:
   // Data.
 
