@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_component_fwd.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_component_fwd.h 89076 2010-02-18 22:54:36Z parsons $
 
 #ifndef _AST_COMPONENT_FWD_AST_COMPONENT_FWD_HH
 #define _AST_COMPONENT_FWD_AST_COMPONENT_FWD_HH
@@ -11,8 +11,6 @@
 class TAO_IDL_FE_Export AST_ComponentFwd : public virtual AST_InterfaceFwd
 {
 public:
-  AST_ComponentFwd (void);
-
   AST_ComponentFwd (AST_Interface *dummy,
                     UTL_ScopedName *n);
 
@@ -30,6 +28,8 @@ public:
 
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
+
+  static AST_Decl::NodeType const NT;
 };
 
 #endif           // _AST_COMPONENT_FWD_AST_COMPONENT_FWD_HH
