@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_constant.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_constant.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -84,8 +84,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 class TAO_IDL_FE_Export AST_Constant : public virtual AST_Decl
 {
 public:
-  AST_Constant (void);
-
   AST_Constant (AST_Expression::ExprType et,
                 AST_Decl::NodeType nt,
                 AST_Expression *ev,
@@ -127,6 +125,8 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
+  static AST_Decl::NodeType const NT;
+
 protected:
   AST_Expression *pd_constant_value;
   // The value.
