@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_enum.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_enum.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -72,11 +72,11 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 class AST_EnumVal;
 
-class TAO_IDL_FE_Export AST_Enum : public virtual AST_ConcreteType,
-                                   public virtual UTL_Scope
+class TAO_IDL_FE_Export AST_Enum
+  : public virtual AST_ConcreteType,
+    public virtual UTL_Scope
 {
 public:
-  AST_Enum (void);
   AST_Enum (UTL_ScopedName *n,
             bool local,
             bool abstract);
@@ -109,6 +109,8 @@ public:
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
 
+  static AST_Decl::NodeType const NT;
+
 private:
   friend int tao_yyparse (void);
 
