@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_exception.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_exception.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -80,8 +80,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 class TAO_IDL_FE_Export AST_Exception : public virtual AST_Structure
 {
 public:
-  AST_Exception (void);
-
   AST_Exception (UTL_ScopedName *n,
                  bool local,
                  bool abstract);
@@ -105,15 +103,7 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
-private:
-  friend int tao_yyparse (void);
-
-  // Scope Management Protocol.
-  virtual AST_Field *fe_add_field (AST_Field *f);
-  virtual AST_Union *fe_add_union (AST_Union *u);
-  virtual AST_Structure *fe_add_structure (AST_Structure *s);
-  virtual AST_Enum *fe_add_enum (AST_Enum *e);
-  virtual AST_EnumVal *fe_add_enum_val (AST_EnumVal *v);
+  static AST_Decl::NodeType const NT;
 };
 
 #endif           // _AST_EXCEPTION_AST_EXCEPTION_HH
