@@ -1,5 +1,5 @@
-// This may look like C, but it's really -*- C++ -*-
-// $Id: ast_field.h 78883 2007-07-13 17:55:30Z ossama $
+// -*- C++ -*-
+// $Id: ast_field.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -91,11 +91,6 @@ public:
       vis_PRIVATE
     };
 
-  // Operations.
-
-  // Constructor(s).
-  AST_Field (void);
-
   AST_Field (AST_Type *field_type,
              UTL_ScopedName *n,
              Visibility vis = vis_NA);
@@ -109,12 +104,11 @@ public:
 
   // Data Accessors.
   AST_Type *field_type (void) const;
-
-  Visibility visibility (void);
+  Visibility visibility (void) const;
 
   // Are we or do we contain a wstring?
   virtual int contains_wstring (void);
-  
+
   // Determine this bit of state after we have
   // be added to our aggregate type and before
   // we are destroyed.
@@ -122,7 +116,7 @@ public:
 
   // Narrowing.
 
-  DEF_NARROW_FROM_DECL(AST_Field);
+  DEF_NARROW_FROM_DECL (AST_Field);
 
   // AST Dumping.
   virtual void dump (ACE_OSTREAM_TYPE &o);
@@ -133,16 +127,18 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
-private:
+  static AST_Decl::NodeType const NT;
+
+protected:
   // Data.
 
-  AST_Type *pd_field_type;
+  AST_Type *ref_type_;
   // Base type for field.
 
-  Visibility pd_visibility;
+  Visibility visibility_;
   // Used with valuetype and eventtype fields.
   
-  bool anonymous_type_;
+  bool owns_base_type_;
   // If our field type is anonymous array or sequence, we're
   // responsible for destroying it.
 };
