@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_generator.h 73110 2006-06-15 18:56:10Z parsons $
+// $Id: ast_generator.h 88827 2010-02-04 08:42:41Z johnnyw $
 /*
 
 COPYRIGHT
@@ -71,13 +71,28 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_argument.h"
 #include "ast_predefined_type.h"
 #include "ast_union_label.h"
-#include "idl_uns_long.h"
+#include "ast_porttype.h"
+
+#include "fe_utils.h"
 
 class UTL_LabelList;
 class UTL_ExprList;
 class AST_Root;
 class AST_EventType;
 class AST_EventTypeFwd;
+class AST_Extended_Port;
+class AST_Mirror_Port;
+class AST_Connector;
+class AST_Provides;
+class AST_Uses;
+class AST_Publishes;
+class AST_Emits;
+class AST_Consumes;
+class AST_Template_Module;
+class AST_Template_Module_Inst;
+class AST_Template_Module_Ref;
+class AST_Param_Holder;
+class AST_Finder;
 
 // Defines base class for node generators.
 
@@ -105,7 +120,7 @@ public:
   // Create a node representing an interface.
   virtual AST_Interface *create_interface (
       UTL_ScopedName *n,
-      AST_Interface **inherits,
+      AST_Type **inherits,
       long n_inherits,
       AST_Interface **inherits_flat,
       long n_inherits_flat,
@@ -123,14 +138,14 @@ public:
   // Create a node representing a valuetype.
   virtual AST_ValueType *create_valuetype (
       UTL_ScopedName *n,
-      AST_Interface **inherits,
+      AST_Type **inherits,
       long n_inherits,
-      AST_ValueType *inherits_concrete,
+      AST_Type *inherits_concrete,
       AST_Interface **inherits_flat,
       long n_inherits_flat,
-      AST_Interface **supports_list,
+      AST_Type **supports_list,
       long n_supports,
-      AST_Interface *supports_concrete,
+      AST_Type *supports_concrete,
       bool is_abstract,
       bool is_truncatable,
       bool is_custom
@@ -145,14 +160,14 @@ public:
   // Create a node representing an eventtype.
   virtual AST_EventType *create_eventtype (
       UTL_ScopedName *n,
-      AST_Interface **inherits,
+      AST_Type **inherits,
       long n_inherits,
-      AST_ValueType *inherits_concrete,
+      AST_Type *inherits_concrete,
       AST_Interface **inherits_flat,
       long n_inherits_flat,
-      AST_Interface **supports_list,
+      AST_Type **supports_list,
       long n_supports,
-      AST_Interface *supports_concrete,
+      AST_Type *supports_concrete,
       bool is_abstract,
       bool is_truncatable,
       bool is_custom
@@ -168,7 +183,7 @@ public:
   virtual AST_Component *create_component (
       UTL_ScopedName *n,
       AST_Component *base_component,
-      AST_Interface **supports_list,
+      AST_Type **supports_list,
       long n_supports,
       AST_Interface **supports_flat,
       long n_supports_flat
@@ -184,8 +199,8 @@ public:
       UTL_ScopedName *n,
       AST_Home *base_home,
       AST_Component *managed_component,
-      AST_ValueType *primary_key,
-      AST_Interface **support_lists,
+      AST_Type *primary_key,
+      AST_Type **support_lists,
       long n_supports,
       AST_Interface **supports_flat,
       long n_supports_flat
@@ -282,30 +297,30 @@ public:
                                        AST_Expression *v1,
                                        AST_Expression *v2);
 
-  virtual AST_Expression *create_expr (long v);
+  virtual AST_Expression *create_expr (ACE_CDR::Long v);
 
-  virtual AST_Expression *create_expr (bool b);
+  virtual AST_Expression *create_expr (ACE_CDR::Boolean b);
 
-  virtual AST_Expression *create_expr (idl_uns_long v,
+  virtual AST_Expression *create_expr (ACE_CDR::ULong v,
                                        AST_Expression::ExprType t);
 
   virtual AST_Expression *create_expr (UTL_String *s);
 
   virtual AST_Expression *create_expr (char *s);
 
-  virtual AST_Expression *create_expr (char c);
+  virtual AST_Expression *create_expr (ACE_CDR::Char c);
 
   virtual AST_Expression *create_expr (ACE_OutputCDR::from_wchar wc);
 
-  virtual AST_Expression *create_expr (double d);
+  virtual AST_Expression *create_expr (ACE_CDR::Double d);
 
   // Create a node representing an enumerator.
-  virtual AST_EnumVal *create_enum_val (unsigned long v,
+  virtual AST_EnumVal *create_enum_val (ACE_CDR::ULong v,
                                         UTL_ScopedName *n);
 
   // Create a node representing an array type.
   virtual AST_Array *create_array (UTL_ScopedName *n,
-                                   unsigned long ndims,
+                                   ACE_CDR::ULong ndims,
                                    UTL_ExprList *dims,
                                    bool is_local,
                                    bool is_abstract);
@@ -324,20 +339,84 @@ public:
   virtual AST_String *create_wstring (AST_Expression *v);
 
   // Create a node representing a type renaming (typedef).
-  virtual AST_Typedef*create_typedef (AST_Type *bt,
-                                      UTL_ScopedName *n,
-                                      bool is_local,
-                                      bool is_abstract);
+  virtual AST_Typedef *create_typedef (AST_Type *bt,
+                                       UTL_ScopedName *n,
+                                       bool is_local,
+                                       bool is_abstract);
 
   // Create a node representing a native.
   virtual AST_Native *create_native (UTL_ScopedName *n);
 
-  // Create a node representing an OBV factory construct.
+  // Create a node representing an OBV or home factory construct.
   virtual AST_Factory *create_factory (UTL_ScopedName *n);
 
+  // Create a node representing an home finder construct.
+  virtual AST_Finder *create_finder (UTL_ScopedName *n);
+
   // Create a node representing a valuebox.
   virtual AST_ValueBox *create_valuebox (UTL_ScopedName *n,
                                          AST_Type *boxed_type);
+
+  virtual
+  AST_PortType *create_porttype (UTL_ScopedName *n);
+    
+  virtual
+  AST_Provides *create_provides (UTL_ScopedName *n,
+                                 AST_Type *provides_type);
+                                 
+  virtual
+  AST_Uses *create_uses (UTL_ScopedName *n,
+                         AST_Type *uses_type,
+                         bool is_multiple);
+    
+  virtual
+  AST_Publishes *create_publishes (UTL_ScopedName *n,
+                                   AST_Type *publishes_type);
+    
+  virtual
+  AST_Emits *create_emits (UTL_ScopedName *n,
+                           AST_Type *emits_type);
+    
+  virtual
+  AST_Consumes *create_consumes (UTL_ScopedName *n,
+                                 AST_Type *consumes_type);
+                                 
+  virtual
+  AST_Extended_Port *create_extended_port (
+    UTL_ScopedName *n,
+    AST_PortType *porttype_ref);
+    
+  virtual
+  AST_Mirror_Port *create_mirror_port (
+    UTL_ScopedName *n,
+    AST_PortType *porttype_ref);
+    
+  virtual
+  AST_Connector *create_connector (
+    UTL_ScopedName  *n,
+    AST_Connector *base_connector);
+    
+  virtual
+  AST_Template_Module *create_template_module (
+    UTL_ScopedName *n,
+    FE_Utils::T_PARAMLIST_INFO *template_params);
+    
+  virtual
+  AST_Template_Module_Inst *create_template_module_inst (
+    UTL_ScopedName *n,
+    AST_Template_Module *ref,
+    FE_Utils::T_ARGLIST *template_args);
+    
+  virtual
+  AST_Template_Module_Ref *create_template_module_ref (
+    UTL_ScopedName *n,
+    AST_Template_Module *ref,
+    UTL_StrList *param_refs);
+    
+  virtual
+  AST_Param_Holder *create_param_holder (
+    UTL_ScopedName *parameter_name,
+    FE_Utils::T_Param_Info *info);
 };
 
 #endif           // _AST_GENERATOR_AST_GENERATOR_HH
