@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_interface_fwd.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_interface_fwd.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -76,8 +76,6 @@ class AST_Interface;
 class TAO_IDL_FE_Export AST_InterfaceFwd : public virtual AST_Type
 {
 public:
-  AST_InterfaceFwd (void);
-
   AST_InterfaceFwd (AST_Interface *dummy,
                     UTL_ScopedName *n);
 
@@ -108,6 +106,8 @@ public:
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
 
+  static AST_Decl::NodeType const NT;
+
 private:
   AST_Interface *pd_full_definition;
   // The interface this is a forward declaration of.
