@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_native.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_native.h 89076 2010-02-18 22:54:36Z parsons $
 
 #ifndef _AST_NATIVE_H_
 #define _AST_NATIVE_H_
@@ -15,24 +15,14 @@
 class TAO_IDL_FE_Export AST_Native : public virtual AST_Exception
 {
 public:
-  // Operations.
-
-  // Constructor(s).
-
-  AST_Native (void);
-  // Default constructor.
-
   AST_Native (UTL_ScopedName *n);
-  // Constructor that initializes the scoped name.
 
   virtual ~AST_Native (void);
-  // Destructor.
   
-  virtual void destroy (void);
   // Cleanup.
+  virtual void destroy (void);
 
   // Narrowing.
-
   DEF_NARROW_FROM_DECL(AST_Native);
 
   // AST Dumping.
@@ -40,6 +30,8 @@ public:
 
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
+
+  static AST_Decl::NodeType const NT;
 };
 
 #endif /* AST_NATIVE_H */
