@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_predefined_type.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_predefined_type.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -98,11 +98,6 @@ public:
       , PT_pseudo       // Predefined type for pseudo objects
     };
 
-  // Operations.
-
-  // Constructor(s).
-  AST_PredefinedType (void);
-
   AST_PredefinedType (PredefinedType t,
                       UTL_ScopedName *n);
 
@@ -112,7 +107,6 @@ public:
   PredefinedType pt (void);
 
   // Narrowing
-
   DEF_NARROW_FROM_DECL(AST_PredefinedType);
 
   // AST Dumping
@@ -124,6 +118,8 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
+  static AST_Decl::NodeType const NT;
+
 protected:
   virtual int compute_size_type (void);
   // Compute the size type if it is unknown.
