@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_root.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_root.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -74,12 +74,10 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 class TAO_IDL_FE_Export AST_Root : public virtual AST_Module
 {
 public:
-  AST_Root (void);
-
   AST_Root (UTL_ScopedName *n);
 
   virtual ~AST_Root (void);
-  
+
   virtual unsigned long nmembers (void);
 
   // Narrowing.
@@ -95,10 +93,12 @@ public:
 
   // Cleanup.
   virtual void destroy ();
-  
+
   // Final cleanup.
   void fini (void);
 
+  static AST_Decl::NodeType const NT;
+
 private:
   friend class FE_Declarator;
   friend int tao_yyparse (void);
