@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_string.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_string.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -78,11 +78,6 @@ class AST_Expression;
 class TAO_IDL_FE_Export AST_String : public virtual AST_ConcreteType
 {
 public:
-  // Operations.
-
-  // Constructor(s) and destructor
-  AST_String (void);
-
   AST_String (AST_Decl::NodeType nt,
               UTL_ScopedName *n,
               AST_Expression *max_size,
@@ -95,7 +90,6 @@ public:
   long width (void);
 
   // Narrowing.
-
   DEF_NARROW_FROM_DECL(AST_String);
 
   // AST Dumping.
@@ -107,6 +101,8 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
+  static AST_Decl::NodeType const NT;
+
 private:
   // Data.
 
