@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_structure.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_structure.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -81,12 +81,11 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "utl_scope.h"
 #include "ace/Unbounded_Queue.h"
 
-class TAO_IDL_FE_Export AST_Structure : public virtual AST_ConcreteType,
-                                        public virtual UTL_Scope
+class TAO_IDL_FE_Export AST_Structure
+  : public virtual AST_ConcreteType,
+    public virtual UTL_Scope
 {
 public:
-  AST_Structure (void);
-
   AST_Structure (UTL_ScopedName *n,
                  bool local,
                  bool abstract);
@@ -113,11 +112,11 @@ public:
   virtual int member_count (void);
   // Return the count of members.
 
-  virtual size_t nfields (void) const;
+  virtual ACE_CDR::ULong nfields (void) const;
   // Return the count of actual fields.
 
   virtual int field (AST_Field **&result,
-                     size_t slot) const;
+                     ACE_CDR::ULong slot) const;
   // Get an individual field node.
 
   virtual bool is_local (void);
@@ -151,6 +150,11 @@ public:
 
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
+  
+  // Accessor for the member.
+  ACE_Unbounded_Queue<AST_Field *> &fields (void);
+
+  static AST_Decl::NodeType const NT;
 
 protected:
   friend int tao_yyparse (void);
