@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_structure_fwd.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_structure_fwd.h 89076 2010-02-18 22:54:36Z parsons $
 
 #ifndef _AST_STRUCTURE_FWD_AST_STRUCTURE_FWD_HH
 #define _AST_STRUCTURE_FWD_AST_STRUCTURE_FWD_HH
@@ -13,8 +13,6 @@ class AST_Structure;
 class TAO_IDL_FE_Export AST_StructureFwd : public virtual AST_Type
 {
 public:
-  AST_StructureFwd (void);
-
   AST_StructureFwd (AST_Structure *full_defn,
                     UTL_ScopedName *n);
 
@@ -39,6 +37,8 @@ public:
   // Visiting.
   virtual int ast_accept (ast_visitor *visitor);
 
+  static AST_Decl::NodeType const NT;
+
 private:
   AST_Structure *pd_full_definition;
   // The structure this is a forward declaration of.
