@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_type.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_type.h 89076 2010-02-18 22:54:36Z parsons $
 /*
 
 COPYRIGHT
@@ -88,10 +88,6 @@ public:
   // Indicates if we are fixed size or variable. Most useful for structs,
   // unions, and arrays.
 
-  // Operations.
-
-  AST_Type (void);
-
   AST_Type (AST_Decl::NodeType nt,
             UTL_ScopedName *n);
 
