@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: ast_valuebox.h 78883 2007-07-13 17:55:30Z ossama $
+// $Id: ast_valuebox.h 89076 2010-02-18 22:54:36Z parsons $
 
 #ifndef _AST_VALUEBOX_AST_VALUEBOX_HH
 #define _AST_VALUEBOX_AST_VALUEBOX_HH
@@ -9,10 +9,6 @@
 class TAO_IDL_FE_Export AST_ValueBox :  public virtual AST_ConcreteType
 {
 public:
-
-  // Constructor(s) and destructor.
-  AST_ValueBox (void);
-
   AST_ValueBox (UTL_ScopedName *n,
                 AST_Type       *boxed_type);
   
@@ -22,7 +18,6 @@ public:
   AST_Type            *boxed_type (void) const;
    
   // Narrowing.
-
   DEF_NARROW_FROM_DECL(AST_ValueBox);
 
   // AST Dumping.
@@ -34,6 +29,8 @@ public:
   // Cleanup.
   virtual void destroy (void);
 
+  static AST_Decl::NodeType const NT;
+
 protected:
   AST_Type                    *pd_boxed_type;
 };
