@@ -1,4 +1,4 @@
-// $Id: fe_extern.h 80525 2008-01-30 23:18:43Z parsons $
+// $Id: fe_extern.h 82288 2008-07-11 08:03:55Z vzykov $
 
 /*
 
@@ -69,11 +69,13 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "TAO_IDL_FE_Export.h"
 #include "ace/SString.h"
+#include "ace/Unbounded_Queue.h"
 
 // Declares all global functions for the FE
 
 TAO_IDL_FE_Export void FE_init (void);
 TAO_IDL_FE_Export void FE_populate (void);
+TAO_IDL_FE_Export void FE_extract_env_include_paths (ACE_Unbounded_Queue<ACE_CString> &list);
 TAO_IDL_FE_Export void FE_store_env_include_paths (void);
 TAO_IDL_FE_Export const char *FE_get_cpp_loc_from_env (void);
 TAO_IDL_FE_Export const char *FE_get_cpp_args_from_env (void);
@@ -82,7 +84,11 @@ TAO_IDL_FE_Export int
 FE_yyparse (void);
 
 TAO_IDL_FE_Export void
+#ifdef USE_MCPP_BUFFER_LEXING
+FE_set_yyin (char *);    // Set yyin
+#else
 FE_set_yyin (FILE *);    // Set yyin
+#endif /* USE_MCPP_BUFFER_LEXING */
 
 // Interface to constructors for objects need by the driver
 
