@@ -1,4 +1,4 @@
-// $Id: idl_global.h 80119 2007-11-28 10:50:05Z vzykov $
+// $Id: idl_global.h 89213 2010-02-24 21:09:37Z parsons $
 
 /*
 
@@ -76,10 +76,13 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "ast_expression.h"
 #include "ast_predefined_type.h"
-#include "ast_component.h"
 #include "utl_stack.h"
+#include "fe_utils.h"
 
 class AST_Root;
+class AST_ValueType;
+class AST_Component;
+class AST_Uses;
 class AST_Generator;
 class UTL_Error;
 class UTL_String;
@@ -110,15 +113,21 @@ public:
     , PS_ComponentDeclSeen      // Seen complete component declaration
     , PS_HomeDeclSeen           // Seen complete home declaration
     , PS_EventDeclSeen          // Seen complete eventtype declartion
+    , PS_PorttypeDeclSeen       // Seen complete porttype declaration
+    , PS_ConnectorDeclSeen      // Seen complete connector declaration
     , PS_AttrDeclSeen           // Seen complete attribute declaration
     , PS_OpDeclSeen             // Seen complete operation declaration
     , PS_ProvidesDeclSeen       // Seen complete privides declaration
+    , PS_ExtProvidesDeclSeen    // Seen complete extended provides declaration
     , PS_UsesDeclSeen           // Seen complete uses declaration
+    , PS_ExtUsesDeclSeen        // Seen complete extended uses declaration
     , PS_EmitsDeclSeen          // Seen complete emits declaration
     , PS_PublishesDeclSeen      // Seen complete publishes declaration
     , PS_FactoryDeclSeen        // Seen complete factory declaration
     , PS_FinderDeclSeen         // Seen complete finder declaration
     , PS_ConsumesDeclSeen       // Seen complete subscribes declaration
+    , PS_ExtendedPortDeclSeen   // Seen extended port
+    , PS_MirrorPortDeclSeen     // Seen mirror port
     , PS_ModuleSeen             // Seen a MODULE keyword
     , PS_ModuleIDSeen           // Seen the module ID
     , PS_ModuleSqSeen           // '{' seen for module
@@ -136,6 +145,17 @@ public:
     , PS_InterfaceSqSeen        // '{' seen for interface
     , PS_InterfaceQsSeen        // '}' seen for interface
     , PS_InterfaceBodySeen      // Seen an interface body
+    , PS_TmplModuleIDSeen       // Seen the template module ID
+    , PS_TmplModuleParamsSeen   // Seen template module params
+    , PS_TmplModuleSqSeen       // '{' seen for template module
+    , PS_TmplModuleQsSeen       // '}' seen for template module
+    , PS_TmplModuleBodySeen     // Seen a template module body
+    , PS_InstModuleSeen         // Seen MODULE keyword + reference
+    , PS_InstModuleArgsSeen     // Seen template args
+    , PS_InstModuleIDSeen       // Seen instantiated module ID
+    , PS_ModuleRefSeen          // Seen ALIAS keyword + reference
+    , PS_ModuleRefParamsSeen    // Seen the subset of params used
+    , PS_ModuleRefIDSeen        // Seen referenced module ID
     , PS_ValueTypeSeen          // Seen a VALUETYPE keyword
     , PS_ValueTypeForwardSeen   // Forward valuetype decl seen
     , PS_ValueTypeIDSeen        // Seen the valuetype ID
@@ -159,6 +179,11 @@ public:
     , PS_HomeSqSeen             // '{' seen for home
     , PS_HomeQsSeen             // '}' seen for home
     , PS_HomeBodySeen           // Seen a home body
+    , PS_ConnectorSeen          // Seen an CONNECTOR keyword
+    , PS_ConnectorIDSeen        // Seen the connector ID
+    , PS_ConnectorSqSeen        // '{' seen for connector
+    , PS_ConnectorQsSeen        // '}' seen for connector
+    , PS_ConnectorBodySeen      // Seen a connector body
     , PS_SNListCommaSeen        // Seen ',' in list of scoped names
     , PS_ScopedNameSeen         // Seen a complete scoped name
     , PS_SN_IDSeen              // Seen an identifier as part of a scoped name
@@ -264,6 +289,11 @@ public:
     , PS_NativeSeen             // Seen a native declaration
     , PS_PragmaPrefixSyntax     // Could not parse the #pragma prefix
     , PS_ValueBoxDeclSeen       // Seen complete valuebox declaration
+    , PS_PorttypeSeen           // Seen PORTTYPE keyword
+    , PS_PorttypeIDSeen         // Seen porttype indentifier
+    , PS_PorttypeSqSeen         // Seen '{' for porttype
+    , PS_PorttypeQsSeen         // Seen '}' for porttype
+    , PS_PorttypeBodySeen       // Seen complete porttype body
   };
 
   // flags for types of declarations seen while parsing.
@@ -282,6 +312,8 @@ public:
   bool bd_string_arg_seen_;
   bool boolean_seq_seen_;
   bool char_seq_seen_;
+  bool component_seen_;
+  bool connector_seen_;
   bool double_seq_seen_;
   bool enum_seen_;
   bool exception_seen_;
@@ -526,7 +558,7 @@ public:
   void update_prefix (char *filename);
   // Do repo id prefix bookkeeping when the file changes.
 
-  UTL_ScopedName *string_to_scoped_name (char *s);
+  UTL_ScopedName *string_to_scoped_name (const char *s);
   // Parses a string with double colons.
 
   long seen_include_file_before (char *);
@@ -555,13 +587,30 @@ public:
   // keywords e.g. delete, operator etc. with _cxx_ prefix.
   // Is set by the IFR Service.
 
-  void add_include_path (const char *s);
-  // Add another path to 'include_paths_'.
-  
+  void add_include_path (const char *s, bool is_system);
+  // Add another path to 'include_paths_'. is_system is true for TAO/CIAO
+  // specific paths and false for paths provided by user.
+
   void add_rel_include_path (const char *s);
   ACE_Unbounded_Queue<char *> const & rel_include_paths (void) const;
   // Accessor/mutator for the rel_include_paths_ member.
-  
+
+  void add_ciao_lem_file_names (const char *s);
+  ACE_Unbounded_Queue<char *> & ciao_lem_file_names (void);
+  // Accessor/mutator for the ciao_lem_file_names_ member.
+
+  void add_ciao_rti_ts_file_names (const char *s);
+  ACE_Unbounded_Queue<char *> & ciao_rti_ts_file_names (void);
+  // Accessor/mutator for the ciao_rti_ts_file_names_ member.
+
+  void add_ciao_spl_ts_file_names (const char *s);
+  ACE_Unbounded_Queue<char *> & ciao_spl_ts_file_names (void);
+  // Accessor/mutator for the ciao_spl_ts_file_names_ member.
+
+  void add_ciao_oci_ts_file_names (const char *s);
+  ACE_Unbounded_Queue<char *> & ciao_oci_ts_file_names (void);
+  // Accessor/mutator for the ciao_oci_ts_file_names_ member.
+
   FILE * open_included_file (char const * filename,
                              char const *& directory);
   // Attempt to open file for reading until it is found in one of the
@@ -591,7 +640,8 @@ public:
   // Do final cleanup just before process exits.
 
   void create_uses_multiple_stuff (AST_Component *c,
-                                   AST_Component::port_description &pd);
+                                   AST_Uses *u,
+                                   const char *port_prefix = "");
   // We must do this in the front end since the executor
   // mapping IDL will have these data types.
 
@@ -613,10 +663,30 @@ public:
   const char *recursion_start (void) const;
   void recursion_start (const char *val);
   // Accessors for the member.
-  
+
+  bool multi_file_input (void) const;
+  void multi_file_input (bool val);
+  // Accessors for the member.
+
+  const char *big_file_name (void) const;
+  // Just get the const string.
+
+  FE_Utils::T_PARAMLIST_INFO const *current_params (void) const;
+  void current_params (FE_Utils::T_PARAMLIST_INFO *params);
+  // Accessors for the member. If UTL_Scope::lookup_by_name()
+  // has a 0 result, it will check this param list (if it is not
+  // 0, meaning we are in the scope of a template module) for a
+  // match before returning, in case it is processing a
+  // referenced template parameter of the eclosing template
+  // module.
+
   UTL_String *utl_string_factory (const char *str);
   // Utility function to create UTL_String classes on the FE heap.
 
+  ACE_CString check_for_seq_of_param (FE_Utils::T_PARAMLIST_INFO *list);
+  // Check if 'param' is a sequence of a previous param, and if
+  // so, if the previous param exists.
+
 #if defined (ACE_OPENVMS)
   static char* translateName(const char* name, char *name_buf);
 #endif
@@ -624,6 +694,14 @@ public:
   bool validate_orb_include (UTL_String *);
   // Check if included file is in TAO specific include dirs.
 
+  void original_local_name (Identifier *local_name);
+  // Strips _cxx_ prefix for use in port names.
+
+private:
+  bool check_one_seq_of_param (FE_Utils::T_PARAMLIST_INFO *list,
+                               ACE_CString &param_id,
+                               size_t index);
+
 private:
   // Data
   UTL_ScopeStack             pd_scopes;              // Store scopes stack
@@ -699,9 +777,16 @@ private:
   bool preserve_cpp_keywords_;
   // Do we allow C++ keywords as identifiers in the idl to stay as they are ?
 
-  ACE_Unbounded_Queue<char *> include_paths_;
+  struct Include_Path_Info {
+    char *path_;
+    bool is_system_;
+  };
+
+  typedef ACE_Unbounded_Queue<Include_Path_Info> Unbounded_Paths_Queue;
+  typedef ACE_Unbounded_Queue_Iterator<Include_Path_Info> Unbounded_Paths_Queue_Iterator;
+  Unbounded_Paths_Queue include_paths_;
   // List of -I options passed to us.
-  
+
   ACE_Unbounded_Queue<char *> rel_include_paths_;
   // Used by backends with the -r option.
 
@@ -720,7 +805,7 @@ private:
   DCPS_Type_Info_Map dcps_type_info_map_ ;
   // Map of #pragma DCPS_DATA_TYPE and DCPS_DATA_KEY infomation.
 
-  bool dcps_support_zero_copy_read_; 
+  bool dcps_support_zero_copy_read_;
   // Are we enabled to support DCPS zero-copy read.
   // Need this flag to avoid generating wrong code for pre v0.12 DDS
   // with new TAO_IDL compiler.
@@ -734,7 +819,28 @@ private:
   char *recursion_start_;
   // Path to directory subtree we are iterating/recursing over.
   // Not used by all backends.
+
+  bool multi_file_input_;
+  // Some backends process multiple files to a single output.
+
+  const char *big_file_name_;
+  // Used if the above flag is set.
+
+  FE_Utils::T_PARAMLIST_INFO *current_params_;
+  // Stored if we are parsing the scope of a template module,
+  // 0 otherwise.
+
+  ACE_Unbounded_Queue<char *> ciao_lem_file_names_;
+  // Files parsed with ciao lem pragma
+
+  ACE_Unbounded_Queue<char *> ciao_rti_ts_file_names_;
+  // Files parsed with RTI typesupport pragma
+
+  ACE_Unbounded_Queue<char *> ciao_spl_ts_file_names_;
+  // Files parsed with OpenSplice typesupport pragma
+
+  ACE_Unbounded_Queue<char *> ciao_oci_ts_file_names_;
+  // Files parsed with OpenDDS typesupport pragma
 };
 
-
 #endif  //_IDL_IDL_GLOBAL_HH
