@@ -1,4 +1,4 @@
-// $Id: utl_exceptlist.h 73110 2006-06-15 18:56:10Z parsons $
+// $Id: utl_exceptlist.h 88245 2009-12-18 19:03:19Z johnnyw $
 
 /*
 
@@ -69,7 +69,9 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "utl_list.h"
 
-class AST_Exception;
+// Member type is not AST_Exception, since it could also be a
+// param holder for a template parameter.
+class AST_Type;
 
 // NOTE: This list class only works correctly because we use single public
 //       inheritance, as opposed to multiple inheritance or public virtual.
@@ -80,11 +82,11 @@ class AST_Exception;
 class TAO_IDL_FE_Export UTL_ExceptList : public UTL_List
 {
 public:
-  UTL_ExceptList (AST_Exception *s, 
+  UTL_ExceptList (AST_Type *s, 
                   UTL_ExceptList *cdr);
 
   // Get list item.
-  AST_Exception *head (void);
+  AST_Type *head (void);
   
   // Cleanup.
   virtual void destroy (void);
@@ -95,7 +97,7 @@ public:
 
 private:
   // Data.
-  AST_Exception *pd_car_data;
+  AST_Type *pd_car_data;
 };
 
 // Active iterator for UTL_ExceptList.
@@ -106,7 +108,7 @@ public:
   UTL_ExceptlistActiveIterator (UTL_ExceptList *s);
 
   // Get current item
-  AST_Exception *item (void);
+  AST_Type *item (void);
 };
 
 #endif           // _UTL_EXCEPTLIST_UTL_EXCEPTLIST_HH
