@@ -1,4 +1,4 @@
-// $Id: utl_idlist.h 53265 2003-11-04 21:47:52Z dhinton $
+// $Id: utl_idlist.h 88245 2009-12-18 19:03:19Z johnnyw $
 
 /*
 
@@ -101,7 +101,7 @@ public:
   virtual void destroy (void);
   // Cleanup function.
 
-  UTL_List *copy (void);
+  virtual UTL_IdList *copy (void);
   // Copy the list.
 
   Identifier *head (void);
