@@ -1,4 +1,4 @@
-// $Id: utl_labellist.h 73110 2006-06-15 18:56:10Z parsons $
+// $Id: utl_labellist.h 88758 2010-01-28 07:57:56Z johnnyw $
 
 /*
 
@@ -88,6 +88,9 @@ public:
   // Get list item.
   AST_UnionLabel *head (void);
   
+  // Override of base class method.
+  virtual UTL_LabelList *copy (void);
+  
   // Cleanup.
   virtual void destroy (void);
 
@@ -96,7 +99,7 @@ private:
 };
 
 // Active iterator for UTL_LabelList.
-class   UTL_LabellistActiveIterator : public UTL_ListActiveIterator
+class UTL_LabellistActiveIterator : public UTL_ListActiveIterator
 {
 public:
   UTL_LabellistActiveIterator (UTL_LabelList *source);
