@@ -1,4 +1,4 @@
-// $Id: narrow.cpp 46434 2002-09-25 16:25:39Z parsons $
+// $Id: narrow.cpp 89028 2010-02-16 14:23:21Z parsons $
 
 /*
 
@@ -69,25 +69,27 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_valuetype.h"
 #include "ast_eventtype.h"
 #include "ast_component.h"
+#include "ast_porttype.h"
+#include "ast_connector.h"
 #include "ast_home.h"
 #include "ast_operation.h"
 #include "ast_factory.h"
+#include "ast_finder.h"
 #include "ast_exception.h"
 #include "ast_union.h"
 #include "ast_enum.h"
 #include "ast_interface_fwd.h"
 #include "utl_scope.h"
 
-ACE_RCSID (narrow, 
-           narrow, 
-           "$Id: narrow.cpp 46434 2002-09-25 16:25:39Z parsons $")
-
 // Narrowing functions for AST
 
 TAO_IDL_FE_Export AST_Decl *
 ScopeAsDecl (UTL_Scope *s)
 {
-  if (s == 0) return 0;
+  if (s == 0)
+    {
+      return 0;
+    }
 
   switch (s->scope_node_type ())
   {
@@ -103,12 +105,18 @@ ScopeAsDecl (UTL_Scope *s)
       return AST_EventType::narrow_from_scope (s);
     case AST_Decl::NT_component:
       return AST_Component::narrow_from_scope (s);
+    case AST_Decl::NT_porttype:
+      return AST_PortType::narrow_from_scope (s);
+    case AST_Decl::NT_connector:
+      return AST_Connector::narrow_from_scope (s);
     case AST_Decl::NT_home:
       return AST_Home::narrow_from_scope (s);
     case AST_Decl::NT_op:
       return AST_Operation::narrow_from_scope (s);
     case AST_Decl::NT_factory:
       return AST_Factory::narrow_from_scope (s);
+    case AST_Decl::NT_finder:
+      return AST_Finder::narrow_from_scope (s);
     case AST_Decl::NT_except:
       return AST_Exception::narrow_from_scope (s);
     case AST_Decl::NT_union:
@@ -128,46 +136,55 @@ ScopeAsDecl (UTL_Scope *s)
 TAO_IDL_FE_Export UTL_Scope *
 DeclAsScope (AST_Decl *d)
 {
-   if (d == 0) return 0;
+  if (d == 0)
+    {
+      return 0;
+    }
 
-   switch (d->node_type ())
-   {
-     case AST_Decl::NT_interface_fwd:
-        /*
-         * Resolve forward declared interface by looking at full_definition()
-         * field and iterating
-         */
-        d = (AST_InterfaceFwd::narrow_from_decl (d))->full_definition ();
-        /*
-         * Fall through
-         */
-     case AST_Decl::NT_interface:
-        return AST_Interface::narrow_from_decl (d);
-     case AST_Decl::NT_valuetype:
-        return AST_ValueType::narrow_from_decl (d);
-     case AST_Decl::NT_eventtype:
-        return AST_EventType::narrow_from_decl (d);
-     case AST_Decl::NT_component:
-        return AST_Component::narrow_from_decl (d);
-     case AST_Decl::NT_home:
-        return AST_Home::narrow_from_decl (d);
-     case AST_Decl::NT_module:
-        return AST_Module::narrow_from_decl (d);
-     case AST_Decl::NT_root:
-        return AST_Root::narrow_from_decl (d);
-     case AST_Decl::NT_except:
-        return AST_Exception::narrow_from_decl (d);
-     case AST_Decl::NT_union:
-        return AST_Union::narrow_from_decl (d);
-     case AST_Decl::NT_struct:
-        return AST_Structure::narrow_from_decl (d);
-     case AST_Decl::NT_enum:
-        return AST_Enum::narrow_from_decl (d);
-     case AST_Decl::NT_op:
-        return AST_Operation::narrow_from_decl (d);
-     case AST_Decl::NT_factory:
-        return AST_Factory::narrow_from_decl (d);
-     default:
-        return 0;
-   }
+  switch (d->node_type ())
+  {
+    case AST_Decl::NT_interface_fwd:
+      /*
+       * Resolve forward declared interface by looking at full_definition()
+       * field and iterating
+       */
+      d = (AST_InterfaceFwd::narrow_from_decl (d))->full_definition ();
+      /*
+       * Fall through
+       */
+    case AST_Decl::NT_interface:
+      return AST_Interface::narrow_from_decl (d);
+    case AST_Decl::NT_valuetype:
+      return AST_ValueType::narrow_from_decl (d);
+    case AST_Decl::NT_eventtype:
+      return AST_EventType::narrow_from_decl (d);
+    case AST_Decl::NT_component:
+      return AST_Component::narrow_from_decl (d);
+    case AST_Decl::NT_porttype:
+      return AST_PortType::narrow_from_decl (d);
+    case AST_Decl::NT_connector:
+      return AST_Connector::narrow_from_decl (d);
+    case AST_Decl::NT_home:
+      return AST_Home::narrow_from_decl (d);
+    case AST_Decl::NT_module:
+      return AST_Module::narrow_from_decl (d);
+    case AST_Decl::NT_root:
+      return AST_Root::narrow_from_decl (d);
+    case AST_Decl::NT_except:
+      return AST_Exception::narrow_from_decl (d);
+    case AST_Decl::NT_union:
+      return AST_Union::narrow_from_decl (d);
+    case AST_Decl::NT_struct:
+      return AST_Structure::narrow_from_decl (d);
+    case AST_Decl::NT_enum:
+      return AST_Enum::narrow_from_decl (d);
+    case AST_Decl::NT_op:
+      return AST_Operation::narrow_from_decl (d);
+    case AST_Decl::NT_factory:
+      return AST_Factory::narrow_from_decl (d);
+    case AST_Decl::NT_finder:
+      return AST_Finder::narrow_from_decl (d);
+    default:
+      return 0;
+  }
 }
