@@ -1,4 +1,4 @@
-// $Id: utl_decllist.cpp 76840 2007-02-01 18:23:37Z parsons $
+// $Id: utl_decllist.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 
 /*
 
@@ -77,10 +77,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "utl_decllist.h"
 #include "fe_declarator.h"
 
-ACE_RCSID (util,
-           utl_decllist,
-           "$Id: utl_decllist.cpp 76840 2007-02-01 18:23:37Z parsons $")
-
 /*
  * Constructor(s)
  */
