@@ -1,4 +1,4 @@
-// $Id: utl_err.cpp 80525 2008-01-30 23:18:43Z parsons $
+// $Id: utl_err.cpp 88959 2010-02-11 18:52:14Z johnnyw $
 
 /*
 
@@ -84,10 +84,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "ace/Log_Msg.h"
 
-ACE_RCSID (util,
-           utl_err,
-           "$Id: utl_err.cpp 80525 2008-01-30 23:18:43Z parsons $")
-
 // Convert an error code into a const char *
 static const char *
 error_string (UTL_Error::ErrorCode c)
@@ -129,7 +125,7 @@ error_string (UTL_Error::ErrorCode c)
     case UTL_Error::EIDL_LABEL_TYPE:
       return "label type incompatible with union discriminator type, ";
     case UTL_Error::EIDL_ILLEGAL_ADD:
-      return "forward declared type may be used only as a sequence element, ";
+      return "illegal use of incomplete type, ";
     case UTL_Error::EIDL_ILLEGAL_USE:
       return "illegal type used in expression, ";
     case UTL_Error::EIDL_ILLEGAL_RAISES:
@@ -165,6 +161,14 @@ error_string (UTL_Error::ErrorCode c)
       return "abstract type expected: ";
     case UTL_Error::EIDL_EVENTTYPE_EXPECTED:
       return "event type expected: ";
+    case UTL_Error::EIDL_TMPL_MODULE_EXPECTED:
+      return "template module expected: ";
+    case UTL_Error::EIDL_PORTTYPE_EXPECTED:
+      return "porttype expected: ";
+    case UTL_Error::EIDL_CONNECTOR_EXPECTED:
+      return "connector expected: ";
+    case UTL_Error::EIDL_TYPEDEF_EXPECTED:
+      return "typedef expected: ";
     case UTL_Error::EIDL_EVAL_ERROR:
       return "expression evaluation error: ";
     case UTL_Error::EIDL_INCOMPATIBLE_TYPE:
@@ -215,6 +219,14 @@ error_string (UTL_Error::ErrorCode c)
       return "valuetype not allowed as type of boxed value type";
     case UTL_Error::EIDL_ILLEGAL_PRIMARY_KEY:
       return "illegal primary key";
+    case UTL_Error::EIDL_MISMATCHED_T_PARAM:
+      return "mismatched template parameter";
+    case UTL_Error::EIDL_DUPLICATE_T_PARAM:
+      return "duplicate template parameter id";
+    case UTL_Error::EIDL_T_ARG_LENGTH:
+      return "wrong # of template args";
+    case UTL_Error::EIDL_MISMATCHED_SEQ_PARAM:
+      return "no match for identifier";
   }
 
   return 0;
@@ -227,7 +239,7 @@ idl_error_header (UTL_Error::ErrorCode c,
                   ACE_CString s)
 {
   ACE_ERROR ((LM_ERROR,
-              "%s: \"%s\", line %d: %s",
+              "%C: \"%C\", line %d: %C",
               idl_global->prog_name (),
               s.c_str (),
               lineno == -1 ? idl_global->lineno () : lineno,
@@ -306,6 +318,10 @@ parse_state_to_error_message (IDL_GlobalData::ParseState ps)
     return "Malformed home declaration";
   case IDL_GlobalData::PS_EventDeclSeen:
     return "Malformed event type declaration";
+  case IDL_GlobalData::PS_PorttypeDeclSeen:
+    return "Malformed port type declaration";
+  case IDL_GlobalData::PS_ConnectorDeclSeen:
+    return "Malformed connector declaration";
   case IDL_GlobalData::PS_ModuleDeclSeen:
     return "Malformed module declaration";
   case IDL_GlobalData::PS_AttrDeclSeen:
@@ -313,15 +329,23 @@ parse_state_to_error_message (IDL_GlobalData::ParseState ps)
   case IDL_GlobalData::PS_OpDeclSeen:
     return "Malformed operation declaration";
   case IDL_GlobalData::PS_ProvidesDeclSeen:
-    return "Malformed provides declaration";
+    return "Malformed simple provides declaration";
+  case IDL_GlobalData::PS_ExtProvidesDeclSeen:
+    return "Malformed extended provides declaration";
   case IDL_GlobalData::PS_UsesDeclSeen:
-    return "Malformed uses declaration";
+    return "Malformed simple uses declaration";
+  case IDL_GlobalData::PS_ExtUsesDeclSeen:
+    return "Malformed extended uses declaration";
   case IDL_GlobalData::PS_EmitsDeclSeen:
     return "Malformed emits declaration";
   case IDL_GlobalData::PS_PublishesDeclSeen:
     return "Malformed publishes declaration";
   case IDL_GlobalData::PS_ConsumesDeclSeen:
     return "Malformed consumes declaration";
+  case IDL_GlobalData::PS_ExtendedPortDeclSeen:
+    return "Malformed extended port declaration";
+  case IDL_GlobalData::PS_MirrorPortDeclSeen:
+    return "Malformed mirror port declaration";
   case IDL_GlobalData::PS_FactoryDeclSeen:
     return "Malformed factory declaration";
   case IDL_GlobalData::PS_FinderDeclSeen:
@@ -360,6 +384,28 @@ parse_state_to_error_message (IDL_GlobalData::ParseState ps)
     return "Illegal syntax following interface '}' closer";
   case IDL_GlobalData::PS_InterfaceBodySeen:
     return "Illegal syntax following interface body statement(s)";
+  case IDL_GlobalData::PS_TmplModuleIDSeen:
+    return "Illegal syntax following '<' in template module";
+  case IDL_GlobalData::PS_TmplModuleParamsSeen:
+    return "Illegal syntax following '>' in template module";
+  case IDL_GlobalData::PS_TmplModuleSqSeen:
+    return "Illegal syntax or missing type following '{' in template module";
+  case IDL_GlobalData::PS_TmplModuleQsSeen:
+    return "Illegal syntax or missing type following '}' in template module";
+  case IDL_GlobalData::PS_TmplModuleBodySeen:
+    return "Illegal syntax following template module body statement(s)";
+  case IDL_GlobalData::PS_InstModuleSeen:
+    return "Illegal syntax following following '<' of module instantiation";
+  case IDL_GlobalData::PS_InstModuleArgsSeen:
+    return "Illegal syntax following following template args";
+  case IDL_GlobalData::PS_InstModuleIDSeen:
+    return "Illegal syntax following following instantiated module identifier";
+  case IDL_GlobalData::PS_ModuleRefSeen:
+    return "Mising '<' or illegal syntax in template module alias";
+  case IDL_GlobalData::PS_ModuleRefParamsSeen:
+    return "Illegal syntax following module alias param names";
+  case IDL_GlobalData::PS_ModuleRefIDSeen:
+    return "Illegal syntax following module alias identifier";
   case IDL_GlobalData::PS_ValueTypeSeen:
     return "Missing interface identifier following VALUETYPE keyword";
   case IDL_GlobalData::PS_ValueTypeForwardSeen:
@@ -406,6 +452,16 @@ parse_state_to_error_message (IDL_GlobalData::ParseState ps)
     return "Illegal syntax following home '}' closer";
   case IDL_GlobalData::PS_HomeBodySeen:
     return "Illegal syntax following home body statement(s)";
+  case IDL_GlobalData::PS_ConnectorSeen:
+    return "Missing connector identifier following CONNECTOR keyword";
+  case IDL_GlobalData::PS_ConnectorIDSeen:
+    return "Missing '{' or illegal syntax following connector identifier";
+  case IDL_GlobalData::PS_ConnectorSqSeen:
+    return "Illegal syntax following connector '{' opener";
+  case IDL_GlobalData::PS_ConnectorQsSeen:
+    return "Illegal syntax following connector '}' closer";
+  case IDL_GlobalData::PS_ConnectorBodySeen:
+    return "Illegal syntax following connector body statement(s)";
   case IDL_GlobalData::PS_StructForwardSeen:
     return "Missing ';' following forward struct declaration";
   case IDL_GlobalData::PS_UnionForwardSeen:
@@ -613,6 +669,16 @@ parse_state_to_error_message (IDL_GlobalData::ParseState ps)
     return "Illegal syntax for #pragma prefix";
   case IDL_GlobalData::PS_ValueBoxDeclSeen:
     return "Missing boxed valuetype identifier following VALUETYPE keyword";
+  case IDL_GlobalData::PS_PorttypeSeen:
+    return "Illegal syntax or missing identifier after PORTTYPE keyword";
+  case IDL_GlobalData::PS_PorttypeIDSeen:
+    return "Illegal syntax or missing '{' after porttype identifier";
+  case IDL_GlobalData::PS_PorttypeSqSeen:
+    return "Illegal syntax after porttype '{' opener";
+  case IDL_GlobalData::PS_PorttypeQsSeen:
+    return "Illegal syntax after porttype '}' closer";
+  case IDL_GlobalData::PS_PorttypeBodySeen:
+    return "Illegal syntax after porttype body statement(s)";
   default:
     return "Some syntax error";
   }
@@ -629,7 +695,7 @@ UTL_Error::syntax_error (IDL_GlobalData::ParseState ps)
                     idl_global->lineno (),
                     idl_global->filename ()->get_string ());
   ACE_ERROR ((LM_ERROR,
-              "%s\n",
+              "%C\n",
               parse_state_to_error_message (ps)));
 
   // Better to bail here than to increment the error count and
@@ -656,6 +722,7 @@ UTL_Error::error1 (UTL_Error::ErrorCode c,
   idl_error_header (c,
                     idl_global->lineno (),
                     idl_global->filename ()->get_string ());
+  ACE_ERROR ((LM_ERROR, " - "));
   d->name ()->dump (*ACE_DEFAULT_LOG_STREAM);;
   ACE_ERROR ((LM_ERROR,
               "\n"));
@@ -780,7 +847,7 @@ UTL_Error::coercion_error (AST_Expression *v,
                     v->file_name ()->get_string ());
   v->dump (*ACE_DEFAULT_LOG_STREAM);
   ACE_ERROR ((LM_ERROR,
-              " to %s\n",
+              " to %C\n",
               exprtype_to_string (t)));
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
@@ -806,7 +873,7 @@ UTL_Error::version_number_error (char *n)
                     idl_global->lineno (),
                     idl_global->filename ()->get_string ());
   ACE_ERROR ((LM_ERROR,
-              "%s\n",
+              "%C\n",
               n));
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
@@ -818,7 +885,7 @@ UTL_Error::version_syntax_error (const char *msg)
                     idl_global->lineno (),
                     idl_global->filename ()->get_string ());
   ACE_ERROR ((LM_ERROR,
-              "%s\n",
+              "%C\n",
               msg));
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
@@ -1061,6 +1128,18 @@ UTL_Error::interface_expected (AST_Decl *d)
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
 
+void
+UTL_Error::template_module_expected (AST_Decl *d)
+{
+  idl_error_header (EIDL_TMPL_MODULE_EXPECTED,
+                    idl_global->lineno (),
+                    idl_global->filename ()->get_string ());
+  d->name ()->dump (*ACE_DEFAULT_LOG_STREAM);
+  ACE_ERROR ((LM_ERROR,
+              "\n"));
+  idl_global->set_err_count (idl_global->err_count () + 1);
+}
+
 // Report a situation where an value type was expected but we got
 // something else instead. This most likely is a case in a primary
 // key, emits, publishes or consumes declaration.
@@ -1152,7 +1231,7 @@ UTL_Error::enum_val_expected (AST_Union *u,
                     u->line (),
                     u->file_name ());
   ACE_ERROR ((LM_ERROR,
-              " union %s, ",
+              " union %C, ",
               u->local_name ()->get_string ()));
   l->dump (*ACE_DEFAULT_LOG_STREAM);
   ACE_ERROR ((LM_ERROR,
@@ -1174,7 +1253,7 @@ UTL_Error::enum_val_lookup_failure (AST_Union *u,
                     u->line (),
                     u->file_name ());
   ACE_ERROR ((LM_ERROR,
-              " union %s,  enum %s,  enumerator ",
+              " union %C,  enum %C,  enumerator ",
               u->local_name ()->get_string (),
               e->local_name ()->get_string ()));
   n->dump (*ACE_DEFAULT_LOG_STREAM);
@@ -1185,8 +1264,7 @@ UTL_Error::enum_val_lookup_failure (AST_Union *u,
 
 // Report clash between declared and referenced indentifiers.
 void
-UTL_Error::redef_error (char *b,
-                        char *n)
+UTL_Error::redef_error (const char *b, const char *n)
 {
   idl_error_header (EIDL_REDEF,
                     idl_global->lineno (),
@@ -1200,14 +1278,13 @@ UTL_Error::redef_error (char *b,
 
 // Report two or more spellings for an identifier.
 void
-UTL_Error::name_case_error (char *b,
-                            char *n)
+UTL_Error::name_case_error (char *b, char *n)
 {
   idl_error_header (EIDL_NAME_CASE_ERROR,
                     idl_global->lineno (),
                     idl_global->filename ()->get_string ());
   ACE_ERROR ((LM_ERROR,
-              "\"%s\" and \"%s\"\n",
+              "\"%C\" and \"%C\"\n",
               b,
               n));
   idl_global->set_err_count (idl_global->err_count () + 1);
@@ -1223,7 +1300,7 @@ UTL_Error::name_case_warning (char *b,
                         idl_global->lineno (),
                         idl_global->filename ()->get_string ());
       ACE_ERROR ((LM_ERROR,
-                  "\"%s\" and \"%s\"\n",
+                  "\"%C\" and \"%C\"\n",
                   b,
                   n));
     }
@@ -1236,7 +1313,7 @@ UTL_Error::idl_keyword_error (char *n)
                     idl_global->lineno (),
                     idl_global->filename ()->get_string ());
   ACE_ERROR ((LM_ERROR,
-              "\"%s\"\n",
+              "\"%C\"\n",
               n));
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
@@ -1250,7 +1327,7 @@ UTL_Error::idl_keyword_warning (char *n)
                         idl_global->lineno (),
                         idl_global->filename ()->get_string ());
       ACE_ERROR ((LM_ERROR,
-                  "\"%s\"\n",
+                  "\"%C\"\n",
                   n));
     }
 }
@@ -1265,27 +1342,25 @@ UTL_Error::ambiguous (UTL_Scope *s,
                     d->line (),
                     d->file_name ());
   ACE_ERROR ((LM_ERROR,
-              " scope: %s,  collision: ",
+              " scope: %C,  collision: ",
               (ScopeAsDecl (s))->local_name ()->get_string ()));
-  d->name ()->dump (*ACE_DEFAULT_LOG_STREAM);;
+  d->name ()->dump (*ACE_DEFAULT_LOG_STREAM);
   ACE_ERROR ((LM_ERROR,
               " vs. "));
-  l->name ()->dump (*ACE_DEFAULT_LOG_STREAM);;
+  l->name ()->dump (*ACE_DEFAULT_LOG_STREAM);
   ACE_ERROR ((LM_ERROR,
               "\n"));
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
 
-// Report a forward declared interface which was never defined.
+// Report a forward declared struct or union which was never defined.
 void
 UTL_Error::fwd_decl_not_defined (AST_Type *d)
 {
   idl_error_header (EIDL_DECL_NOT_DEFINED,
                     d->line (),
                     d->file_name ());
-  ACE_ERROR ((LM_ERROR,
-              "interface "));
-  d->local_name ()->dump (*ACE_DEFAULT_LOG_STREAM);
+  d->name ()->dump (*ACE_DEFAULT_LOG_STREAM);
   ACE_ERROR ((LM_ERROR,
               "\n"));
   idl_global->set_err_count (idl_global->err_count () + 1);
@@ -1414,3 +1489,35 @@ UTL_Error::illegal_primary_key (AST_Decl *d)
   idl_global->set_err_count (idl_global->err_count () + 1);
 }
 
+void
+UTL_Error::duplicate_param_id (UTL_ScopedName *n)
+{
+  idl_error_header (EIDL_DUPLICATE_T_PARAM,
+                    idl_global->lineno (),
+                    idl_global->filename ()->get_string ());
+  ACE_ERROR ((LM_ERROR, " - "));
+  n->dump (*ACE_DEFAULT_LOG_STREAM);
+  ACE_ERROR ((LM_ERROR, "\n"));
+  idl_global->set_err_count (idl_global->err_count () + 1);
+}
+
+void
+UTL_Error::mismatched_template_param (const char *name)
+{
+  idl_error_header (EIDL_MISMATCHED_T_PARAM,
+                    idl_global->lineno (),
+                    idl_global->filename ()->get_string ());
+  ACE_ERROR ((LM_ERROR, " - %s\n", name));
+  idl_global->set_err_count (idl_global->err_count () + 1);
+}
+
+void
+UTL_Error::mismatch_seq_of_param (const char *param_id)
+{
+  idl_error_header (EIDL_MISMATCHED_SEQ_PARAM,
+                    idl_global->lineno (),
+                    idl_global->filename ()->get_string ());
+  ACE_ERROR ((LM_ERROR, " - %s\n", param_id));
+  idl_global->set_err_count (idl_global->err_count () + 1);
+}
+
