@@ -1,4 +1,4 @@
-// $Id: utl_global.cpp 80525 2008-01-30 23:18:43Z parsons $
+// $Id: utl_global.cpp 89213 2010-02-24 21:09:37Z parsons $
 
 /*
 
@@ -71,11 +71,14 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ast_structure.h"
 #include "ast_sequence.h"
 #include "ast_valuetype.h"
+#include "ast_component.h"
+#include "ast_uses.h"
 #include "utl_identifier.h"
 #include "utl_indenter.h"
 #include "utl_err.h"
 #include "utl_string.h"
 #include "fe_extern.h"
+#include "fe_private.h"
 #include "nr_extern.h"
 #include "ace/OS_NS_stdio.h"
 #include "ace/OS_NS_unistd.h"
@@ -84,10 +87,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "ace/OS_NS_ctype.h"
 #include "ace/Env_Value_T.h"
 
-ACE_RCSID (util,
-           utl_global,
-           "$Id: utl_global.cpp 80525 2008-01-30 23:18:43Z parsons $")
-
 // Define an increment for the size of the array used to store names of
 // included files.
 #undef INCREMENT
@@ -149,7 +148,10 @@ IDL_GlobalData::IDL_GlobalData (void)
     ignore_idl3_ (false),
     dcps_support_zero_copy_read_ (false),
     dcps_gen_zero_copy_read_ (false),
-    recursion_start_ (0)  // Not used by all backends.
+    recursion_start_ (0),
+    multi_file_input_ (false),
+    big_file_name_ ("PICML_IDL_file_bag"),
+    current_params_ (0)
 {
   // Path for the perfect hash generator(gperf) program.
   // Default is $ACE_ROOT/bin/gperf unless ACE_GPERF is defined.
@@ -188,17 +190,17 @@ IDL_GlobalData::IDL_GlobalData (void)
                      + ACE_OS::strlen (ace_gperf)
                      + 1]);
       ACE_OS::sprintf (this->gperf_path_,
-                       "%s" ACE_DIRECTORY_SEPARATOR_STR "bin" ACE_DIRECTORY_SEPARATOR_STR "%s",
+                       "%s" ACE_DIRECTORY_SEPARATOR_STR_A "bin" ACE_DIRECTORY_SEPARATOR_STR_A "%s",
                        ace_root,
                        ace_gperf);
 #else /* Not ACE_GPERF */
       // Set it to the default value.
       ACE_NEW (this->gperf_path_,
                char [ACE_OS::strlen (ace_root)
-                     + ACE_OS::strlen ("/bin/gperf")
+                     + ACE_OS::strlen ("/bin/ace_gperf")
                      + 1]);
       ACE_OS::sprintf (this->gperf_path_,
-                       "%s" ACE_DIRECTORY_SEPARATOR_STR "bin" ACE_DIRECTORY_SEPARATOR_STR "gperf",
+                       "%s" ACE_DIRECTORY_SEPARATOR_STR_A "bin" ACE_DIRECTORY_SEPARATOR_STR_A "ace_gperf",
                        ace_root);
 #endif /* ACE_GPERF */
     }
@@ -233,6 +235,8 @@ IDL_GlobalData::reset_flag_seen (void)
   bd_string_arg_seen_ = false;
   boolean_seq_seen_ = false;
   char_seq_seen_ = false;
+  component_seen_ = false;
+  connector_seen_ = false;
   double_seq_seen_ = false;
   enum_seen_ = false;
   exception_seen_ = false;
@@ -714,136 +718,130 @@ void
 IDL_GlobalData::validate_included_idl_files (void)
 {
   // Flag to make sure we don't repeat things.
-  static int already_done = 0;
-
-  if (already_done == 1)
+  static bool already_done = false;
+  if (already_done)
     {
       return;
     }
-
-  already_done = 1;
+  already_done = true;
 
   // New number of included_idl_files.
   size_t newj = 0;
-  size_t n_found = 0;
   size_t n_pre_preproc_includes = idl_global->n_included_idl_files ();
   char **pre_preproc_includes = idl_global->included_idl_files ();
   size_t n_post_preproc_includes = idl_global->n_include_file_names ();
   UTL_String **post_preproc_includes = idl_global->include_file_names ();
 
-  char pre_abspath[MAXPATHLEN] = "";
-  char post_abspath[MAXPATHLEN] = "";
-  char **path_tmp = 0;
+  char pre_abspath [MAXPATHLEN] = "";
+  char post_abspath [MAXPATHLEN] = "";
+  Include_Path_Info *path_info = 0;
   char *post_tmp = 0;
   char *full_path = 0;
 
-  for (size_t j = 0; j < n_pre_preproc_includes; ++j)
+  // We are going to assemble a list of the include files found in
+  // the top level file in the order that they are found in the pre-
+  // processor output here
+  // @see bug TAO#711 / Bugzilla #3513 for more
+  char** ordered_include_files = new char* [n_pre_preproc_includes];
+  for (size_t i = 0u; i < n_post_preproc_includes; ++i)
     {
-      // Check this name with the names list that we got from the
-      // preprocessor.
-      size_t valid_file = 0;
-      full_path = ACE_OS::realpath (pre_preproc_includes[j],
-                                    pre_abspath);
-
-      if (full_path != 0)
+      post_tmp = post_preproc_includes [i]->get_string ();
+      full_path = ACE_OS::realpath (post_tmp, post_abspath);
+      if (full_path)
         {
-          for (size_t ni = 0; ni < n_post_preproc_includes; ++ni)
+          for (size_t j = 0u; j < n_pre_preproc_includes; ++j)
             {
-              post_tmp = post_preproc_includes[ni]->get_string ();
-              full_path = ACE_OS::realpath (post_tmp, post_abspath);
-              if (full_path != 0
-                  && this->path_cmp (pre_abspath, post_abspath) == 0
-                  && ACE_OS::access (post_abspath, R_OK) == 0)
+              // Check this name with the name that we got from the
+              // preprocessor.
+
+              bool valid_file = false;
+              full_path = ACE_OS::realpath (pre_preproc_includes [j],
+                                            pre_abspath);
+              if (full_path &&
+                  this->path_cmp (pre_abspath, post_abspath) == 0 &&
+                  ACE_OS::access (post_abspath, R_OK) == 0)
                 {
                   // This file name is valid.
-                  valid_file = 1;
-                  ++n_found;
-                  break;
+                  valid_file = true;
                 }
-            }
-        }
-
-      if (valid_file == 0)
-        {
-          for (ACE_Unbounded_Queue_Iterator<char *>iter (
-                   this->include_paths_
-                 );
-               !iter.done ();
-               iter.advance ())
-            {
-              iter.next (path_tmp);
-              ACE_CString pre_partial (*path_tmp);
-
-              // If the include path has literal "s (because of an include
-              // of a Windows path with spaces), we must remove them here.
-              if (this->hasspace (pre_partial.c_str ()))
+              else for (Unbounded_Paths_Queue_Iterator iter (this->include_paths_);
+                   !iter.done ();
+                   iter.advance ())
                 {
-                  pre_partial =
-                    pre_partial.substr (1, pre_partial.length () - 2);
-                }
+                  iter.next (path_info);
+                  ACE_CString pre_partial (path_info->path_);
 
-              pre_partial += ACE_DIRECTORY_SEPARATOR_STR;
-              pre_partial += pre_preproc_includes[j];
-              full_path =
-                ACE_OS::realpath (pre_partial.c_str (), pre_abspath);
-
-              if (full_path != 0)
-                {
-                  for (size_t m = 0; m < n_post_preproc_includes; ++m)
+                  // If the include path has literal "s (because of an include
+                  // of a Windows path with spaces), we must remove them here.
+                  if (pre_partial.c_str () &&
+                      2u < pre_partial.length () &&
+                      '"' == pre_partial [0] &&
+                      '"' == pre_partial [pre_partial.length () - 1u])
                     {
-                      post_tmp = post_preproc_includes[m]->get_string ();
-                      full_path = ACE_OS::realpath (post_tmp, post_abspath);
-
-                      if (full_path != 0
-                          && this->path_cmp (pre_abspath, post_abspath) == 0
-                          && ACE_OS::access (post_abspath, R_OK) == 0)
-                        {
-                          // This file name is valid.
-                          valid_file = 1;
-                          ++n_found;
-                          break;
-                        }
+                      pre_partial =
+                        pre_partial.substr (1, pre_partial.length () - 2u);
+                    }
+                  pre_partial += ACE_DIRECTORY_SEPARATOR_STR_A;
+                  pre_partial += pre_preproc_includes [j];
+                  full_path = ACE_OS::realpath (pre_partial.c_str (), pre_abspath);
+                  if (full_path &&
+                      this->path_cmp (pre_abspath, post_abspath) == 0 &&
+                      ACE_OS::access (post_abspath, R_OK) == 0)
+                    {
+                      // This file name is valid.
+                      valid_file = true;
+                      break;
                     }
                 }
 
-              if (valid_file == 1)
+              if (valid_file)
                 {
+                  // File is valid.
+                  // Move to the new index position.
+                  // ... in the ordered list
+                  ordered_include_files [newj] =
+                        pre_preproc_includes [j];
+
+                  // Increment the new index.
+                  ++newj;
+
+                  for (size_t k = j + 1; k < n_pre_preproc_includes; ++k)
+                    {
+                      // Shift remaining entries down
+                      pre_preproc_includes [k-1] = pre_preproc_includes [k];
+                    }
+
+                  // Reduce length and zero the discarded element
+                  pre_preproc_includes [--n_pre_preproc_includes] = 0;
+
+                  // Break out to next entry in pre-processor
+                  // output
                   break;
                 }
             }
-        }
 
-      // Remove the file, if it is not valid.
-      if (valid_file == 0)
-        {
-          delete [] pre_preproc_includes[j];
-          pre_preproc_includes[j] = 0;
-        }
-      else
-        {
-          // File is valid.
-
-          // Move it to new index if necessary.
-          if (j != newj)
+          if (n_pre_preproc_includes == 0)
             {
-              // Move to the new index position.
-              pre_preproc_includes[newj] =
-                pre_preproc_includes[j];
-
-              // Make old position 0.
-              pre_preproc_includes[j] = 0;
+              break;
             }
-
-          // Increment the new index.
-          newj++;
-        }
-
-      if (n_found == n_post_preproc_includes)
-        {
-          break;
         }
     }
 
+  // Tidy up not required includes
+  for (size_t l = 0u; l < n_pre_preproc_includes; ++l)
+    {
+      delete [] pre_preproc_includes [l];
+      pre_preproc_includes [l] = 0;
+    }
+
+  // Copy list back
+  for (size_t m = 0u; m < newj; ++m)
+    {
+      pre_preproc_includes [m] = ordered_include_files [m];
+    }
+
+  delete [] ordered_include_files;
+
   // Now adjust the count on the included_idl_files.
   idl_global->n_included_idl_files (newj);
 }
@@ -919,18 +917,29 @@ IDL_GlobalData::temp_dir (const char *s)
 {
   // Delete the old pointer.
   delete [] this->temp_dir_;
+  this->temp_dir_ = 0; // In case the ACE_NEW fails below.
+
+  const size_t lengthSep = sizeof (ACE_DIRECTORY_SEPARATOR_STR_A) - 1u;
+  const size_t lengthPath = ACE_OS::strlen (s);
 
   // Allocate memory, 1 for the end of string.
-  ACE_NEW (this->temp_dir_,
-           char [ACE_OS::strlen (s) +
-                ACE_OS::strlen (ACE_DIRECTORY_SEPARATOR_STR) +
-                1]);
+  ACE_NEW (this->temp_dir_, char [lengthPath + lengthSep + 1u]);
 
   // Copy the strings.
-  ACE_OS::sprintf (this->temp_dir_,
-                   "%s%s",
-                   s,
-                   ACE_DIRECTORY_SEPARATOR_STR);
+  if (lengthSep < lengthPath &&
+      0 == ACE_OS::strcmp (s + lengthPath - lengthSep, ACE_DIRECTORY_SEPARATOR_STR_A))
+    {
+      // Already has a directory seporator on end of temp root, don't add another.
+      ACE_OS::strcpy (this->temp_dir_, s);
+    }
+  else
+    {
+      // Need to add a directory seporator to temp root.
+      ACE_OS::sprintf (this->temp_dir_,
+                       "%s%s",
+                       s,
+                       ACE_DIRECTORY_SEPARATOR_STR_A);
+    }
 }
 
 const char *
@@ -1164,7 +1173,7 @@ IDL_GlobalData::update_prefix (char *filename)
           status =
             this->file_prefixes_.find (this->pd_filename->get_string (),
                                        prefix);
-          
+
           // This function is called just before we transition to a
           // new file at global scope. If there is a non-null prefix
           // stored in the table under our not-yet-changed filename,
@@ -1184,105 +1193,48 @@ IDL_GlobalData::update_prefix (char *filename)
 }
 
 UTL_ScopedName *
-IDL_GlobalData::string_to_scoped_name (char *s)
+IDL_GlobalData::string_to_scoped_name (const char *s)
 {
-  char *start = s;
-  int len = 0;
   UTL_ScopedName *retval = 0;
-  char tmp[256];
-
-  // If we're doing #pragma ID, the id string may have a ::
-  // while the target scoped name does not, so we check for
-  // a space.
-  char *test = ACE_OS::strchr (start, ' ');
-  char *end = ACE_OS::strstr (start, "::");
-
-  if (test != 0 && test - end < 0)
-    {
-      end = test;
-    }
-
-  while (end != 0)
-    {
-      len = end - start;
-
-      if (len != 0)
-        {
-          ACE_OS::strncpy (tmp,
-                           start,
-                           len);
-
-          tmp[len] = '\0';
-
-          Identifier *id = 0;
-          ACE_NEW_RETURN (id,
-                          Identifier (tmp),
-                          0);
-
-          if (retval == 0)
-            {
-              ACE_NEW_RETURN (retval,
-                              UTL_ScopedName (id,
-                                              0),
-                              0);
-            }
-          else
-            {
-              UTL_ScopedName *conc_name = 0;
-              ACE_NEW_RETURN (conc_name,
-                              UTL_ScopedName (id,
-                                              0),
-                              0);
-
-              retval->nconc (conc_name);
-            }
-        }
-
-      start = end + 2;
-      end = (end[0] == ' ' ? 0 : ACE_OS::strstr (start, "::"));
-
-      if (test != 0 && test - end < 0)
-        {
-          end = 0;
-        }
-    }
-
-  len = test - start;
-
-  // This means we've already dealt with the space between the target
-  // name and the id string (above) and we're done.
-  if (test == 0 || len <= 0)
-    {
-      return retval;
-    }
-
-  ACE_OS::strncpy (tmp,
-                   start,
-                   len);
-
-  tmp[len] = '\0';
-
+  ACE_CString str (s);
   Identifier *id = 0;
-  ACE_NEW_RETURN (id,
-                  Identifier (tmp),
-                  0);
+  UTL_ScopedName *sn = 0;
 
-  if (retval == 0)
+  while (! str.empty ())
     {
-      ACE_NEW_RETURN (retval,
-                      UTL_ScopedName (id,
-                                      0),
-                      0);
-    }
-  else
-    {
-      UTL_ScopedName *conc_name = 0;
-      ACE_NEW_RETURN (conc_name,
-                      UTL_ScopedName (id,
-                                      0),
+      // Skip a leading double colon.
+      if (str.find (':') == 0)
+        {
+          str = str.substr (2);
+        }
+
+      // Find the next double colon (if any) and get the next
+      // name segment.
+      ACE_CString::size_type pos = str.find (':');
+      ACE_CString lname (str.substr (0, pos));
+
+      // Construct a UTL_ScopedName segment.
+      ACE_NEW_RETURN (id,
+                      Identifier (lname.c_str ()),
                       0);
 
-      retval->nconc (conc_name);
+      ACE_NEW_RETURN (sn,
+                      UTL_ScopedName (id, 0),
+                      0);
+
+      // Either make it the head of a new list or the tail of
+      // an existing one.
+      if (retval == 0)
+        {
+          retval = sn;
+        }
+      else
+        {
+          retval->nconc (sn);
+        }
+
+      // Update the working string.
+      str = str.substr (pos);
     }
 
   return retval;
@@ -1328,9 +1280,10 @@ IDL_GlobalData::preserve_cpp_keywords (bool val)
 }
 
 void
-IDL_GlobalData::add_include_path (const char *s)
+IDL_GlobalData::add_include_path (const char *s, bool is_system)
 {
-  this->include_paths_.enqueue_tail (ACE::strnew (s));
+  Include_Path_Info info = { ACE::strnew (s), is_system };
+  this->include_paths_.enqueue_tail (info);
 }
 
 void
@@ -1345,6 +1298,54 @@ IDL_GlobalData::rel_include_paths (void) const
   return this->rel_include_paths_;
 }
 
+void
+IDL_GlobalData::add_ciao_lem_file_names (const char *s)
+{
+  this->ciao_lem_file_names_.enqueue_tail (ACE::strnew (s));
+}
+
+ACE_Unbounded_Queue<char *> &
+IDL_GlobalData::ciao_lem_file_names (void)
+{
+  return this->ciao_lem_file_names_;
+}
+
+void
+IDL_GlobalData::add_ciao_rti_ts_file_names (const char *s)
+{
+  this->ciao_rti_ts_file_names_.enqueue_tail (ACE::strnew (s));
+}
+
+ACE_Unbounded_Queue<char *> &
+IDL_GlobalData::ciao_rti_ts_file_names (void)
+{
+  return this->ciao_rti_ts_file_names_;
+}
+
+void
+IDL_GlobalData::add_ciao_spl_ts_file_names (const char *s)
+{
+  this->ciao_spl_ts_file_names_.enqueue_tail (ACE::strnew (s));
+}
+
+ACE_Unbounded_Queue<char *> &
+IDL_GlobalData::ciao_spl_ts_file_names (void)
+{
+  return this->ciao_spl_ts_file_names_;
+}
+
+void
+IDL_GlobalData::add_ciao_oci_ts_file_names (const char *s)
+{
+  this->ciao_oci_ts_file_names_.enqueue_tail (ACE::strnew (s));
+}
+
+ACE_Unbounded_Queue<char *> &
+IDL_GlobalData::ciao_oci_ts_file_names (void)
+{
+  return this->ciao_oci_ts_file_names_;
+}
+
 ACE_Hash_Map_Manager<char *, char *, ACE_Null_Mutex> &
 IDL_GlobalData::file_prefixes (void)
 {
@@ -1424,7 +1425,7 @@ IDL_GlobalData::check_gperf (void)
 #if defined (ACE_GPERF)
       idl_global->gperf_path (ACE_GPERF);
 #else
-      idl_global->gperf_path ("gperf");
+      idl_global->gperf_path ("ace_gperf");
 #endif /* ACE_GPERF */
     }
 
@@ -1437,7 +1438,7 @@ IDL_GlobalData::check_gperf (void)
 #if defined (ACE_GPERF)
   if (ACE_OS::strcmp (idl_global->gperf_path (), ACE_GPERF) != 0)
 #else
-  if (ACE_OS::strcmp (idl_global->gperf_path (), "gperf") != 0)
+  if (ACE_OS::strcmp (idl_global->gperf_path (), "ace_gperf") != 0)
 #endif /* ACE_GPERF */
     {
       // It is absolute path. Check the existance, permissions and
@@ -1452,7 +1453,7 @@ IDL_GlobalData::check_gperf (void)
 #if defined (ACE_GPERF)
           idl_global->gperf_path (ACE_GPERF);
 #else
-          idl_global->gperf_path ("gperf");
+          idl_global->gperf_path ("ace_gperf");
 #endif /* ACE_GPERF */
         }
     }
@@ -1464,9 +1465,7 @@ IDL_GlobalData::check_gperf (void)
   ACE_Process_Options process_options;
 
   // Set the command line for the gperf program.
-  process_options.command_line ("%s"
-                                " "
-                                "-V",
+  process_options.command_line (ACE_TEXT ("\"%s\" -V"),
                                 idl_global->gperf_path ());
 
   // Spawn a process for gperf.
@@ -1548,20 +1547,30 @@ IDL_GlobalData::fini (void)
   delete [] this->pd_include_file_names;
   this->pd_include_file_names = 0;
 
-  char **path_tmp = 0;
+  Include_Path_Info *path_info = 0;
 
-  for (ACE_Unbounded_Queue_Iterator<char *>qiter (
-            this->include_paths_
-          );
+  for (Unbounded_Paths_Queue_Iterator qiter (this->include_paths_);
        qiter.done () == 0;
        qiter.advance ())
     {
-      qiter.next (path_tmp);
+      qiter.next (path_info);
+      ACE::strdelete (path_info->path_);
+    }
+
+  char **path_tmp  = 0;
+
+  for (ACE_Unbounded_Queue_Iterator<char *>riter (
+            this->rel_include_paths_
+          );
+       riter.done () == 0;
+       riter.advance ())
+    {
+      riter.next (path_tmp);
       ACE::strdelete (*path_tmp);
     }
 
   for (ACE_Unbounded_Queue_Iterator<char *>riter (
-            this->rel_include_paths_
+            this->ciao_lem_file_names_
           );
        riter.done () == 0;
        riter.advance ())
@@ -1585,12 +1594,18 @@ IDL_GlobalData::fini (void)
 }
 
 void
-IDL_GlobalData::create_uses_multiple_stuff (
-    AST_Component *c,
-    AST_Component::port_description &pd
-  )
+IDL_GlobalData::create_uses_multiple_stuff (AST_Component *c,
+                                            AST_Uses *u,
+                                            const char *port_prefix)
 {
-  ACE_CString struct_name (pd.id->get_string ());
+  ACE_CString struct_name (port_prefix);
+
+  if (!struct_name.empty ())
+    {
+      struct_name += '_';
+    }
+
+  struct_name += u->local_name ()->get_string ();
   struct_name += "Connection";
   Identifier struct_id (struct_name.c_str ());
   UTL_ScopedName sn (&struct_id, 0);
@@ -1602,7 +1617,7 @@ IDL_GlobalData::create_uses_multiple_stuff (
   UTL_ScopedName object_name (&object_id,
                               0);
   AST_Field *object_field =
-    idl_global->gen ()->create_field (pd.impl,
+    idl_global->gen ()->create_field (u->uses_type (),
                                       &object_name,
                                       AST_Field::vis_NA);
   (void) DeclAsScope (connection)->fe_add_field (object_field);
@@ -1640,7 +1655,7 @@ IDL_GlobalData::create_uses_multiple_stuff (
 
   (void) c->fe_add_structure (connection);
 
-  idl_uns_long bound = 0;
+  ACE_CDR::ULong bound = 0;
   AST_Expression *bound_expr =
     idl_global->gen ()->create_expr (bound,
                                      AST_Expression::EV_ulong);
@@ -1651,8 +1666,8 @@ IDL_GlobalData::create_uses_multiple_stuff (
                                          0,
                                          0);
 
-  ACE_CString seq_string (pd.id->get_string ());
-  seq_string += "Connections";
+  ACE_CString seq_string (struct_name);
+  seq_string += 's';
   Identifier seq_id (seq_string.c_str ());
   UTL_ScopedName seq_name (&seq_id,
                            0);
@@ -1686,14 +1701,15 @@ IDL_GlobalData::path_cmp (const char *s, const char *t)
 bool
 IDL_GlobalData::hasspace (const char *s)
 {
-  size_t length = ACE_OS::strlen (s);
-
-  if (length > 2)
+  if (s)
     {
-      // We don't need to check the first or last slot.
-      for (size_t i = 1; i < length - 1; ++i)
+      const size_t length = ACE_OS::strlen (s);
+
+      // Windows can't have a space as the first or last character
+      // but a unix filename can. Need to check all characters.
+      for (size_t i = 0u; i < length; ++i)
         {
-          if (ACE_OS::ace_isspace (s[i]))
+          if (ACE_OS::ace_isspace (s [i]))
             {
               return true;
             }
@@ -1745,12 +1761,76 @@ IDL_GlobalData::recursion_start (const char *val)
   this->recursion_start_ = ACE::strnew (val);
 }
 
+bool
+IDL_GlobalData::multi_file_input (void) const
+{
+  return this->multi_file_input_;
+}
+
+void
+IDL_GlobalData::multi_file_input (bool val)
+{
+  this->multi_file_input_ = val;
+}
+
+const char *
+IDL_GlobalData::big_file_name (void) const
+{
+  return this->big_file_name_;
+}
+
+FE_Utils::T_PARAMLIST_INFO const *
+IDL_GlobalData::current_params (void) const
+{
+  return this->current_params_;
+}
+
+void
+IDL_GlobalData::current_params (FE_Utils::T_PARAMLIST_INFO *params)
+{
+  this->current_params_ = params;
+}
+
 UTL_String *
 IDL_GlobalData::utl_string_factory (const char *str)
 {
   return new UTL_String (str);
 }
 
+ACE_CString
+IDL_GlobalData::check_for_seq_of_param (FE_Utils::T_PARAMLIST_INFO *list)
+{
+  ACE_CString id, retval;
+  const char *pattern = "sequence<";
+  size_t len = ACE_OS::strlen (pattern);
+  size_t index = 0;
+
+
+  for (FE_Utils::T_PARAMLIST_INFO::CONST_ITERATOR i (*list);
+       !i.done ();
+       i.advance (), ++index)
+    {
+      FE_Utils::T_Param_Info *param = 0;
+      i.next (param);
+
+      if (param->name_.find (pattern) == 0)
+        {
+          // Get the substring of what's between the brackets.
+          // It will have to match a previous param in the list.
+          id = param->name_.substr (len,
+                                    param->name_.length () - (len + 1));
+
+          if (!this->check_one_seq_of_param (list, id, index))
+            {
+              retval = id;
+              break;
+            }
+        }
+    }
+
+  return retval;
+}
+
 void
 IDL_GlobalData::add_dcps_data_type (const char* id)
 {
@@ -1760,10 +1840,9 @@ IDL_GlobalData::add_dcps_data_type (const char* id)
     {
       // No existing entry, add one.
 
-      // trailing space required!!
       char* foo_type;
-      ACE_NEW (foo_type, char [ACE_OS::strlen (id) + 2]);
-      ACE_OS::sprintf (foo_type, "%s ", id);
+      ACE_NEW (foo_type, char [ACE_OS::strlen (id) + 1]);
+      ACE_OS::strcpy (foo_type, id);
 
       UTL_ScopedName* t1 = idl_global->string_to_scoped_name (foo_type);
       // chained with null Identifier required!!
@@ -1776,8 +1855,7 @@ IDL_GlobalData::add_dcps_data_type (const char* id)
       if (this->dcps_type_info_map_.bind( id, newinfo) != 0)
         {
           ACE_ERROR ((LM_ERROR,
-                      ACE_TEXT ("(%P|%t) Unable to insert type")
-                      ACE_TEXT (" into DCPS type container: %s.\n"),
+                      "(%P|%t) Unable to insert type into DCPS type container: %s.\n",
                       id));
           return;
         }
@@ -1785,7 +1863,7 @@ IDL_GlobalData::add_dcps_data_type (const char* id)
   else
     {
       ACE_ERROR ((LM_WARNING,
-                  ACE_TEXT ("(%P|%t) Duplicate DCPS type defined: %s.\n"),
+                  "(%P|%t) Duplicate DCPS type defined: %s.\n",
                   id));
     }
 
@@ -1800,13 +1878,13 @@ IDL_GlobalData::add_dcps_data_key (const char* id, const char* key)
   if (this->dcps_type_info_map_.find (id, newinfo) == 0)
     {
        // Add the new key field to the type.
-       newinfo->key_list_.enqueue_tail (key);
+       newinfo->key_list_.enqueue_tail (ACE_TEXT_CHAR_TO_TCHAR (key));
        return true;
     }
   else
     {
       ACE_ERROR((LM_ERROR,
-                 ACE_TEXT ("missing previous #pragma DCPS_DATA_TYPE\n")));
+                 "missing previous #pragma DCPS_DATA_TYPE\n"));
     }
 
   return false;
@@ -1840,23 +1918,23 @@ IDL_GlobalData::open_included_file (char const * filename,
   FILE * f = 0;
   ACE_CString const the_file (ACE_CString ('/')
                               + ACE_CString (filename));
-  
-  for (ACE_Unbounded_Queue_Iterator<char *> i (this->include_paths_);
+
+  for (Unbounded_Paths_Queue_Iterator i (this->include_paths_);
        !i.done () && f == 0;
        i.advance ())
     {
-      char ** path = 0;
-      (void) i.next (path);
+      Include_Path_Info *path_info = 0;
+      (void) i.next (path_info);
 
-      if (path != 0)
+      if (path_info->path_ != 0)
         {
-          ACE_CString const complete_filename (ACE_CString (*path)
+          ACE_CString const complete_filename (ACE_CString (path_info->path_)
                                                + the_file);
 
           f = ACE_OS::fopen (complete_filename.c_str (), "r");
 
           if (f != 0)
-            directory = *path;
+            directory = path_info->path_;
         }
     }
 
@@ -1880,7 +1958,7 @@ is_include_file_found (ACE_CString & inc_file,
         inc_file.substr (1, inc_file.length () - 2);
     }
 
-  inc_file += ACE_DIRECTORY_SEPARATOR_STR;
+  inc_file += ACE_DIRECTORY_SEPARATOR_STR_A;
   inc_file += idl_file_name->get_string ();
   full_path =
     ACE_OS::realpath (inc_file.c_str (), abspath);
@@ -1908,131 +1986,39 @@ is_include_file_found (ACE_CString & inc_file,
 bool
 IDL_GlobalData::validate_orb_include (UTL_String * idl_file_name)
 {
-  // It's important to update the check of include_counter when
-  // we decide which group is processed once new TAO include dirs
-  // are added somewhere in driver/drv_preproc.cpp
-
-  // Count number of includes in environment variable.
-  // If the way how INCLUDE environment variable is processed
-  // will change in fe/fe_init.cpp:FE_store_env_include_paths ()
-  // then the below do/while loop has to be changed accordingly.
-  unsigned int env_includes = 0;
-  ACE_Env_Value<char*> incl_paths ("INCLUDE",
-                                   (char *) 0);
-  const char *aggr_str = incl_paths;
-  if (aggr_str != 0)
-    {
-      char separator;
-#if defined (ACE_WIN32)
-      separator = ';';
-#else
-      separator = ':';
-#endif
-      do
-        {
-          aggr_str = ACE_OS::strchr (aggr_str, separator);
-          ++env_includes;
-        } while (aggr_str != 0 && aggr_str++);
-    }
-
-  // We try to search for idl_file_name in several folders in the
-  // following order.
-  //   1) Current folder (include_counter == 0). If idl_file_name is
-  //      found here then it's definitely not TAO specific. Return false.
-  //   2) Those includes that were extracted from INCLUDE environment
-  //      variable if one existed (include_counter >= 1 && include_counter
-  //      < env_includes + 1). If idl_file_name is found here then
-  //      we have to check if its complete path is not equal to any of
-  //      those in group 3 or 5.
-  //   3) $TAO_ROOT, $TAO_ROOT/tao
-  //      (include_counter >= env_includes + 1 && include_counter <
-  //      env_includes + 3). Return true if nothing was found in group
-  //      2 and idl_file_name is found here OR idl_file_name was found
-  //      in group 2 and path is the same as here.
-  //   4) User specific includes i.e. those that were provided with -I
-  //      option (include_counter >= env_includes + 3 && include_counter
-  //      < include_paths_.size () - 2). If idl_file_name is found here
-  //      then check for existence of the same path in group 5.
-  //   5) $TAO_ROOT/orbsvcs, $TAO_ROOT/CIAO, $TAO_ROOT/CIAO/ciao
-  //      (include_counter >= include_paths_.size () - 2 && include_counter
-  //      < include_paths_.size () + 1). Return true if nothing was found
-  //      in groups 2 or 4 and idl_file_name is found here OR idl_file_name
-  //      was found in groups 2 or 4 and path is the same as here.
-  // Return false if idl_file_name was found neither in groups 3 nor 5.
-
   char foundpath[MAXPATHLEN] = "";
-  unsigned int include_counter = 0;
 
-  for (ACE_Unbounded_Queue_Iterator<char *>iter (this->include_paths_);
-       !iter.done (); ++include_counter)
+  {
+    // Check in the current folder.
+    char abspath[MAXPATHLEN] = "";
+    ACE_CString cwd_path = ACE_OS::getcwd (abspath,
+                                           sizeof (abspath) / sizeof (char));
+    if (is_include_file_found (cwd_path, idl_file_name, this))
+      {
+        ACE_OS::strcpy (foundpath, cwd_path.c_str ());
+      }
+  }
+
+  for (Unbounded_Paths_Queue_Iterator iter (this->include_paths_);
+       !iter.done ();
+       iter.advance ())
     {
-      unsigned int inc_group = 0;
-      if (include_counter == 0)
-        {
-          inc_group = 1;
-        }
-      else if (include_counter >= 1 &&
-               include_counter < env_includes + 1)
-        {
-          inc_group = 2;
-        }
-      else if (include_counter >= env_includes + 1 &&
-               include_counter < env_includes + 3)
-        {
-          inc_group = 3;
-        }
-      else if (include_counter >= env_includes + 3 &&
-               include_counter < this->include_paths_.size () - 2)
-        {
-          inc_group = 4;
-        }
-      else if (include_counter >= this->include_paths_.size () - 2 &&
-               include_counter < this->include_paths_.size () + 1)
-        {
-          inc_group = 5;
-        }
+      Include_Path_Info *path_info = 0;
+      iter.next (path_info);
 
-      // We don't need to check anything in groups 2 and 4 if
-      // foundpath was already set and we only have to check
-      // whether it belongs to groups 3 or 5.
-      if (foundpath[0] != 0 && (inc_group == 2 || inc_group == 4))
+      ACE_CString partial = path_info->path_;
+
+      // We don't need to check anything if the file is already
+      // found and the folder where are currently checking is
+      // provided by user.
+      if (foundpath[0] != 0 && !path_info->is_system_)
         {
-          iter.advance ();
           continue;
         }
 
-      ACE_CString partial;
-      if (inc_group == 1)
-        {
-          char abspath[MAXPATHLEN] = "";
-          char *path_tmp = ACE_OS::getcwd (abspath, MAXPATHLEN);
-          partial = path_tmp;
-        }
-      else
-        {
-          char **path_tmp = 0;
-          iter.next (path_tmp);
-          iter.advance ();
-          partial = *path_tmp;
-        }
-
       if (is_include_file_found (partial, idl_file_name, this))
         {
-          // 1)
-          if (inc_group == 1)
-            {
-              return false;
-            }
-          // 2)
-          else if (inc_group == 2)
-            {
-              // We can fill in foundpath here since we are sure
-              // that it was not set before. Check above ensures that.
-              ACE_OS::strcpy (foundpath, partial.c_str ());
-              continue;
-            }
-          // 3)
-          else if (inc_group == 3)
+          if (path_info->is_system_)
             {
               if (foundpath[0] == 0 ||
                   ACE_OS::strcmp (foundpath, partial.c_str ()) == 0)
@@ -2040,25 +2026,72 @@ IDL_GlobalData::validate_orb_include (UTL_String * idl_file_name)
                   return true;
                 }
             }
-          // 4)
-          else if (inc_group == 4)
+          else
             {
               // We can fill in foundpath here since we are sure
               // that it was not set before. Check above ensures that.
               ACE_OS::strcpy (foundpath, partial.c_str ());
               continue;
             }
-          // 5)
-          else if (inc_group == 5)
-            {
-              if (foundpath[0] == 0 ||
-                  ACE_OS::strcmp (foundpath, partial.c_str ()) == 0)
-                {
-                  return true;
-                }
-            }
         }
     }
 
   return false;
 }
+
+void
+IDL_GlobalData::original_local_name (Identifier *local_name)
+{
+  const char *lname = local_name->get_string ();
+
+  // Remove _cxx_ if:
+  // 1. it occurs and
+  // 2. it occurs at the beginning of the string and
+  // 3. the rest of the string is a C++ keyword
+  if (ACE_OS::strstr (lname, "_cxx_") == lname)
+    {
+      TAO_IDL_CPP_Keyword_Table cpp_key_tbl;
+
+      unsigned int len =
+        static_cast<unsigned int> (ACE_OS::strlen (lname + 5));
+
+      const TAO_IDL_CPP_Keyword_Entry *entry =
+        cpp_key_tbl.lookup (lname + 5, len);
+
+      if (entry != 0)
+        {
+          ACE_CString tmp (lname + 5);
+          local_name->replace_string (tmp.c_str ());
+        }
+    }
+}
+
+bool
+IDL_GlobalData::check_one_seq_of_param (FE_Utils::T_PARAMLIST_INFO *list,
+                                        ACE_CString &param_id,
+                                        size_t index)
+{
+  size_t local_index = 0;
+
+  for (FE_Utils::T_PARAMLIST_INFO::CONST_ITERATOR i (*list);
+       !i.done ();
+       i.advance (), ++local_index)
+    {
+      if (local_index == index)
+        {
+          break;
+        }
+
+      FE_Utils::T_Param_Info *info = 0;
+      i.next (info);
+
+      if (info->name_ == param_id)
+        {
+          return true;
+        }
+    }
+
+  return false;
+}
+
+
