@@ -1,4 +1,4 @@
-// $Id: utl_namelist.cpp 73110 2006-06-15 18:56:10Z parsons $
+// $Id: utl_namelist.cpp 88566 2010-01-15 10:18:56Z johnnyw $
 
 /*
 
@@ -74,10 +74,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 
 #include "utl_namelist.h"
 
-ACE_RCSID (util,
-           utl_namelist,
-           "$Id: utl_namelist.cpp 73110 2006-06-15 18:56:10Z parsons $")
-
 UTL_NameList::UTL_NameList (UTL_ScopedName *s,
                             UTL_NameList *cdr)
   : UTL_List (cdr),
