@@ -1,4 +1,4 @@
-// $Id: utl_stack.cpp 73390 2006-07-03 13:05:13Z jwillemsen $
+// $Id: utl_stack.cpp 88827 2010-02-04 08:42:41Z johnnyw $
 
 /*
 
@@ -68,10 +68,6 @@ trademarks or registered trademarks of Sun Microsystems, Inc.
 #include "utl_scope.h"
 #include "global_extern.h"
 
-ACE_RCSID (util,
-           utl_stack,
-           "$Id: utl_stack.cpp 73390 2006-07-03 13:05:13Z jwillemsen $")
-
 #undef  INCREMENT
 #define  INCREMENT  64
 
