@@ -1,5 +1,5 @@
 //
-// Stock_i.cpp,v 1.1 1999/11/28 21:18:35 coryan Exp
+// $Id: Stock_i.cpp 77780 2007-03-23 12:09:30Z johnnyw $
 //
 
 #include "Stock_i.h"
@@ -14,19 +14,19 @@ Quoter_Stock_i::Quoter_Stock_i (const char *symbol,
 }
 
 char *
-Quoter_Stock_i::symbol () throw (CORBA::SystemException)
+Quoter_Stock_i::symbol ()
 {
   return CORBA::string_dup (this->symbol_.c_str ());
 }
 
 char *
-Quoter_Stock_i::full_name () throw (CORBA::SystemException)
+Quoter_Stock_i::full_name ()
 {
   return CORBA::string_dup (this->full_name_.c_str ());
 }
 
 CORBA::Double
-Quoter_Stock_i::price () throw (CORBA::SystemException)
+Quoter_Stock_i::price ()
 {
   return this->price_;
 }
@@ -34,7 +34,6 @@ Quoter_Stock_i::price () throw (CORBA::SystemException)
 CORBA::Double
 Quoter_Stock_i::get_price_and_names (CORBA::String_out symbol,
                                      CORBA::String_out full_name)
-    throw (CORBA::SystemException)
 {
   symbol = CORBA::string_dup (this->symbol_.c_str ());
   full_name = CORBA::string_dup (this->full_name_.c_str ());
