@@ -1,5 +1,5 @@
 //
-// Consumer_i.h,v 1.6 2004/08/18 00:35:31 jtc Exp
+// $Id: Consumer_i.h 76591 2007-01-25 18:17:52Z elliott_c $
 //
 
 #ifndef TAO_TUTORIALS_QUOTER_EVENT_SERVICE_CONSUMER_I_H
@@ -14,8 +14,8 @@ public:
 
   void connect (CosEventChanneAdmin::ConsumerAdmin_ptr consumer_admin);
 
-  void push (const CORBA::Any& data ACE_ENV_ARG_DECL_NOT_USED);
-  void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  void push (const CORBA::Any& data);
+  void disconnect_push_consumer (void);
 
 private:
 };
