@@ -1,5 +1,5 @@
 //
-// Stock_Consumer.h,v 1.7 2004/08/18 00:35:31 jtc Exp
+// $Id: Stock_Consumer.h 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #ifndef TAO_TUTORIALS_QUOTER_EVENT_SERVICE_STOCK_CONSUMER_H
@@ -18,10 +18,8 @@ public:
   void disconnect ();
   // Disconnect from the event channel.
 
-  void push (const CORBA::Any& data ACE_ENV_ARG_DECL_NOT_USED)
-    throw (CORBA::SystemException);
-  void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    throw (CORBA::SystemException);
+  void push (const CORBA::Any& data);
+  void disconnect_push_consumer (void);
 
 private:
   CosEventChannelAdmin::ProxyPushSupplier_var supplier_proxy_;
