@@ -1,5 +1,5 @@
 //
-// Stock_Factory_i.h,v 1.4 2004/08/18 00:35:31 jtc Exp
+// $Id: Stock_Factory_i.h 77780 2007-03-23 12:09:30Z johnnyw $
 //
 
 #ifndef TAO_TUTORIAL_QUOTER_EVENT_SERVICE_STOCK_FACTORY_I_H
@@ -17,8 +17,7 @@ public:
                            CosEventChannelAdmin::SupplierAdmin_ptr supplier_admin);
   void destroy_stock_objects ();
 
-  Quoter::Stock_ptr get_stock (const char *symbol)
-    throw (Quoter::Invalid_Stock_Symbol);
+  Quoter::Stock_ptr get_stock (const char *symbol);
 
 private:
   PortableServer::POA_var stock_factory_poa_;
