@@ -1,5 +1,5 @@
 //
-// Stock_i.cpp,v 1.3 2002/01/29 20:20:39 okellogg Exp
+// $Id: Stock_i.cpp 77780 2007-03-23 12:09:30Z johnnyw $
 //
 
 #include "Stock_i.h"
@@ -15,26 +15,25 @@ Quoter_Stock_i::Quoter_Stock_i (const char *symbol,
 }
 
 char *
-Quoter_Stock_i::symbol () throw (CORBA::SystemException)
+Quoter_Stock_i::symbol ()
 {
   return CORBA::string_dup (this->data_.symbol.in ());
 }
 
 char *
-Quoter_Stock_i::full_name () throw (CORBA::SystemException)
+Quoter_Stock_i::full_name ()
 {
   return CORBA::string_dup (this->data_.full_name.in ());
 }
 
 CORBA::Double
-Quoter_Stock_i::price () throw (CORBA::SystemException)
+Quoter_Stock_i::price ()
 {
   return this->data_.price;
 }
 
 void
 Quoter_Stock_i::set_price (CORBA::Double new_price)
-  throw (CORBA::SystemException)
 {
   this->data_.price = new_price;
   if (CORBA::is_nil (this->consumer_proxy_.in ()))
@@ -46,8 +45,7 @@ Quoter_Stock_i::set_price (CORBA::Double new_price)
 }
 
 void
-Quoter_Stock_i::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  throw (CORBA::SystemException)
+Quoter_Stock_i::disconnect_push_supplier (void)
 {
   // Forget about the consumer it is not there anymore
   this->consumer_proxy_ =
@@ -64,12 +62,3 @@ Quoter_Stock_i::connect (CosEventChannelAdmin::SupplierAdmin_ptr supplier_admin)
   this->consumer_proxy_->connect_push_supplier (supplier.in ());
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class POA_CosEventComm::PushSupplier_tie<Quoter_Stock_i>;
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate POA_CosEventComm::PushSupplier_tie<Quoter_Stock_i>
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
