@@ -1,5 +1,5 @@
 //
-// Stock_i.h,v 1.7 2005/07/04 09:27:28 jwillemsen Exp
+// $Id: Stock_i.h 77780 2007-03-23 12:09:30Z johnnyw $
 //
 
 #ifndef TAO_TUTORIAL_QUOTER_EVENT_SERVICE_STOCK_I_H
@@ -17,13 +17,12 @@ public:
                   const char *full_name,
                   CORBA::Double price);
 
-  char *symbol () throw (CORBA::SystemException);
-  char *full_name () throw (CORBA::SystemException);
-  CORBA::Double price () throw (CORBA::SystemException);
-  void set_price (CORBA::Double new_price) throw (CORBA::SystemException);
+  char *symbol ();
+  char *full_name ();
+  CORBA::Double price ();
+  void set_price (CORBA::Double new_price);
 
-  void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    throw (CORBA::SystemException);
+  void disconnect_push_supplier (void);
 
   void connect (CosEventChannelAdmin::SupplierAdmin_ptr supplier_admin);
 
