@@ -1,18 +1,17 @@
 //
-// $Id: client.cpp 59602 2004-08-18 00:35:32Z jtc $
+// $Id: client.cpp 82168 2008-06-25 11:50:02Z sma $
 //
 
 #include "Stock_Consumer.h"
 #include <orbsvcs/CosNamingC.h>
 #include "ace/streams.h"
 
-int main (int argc, char* argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR* argv[])
 {
   try {
     // First initialize the ORB, that will remove some arguments...
     CORBA::ORB_var orb =
-      CORBA::ORB_init (argc, argv,
-                       "" /* the ORB name, it can be anything! */);
+      CORBA::ORB_init (argc, argv);
     CORBA::Object_var poa_object =
       orb->resolve_initial_references ("RootPOA");
     PortableServer::POA_var poa =
