@@ -1,5 +1,5 @@
 //
-// Stock_i.h,v 1.4 2001/11/05 19:13:35 elliott_c Exp
+// $Id: Stock_i.h 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #ifndef TAO_TUTORIAL_QUOTER_SIMPLE_SERVER_STOCK_I_H
@@ -14,9 +14,9 @@ public:
                   const char *full_name,
                   CORBA::Double price);
 
-  char *symbol () throw (CORBA::SystemException);
-  char *full_name () throw (CORBA::SystemException);
-  CORBA::Double price () throw (CORBA::SystemException);
+  char *symbol ();
+  char *full_name ();
+  CORBA::Double price ();
 
 private:
 #if defined (HPUX) && (ACE_HAS_STANDARD_CPP_LIBRARY == 0)
