@@ -1,5 +1,5 @@
 //
-// Stock_Consumer.cpp,v 1.6 2003/07/23 18:21:59 dhinton Exp
+// $Id: Stock_Consumer.cpp 78603 2007-06-27 09:40:37Z johnnyw $
 //
 
 #include "Stock_Consumer.h"
@@ -33,9 +33,7 @@ Stock_Consumer::disconnect ()
 }
 
 void
-Stock_Consumer::push (const RtecEventComm::EventSet &data
-                      ACE_ENV_ARG_DECL_NOT_USED)
-  throw (CORBA::SystemException)
+Stock_Consumer::push (const RtecEventComm::EventSet &data)
 {
   for (CORBA::ULong i = 0; i != data.length (); ++i) {
     const RtecEventComm::Event &e = data[i];
@@ -52,8 +50,7 @@ Stock_Consumer::push (const RtecEventComm::EventSet &data
 }
 
 void
-Stock_Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    throw (CORBA::SystemException)
+Stock_Consumer::disconnect_push_consumer (void)
 {
   this->supplier_proxy_ =
     RtecEventChannelAdmin::ProxyPushSupplier::_nil ();
