@@ -1,5 +1,5 @@
 //
-// Stock_Factory_i.cpp,v 1.1 2001/03/07 00:48:55 doccvs Exp
+// $Id: Stock_Factory_i.cpp 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #include "Stock_Factory_i.h"
@@ -12,11 +12,10 @@ Quoter_Stock_Factory_i::Quoter_Stock_Factory_i ()
 
 Quoter::Stock_ptr
 Quoter_Stock_Factory_i::get_stock (const char *symbol)
-    throw (Quoter::Invalid_Stock_Symbol)
 {
-  if (strcmp (symbol, "RHAT") == 0) {
+  if (ACE_OS::strcmp (symbol, "RHAT") == 0) {
     return this->rhat_._this ();
-  } else if (strcmp (symbol, "MSFT") == 0) {
+  } else if (ACE_OS::strcmp (symbol, "MSFT") == 0) {
     return this->msft_._this ();
   }
   throw Quoter::Invalid_Stock_Symbol ();
