@@ -1,4 +1,4 @@
-// $Id: server.cpp 79621 2007-09-10 11:18:02Z sowayaa $
+// $Id: server.cpp 82148 2008-06-24 12:03:55Z sma $
 
 //===========================================================================
 //
@@ -18,7 +18,7 @@
 #include "tao/IORTable/IORTable.h"
 #include "ace/streams.h"
 
-int main (int argc, char* argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR* argv[])
 {
   try {
 
