@@ -1,5 +1,5 @@
 //
-// Stock_Factory_i.cpp,v 1.1 1999/11/29 01:03:00 coryan Exp
+// $Id: Stock_Factory_i.cpp 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #include "Stock_Factory_i.h"
@@ -11,7 +11,6 @@ Quoter_Stock_Factory_i::Quoter_Stock_Factory_i (PortableServer::POA_ptr poa)
 
 Quoter::Stock_ptr
 Quoter_Stock_Factory_i::get_stock (const char *symbol)
-    throw (Quoter::Invalid_Stock_Symbol)
 {
   PortableServer::ObjectId_var oid =
     PortableServer::string_to_ObjectId (symbol);
