@@ -1,5 +1,5 @@
 //
-// Stock_Factory_i.h,v 1.3 2005/03/11 11:54:34 jwillemsen Exp
+// $Id: Stock_Factory_i.h 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #ifndef TAO_TUTORIAL_QUOTER_SIMPLE_IMPROVEDSERVER_STOCK_FACTORY_I_H
@@ -16,8 +16,7 @@ class Quoter_Stock_Factory_i : public POA_Quoter::Stock_Factory {
 public:
   Quoter_Stock_Factory_i (PortableServer::POA_ptr stock_factory_poa);
 
-  Quoter::Stock_ptr get_stock (const char *symbol)
-    throw (Quoter::Invalid_Stock_Symbol);
+  Quoter::Stock_ptr get_stock (const char *symbol);
 
 private:
   PortableServer::POA_var stock_factory_poa_;
