@@ -1,18 +1,17 @@
 //
-// $Id: server.cpp 51221 2003-07-23 18:21:59Z dhinton $
+// $Id: server.cpp 82168 2008-06-25 11:50:02Z sma $
 //
 
 #include "Stock_Factory_i.h"
 #include "Stock_i.h"
 #include "ace/streams.h"
 
-int main (int argc, char* argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR* argv[])
 {
   try {
     // First initialize the ORB, that will remove some arguments...
     CORBA::ORB_var orb =
-      CORBA::ORB_init (argc, argv,
-                       "" /* the ORB name, it can be anything! */);
+      CORBA::ORB_init (argc, argv);
     CORBA::Object_var poa_object =
       orb->resolve_initial_references ("RootPOA");
     PortableServer::POA_var poa =
