@@ -1,4 +1,4 @@
-// $Id: server.cpp 51221 2003-07-23 18:21:59Z dhinton $
+// $Id: server.cpp 82148 2008-06-24 12:03:55Z sma $
 
 //===========================================================================
 //
@@ -18,7 +18,7 @@
 #include "Stock_Factory_i.h"
 #include "ace/streams.h"
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try {
 
