@@ -1,5 +1,5 @@
 //
-// Stock_Factory_i.h,v 1.1 1999/11/28 17:41:12 coryan Exp
+// $Id: Stock_Factory_i.h 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #ifndef TAO_TUTORIAL_QUOTER_SIMPLE_SERVER_STOCK_FACTORY_I_H
@@ -11,8 +11,7 @@ class Quoter_Stock_Factory_i : public POA_Quoter::Stock_Factory {
 public:
   Quoter_Stock_Factory_i ();
 
-  Quoter::Stock_ptr get_stock (const char *symbol)
-    throw (Quoter::Invalid_Stock_Symbol);
+  Quoter::Stock_ptr get_stock (const char *symbol);
 
 private:
   Quoter_Stock_i rhat_;
