@@ -4,7 +4,7 @@
 /**
  *  @file  AMH_Servant.h
  *
- *  $Id: AMH_Servant.h 77003 2007-02-12 09:23:36Z johnnyw $
+ *  $Id: AMH_Servant.h 82731 2008-09-16 11:10:20Z johnnyw $
  *
  *  @author Mayur Deshpande <mayur@ics.uci.edu>
  *
@@ -30,7 +30,7 @@ public:
   virtual ~AMH_Servant (void);
 
   /// parse arguments from command line for sleep time
-  virtual int parse_args (int& argc, char **argv);
+  virtual int parse_args (int &argc, ACE_TCHAR **argv);
 
   // = The skeleton methods
   virtual void start_test (Test::AMH_RoundtripResponseHandler_ptr _tao_rh);
