@@ -4,7 +4,7 @@
 /**
  *  @file  Client_Task.h
  *
- *  $Id: Client_Task.h 46793 2002-10-18 01:52:49Z mayur $
+ *  $Id: Client_Task.h 82946 2008-10-06 19:38:50Z johnnyw $
  *
  *  @desc  Provides common functionality needed to run a client
  *  thread. Also incorporates functionality to collect and print
@@ -30,13 +30,13 @@ class Client_Task : public ACE_Task_Base
 {
 public:
   /// Constructor
-  Client_Task (int &argc, char ** argv);
+  Client_Task (int &argc, ACE_TCHAR **argv);
 
   int parse_args (void);
 
   void try_RT_scheduling (void);
 
-  int narrow_servant (void);
+  int narrow_servant (CORBA::ORB_ptr orb);
 
   int run_test (void);
 
@@ -47,7 +47,7 @@ protected:
 private:
   /// Print Statistics
   void accumulate_and_dump (ACE_Basic_Stats &totals,
-                            const char *msg,
+                            const ACE_TCHAR *msg,
                             ACE_UINT32 gsf);
 
 private:
@@ -58,8 +58,8 @@ private:
   ACE_Basic_Stats latency_;
 
   int &argc_;
-  char **argv_;
-  const char *ior_;
+  ACE_TCHAR **argv_;
+  const ACE_TCHAR *ior_;
   int iterations_;
 };
 
