@@ -4,7 +4,7 @@
 /**
  *  @file  MT_AMH_Server.h
  *
- *  $Id: MT_AMH_Server.h 46793 2002-10-18 01:52:49Z mayur $
+ *  $Id: MT_AMH_Server.h 83898 2008-11-28 11:11:10Z johnnyw $
  *
  *  @desc  Provides Multi-threaded functionality to the Base_Server.
  *
@@ -26,20 +26,14 @@ class MT_AMH_Server
   , public ACE_Task_Base
 {
 public:
-  // @@ Mayur, have you considered passing in argc by reference
-  //    instead of as a pointer?  It would save you the indirection
-  //    code in below, and make the code cleaner.  This is what
-  //    ORB_init() does.  Not a big deal in any case.
-  //
-  // Mayur: Nice point. Done.
-  MT_AMH_Server (int& argc, char **argv);
+  MT_AMH_Server (int &argc, ACE_TCHAR **argv);
 
   ~MT_AMH_Server (void);
 
   // print usage text
   void usage (const char *message);
 
-  // We need to parse an extra thread_count paramter for
+  // We need to parse an extra thread_count parameter for
   // multi-threraded server.
   int parse_args (void);
 
