@@ -1,4 +1,4 @@
-// $Id: peer.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: peer.cpp 82837 2008-09-25 20:56:20Z johnnyw $
 
 #include "Peer_i.h"
 #include "ace/Get_Opt.h"
@@ -8,16 +8,16 @@
 
 ACE_RCSID (FL_Callback,
            peer,
-           "$Id: peer.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+           "$Id: peer.cpp 82837 2008-09-25 20:56:20Z johnnyw $")
 
-const char *ior = "file://progress.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://progress.ior");
 int nthreads = 4;
 int interval = 0; // microseconds
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:n:t:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:n:t:"));
   int c;
 
   while ((c = get_opts ()) != -1)
