@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 84781 2009-03-10 08:05:12Z johnnyw $
 
 // ============================================================================
 //
@@ -19,8 +19,7 @@
 //
 // ============================================================================
 
-#include <iostream>
-#include <fstream>
+#include <ace/streams.h>
 #include <strstream>
 #include "server.h"
 #include <algorithm>
@@ -46,7 +45,7 @@ resolve_init (CORBA::ORB_ptr orb, const char * id)
   catch (const CORBA::Exception & e) {
     std::cerr << "Cannot get initial reference for "
          << id << ": "
-         //<< e
+         << e
          << std::endl;
     throw 0;
   }
@@ -59,7 +58,7 @@ resolve_init (CORBA::ORB_ptr orb, const char * id)
   catch (const CORBA::Exception & e) {
     std::cerr << "Cannot narrow reference for "
          << id << ": "
-         //<< e
+         << e
          << std::endl;
     throw 0;
   }
@@ -761,7 +760,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     }
     catch (const CORBA::Exception & e) {
         std::cerr << "Uncaught CORBA exception: "
-                  //<< e
+                  << e
                   << std::endl;
         return 1;
     }
