@@ -1,4 +1,4 @@
-// $Id: server.h 78897 2007-07-15 01:45:47Z sowayaa $
+// $Id: server.h 84768 2009-03-09 11:21:45Z johnnyw $
 // ============================================================================
 //
 // = LIBRARY
@@ -28,7 +28,8 @@
 #include <map>
 #include <list>
 #include <assert.h>
-//#include <corba/poaS.h>
+#include "tao/PortableServer/PortableServer.h"
+#include "tao/PortableServer/ServantLocatorC.h"
 
 using namespace std;
 
