@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 84795 2009-03-11 07:20:28Z johnnyw $
 
 // ============================================================================
 //
@@ -18,8 +18,7 @@
 //
 // ============================================================================
 
-#include <iostream>
-#include <fstream>
+#include <ace/streams.h>
 #include <strstream>
 #include "server.h"
 #include <ace/Synch_T.h>
@@ -530,8 +529,8 @@ find (CCS::Controller::SearchSeq & slist)
         CCS::Controller::SearchCriterion sc = slist[i].key._d ();
         if (sc == CCS::Controller::ASSET) {
             // Search for matching asset number.
-                bool make = false;
-            CCS::AssetType num;
+            bool make = false;
+            CCS::AssetType num = 0;
                 {
                 ACE_Guard<ACE_Mutex> guard (m_assets_mutex);
                 where = m_assets.find (slist[i].key.asset_num ());
@@ -738,7 +737,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     }
     catch (const CORBA::Exception & e) {
         std::cerr << "Uncaught CORBA exception: "
-                  //<< e
+                  << e
                   << std::endl;
         return 1;
     }
