@@ -1,4 +1,4 @@
-// $Id: icp.h 56689 2004-03-31 23:57:50Z bala $
+// $Id: icp.h 84768 2009-03-09 11:21:45Z johnnyw $
 // ============================================================================
 //
 // = LIBRARY
@@ -17,11 +17,11 @@
 //
 // ============================================================================
 
-
-
 #ifndef _ICP_H
 #define _ICP_H
 
+#include "ace/OS.h"
+
 extern "C" {
     int ICP_online(unsigned long id);   // Add device
     int ICP_offline(unsigned long id);  // Remove device
@@ -38,6 +38,4 @@ extern "C" {
         );
 }
 
-size_t min(const size_t len1, const size_t len2);
-
 #endif /* _ICP_H */
