@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 84768 2009-03-09 11:21:45Z johnnyw $
 
 // ============================================================================
 //
@@ -445,7 +445,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     }
     catch (const CORBA::Exception & e) {
         std::cerr << "Uncaught CORBA exception: "
-                  //<< e
+                  << e
                   << std::endl;
         return 1;
     }
