@@ -1,4 +1,4 @@
-// $Id: server.h 78897 2007-07-15 01:45:47Z sowayaa $
+// $Id: server.h 84405 2009-02-11 14:54:53Z schmidt $
 // ============================================================================
 //
 // = LIBRARY
@@ -68,7 +68,7 @@ class Thermostat_impl :
 public:
     // CORBA operations
     virtual CCS::TempType get_nominal();
-    virtual CCS::TempType set_nominal(CCS::TempType new_temp));
+    virtual CCS::TempType set_nominal(CCS::TempType new_temp);
 
     // Constructor and destructor
     Thermostat_impl(
