@@ -1,4 +1,4 @@
-// $Id: ChatClientWnd.cpp 79593 2007-09-06 12:37:28Z johnnyw $
+// $Id: ChatClientWnd.cpp 82011 2008-06-17 13:58:27Z sma $
 //---------------------------------------------------------------------------
 #include "pch.h"
 #pragma hdrstop
@@ -23,7 +23,7 @@ __fastcall TChatClientWindow::TChatClientWindow (TComponent* Owner)
       ior_file_name_ = OpenDialog->FileName;
 
       // Retrieve the ORB.
-      orb_ = CORBA::ORB_init (_argc, _argv, 0);
+      orb_ = CORBA::ORB_init (_argc, _argv);
 
       // Get reference to the Root POA
       CORBA::Object_var obj =
