@@ -1,4 +1,4 @@
-// $Id: client.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: client.cpp 86507 2009-08-14 13:30:24Z johnnyw $
 
 // ================================================================
 //
@@ -22,10 +22,10 @@
 
 ACE_RCSID (Buffered_AMI,
            client,
-           "$Id: client.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+           "$Id: client.cpp 86507 2009-08-14 13:30:24Z johnnyw $")
 
 // Name of file contains ior.
-static const char *IOR = "file://ior";
+static const ACE_TCHAR *IOR = ACE_TEXT ("file://ior");
 
 // Default iterations.
 static CORBA::ULong iterations = 20;
@@ -95,9 +95,9 @@ public:
 };
 
 static int
-parse_args (int argc, char **argv)
+parse_args (int argc, ACE_TCHAR **argv)
 {
-  ACE_Get_Opt get_opts (argc, argv, "a:b:k:m:i:t:x");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("a:b:k:m:i:t:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -163,7 +163,7 @@ parse_args (int argc, char **argv)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
                          "<message_count> must be a multiple <iterations> "
-                         "or the program should be changed to flush explicitly \n"),
+                         "or the program should be changed to flush explicitly\n"),
                         -1);
     }
 
@@ -234,16 +234,14 @@ setup_buffering_constraints (CORBA::ORB_ptr orb)
 }
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
 
   try
     {
       // Initialize the ORB.
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         0);
+        CORBA::ORB_init (argc, argv);
 
       // Initialize options based on command-line arguments.
       int parse_args_result = parse_args (argc, argv);
