@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "ace/OS_NS_stdio.h"
@@ -6,14 +6,14 @@
 
 ACE_RCSID (Buffered_AMI,
            server,
-           "$Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+           "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")
 
-const char *ior_output_file = "ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -37,14 +37,12 @@ parse_args (int argc, char *argv[])
 }
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         "");
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var poa_object =
         orb->resolve_initial_references ("RootPOA");
@@ -66,7 +64,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::String_var ior =
         orb->object_to_string (server.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       FILE *output_file = ACE_OS::fopen (ior_output_file, "w");
       if (output_file == 0)
