@@ -1,4 +1,4 @@
-// $Id: client.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: client.cpp 86507 2009-08-14 13:30:24Z johnnyw $
 
 // ================================================================
 //
@@ -20,10 +20,10 @@
 #include "ace/Get_Opt.h"
 #include "ace/Read_Buffer.h"
 
-ACE_RCSID(Buffered_Oneways, client, "$Id: client.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Buffered_Oneways, client, "$Id: client.cpp 86507 2009-08-14 13:30:24Z johnnyw $")
 
 // Name of file contains ior.
-static const char *IOR = "file://ior";
+static const ACE_TCHAR *IOR = ACE_TEXT ("file://ior");
 
 // Default iterations.
 static CORBA::ULong iterations = 20;
@@ -48,9 +48,9 @@ static long interval = 1000;
 static int shutdown_server = 0;
 
 static int
-parse_args (int argc, char **argv)
+parse_args (int argc, ACE_TCHAR **argv)
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:f:c:b:i:z:t:x");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:f:c:b:i:z:t:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -114,16 +114,14 @@ parse_args (int argc, char **argv)
 }
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
 
   try
     {
       // Initialize the ORB.
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         0);
+        CORBA::ORB_init (argc, argv);
 
       // Initialize options based on command-line arguments.
       int parse_args_result = parse_args (argc, argv);
