@@ -1,4 +1,4 @@
-// $Id: ClientApp.h 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: ClientApp.h 82946 2008-10-06 19:38:50Z johnnyw $
 #ifndef CLIENTAPP_H
 #define CLIENTAPP_H
 
@@ -13,17 +13,17 @@ class ClientApp
     ClientApp();
     ~ClientApp();
 
-    int run(int argc, char* argv[]);
+    int run(int argc, ACE_TCHAR* argv[]);
 
 
   private:
 
-    int parse_args(int argc, char* argv[]);
+    int parse_args(int argc, ACE_TCHAR* argv[]);
     void usage_statement();
 
-    ACE_CString ior_;
+    ACE_TString ior_;
 
-    ACE_CString exe_name_;
+    ACE_TString exe_name_;
 };
 
 #endif
