@@ -1,9 +1,9 @@
-// $Id: Foo_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Foo_i.cpp 82946 2008-10-06 19:38:50Z johnnyw $
 #include "Foo_i.h"
 #include "FooServantList.h"
 #include "ace/OS.h"
 
-Foo_i::Foo_i(const char* servant_name,FooServantList* mgr)
+Foo_i::Foo_i(const ACE_TCHAR* servant_name,FooServantList* mgr)
   : value_(0),
     count_op1_(0),
     count_op2_(0),
@@ -67,7 +67,7 @@ Foo_i::op4(CORBA::Long value)
 void
 Foo_i::op5(void)
 {
-  ++this->count_op5_;;
+  ++this->count_op5_;
 }
 
 
