@@ -1,4 +1,4 @@
-// $Id: Foo_i.h 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Foo_i.h 82946 2008-10-06 19:38:50Z johnnyw $
 #ifndef FOO_I_H
 #define FOO_I_H
 
@@ -13,7 +13,7 @@ class Foo_i : public virtual POA_Foo
 {
   public:
 
-    Foo_i(const char* servant_name, FooServantList* mgr);
+    Foo_i(const ACE_TCHAR* servant_name, FooServantList* mgr);
     virtual ~Foo_i();
 
     virtual void op1(void);
@@ -39,7 +39,7 @@ class Foo_i : public virtual POA_Foo
     unsigned count_op4_;
     unsigned count_op5_;
 
-    ACE_CString     servant_name_;
+    ACE_TString     servant_name_;
     FooServantList* mgr_;
 };
 
