@@ -1,4 +1,4 @@
-// $Id: ServerApp.h 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: ServerApp.h 82946 2008-10-06 19:38:50Z johnnyw $
 #ifndef SERVERAPP_H
 #define SERVERAPP_H
 
@@ -14,16 +14,16 @@ class ServerApp
     ServerApp();
     ~ServerApp();
 
-    int run(int argc, char* argv[]);
+    int run(int argc, ACE_TCHAR* argv[]);
 
 
   private:
 
-    int parse_args(int argc, char* argv[]);
+    int parse_args(int argc, ACE_TCHAR* argv[]);
     void usage_statement();
 
-    ACE_CString exe_name_;
-    ACE_CString ior_filename_;
+    ACE_TString exe_name_;
+    ACE_TString ior_filename_;
     unsigned    num_clients_;
     unsigned    num_orb_threads_;
 };
