@@ -1,4 +1,4 @@
-// $Id: Consumer_Handler.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: Consumer_Handler.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 // ===========================================================
 //
@@ -62,7 +62,7 @@ Consumer_Handler::~Consumer_Handler (void)
 // Reads the Server factory IOR from a file.
 
 int
-Consumer_Handler::read_ior (char *filename)
+Consumer_Handler::read_ior (ACE_TCHAR *filename)
 {
   // Open the file for reading.
   ACE_HANDLE f_handle = ACE_OS::open (filename, 0);
@@ -81,7 +81,7 @@ Consumer_Handler::read_ior (char *filename)
                        "Unable to read ior: %p\n"),
                       -1);
 
-  this->ior_ = ACE_OS::strdup (data);
+  this->ior_ = ACE_OS::strdup (ACE_TEXT_CHAR_TO_TCHAR(data));
   ior_buffer.alloc ()->free (data);
 
   ACE_OS::close (f_handle);
@@ -94,7 +94,7 @@ Consumer_Handler::read_ior (char *filename)
 int
 Consumer_Handler::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "a:t:d:f:xk:xs");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("a:t:d:f:xk:xs"));
   int c;
   int result;
 
@@ -123,7 +123,7 @@ Consumer_Handler::parse_args (void)
         break;
 
       case 'a': // to be given only on using run_test.pl
-        this->stock_name_ = get_opts.opt_arg ();
+        this->stock_name_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
         this->interactive_ = 0;
         break;
 
@@ -167,7 +167,7 @@ Consumer_Handler::via_naming_service (void)
       if (naming_services_client_.init (orb_.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            " (%P|%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
 
       CosNaming::Name notifier_ref_name (1);
@@ -196,7 +196,7 @@ Consumer_Handler::via_naming_service (void)
 
 // Init function.
 int
-Consumer_Handler::init (int argc, char **argv)
+Consumer_Handler::init (int argc, ACE_TCHAR **argv)
 {
 
   this->argc_ = argc;
@@ -208,10 +208,7 @@ Consumer_Handler::init (int argc, char **argv)
   try
     {
       // Retrieve the ORB.
-      this->orb_ = CORBA::ORB_init (this->argc_,
-                                    this->argv_,
-                                    0);
-
+      this->orb_ = CORBA::ORB_init (this->argc_, this->argv_);
 
       // Parse command line and verify parameters.
       if (this->parse_args () == -1)
@@ -222,10 +219,10 @@ Consumer_Handler::init (int argc, char **argv)
       if (this->interactive_ == 1)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      " Services provided:\n "
-                      " * Registration <type 'r'>\n "
-                      " * Unregistration <type 'u'>\n "
-                      " * Quit <type 'q'>\n "));
+                      " Services provided:\n"
+                      " * Registration <type 'r'>\n"
+                      " * Unregistration <type 'u'>\n"
+                      " * Quit <type 'q'>\n"));
 
           ACE_NEW_RETURN (consumer_input_handler_,
                           Consumer_Input_Handler (this),
@@ -325,7 +322,7 @@ Consumer_Handler::run (void)
         {
 
           // Register with the server.
-          this->server_->register_callback (this->stock_name_,
+          this->server_->register_callback (this->stock_name_.c_str (),
                                             this->threshold_value_,
                                             this->consumer_var_.in ());
 
