@@ -1,4 +1,4 @@
-// $Id: Supplier_i.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: Supplier_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 // ===========================================================
 //
 //
@@ -54,7 +54,7 @@ Supplier::~Supplier (void)
 // Reads the Server factory IOR from a file.
 
 int
-Supplier::read_ior (char *filename)
+Supplier::read_ior (ACE_TCHAR *filename)
 {
   // Open the file for reading.
   ACE_HANDLE f_handle = ACE_OS::open (filename, 0);
@@ -73,7 +73,7 @@ Supplier::read_ior (char *filename)
                        "Unable to read ior\n"),
                       -1);
 
-  this->ior_ = ACE_OS::strdup (data);
+  this->ior_ = ACE_OS::strdup (ACE_TEXT_CHAR_TO_TCHAR(data));
   ior_buffer.alloc ()->free (data);
 
   ACE_OS::close (f_handle);
@@ -86,7 +86,7 @@ Supplier::read_ior (char *filename)
 int
 Supplier::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "dn:f:i:xk:xs");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("dn:f:i:xk:xs"));
 
   int c;
   int result;
@@ -107,8 +107,7 @@ Supplier::parse_args (void)
         if (result < 0)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "Unable to read stock information from %s : %p\n",
-                             get_opts.opt_arg (),
-                             "get_args"),
+                             get_opts.opt_arg ()),
                             -1);
         break;
 
@@ -121,8 +120,7 @@ Supplier::parse_args (void)
         if (result < 0)
           ACE_ERROR_RETURN ((LM_ERROR,
                              "Unable to read ior from %s : %p\n",
-                             get_opts.opt_arg (),
-                             "get_args"),
+                             get_opts.opt_arg ()),
                             -1);
         break;
 
@@ -188,7 +186,7 @@ Supplier::run (void)
   long timer_id = 0;
 
   ACE_DEBUG ((LM_DEBUG,
-              "Market Status Supplier Daemon is running...\n "));
+              "Market Status Supplier Daemon is running...\n"));
 
   // This sets the period for the stock-feed.
   ACE_Time_Value period (period_value_);
@@ -219,7 +217,7 @@ Supplier::via_naming_service (void)
       if (naming_services_client_.init (orb_.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            " (%P|%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
       CosNaming::Name notifier_ref_name (1);
       notifier_ref_name.length (1);
@@ -252,18 +250,15 @@ Supplier::via_naming_service (void)
 // Init function.
 
 int
-Supplier::init (int argc, char **argv)
+Supplier::init (int argc, ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
 
-
   try
     {
       // Retrieve the ORB.
-      this->orb_ = CORBA::ORB_init (this->argc_,
-                                    this->argv_,
-                                    0);
+      this->orb_ = CORBA::ORB_init (this->argc_, this->argv_);
 
       // Parse command line and verify parameters.
       if (this->parse_args () == -1)
@@ -319,12 +314,13 @@ Supplier::reactor_used (void) const
 // The stock market information is read from a file.
 
 int
-Supplier::read_file (char *filename)
+Supplier::read_file (ACE_TCHAR *filename)
 {
   f_ptr_ = ACE_OS::fopen (filename, "r");
 
   ACE_DEBUG ((LM_DEBUG,
-              "filename = %s\n",filename));
+              "filename = %s\n",
+              filename));
 
   // the stock values are to be read from a file.
   if (f_ptr_ == 0)
