@@ -1,11 +1,11 @@
-// consumer.cpp,v 1.2 1998/10/25 04:55:46 kirthika Exp
+// $Id: consumer.cpp 79317 2007-08-11 17:28:39Z sowayaa $
 
 #include "Consumer_Handler.h"
 
 // This function runs the Callback Quoter Consumer application.
 
 int
-main (int argc, char **argv)
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   Consumer_Handler consumer;
 
