@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Callback_Handler.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Callback_Handler.cpp 82946 2008-10-06 19:38:50Z johnnyw $
 
 // Ossama Othman <ossama@uci.edu>
 
@@ -7,11 +7,11 @@
 #include "ace/Log_Msg.h"
 #include "Callback_Handler.h"
 
-ACE_RCSID (AMI_Observer, Callback_Handler, "$Id: Callback_Handler.cpp 77003 2007-02-12 09:23:36Z johnnyw $")
+ACE_RCSID (AMI_Observer, Callback_Handler, "$Id: Callback_Handler.cpp 82946 2008-10-06 19:38:50Z johnnyw $")
 
 Callback_Handler::Callback_Handler (const char *pathname,
                                     Web_Server::Callback_ptr client_callback)
-  : file_ (pathname),
+  : file_ (ACE_TEXT_CHAR_TO_TCHAR(pathname)),
     file_io_ (),
     callback_ (Web_Server::Callback::_duplicate (client_callback)),
     ami_handler_ (),
