@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// Callback_i.cpp,v 1.11 2005/01/31 04:22:40 ossama Exp
+// $Id: Callback_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
 
 // Ossama Othman <ossama@uci.edu>
 
@@ -13,7 +13,7 @@
 
 ACE_RCSID (AMI_Observer,
            Callback_i,
-           "Callback_i.cpp,v 1.11 2005/01/31 04:22:40 ossama Exp")
+           "$Id: Callback_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $")
 
 
 Callback_i::Callback_i (int *request_count)
@@ -51,9 +51,7 @@ Callback_i::~Callback_i (void)
 
 void
 Callback_i::next_chunk (const Web_Server::Chunk_Type & chunk_data,
-                        CORBA::Boolean last_chunk
-                        ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                        CORBA::Boolean last_chunk)
 {
   if (!last_chunk)
     {
@@ -98,8 +96,7 @@ Callback_i::next_chunk (const Web_Server::Chunk_Type & chunk_data,
       if (this->metadata_received ())
         {
           (void) this->file_io_.close ();
-          this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_CHECK;
+          this->deactivate ();
 
           (void) this->spawn_viewer ();
         }
@@ -109,8 +106,7 @@ Callback_i::next_chunk (const Web_Server::Chunk_Type & chunk_data,
 void
 Callback_i::metadata (const Web_Server::Metadata_Type &metadata)
 {
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       {
         ACE_MT (ACE_GUARD (TAO_SYNCH_MUTEX,
@@ -131,19 +127,17 @@ Callback_i::metadata (const Web_Server::Metadata_Type &metadata)
       // an external viewer to display it.
       if (this->content_received ())
         {
-          this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->deactivate ();
 
           (void) this->spawn_viewer ();
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                           ACE_TEXT ("Caught unexpected exception ")
-                           ACE_TEXT ("in Callback_i::metdata(...):"));
+      ex._tao_print_exception (
+        ACE_TEXT ("Caught unexpected exception ")
+        ACE_TEXT ("in Callback_i::metdata(...):"));
     }
-  ACE_ENDTRY;
 }
 
 int
@@ -278,19 +272,15 @@ Callback_i::spawn_viewer (void)
 }
 
 void
-Callback_i::deactivate (ACE_ENV_SINGLE_ARG_DECL)
+Callback_i::deactivate (void)
 {
   // Get the POA used when activating the Reply Handler object.
-  PortableServer::POA_var poa = this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  PortableServer::POA_var poa = this->_default_POA ();
 
   // Get the object ID associated with this servant.
   PortableServer::ObjectId_var oid =
-    poa->servant_to_id (this
-                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    poa->servant_to_id (this);
 
   // Now deactivate the iterator object.
-  poa->deactivate_object (oid.in () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  poa->deactivate_object (oid.in ());
 }
