@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// Content_Iterator_i.h,v 1.9 2005/07/04 08:50:14 jwillemsen Exp
+// $Id: Content_Iterator_i.h 77003 2007-02-12 09:23:36Z johnnyw $
 
 
 // ============================================================================
@@ -45,21 +45,18 @@ class Content_Iterator_i :
   friend class Iterator_Factory_i;
 public:
 
-  Content_Iterator_i (const char *filename, CORBA::ULong file_size);
+  Content_Iterator_i (const char *filename, CORBA::ULongLong file_size);
   // Constructor
 
   ~Content_Iterator_i (void);
   // Destructor
 
-  virtual CORBA::Boolean next_chunk (CORBA::ULong offset,
-                                     Web_Server::Chunk_Type_out chunk
-                                     ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CORBA::Boolean next_chunk (CORBA::ULongLong offset,
+                                     Web_Server::Chunk_Type_out chunk);
   // This operation returns the next <chunk> of the file starting at
   // <offset>.  If there are no more bindings, false is returned.
 
-  virtual void destroy (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void destroy (void);
   // Destroy the iterator.
 
 private:
@@ -75,10 +72,10 @@ private:
   ACE_FILE_IO file_io_;
   // Object that handles all IO operations on the requested file.
 
-  CORBA::ULong file_size_;
+  CORBA::ULongLong file_size_;
   // The size of the file being iterated over.
 
-  CORBA::ULong chunk_index_;
+  CORBA::ULongLong chunk_index_;
   // The number of the current chunk of data being sent.  (Used only
   // for debugging purposes.)
 };
