@@ -1,9 +1,9 @@
-// $Id: Consumer_Handler.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: Consumer_Handler.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Consumer_Handler.h"
 #include "tao/ORB_Core.h"
 
-ACE_RCSID(Consumer, Consumer_Handler, "$Id: Consumer_Handler.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+ACE_RCSID(Consumer, Consumer_Handler, "$Id: Consumer_Handler.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 Consumer_Handler::Consumer_Handler (void)
   : receiver_ (0),
@@ -20,7 +20,7 @@ Consumer_Handler::~Consumer_Handler (void)
 
 int
 Consumer_Handler::init (int argc,
-                        char *argv[],
+                        ACE_TCHAR *argv[],
                         ShutdownCallback *_shutdowncallback)
 {
   const char *filtering_criteria = "";
@@ -31,17 +31,15 @@ Consumer_Handler::init (int argc,
 
    // Then override these variables with command-line arguments if
    // necessary.
-  filtering_criteria = argc > 1 ? argv[1] : "";
+  filtering_criteria = argc > 1 ? ACE_TEXT_ALWAYS_CHAR(argv[1]) : "";
 
   try
     {
       // Retrieve the ORB.
-      this->orb_ = CORBA::ORB_init (argc,
-                                    argv,
-                                    0);
+      this->orb_ = CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var poa_object  =
-        this->orb_->resolve_initial_references("RootPOA");
+        this->orb_->resolve_initial_references ("RootPOA");
 
       PortableServer::POA_var poa =
         PortableServer::POA::_narrow (poa_object.in ());
@@ -65,7 +63,7 @@ Consumer_Handler::init (int argc,
       if (this->get_notifier () == -1)
         ACE_ERROR_RETURN ((LM_ERROR,
                            " (%P|%t) Unable to get the notifier "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
 
       // Subscribe ourselves with the notifier's broker.
@@ -90,7 +88,7 @@ Consumer_Handler::get_notifier (void)
       if (naming_services_client_.init (orb_.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            " (%P|%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
 
       CosNaming::Name notifier_ref_name (1);
