@@ -1,11 +1,11 @@
-// Event_Comm_i.cpp,v 1.26 2005/04/30 07:52:10 ossama Exp
+// $Id: Event_Comm_i.cpp 78672 2007-06-29 23:46:36Z sowayaa $
 
 #include "Event_Comm_i.h"
 #if defined (ACE_HAS_REGEX)
 # include "ace/OS_NS_regex.h"
 #endif
 
-ACE_RCSID(Event_Comm, Event_Comm_i, "Event_Comm_i.cpp,v 1.26 2005/04/30 07:52:10 ossama Exp")
+ACE_RCSID(Event_Comm, Event_Comm_i, "$Id: Event_Comm_i.cpp 78672 2007-06-29 23:46:36Z sowayaa $")
 
 
 class Consumer_Entry
@@ -160,12 +160,7 @@ The filtering criteria will not work.\n"));
 
 void
 Notifier_i::subscribe (Event_Comm::Consumer_ptr consumer_ref,
-                       const char *filtering_criteria
-                       ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((
-                   CORBA::SystemException,
-                   Event_Comm::Notifier::CannotSubscribe
-                   ))
+                       const char *filtering_criteria)
 {
   ACE_DEBUG ((LM_DEBUG,
               "in Notifier_i::subscribe for %x with filtering criteria \"%s\"\n",
@@ -198,7 +193,8 @@ Notifier_i::subscribe (Event_Comm::Consumer_ptr consumer_ref,
           // Inform the caller that the <Event_Comm::Consumer> * is
           // already being used.
 
-          ACE_THROW (Event_Comm::Notifier::CannotSubscribe ("Duplicate consumer and filtering criteria found.\n"));
+          throw Event_Comm::Notifier::CannotSubscribe (
+            "Duplicate consumer and filtering criteria found.\n");
         }
     }
 
@@ -214,7 +210,8 @@ Notifier_i::subscribe (Event_Comm::Consumer_ptr consumer_ref,
     {
       // Prevent memory leaks.
       delete nr_entry;
-      ACE_THROW (Event_Comm::Notifier::CannotSubscribe ("Failed to add Consumer to internal map\n"));
+      throw Event_Comm::Notifier::CannotSubscribe (
+        "Failed to add Consumer to internal map\n");
     }
 }
 
@@ -222,12 +219,7 @@ Notifier_i::subscribe (Event_Comm::Consumer_ptr consumer_ref,
 
 void
 Notifier_i::unsubscribe (Event_Comm::Consumer_ptr consumer_ref,
-                         const char *filtering_criteria
-                         ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((
-                   CORBA::SystemException,
-                   Event_Comm::Notifier::CannotUnsubscribe
-                   ))
+                         const char *filtering_criteria)
 {
   ACE_DEBUG ((LM_DEBUG,
               "in Notifier_i::unsubscribe for %x\n",
@@ -265,22 +257,22 @@ Notifier_i::unsubscribe (Event_Comm::Consumer_ptr consumer_ref,
           // @@ This is a hack, we need a better approach!
           if (this->map_.unbind (me->ext_id_,
                                  nr_entry) == -1)
-            ACE_THROW (Event_Comm::Notifier::CannotUnsubscribe ("Internal map unbind failed."));
+            throw Event_Comm::Notifier::CannotUnsubscribe (
+              "Internal map unbind failed.");
           else
             delete nr_entry;
         }
     }
 
   if (found == 0)
-    ACE_THROW (Event_Comm::Notifier::CannotUnsubscribe ("The Consumer and filtering criteria were not found."));
+    throw Event_Comm::Notifier::CannotUnsubscribe (
+      "The Consumer and filtering criteria were not found.");
 }
 
 // Disconnect all the consumers, giving them the <reason>.
 
 void
-Notifier_i::disconnect (const char *reason
-                        ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Notifier_i::disconnect (const char *reason)
 {
   ACE_DEBUG ((LM_DEBUG,
               "in Notifier_i::send_disconnect = %s\n",
@@ -303,17 +295,14 @@ Notifier_i::disconnect (const char *reason
       ACE_DEBUG ((LM_DEBUG,
                   "disconnecting client %x\n",
                   consumer_ref));
-      ACE_TRY
+      try
         {
-          consumer_ref->disconnect (reason
-                                    ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          consumer_ref->disconnect (reason);
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception& ex)
         {
-          ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Unexpected exception\n");
+          ex._tao_print_exception ("Unexpected exception\n");
         }
-      ACE_ENDTRY;
 
       delete me->int_id_;
       count++;
@@ -333,9 +322,7 @@ Notifier_i::disconnect (const char *reason
 // Notify all consumers whose filtering criteria match the event.
 
 void
-Notifier_i::push (const Event_Comm::Event &event
-                  ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Notifier_i::push (const Event_Comm::Event &event)
 {
   ACE_DEBUG ((LM_DEBUG,
               "in Notifier_i::send_notification = %s\n",
@@ -369,19 +356,15 @@ Notifier_i::push (const Event_Comm::Event &event
                       (const char *) event.tag_,
                       me->int_id_->criteria (),
                       consumer_ref));
-          ACE_TRY
+          try
             {
-              consumer_ref->push (event
-                                  ACE_ENV_ARG_PARAMETER);
-              ACE_TRY_CHECK;
+              consumer_ref->push (event);
             }
-          ACE_CATCHANY
+          catch (const CORBA::Exception& ex)
             {
-              ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                                   "Unexpected exception\n");
+              ex._tao_print_exception ("Unexpected exception\n");
               continue;
             }
-          ACE_ENDTRY;
           count++;
         }
     }
@@ -403,10 +386,12 @@ ShutdownCallback::~ShutdownCallback (void)
 
 // -------------
 
+//FUZZ: disable check_for_lack_ACE_OS
 Consumer_i::Consumer_i (void)
   : shutdown (0)
 {
 }
+//FUZZ: enable check_for_lack_ACE_OS
 
 Consumer_i::~Consumer_i (void)
 {
@@ -416,9 +401,7 @@ Consumer_i::~Consumer_i (void)
 // occurred.
 
 void
-Consumer_i::push (const Event_Comm::Event &event
-                  ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Consumer_i::push (const Event_Comm::Event &event)
 {
   const char *tmpstr = event.tag_;
 
@@ -431,9 +414,7 @@ Consumer_i::push (const Event_Comm::Event &event
 // <Event_Comm::Notifier>.
 
 void
-Consumer_i::disconnect (const char *reason
-                        ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Consumer_i::disconnect (const char *reason)
 {
   ACE_DEBUG ((LM_DEBUG,
               "**** got disconnected due to %s\n",
@@ -450,24 +431,3 @@ Consumer_i::set (ShutdownCallback *_shutdown)
   shutdown = _shutdown;
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_Map_Manager<Event_Comm::Consumer *,
-  Consumer_Entry *, ACE_Null_Mutex>;
-template class ACE_Map_Iterator<Event_Comm::Consumer *, Consumer_Entry *,
-  ACE_Null_Mutex>;
-template class ACE_Map_Entry<Event_Comm::Consumer *, Consumer_Entry *>;
-template class ACE_Map_Reverse_Iterator<Event_Comm::Consumer *,
-  Consumer_Entry *, ACE_Null_Mutex>;
-template class ACE_Map_Iterator_Base<Event_Comm::Consumer *,
-  Consumer_Entry *, ACE_Null_Mutex>;
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_Map_Manager<Event_Comm::Consumer *, Consumer_Entry *, ACE_Null_Mutex>
-#pragma instantiate ACE_Map_Iterator<Event_Comm::Consumer *, Consumer_Entry *, ACE_Null_Mutex>
-#pragma instantiate ACE_Map_Entry<Event_Comm::Consumer *, Consumer_Entry *>
-#pragma instantiate ACE_Map_Reverse_Iterator<Event_Comm::Consumer *, Consumer_Entry *, ACE_Null_Mutex>
-#pragma instantiate ACE_Map_Iterator_Base<Event_Comm::Consumer *, Consumer_Entry *, ACE_Null_Mutex>
-
-#endif /* ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA */
