@@ -1,9 +1,9 @@
-// $Id: Notifier_Handler.cpp 76601 2007-01-25 19:59:59Z elliott_c $
+// $Id: Notifier_Handler.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Notifier_Handler.h"
 #include "tao/ORB_Core.h"
 
-ACE_RCSID(Supplier, Notifier_Handler, "$Id: Notifier_Handler.cpp 76601 2007-01-25 19:59:59Z elliott_c $")
+ACE_RCSID(Supplier, Notifier_Handler, "$Id: Notifier_Handler.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 Notifier_Handler::Notifier_Handler (void)
 {
@@ -79,7 +79,7 @@ Notifier_Handler::notifier (Event_Comm::Notifier *notifier)
 
 int
 Notifier_Handler::init (int argc,
-                        char *argv[],
+                        ACE_TCHAR *argv[],
                         ShutdownCallback* _shutdowncallback)
 {
   // set the callback
@@ -88,12 +88,10 @@ Notifier_Handler::init (int argc,
  try
     {
       // Retrieve the ORB.
-      this->orb_ = CORBA::ORB_init (argc,
-                                    argv,
-                                    0);
+      this->orb_ = CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var poa_object  =
-        this->orb_->resolve_initial_references("RootPOA");
+        this->orb_->resolve_initial_references ("RootPOA");
 
       PortableServer::POA_var poa =
         PortableServer::POA::_narrow (poa_object.in ());
@@ -107,7 +105,7 @@ Notifier_Handler::init (int argc,
       if (this->naming_client_.init (orb_.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "(%P|%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
 
       CosNaming::Name notifier_ref_name (1);
