@@ -1,9 +1,9 @@
-// $Id: consumer.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: consumer.cpp 82868 2008-09-29 07:58:36Z johnnyw $
 
 #include "Consumer_Handler.h"
 #include "Consumer_Input_Handler.h"
 
-ACE_RCSID(Consumer, consumer, "$Id: consumer.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Consumer, consumer, "$Id: consumer.cpp 82868 2008-09-29 07:58:36Z johnnyw $")
 
 class Consumer : public ACE_Event_Handler, public ShutdownCallback
 {
@@ -21,7 +21,7 @@ public:
   ~Consumer (void);
   // Destructor.
 
-  int initialize (int argc, char *argv[]);
+  int initialize (int argc, ACE_TCHAR *argv[]);
   // Initialization method.
 
   int run (void);
@@ -87,7 +87,7 @@ Consumer::run (void)
 }
 
 int
-Consumer::initialize (int argc, char *argv[])
+Consumer::initialize (int argc, ACE_TCHAR *argv[])
 {
   // Initialize the <Consumer_Handler>.
   if (this->ch_.init (argc, argv, this) == -1)
