@@ -1,8 +1,8 @@
-// $Id: notifier.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: notifier.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Notifier_Server.h"
 #include "notifier.h"
-ACE_RCSID(Notifier, notifier, "$Id: notifier.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Notifier, notifier, "$Id: notifier.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 
 int
@@ -30,7 +30,7 @@ Notifier::run (void)
     }
 }
 
-Notifier::Notifier (int argc, char *argv[])
+Notifier::Notifier (int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -38,7 +38,7 @@ Notifier::Notifier (int argc, char *argv[])
     }
   catch (const CORBA::Exception& ex)
     {
-      ex._tao_print_exception ("Notifier_Server.init failed\n ");
+      ex._tao_print_exception ("Notifier_Server.init failed\n");
     }
 
   // Register with the ORB's Reactor to receive a signal to shut us
