@@ -1,10 +1,10 @@
-// $Id: supplier.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: supplier.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Notifier_Handler.h"
 #include "Supplier_Input_Handler.h"
 #include "supplier.h"
 
-ACE_RCSID(Supplier, supplier, "$Id: supplier.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Supplier, supplier, "$Id: supplier.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 Supplier::Supplier (void)
 {
   // No-Op.
@@ -43,7 +43,7 @@ Supplier::close (void)
 }
 
 int
-Supplier::init (int argc, char *argv[])
+Supplier::init (int argc, ACE_TCHAR *argv[])
 {
   if (this->nh_.init (argc, argv, this) == -1)
     ACE_ERROR_RETURN ((LM_ERROR,
@@ -61,7 +61,7 @@ Supplier::init (int argc, char *argv[])
                        "register_handler"),
                       -1);
   ACE_DEBUG ((LM_DEBUG,
-              "Supplier initialized.. \n"));
+              "Supplier initialized..\n"));
   return 0;
 }
 
