@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: supplier.h 79327 2007-08-13 12:14:16Z sowayaa $ 
+// $Id: supplier.h 82868 2008-09-29 07:58:36Z johnnyw $
 
 // ============================================================================
 //
@@ -33,7 +33,7 @@ public:
   ~Supplier (void);
   // Destructor.
 
-  int init (int argc, char *argv[]);
+  int init (int argc, ACE_TCHAR *argv[]);
   // Initialization method. returns 0 on success, -1 on error.
 
   void run (void);
