@@ -1,4 +1,4 @@
-//$Id: EDF_Scheduler.h 77003 2007-02-12 09:23:36Z johnnyw $
+//$Id: EDF_Scheduler.h 81490 2008-04-28 14:32:24Z johnnyw $
 
 #ifndef EDF_SCHEDULER_H
 #define EDF_SCHEDULER_H
@@ -47,7 +47,7 @@ struct EDF_Scheduler_Traits
 
 class Kokyu_DSRT_Schedulers_Export EDF_Sched_Param_Policy:
 public EDF_Scheduling::SchedulingParameterPolicy,
-       public TAO_Local_RefCounted_Object
+       public ::CORBA::LocalObject
 {
  public:
 
@@ -61,7 +61,7 @@ public EDF_Scheduling::SchedulingParameterPolicy,
 
 class Kokyu_DSRT_Schedulers_Export EDF_Scheduler:
 public EDF_Scheduling::Scheduler,
-public TAO_Local_RefCounted_Object
+public ::CORBA::LocalObject
 {
  public:
 
