@@ -1,4 +1,4 @@
-//$Id: FP_Scheduler.cpp 79327 2007-08-13 12:14:16Z sowayaa $
+//$Id: FP_Scheduler.cpp 87620 2009-11-18 11:10:53Z msmit $
 
 #include "FP_Scheduler.h"
 #include "Kokyu_qosC.h"
@@ -12,28 +12,24 @@ FP_Segment_Sched_Param_Policy::FP_Segment_Sched_Param_Policy ()
 }
 
 FP_Segment_Sched_Param_Policy::FP_Segment_Sched_Param_Policy (
-    const FP_Segment_Sched_Param_Policy &rhs
-  )
+    const FP_Segment_Sched_Param_Policy &rhs)
   : CORBA::Object (),
   CORBA::Policy (),
-  CORBA::LocalObject (),
   FP_Scheduling::SegmentSchedulingParameterPolicy (),
-  TAO_Local_RefCounted_Object (),
+  CORBA::LocalObject (),
   value_ (rhs.value_)
 {
 }
 
 FP_Scheduling::SegmentSchedulingParameter
-FP_Segment_Sched_Param_Policy::value (
-      )
+FP_Segment_Sched_Param_Policy::value (void)
 {
   return value_;
 }
 
 void
 FP_Segment_Sched_Param_Policy::value (
-        const FP_Scheduling::SegmentSchedulingParameter & value
-      )
+        const FP_Scheduling::SegmentSchedulingParameter & value)
 {
   this->value_ = value;
 }
@@ -41,7 +37,7 @@ FP_Segment_Sched_Param_Policy::value (
 CORBA::Policy_ptr
 FP_Segment_Sched_Param_Policy::copy (void)
 {
-  FP_Segment_Sched_Param_Policy* tmp;
+  FP_Segment_Sched_Param_Policy* tmp = 0;
   ACE_NEW_THROW_EX (tmp, FP_Segment_Sched_Param_Policy (*this),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
@@ -49,6 +45,12 @@ FP_Segment_Sched_Param_Policy::copy (void)
   return tmp;
 }
 
+CORBA::PolicyType
+FP_Segment_Sched_Param_Policy::policy_type (void)
+{
+  return 0;
+}
+
 void
 FP_Segment_Sched_Param_Policy::destroy (void)
 {
