@@ -1,4 +1,4 @@
-//$Id: MIF_Scheduler.cpp 79327 2007-08-13 12:14:16Z sowayaa $
+//$Id: MIF_Scheduler.cpp 87620 2009-11-18 11:10:53Z msmit $
 
 #include "MIF_Scheduler.h"
 #include "Kokyu_qosC.h"
@@ -16,9 +16,8 @@ MIF_Sched_Param_Policy::MIF_Sched_Param_Policy (
   )
   : CORBA::Object (),
   CORBA::Policy (),
-  CORBA::LocalObject (),
   MIF_Scheduling::SchedulingParameterPolicy (),
-  TAO_Local_RefCounted_Object (),
+  CORBA::LocalObject (),
   value_ (rhs.value_)
 {
 }
@@ -47,6 +46,12 @@ MIF_Sched_Param_Policy::copy (void)
   return tmp;
 }
 
+CORBA::PolicyType
+MIF_Sched_Param_Policy::policy_type (void)
+{
+  return 0;
+}
+
 void
 MIF_Sched_Param_Policy::destroy (void)
 {
