@@ -1,4 +1,4 @@
-//$Id: MUF_Scheduler.cpp 79327 2007-08-13 12:14:16Z sowayaa $
+//$Id: MUF_Scheduler.cpp 87620 2009-11-18 11:10:53Z msmit $
 
 #include "MUF_Scheduler.h"
 #include "Kokyu_qosC.h"
@@ -16,9 +16,8 @@ MUF_Sched_Param_Policy::MUF_Sched_Param_Policy (
   )
   : CORBA::Object (),
   CORBA::Policy (),
-  CORBA::LocalObject (),
   MUF_Scheduling::SchedulingParameterPolicy (),
-  TAO_Local_RefCounted_Object (),
+  CORBA::LocalObject (),
   value_ (rhs.value_)
 {
 }
@@ -38,7 +37,7 @@ MUF_Sched_Param_Policy::value (const MUF_Scheduling::SchedulingParameter& value)
 CORBA::Policy_ptr
 MUF_Sched_Param_Policy::copy (void)
 {
-  MUF_Sched_Param_Policy* tmp;
+  MUF_Sched_Param_Policy* tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     MUF_Sched_Param_Policy (*this),
                     CORBA::NO_MEMORY (TAO::VMCID,
@@ -47,6 +46,12 @@ MUF_Sched_Param_Policy::copy (void)
   return tmp;
 }
 
+CORBA::PolicyType
+MUF_Sched_Param_Policy::policy_type (void)
+{
+  return 0;
+}
+
 void
 MUF_Sched_Param_Policy::destroy (void)
 {
@@ -461,7 +466,7 @@ MUF_Scheduler::send_reply (PortableInterceptor::ServerRequestInfo_ptr ri)
   {
 #ifdef KOKYU_DSRT_LOGGING
     ACE_DEBUG ((LM_DEBUG,
-                "(%t|%T): sched_policy nil.\n "));
+                "(%t|%T): sched_policy nil.\n"));
 #endif
     //24 hrs from now - infinity
     ACE_Time_Value deadline_tv = ACE_OS::gettimeofday () + ACE_Time_Value (24*60*60,0);
