@@ -1,4 +1,4 @@
-// $Id: client.cpp 79327 2007-08-13 12:14:16Z sowayaa $
+// $Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "ace/Task.h"
@@ -8,9 +8,9 @@
 #include "testC.h"
 #include "FP_Scheduler.h"
 
-ACE_RCSID(MT_Server, client, "$Id: client.cpp 79327 2007-08-13 12:14:16Z sowayaa $")
+ACE_RCSID(MT_Server, client, "$Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 5;
 int do_shutdown = 0;
 int enable_dynamic_scheduling = 0;
@@ -50,9 +50,9 @@ private:
 };
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "xk:i:ds");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("xk:i:ds"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -157,7 +157,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (CORBA::is_nil (server.in ()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             "Object reference <%s> is nil\n",
+                             "Object reference <%s> is nil.\n",
                              ior),
                             1);
         }
