@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $
 
 #include "test_i.h"
 #include "ace/Get_Opt.h"
@@ -8,9 +8,9 @@
 #include "MUF_Scheduler.h"
 #include "Task_Stats.h"
 
-ACE_RCSID(MT_Server, server, "$Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(MT_Server, server, "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")
 
-const char *ior_output_file = "test.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
 
 int nthreads = 3;
 int enable_dynamic_scheduling = 0;
@@ -18,9 +18,9 @@ const CORBA::Short max_importance = 100;
 int enable_yield = 1;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:n:ds");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:n:ds"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -161,7 +161,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::String_var ior =
         orb->object_to_string (server.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       // If the ior_output_file exists, output the ior to it
       if (ior_output_file != 0)
@@ -212,9 +212,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     }
 
   ACE_DEBUG ((LM_DEBUG, "Exiting main...\n"));
-  task_stats.dump_samples ("timeline.txt",
-                            "Time\t\tGUID",
-                            ACE_High_Res_Timer::global_scale_factor ());
+  task_stats.dump_samples (ACE_TEXT("timeline.txt"),
+                           ACE_TEXT("Time\t\tGUID"),
+                           ACE_High_Res_Timer::global_scale_factor ());
   return 0;
 }
 
