@@ -1,4 +1,4 @@
-// $Id: Identity_Client.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: Identity_Client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 // ============================================================================
 //
 // = LIBRARY
@@ -29,9 +29,9 @@ Identity_Client::Identity_Client (void)
 }
 
 int
-Identity_Client::parse_args (int argc, char *argv[])
+Identity_Client::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "di:n:r");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("di:n:r"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -70,14 +70,13 @@ Identity_Client::parse_args (int argc, char *argv[])
 
 int
 Identity_Client::init (int argc,
-                       char* argv[])
+                       ACE_TCHAR* argv[])
 {
   int result;
 
   try
     {
-      result = this->orb_manager_.init (argc,
-                                        argv);
+      result = this->orb_manager_.init (argc, argv);
       if (result == -1)
         return result;
 
@@ -98,7 +97,7 @@ Identity_Client::init (int argc,
 int
 Identity_Client::run (void)
 {
-  ACE_DEBUG ((LM_DEBUG, "Identity_Client: Initialized \n"));
+  ACE_DEBUG ((LM_DEBUG, "Identity_Client: Initialized\n"));
 
   // Contact the <Object_Group_Factory> to obtain an <Object_Group>.
   CORBA::ORB_var orb = orb_manager_.orb ();
@@ -112,7 +111,7 @@ Identity_Client::run (void)
                        "Identity_Client: problems using the factory ior\n"),
                       -1);
 
-  const char *group_name;
+  const char *group_name = 0;
   if (this->use_random_)
     group_name = "Identity, Random";
   else
@@ -120,7 +119,7 @@ Identity_Client::run (void)
 
   ACE_DEBUG ((LM_DEBUG,
               "Identity_Client: Requesting Object Group "
-              "with id <%s>\n", group_name));
+              "with id <%C>\n", group_name));
   Load_Balancer::Object_Group_var object_group =
     factory->resolve (group_name);
 
@@ -135,7 +134,7 @@ Identity_Client::run (void)
 
   // List all <Object_Group>s members.
   ACE_DEBUG ((LM_DEBUG,
-              "Identity_Client: Requesting member list of <%s> Object Group\n",
+              "Identity_Client: Requesting member list of <%C> Object Group\n",
               group_name));
 
   Load_Balancer::Member_ID_List_var id_list =
@@ -145,7 +144,7 @@ Identity_Client::run (void)
               "Identity_Client: The Group contains %d members:\n",
               id_list->length ()));
   for (CORBA::ULong i = 0; i < id_list->length (); ++i)
-    ACE_DEBUG ((LM_DEBUG, "                 <%s>\n",
+    ACE_DEBUG ((LM_DEBUG, "                 <%C>\n",
                 static_cast<char const*>((id_list[i]))));
 
   // Perform <number_of_invocations_> method calls on <Identity>
@@ -157,7 +156,7 @@ Identity_Client::run (void)
 
   ACE_DEBUG ((LM_DEBUG,
               "Identity_Client: Performing %d invocation(s), "
-              "consulting the <%s> Group\n"
+              "consulting the <%C> Group\n"
               "                 for Identity object "
               "to use before each invocation\n",
               this->number_of_invocations_,
