@@ -1,4 +1,4 @@
-// $Id: Identity_Server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: Identity_Server.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 // ============================================================================
 //
 // = LIBRARY
@@ -26,9 +26,9 @@ Identity_Server::Identity_Server (void)
 }
 
 int
-Identity_Server::parse_args (int argc, char *argv[])
+Identity_Server::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "di:a:o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("di:a:o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -66,7 +66,7 @@ Identity_Server::parse_args (int argc, char *argv[])
 
 int
 Identity_Server::init (int argc,
-                       char* argv[])
+                       ACE_TCHAR* argv[])
 {
   int result;
 
@@ -146,21 +146,21 @@ Identity_Server::create_objects (size_t number_of_objects,
   for (size_t i = 0; i < number_of_objects; ++i)
     {
       // Create an id for this servant.
-      char id[BUFSIZ];
+      ACE_TCHAR id[BUFSIZ];
       ACE_OS::sprintf (id,
-                       "Identity object " ACE_SIZE_T_FORMAT_SPECIFIER,
+                       ACE_TEXT("Identity object ") ACE_SIZE_T_FORMAT_SPECIFIER,
                        i);
 
       // Create and activate a servant.
-      Identity_i * identity_servant;
+      Identity_i * identity_servant = 0;
       ACE_NEW_THROW_EX (identity_servant,
-                        Identity_i (id),
+                        Identity_i (ACE_TEXT_ALWAYS_CHAR(id)),
                         CORBA::NO_MEMORY ());
       PortableServer::ServantBase_var s = identity_servant;
       orb_manager_.activate (identity_servant);
 
       Load_Balancer::Member member;
-      member.id = CORBA::string_dup (id);
+      member.id = CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(id));
       member.obj = identity_servant->_this ();
 
       // Bind the servant in the <Object_Group>.
@@ -172,7 +172,7 @@ int
 Identity_Server::run (void)
 {
   ACE_DEBUG ((LM_DEBUG,
-              "Identity_Server: Initialized \n"));
+              "Identity_Server: Initialized\n"));
 
   int result;
 
