@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Identity_i.cpp,v 1.6 2002/01/29 20:20:40 okellogg Exp
+// $Id: Identity_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
 // ============================================================================
 //
 // = FILENAME
@@ -25,8 +25,7 @@ Identity_i::~Identity_i (void)
 
 void
 Identity_i::get_name (CORBA::String_out name
-                      ACE_ENV_ARG_DECL_NOT_USED )
-    ACE_THROW_SPEC ((CORBA::SystemException))
+ )
 {
   name = this->name_.in ();
 }
