@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Identity_i.h,v 1.4 2005/07/04 08:50:14 jwillemsen Exp
+// $Id: Identity_i.h 77003 2007-02-12 09:23:36Z johnnyw $
 // ============================================================================
 //
 // = FILENAME
@@ -30,9 +30,7 @@ public:
   ~Identity_i (void);
   // Destructor.
 
-  virtual void get_name (CORBA::String_out name
-                         ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void get_name (CORBA::String_out name);
   // Returns the name of this object.
 
 private:
