@@ -1,4 +1,4 @@
-// $Id: Load_Balancing_Service.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: Load_Balancing_Service.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 // ============================================================================
 //
 // = LIBRARY
@@ -24,9 +24,9 @@ Load_Balancing_Service::Load_Balancing_Service (void)
 }
 
 int
-Load_Balancing_Service::parse_args (int argc, char *argv[])
+Load_Balancing_Service::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "do:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("do:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -61,7 +61,7 @@ Load_Balancing_Service::parse_args (int argc, char *argv[])
 
 int
 Load_Balancing_Service::init (int argc,
-                    char* argv[])
+                    ACE_TCHAR* argv[])
 {
   int result;
   CORBA::String_var ior;
@@ -90,7 +90,7 @@ Load_Balancing_Service::init (int argc,
         return -1;
       else if (TAO_debug_level > 1)
         ACE_DEBUG ((LM_DEBUG,
-                    "Load_Balancer: Object Group Factory ior is %s\n",
+                    "Load_Balancer: Object Group Factory ior is %C\n",
                     ior.in ()));
     }
   catch (const CORBA::Exception& ex)
@@ -115,7 +115,7 @@ int
 Load_Balancing_Service::run (void)
 {
   ACE_DEBUG ((LM_DEBUG,
-              "Load_Balancer: Initialized \n"));
+              "Load_Balancer: Initialized\n"));
 
   int result;
 
