@@ -1,4 +1,4 @@
-// $Id: Identity_Client.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: Identity_Client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 // ============================================================================
 //
 // = LIBRARY
@@ -29,9 +29,9 @@ Identity_Client::Identity_Client (void)
 }
 
 int
-Identity_Client::parse_args (int argc, char *argv[])
+Identity_Client::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "di:n:k:r");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("di:n:k:r"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -72,15 +72,13 @@ Identity_Client::parse_args (int argc, char *argv[])
 }
 
 int
-Identity_Client::init (int argc,
-                       char* argv[])
+Identity_Client::init (int argc, ACE_TCHAR* argv[])
 {
   int result;
 
   try
     {
-      result = this->orb_manager_.init (argc,
-                                        argv);
+      result = this->orb_manager_.init (argc, argv);
       if (result == -1)
         return result;
 
@@ -108,8 +106,8 @@ Identity_Client::run (void)
 
   if (obj.in () == 0)
     ACE_ERROR_RETURN ((LM_ERROR,
-                       ACE_TEXT ("(%N|%l) <ERROR> [Identity_Client::run] \n")
-                       ACE_TEXT ("factory_resolve \n")),
+                       ACE_TEXT ("(%N|%l) <ERROR> [Identity_Client::run]\n")
+                       ACE_TEXT ("factory_resolve\n")),
                       -1);
 
   Load_Balancer::Object_Group_Factory_var factory =
@@ -153,7 +151,7 @@ Identity_Client::run (void)
         orb->object_to_string (object_group.in ());
 
       ACE_DEBUG ((LM_DEBUG,
-                  "The ior string is %s \n", iorstring.in ()));
+                  "The ior string is %s\n", iorstring.in ()));
 #if defined (DOORS_MEASURE_STATS)
       // Grab timestamp again.
       ACE_hrtime_t now = ACE_OS::gethrtime ();
@@ -164,8 +162,8 @@ Identity_Client::run (void)
 
     }
 
-  ACE_OS::printf ("*=*=*=*=Aggregated result *=*=*=*=*= \n");
-  throughput.dump_results ("Aggregated", gsf);
+  ACE_OS::printf ("*=*=*=*=Aggregated result *=*=*=*=*=\n");
+  throughput.dump_results (ACE_TEXT("Aggregated"), gsf);
 #endif /*TAO_MEASURE_STATS */
 
   if (CORBA::is_nil (object_group.in ()))
