@@ -1,4 +1,4 @@
-// $Id: Identity_Server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: Identity_Server.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Identity_Server.h"
 #include "Identity_i.h"
@@ -14,9 +14,9 @@ Identity_Server::Identity_Server (void)
 }
 
 int
-Identity_Server::parse_args (int argc, char *argv[])
+Identity_Server::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "di:a:o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("di:a:o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -54,7 +54,7 @@ Identity_Server::parse_args (int argc, char *argv[])
 
 int
 Identity_Server::init (int argc,
-                       char* argv[])
+                       ACE_TCHAR* argv[])
 {
   int result;
 
@@ -130,7 +130,7 @@ Identity_Server::register_groups (void)
   catch (const CORBA::Exception&)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "(%N | %l) <Unbind> harmless here \n"));
+                  "(%N | %l) <Unbind> harmless here\n"));
     }
 
   // Unbind the previously registered round robin group
@@ -141,7 +141,7 @@ Identity_Server::register_groups (void)
   catch (const CORBA::Exception&)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "(%N | %l) <Unbind> harmless here \n"));
+                  "(%N | %l) <Unbind> harmless here\n"));
     }
 
 
@@ -186,15 +186,15 @@ Identity_Server::create_objects (size_t number_of_objects,
   for (size_t i = 0; i < number_of_objects; ++i)
     {
       // Create an id for this servant.
-      char id[BUFSIZ];
+      ACE_TCHAR id[BUFSIZ];
       ACE_OS::sprintf (id,
-                       "Identity object " ACE_SIZE_T_FORMAT_SPECIFIER,
+                       ACE_TEXT("Identity object ") ACE_SIZE_T_FORMAT_SPECIFIER,
                        i);
 
       // Create and activate a servant.
       Identity_i * identity_servant;
       ACE_NEW_THROW_EX (identity_servant,
-                        Identity_i (id, this->persistent_POA_.in ()),
+                        Identity_i (ACE_TEXT_ALWAYS_CHAR(id), this->persistent_POA_.in ()),
                         CORBA::NO_MEMORY ());
 
       PortableServer::ServantBase_var s = identity_servant;
@@ -203,19 +203,18 @@ Identity_Server::create_objects (size_t number_of_objects,
       CORBA::Object_var obj = identity_servant->_this ();
 
       Load_Balancer::Member member;
-      member.id = CORBA::string_dup (id);
-      member.obj =
-        this->orb_manager_.orb ()->object_to_string (obj.in ());
+      member.id = CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(id));
+      member.obj = this->orb_manager_.orb ()->object_to_string (obj.in ());
 
       // Do an unbind and then bind
       try
         {
-          group->unbind (id);
+          group->unbind (ACE_TEXT_ALWAYS_CHAR(id));
         }
       catch (const CORBA::Exception&)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "(%N | %l) Harmless here \n"));
+                      "(%N | %l) Harmless here\n"));
         }
 
       // Bind the servant in the random <Object_Group>.
