@@ -1,4 +1,4 @@
-//Simple_util.h,v 1.9 2005/02/18 09:07:06 jwillemsen Exp
+//$Id: Simple_util.h 82994 2008-10-08 19:18:08Z johnnyw $
 
 // This version of Simple_Util doesn't need to link against orbsvcs
 // On the other hand it has no naming service.
@@ -51,8 +51,7 @@ public:
 
   int init (const char *servant_name,
             int argc,
-            char *argv[]
-            ACE_ENV_ARG_DECL);
+            ACE_TCHAR *argv[]);
   // Initialize the Server state - parsing arguments and waiting.
   // interface_name is the name used to register the Servant.
 
@@ -60,7 +59,7 @@ public:
   // After calling <init>, this method will register the server with
   // the TAO Naming Service using the servant_name passed to <init>.
 
-  int run (ACE_ENV_SINGLE_ARG_DECL);
+  int run (void);
   // Run the orb.
 
 protected:
@@ -86,7 +85,7 @@ protected:
   int argc_;
   // Number of command line arguments.
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // The command line arguments.
 };
 
@@ -109,7 +108,7 @@ public:
   ~Client (void);
   // Destructor.
 
-  int init (const char *name,int argc, char *argv[]);
+  int init (const char *name,int argc, ACE_TCHAR *argv[]);
   // Initialize the client communication endpoint with server.
 
   InterfaceObj *operator-> () { return server_.in ();};
@@ -121,11 +120,11 @@ public:
   void shutdown (int);
   // Fills in the shutdwon flag.
 
-  int obtain_initial_references (ACE_ENV_SINGLE_ARG_DECL);
+  int obtain_initial_references (void);
   // Initialize naming service
 
 protected:
-  int read_ior (char *filename);
+  int read_ior (ACE_TCHAR *filename);
   // Function to read the server IOR from a file.
 
   int parse_args (void);
@@ -137,7 +136,7 @@ protected:
   int argc_;
   // # of arguments on the command line.
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // arguments from command line.
 
   char *ior_;
