@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Client_i.h 27352 1999-08-01 15:42:07Z nanbor $
+// $Id: Client_i.h 82916 2008-10-03 11:09:51Z johnnyw $
 
 // ============================================================================
 //
@@ -46,7 +46,7 @@ public:
   virtual  ~Checkpoint_Client_i (void);
   // Destructor
 
-  virtual int run (const char *,int, char** );
+  virtual int run (const char *,int, ACE_TCHAR** );
   // Execute the methods
 
 private:
