@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Grid_i.h 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Grid_i.h 83017 2008-10-09 18:15:04Z johnnyw $
 
 // ============================================================================
 //
@@ -54,14 +54,14 @@ public:
   void orb (CORBA::ORB_ptr o);
   // Set the ORB pointer.
 
-  void pool_name (const char *name);
+  void pool_name (const ACE_TCHAR *name);
   // Set the pool pointer
 
 private:
   CORBA::ORB_var orb_;
   // ORB pointer.
 
-  char *pool_name_;
+  ACE_TCHAR *pool_name_;
   // Name of the pool
 
   pool_t *pool_t_;
