@@ -1,4 +1,4 @@
-//$Id: Persistent_Client_i.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+//$Id: Persistent_Client_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 #include "Persistent_Client.h"
 #include "ace/Get_Opt.h"
 #include "ace/Read_Buffer.h"
@@ -21,10 +21,10 @@ Persistent_Client_i::~Persistent_Client_i (void)
 
 int
 Persistent_Client_i::parse_args (int argc,
-                                 char *argv[])
+                                 ACE_TCHAR *argv[])
 {
   // Parses some of the options that are specific to this example
-  ACE_Get_Opt get_opts (argc, argv, "dk:f:xw:h:r");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dk:f:xw:h:r"));
 
   int c = 0;
   while ((c = get_opts ()) != -1)
@@ -49,7 +49,7 @@ Persistent_Client_i::parse_args (int argc,
 int
 Persistent_Client_i::run (const char *name,
                           int argc,
-                          char *argv[])
+                          ACE_TCHAR *argv[])
 {
   // Initialize the client.
   if (client.init (name, argc, argv) == -1)
@@ -77,7 +77,7 @@ Persistent_Client_i::run (const char *name,
                                                ctr);
 
               ACE_DEBUG ((LM_DEBUG,
-                          "Grid value [%d][%d] =  %d \n",index_, ctr,ret_val));
+                          "Grid value [%d][%d] =  %d\n",index_, ctr,ret_val));
             }
         }
 
