@@ -1,4 +1,4 @@
-//$Id: Simple_util.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+//$Id: Simple_util.cpp 83165 2008-10-12 20:52:46Z johnnyw $
 
 #ifndef SIMPLE_UTIL_C
 #define SIMPLE_UTIL_C
@@ -11,7 +11,6 @@
 
 // Constructor.
 
-
 template <class Servant>
 Server<Servant>::Server (void)
   : ior_output_file_ (0),
@@ -32,7 +31,7 @@ Server<Servant>::~Server (void)
 template <class Servant> int
 Server<Servant>::parse_args (void)
 {
-  ACE_Get_Opt get_opts (this->argc_, this->argv_, "do:m:");
+  ACE_Get_Opt get_opts (this->argc_, this->argv_, ACE_TEXT("do:m:"));
   int c = 0;
 
   while ((c = get_opts ()) != -1)
@@ -59,7 +58,7 @@ Server<Servant>::parse_args (void)
                            " [-d]"
                            " [-o] <ior_output_file>"
                            "\n",
-                           argv_ [0]),
+                           this->argv_ [0]),
                           -1);
       }
 
@@ -72,7 +71,7 @@ Server<Servant>::parse_args (void)
 template <class Servant> int
 Server<Servant>::init (const char *servant_name,
                        int argc,
-                       char *argv[])
+                       ACE_TCHAR *argv[])
 {
   // Call the init of <TAO_ORB_Manager> to initialize the ORB and
   // create a child POA under the root POA.
@@ -112,7 +111,7 @@ Server<Servant>::init (const char *servant_name,
                                                      &this->servant_);
 
       ACE_DEBUG ((LM_DEBUG,
-                  "The IOR is: <%s>\n",
+                  "The IOR is: <%C>\n",
                   str.in ()));
 
       if (this->ior_output_file_)
@@ -164,7 +163,7 @@ Client<InterfaceObj, Var>::Client (void)
 // Reads the Server ior from a file
 
 template <class InterfaceObj, class Var> int
-Client<InterfaceObj, Var>::read_ior (char *filename)
+Client<InterfaceObj, Var>::read_ior (ACE_TCHAR *filename)
 {
   // Open the file for reading.
   ACE_HANDLE f_handle = ACE_OS::open (filename, 0);
@@ -196,7 +195,7 @@ Client<InterfaceObj, Var>::read_ior (char *filename)
 template <class InterfaceObj, class Var> int
 Client<InterfaceObj, Var>::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "df:k:x");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("df:k:x"));
   int c = 0;
   int result = 0;
 
@@ -207,7 +206,7 @@ Client<InterfaceObj, Var>::parse_args (void)
         TAO_debug_level++;
         break;
       case 'k':  // ior provide on command line
-        this->ior_ = ACE_OS::strdup (get_opts.opt_arg ());
+        this->ior_ = ACE_OS::strdup (ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ()));
         break;
       case 'f': // read the IOR from the file.
         result = this->read_ior (get_opts.opt_arg ());
@@ -235,18 +234,15 @@ Client<InterfaceObj, Var>::~Client (void)
 template <class InterfaceObj, class Var> int
 Client<InterfaceObj, Var>::init (const char * /*name*/,
                                  int argc,
-                                 char **argv)
+                                 ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
 
-
   try
     {
       // Retrieve the ORB.
-      this->orb_ = CORBA::ORB_init (this->argc_,
-                                    this->argv_,
-                                    0);
+      this->orb_ = CORBA::ORB_init (this->argc_, this->argv_);
 
       // Parse command line and verify parameters.
       if (this->parse_args () == -1)
@@ -257,10 +253,9 @@ Client<InterfaceObj, Var>::init (const char * /*name*/,
           CORBA::Object_var server_object =
             this->orb_->string_to_object (this->ior_);
 
-
           if (CORBA::is_nil (server_object.in ()))
             ACE_ERROR_RETURN ((LM_ERROR,
-                               "invalid ior <%s>\n",
+                               "invalid ior <%C>\n",
                                this->ior_),
                               -1);
           this->server_ = InterfaceObj::_narrow (server_object.in ());
