@@ -1,4 +1,4 @@
-// $Id: client.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $
 
 // ============================================================================
 //
@@ -29,17 +29,17 @@
 // executable and initialized for static builds.
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(Performance, client, "$Id: client.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Performance, client, "$Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 ACE_UINT32 burst_messages = 1000;
 
 unsigned char performance_test = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:t:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:t:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -85,7 +85,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (CORBA::is_nil (udp_var.in ()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             "Object reference <%s> is nil\n",
+                             "Object reference <%s> is nil.\n",
                              ior),
                             1);
         }
