@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $
 
 // ============================================================================
 //
@@ -26,15 +26,15 @@
 #include "tao/Strategies/advanced_resource.h"
 
 
-ACE_RCSID(Performance, server, "$Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Performance, server, "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")
 
-const char *ior_output_file = "test.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
 int orb_threads = 1; // Number of threads running inside the ORB.
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "i:o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("i:o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -142,7 +142,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::String_var ior =
         orb->object_to_string (udp_var.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       // If the ior_output_file exists, output the ior to it
       if (ior_output_file != 0)
