@@ -1,4 +1,4 @@
-// $Id: server.cpp 76601 2007-01-25 19:59:59Z elliott_c $
+// $Id: server.cpp 87601 2009-11-17 11:49:09Z dbudko $
 
 // ============================================================================
 //
@@ -30,10 +30,35 @@
 # define ACE_MAIN testServer
 #endif
 
+const ACE_TCHAR *ior_output_file = ACE_TEXT ("test.ior");
 
-const char *ior_output_file = "test.ior";
+int
+parse_args (int argc, ACE_TCHAR *argv[])
+{
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
+  int c;
 
-int main (int argc, char *argv[])
+  while ((c = get_opts ()) != -1)
+    switch (c)
+      {
+      case 'o':
+        ior_output_file = get_opts.opt_arg ();
+        break;
+
+      case '?':
+      default:
+        ACE_ERROR_RETURN ((LM_ERROR,
+                           "usage:  %s "
+                           "-o <iorfile>"
+                           "\n",
+                           argv [0]),
+                          -1);
+      }
+  // Indicates sucessful parsing of the command line
+  return 0;
+}
+
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -42,6 +67,9 @@ int main (int argc, char *argv[])
                          argv,
                          "ORB_Test_Server");
 
+      if (parse_args (argc, argv) != 0)
+        return 1;
+
       CORBA::Object_var poa_object =
         orb->resolve_initial_references("RootPOA");
 
@@ -67,16 +95,16 @@ int main (int argc, char *argv[])
       CORBA::String_var ior =
               orb->object_to_string (server.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       // If the ior_output_file exists, output the ior to it
       if (ior_output_file != 0)
               {
-                FILE *output_file= ACE_OS::fopen (ior_output_file, "w");
+                FILE *output_file= ACE_OS::fopen (ACE_TEXT_ALWAYS_CHAR(ior_output_file), "w");
                 if (output_file == 0)
                   ACE_ERROR_RETURN ((LM_ERROR,
                                      "Cannot open output file for writing IOR: %s",
-                                     ior_output_file),
+                                     ACE_TEXT_ALWAYS_CHAR(ior_output_file)),
                                     1);
                 ACE_OS::fprintf (output_file, "%s", ior.in ());
                 ACE_OS::fclose (output_file);
