@@ -1,4 +1,4 @@
-// test_i.h,v 1.3 2002/01/29 20:20:41 okellogg Exp
+// $Id: test_i.h 77003 2007-02-12 09:23:36Z johnnyw $
 
 // ============================================================================
 //
@@ -31,17 +31,13 @@ public:
   // ctor
 
   // = The Simple_Server methods.
-  void sendCharSeq (const Char_Seq & charSeq ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void sendCharSeq (const Char_Seq & charSeq);
 
-  void sendOctetSeq (const Octet_Seq & octetSeq ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void sendOctetSeq (const Octet_Seq & octetSeq);
 
-  CORBA::Long get_number (CORBA::Long num ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  CORBA::Long get_number (CORBA::Long num);
 
-  void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void shutdown (void);
 
 private:
   CORBA::ORB_var orb_;
