@@ -1,4 +1,4 @@
-// $Id: Factory_Finder.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: Factory_Finder.cpp 83153 2008-10-12 18:43:19Z johnnyw $
 
 // ============================================================================
 //
@@ -18,7 +18,7 @@
 
 ACE_RCSID (Quoter,
 
-           Factory_Finder, "$Id: Factory_Finder.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+           Factory_Finder, "$Id: Factory_Finder.cpp 83153 2008-10-12 18:43:19Z johnnyw $")
 
 Quoter_Factory_Finder_Server::Quoter_Factory_Finder_Server (void)
 :   debug_level_ (1)
@@ -47,7 +47,7 @@ Quoter_Factory_Finder_Server::~Quoter_Factory_Finder_Server (void)
 
 int
 Quoter_Factory_Finder_Server::init (int argc,
-                                    char *argv[])
+                                    ACE_TCHAR *argv[])
 {
   const char *exception_message = "Null Message";
 
@@ -88,7 +88,7 @@ Quoter_Factory_Finder_Server::init (int argc,
 
       // Print the IOR.
       if (this->debug_level_ >= 2)
-        ACE_DEBUG ((LM_DEBUG, "Factory Finder: IOR is: <%s>\n", str.in ()));
+        ACE_DEBUG ((LM_DEBUG, "Factory Finder: IOR is: <%C>\n", str.in ()));
 
       // Register the Quoter Factory Finder with the Naming Service
       if (this->debug_level_ >= 2)
@@ -144,7 +144,7 @@ Quoter_Factory_Finder_Server::init (int argc,
     }
   catch (const CORBA::Exception& ex)
     {
-      ACE_ERROR ((LM_ERROR, "Quoter_Factor_Finder_Server::init - %s\n", exception_message));
+      ACE_ERROR ((LM_ERROR, "Quoter_Factor_Finder_Server::init - %C\n", exception_message));
       ex._tao_print_exception ("SYS_EX");
       return -1;
     }
@@ -170,7 +170,7 @@ Quoter_Factory_Finder_Server::run (void)
 u_int
 Quoter_Factory_Finder_Server::parse_args (void)
 {
-  ACE_Get_Opt get_opt (this->argc_, this->argv_, "?d:");
+  ACE_Get_Opt get_opt (this->argc_, this->argv_, ACE_TEXT("?d:"));
   int opt;
   int exit_code = 0;
 
