@@ -1,4 +1,4 @@
-// $Id: Factory_Finder_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Factory_Finder_i.cpp 83153 2008-10-12 18:43:19Z johnnyw $
 
 // ============================================================================
 //
@@ -23,7 +23,7 @@
 
 ACE_RCSID (Quoter,
            Factory_Finder_i,
-           "$Id: Factory_Finder_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $")
+           "$Id: Factory_Finder_i.cpp 83153 2008-10-12 18:43:19Z johnnyw $")
 
 // Constructor
 Quoter_Factory_Finder_i::Quoter_Factory_Finder_i (int debug_level)
@@ -96,7 +96,7 @@ Quoter_Factory_Finder_i::find_factories (const CosLifeCycle::Key &factory_key)
   }
   catch (const CORBA::Exception&)
     {
-      ACE_ERROR ((LM_ERROR, "Quoter_Factory_Finder::find_factories - %s\n", exception_message));
+      ACE_ERROR ((LM_ERROR, "Quoter_Factory_Finder::find_factories - %C\n", exception_message));
       throw CosLifeCycle::NoFactory (factory_key);
     }
 
