@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 83153 2008-10-12 18:43:19Z johnnyw $
 // ============================================================================
 //
 // = FILENAME
@@ -16,7 +16,7 @@
 #include "server.h"
 #include "tao/ORB_Core.h"
 
-ACE_RCSID(Quoter, server, "$Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+ACE_RCSID(Quoter, server, "$Id: server.cpp 83153 2008-10-12 18:43:19Z johnnyw $")
 
 Quoter_Server::Quoter_Server (void)
   : num_of_objs_ (1),
@@ -28,7 +28,7 @@ Quoter_Server::Quoter_Server (void)
 int
 Quoter_Server::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "d:n:");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("d:n:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -61,7 +61,7 @@ Quoter_Server::parse_args (void)
 
 int
 Quoter_Server::init (int argc,
-                    char* argv[])
+                    ACE_TCHAR* argv[])
 {
   const char *exception_message = "Null Message";
   try
@@ -80,7 +80,7 @@ Quoter_Server::init (int argc,
       int i;
 
       // Make a copy of argv since ORB_init will change it.
-      this->argv_ = new char *[argc];
+      this->argv_ = new ACE_TCHAR *[argc];
 
       for (i = 0; i < argc; i++)
         this->argv_[i] = argv[i];
@@ -130,11 +130,11 @@ Quoter_Server::init (int argc,
 
       // Print the IOR.
       if (this->debug_level_ >= 2)
-        ACE_DEBUG ((LM_DEBUG, "Quoter Server: IOR is: <%s>\n", quoter_Factory_ior.in ()));
+        ACE_DEBUG ((LM_DEBUG, "Quoter Server: IOR is: <%C>\n", quoter_Factory_ior.in ()));
     }
   catch (const CORBA::Exception& ex)
     {
-      ACE_ERROR ((LM_ERROR, "Quote_Server::init - %s\n", exception_message));
+      ACE_ERROR ((LM_ERROR, "Quote_Server::init - %C\n", exception_message));
       ex._tao_print_exception ("Exception");
       throw;
     }
@@ -189,7 +189,7 @@ Quoter_Server::init_naming_service (void)
     }
   catch (const CORBA::Exception& ex)
     {
-      ACE_ERROR ((LM_ERROR, "Quote_Server::init_naming_service - %s", exception_message));
+      ACE_ERROR ((LM_ERROR, "Quote_Server::init_naming_service - %C", exception_message));
       ex._tao_print_exception ("Exception");
       return -1;
     }
