@@ -1,4 +1,4 @@
-//$Id: Builder.cpp 79942 2007-11-06 15:54:27Z vzykov $
+//$Id: Builder.cpp 85307 2009-05-08 19:30:46Z mesnier_p $
 #include "Builder.h"
 
 #include "ace/Get_Opt.h"
@@ -23,7 +23,7 @@ Builder::~Builder(void)
 }
 
 int
-Builder::init (int argc, char *argv[])
+Builder::init (int argc, ACE_TCHAR *argv[])
 {
   ACE_Arg_Shifter arg_shifter (argc, argv);
 
@@ -35,40 +35,40 @@ Builder::init (int argc, char *argv[])
 
   while (arg_shifter.is_anything_left ())
     {
-      if (0 != (current_arg = arg_shifter.get_the_parameter ("-TaskCount")))
+      if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-TaskCount"))))
         {
           task_count_ = ACE_OS::atoi (current_arg);
           ACE_NEW_RETURN (task_list_, Periodic_Task*[task_count_], -1);
           ACE_OS::memset (this->task_list_,
-                          this->task_count_ * sizeof (this->task_list_[0]),
-                          0);
+                          0,
+                          this->task_count_ * sizeof (this->task_list_[0]));
           arg_shifter.consume_arg ();
         }
-      if (0 != (current_arg = arg_shifter.get_the_parameter ("-JobCount")))
+      if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-JobCount"))))
         {
           job_count_ = ACE_OS::atoi (current_arg);
           ACE_NEW_RETURN (job_list_, Job_i*[job_count_], -1);
           ACE_OS::memset (this->job_list_,
-                          this->job_count_ * sizeof (this->job_list_[0]),
-                          0);
+                          0,
+                          this->job_count_ * sizeof (this->job_list_[0]));
           arg_shifter.consume_arg ();
         }
-      if (0 != (current_arg = arg_shifter.get_the_parameter ("-POACount")))
+      if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-POACount"))))
         {
           poa_count_ = ACE_OS::atoi (current_arg);
           ACE_NEW_RETURN (poa_list_, POA_Holder*[poa_count_], -1);
           ACE_OS::memset (this->poa_list_,
-                          this->poa_count_ * sizeof (this->poa_list_[0]),
-                          0);
+                          0,
+                          this->poa_count_ * sizeof (this->poa_list_[0]));
           arg_shifter.consume_arg ();
         }
-      else if (arg_shifter.cur_arg_strncasecmp ("-ThreadTask") == 0)
+      else if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-ThreadTask")) == 0)
         {
           if (task_count < this->task_count_)
             {
               arg_shifter.consume_arg ();
 
-              Periodic_Task *task;
+              Periodic_Task *task = 0;
 
               ACE_NEW_RETURN (task, Thread_Task (), -1);
 
@@ -80,7 +80,7 @@ Builder::init (int argc, char *argv[])
           else
             return -1;
         }
-      else if (arg_shifter.cur_arg_strncasecmp ("-Job") == 0)
+      else if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Job")) == 0)
         {
           if (job_count < this->job_count_)
             {
@@ -98,13 +98,13 @@ Builder::init (int argc, char *argv[])
           else
             return -1;
         }
-      else if (arg_shifter.cur_arg_strncasecmp ("-POA") == 0)
+      else if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-POA")) == 0)
         {
           if (poa_count < this->poa_count_)
             {
               arg_shifter.consume_arg ();
 
-              POA_Holder *poa_holder;
+              POA_Holder *poa_holder = 0;
 
               ACE_NEW_RETURN (poa_holder, POA_Holder (), -1);
 
@@ -119,7 +119,7 @@ Builder::init (int argc, char *argv[])
           else
             return -1;
         }
-        else
+      else
         {
           arg_shifter.ignore_arg ();
         }
@@ -145,7 +145,7 @@ Builder::fini (void)
   delete [] this->job_list_;
 
   for (count = 0; count < this->poa_count_; ++count)
-      delete this->poa_list_[count];
+    delete this->poa_list_[count];
   delete [] this->poa_list_;
 
   already_cleaned = true;
