@@ -1,4 +1,4 @@
-//$Id: Job_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+//$Id: Job_i.cpp 83023 2008-10-09 18:34:53Z johnnyw $
 #include "Job_i.h"
 
 #include "tao/debug.h"
@@ -24,10 +24,12 @@ Job_i::poa (void)
 int
 Job_i::init (ACE_Arg_Shifter& arg_shifter)
 {
-  job_name_ = arg_shifter.get_current (); // Read the name of the Job
+  // Read the name of the Job
+  job_name_ = ACE_TEXT_ALWAYS_CHAR(arg_shifter.get_current ());
   arg_shifter.consume_arg ();
 
-  POA_name_ = arg_shifter.get_current (); // Read the name of the POA
+  // Read the name of the POA
+  POA_name_ = ACE_TEXT_ALWAYS_CHAR(arg_shifter.get_current ());
   arg_shifter.consume_arg ();
 
   return 0;
