@@ -1,4 +1,4 @@
-//$Id: Periodic_Task.cpp 78500 2007-05-27 14:13:19Z sowayaa $
+//$Id: Periodic_Task.cpp 83023 2008-10-09 18:34:53Z johnnyw $
 
 #include "Periodic_Task.h"
 
@@ -31,32 +31,32 @@ Periodic_Task::init_task (ACE_Arg_Shifter& arg_shifter)
 
   while (arg_shifter.is_anything_left ())
     {
-      if (0 != (current_arg = arg_shifter.get_the_parameter ("-JobName")))
+      if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-JobName"))))
         {
-          name_ = current_arg;
+          name_ = ACE_TEXT_ALWAYS_CHAR(current_arg);
           arg_shifter.consume_arg ();
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Priority")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Priority"))))
         {
           task_priority_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Period")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Period"))))
         {
           period_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-ExecTime")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-ExecTime"))))
         {
           exec_time_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Phase")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Phase"))))
         {
           phase_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Iter")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Iter"))))
         {
           iter_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
@@ -67,7 +67,7 @@ Periodic_Task::init_task (ACE_Arg_Shifter& arg_shifter)
           if (task_stats_->init () == -1)
             return -1;
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Load")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Load"))))
         {
           load_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
@@ -102,12 +102,12 @@ Periodic_Task::job (Job_ptr job)
 void
 Periodic_Task::dump_stats (ACE_TCHAR* msg)
 {
-  char buf[BUFSIZ];
-  ACE_OS::sprintf (buf, "%s%s", name_.c_str (),".dat");
+  ACE_TCHAR buf[BUFSIZ];
+  ACE_OS::sprintf (buf, ACE_TEXT("%s%s"), name_.c_str (), ACE_TEXT(".dat"));
 
-  ACE_CString fname (buf);
+  ACE_TString fname (buf);
 
-  ACE_OS::sprintf (buf,"#%s #name %s, priority %d, period %ld, exec_time %ld, phase %ld, iter_ %d , load_ %d",
+  ACE_OS::sprintf (buf,ACE_TEXT("#%s #name %s, priority %d, period %ld, exec_time %ld, phase %ld, iter_ %d , load_ %d"),
                    msg, name_.c_str(), task_priority_, period_, exec_time_, phase_, iter_, load_);
 
   task_stats_->dump_samples (fname.c_str (), buf,
