@@ -1,4 +1,4 @@
-//$Id: Task_Stats.cpp 80173 2007-12-03 16:25:40Z sowayaa $
+//$Id: Task_Stats.cpp 83023 2008-10-09 18:34:53Z johnnyw $
 #include "Task_Stats.h"
 #include "ace/OS.h"
 #include "ace/Log_Msg.h"
@@ -75,8 +75,8 @@ Task_Stats::dump_samples (const ACE_TCHAR *file_name, const ACE_TCHAR *msg,
   double throughput =
     double(samples_count_) / elapsed_seconds;
 
-  ACE_OS::sprintf (out_msg, "#Throughtput: %f\n", throughput);
-  ACE_OS::fprintf (output_file, "%s\n",out_msg);
+  ACE_OS::sprintf (out_msg, ACE_TEXT("#Throughtput: %f\n"), throughput);
+  ACE_OS::fprintf (output_file, ACE_TEXT("%s\n"),out_msg);
 
   // dump latency stats.
   this->dump_latency_stats (out_msg, scale_factor);
