@@ -1,4 +1,4 @@
-//$Id: FP_Task.h 79327 2007-08-13 12:14:16Z sowayaa $
+//$Id: FP_Task.h 82046 2008-06-18 14:46:20Z elliott_c $
 #ifndef FP_TASK_H
 #define FP_TASK_H
 
@@ -8,7 +8,7 @@ class FP_Task : public Thread_Task
 {
 public:
   FP_Task (int importance,
-           int start_time,
+           time_t start_time,
            int load,
            int iter,
            int dist,
