@@ -1,4 +1,4 @@
-//$Id: test.h 76591 2007-01-25 18:17:52Z elliott_c $
+//$Id: test.h 83024 2008-10-09 18:45:47Z johnnyw $
 #ifndef TEST_H
 #define TEST_H
 #include /**/ "ace/pre.h"
@@ -21,9 +21,9 @@ class DT_Test :public ACE_Task <ACE_SYNCH>
 
   void check_supported_priorities (void);
 
-  int init (int argc, char *argv []);
+  int init (int argc, ACE_TCHAR *argv []);
 
-  void run (int argc, char *argv []);
+  void run (int argc, ACE_TCHAR *argv []);
 
   void dt_creator (FP_DT_Creator* dt_creator);
   FP_DT_Creator* dt_creator (void);
