@@ -1,4 +1,4 @@
-//$Id: MIF_DT_Creator.cpp 79327 2007-08-13 12:14:16Z sowayaa $
+//$Id: MIF_DT_Creator.cpp 82046 2008-06-18 14:46:20Z elliott_c $
 
 #include "MIF_DT_Creator.h"
 #include "test.h"
@@ -11,7 +11,7 @@ MIF_DT_Creator::MIF_DT_Creator (void)
 
 Thread_Task*
 MIF_DT_Creator::create_thr_task (int importance,
-                                 int start_time,
+                                 time_t start_time,
                                  int load,
                                  int iter,
                                  int dist,
@@ -37,11 +37,16 @@ MIF_DT_Creator::sched_param (int importance)
 }
 
 void
-MIF_DT_Creator::yield (int suspend_time,
+MIF_DT_Creator::yield (time_t suspend_time,
                        Thread_Task*)
 {
   try
     {
+      CORBA::Object_var object =
+        this->orb_->resolve_initial_references ("RTScheduler_Current");
+      RTScheduling::Current_var current =
+        RTScheduling::Current::_narrow (object.in ());
+
       ACE_Time_Value const sus_time_value (suspend_time);
       ACE_Time_Value now (ACE_OS::gettimeofday ());
       while (((now - *base_time_) < sus_time_value) || (suspend_time == 1))
@@ -51,9 +56,9 @@ MIF_DT_Creator::yield (int suspend_time,
           CORBA::Policy_var sched_param;
           sched_param = CORBA::Policy::_duplicate (this->sched_param (100));
           const char * name = 0;
-          current_->update_scheduling_segment (name,
-                                               sched_param.in (),
-                                               sched_param.in ());
+          current->update_scheduling_segment (name,
+                                              sched_param.in (),
+                                              sched_param.in ());
           now = ACE_OS::gettimeofday ();
           if (suspend_time == 1)
             break;
