@@ -1,4 +1,4 @@
-//$Id: MIF_DT_Creator.h 79327 2007-08-13 12:14:16Z sowayaa $
+//$Id: MIF_DT_Creator.h 82046 2008-06-18 14:46:20Z elliott_c $
 
 #ifndef MIF_DT_CREATOR_H
 #define MIF_DT_CREATOR_H
@@ -15,13 +15,13 @@ public:
 
   //virtual Task* task (void);
   virtual Thread_Task* create_thr_task (int importance,
-                                        int start_time,
+                                        time_t start_time,
                                         int load,
                                         int iter,
                                         int dist,
                                         char *job_name);
   
-  virtual void yield (int suspend_time,
+  virtual void yield (time_t suspend_time,
                       Thread_Task* task);
 
   virtual void wait (void);
