@@ -1,4 +1,4 @@
-//$Id: MIF_Scheduler.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+//$Id: MIF_Scheduler.cpp 87661 2009-11-20 08:35:09Z msmit $
 
 #include "MIF_Scheduler.h"
 #include "ace/Atomic_Op.h"
@@ -55,6 +55,12 @@ Segment_Sched_Param_Policy::copy (void)
   return copy;
 }
 
+CORBA::PolicyType
+Segment_Sched_Param_Policy::policy_type (void)
+{
+  return 0;
+}
+
 void
 Segment_Sched_Param_Policy::destroy (void)
 {
@@ -72,7 +78,11 @@ MIF_Scheduler::MIF_Scheduler (CORBA::ORB_ptr orb)
       this->current_ =
         RTScheduling::Current::_narrow (object.in ());
 
-      wait_ = 0;
+      object =
+        orb->resolve_initial_references ("PriorityMappingManager");
+
+      this->mapping_manager_ =
+        RTCORBA::PriorityMappingManager::_narrow (object.in ());
     }
   catch (const CORBA::Exception& ex)
     {
@@ -157,7 +167,7 @@ MIF_Scheduler::begin_new_scheduling_segment (const RTScheduling::Current::IdType
   if (desired_priority != 100)
     {
       //NOT Main Thread
-      DT* new_dt;
+      DT* new_dt = 0;
       ACE_NEW (new_dt,
                DT (this->lock_,
                    count));
@@ -204,7 +214,7 @@ MIF_Scheduler::update_scheduling_segment (const RTScheduling::Current::IdType &/
                 "%t MIF_Scheduler::update_scheduling_segment - Importance %d\n",
                 desired_priority));
 
-  DT* new_dt;
+  DT* new_dt = 0;
   ACE_NEW (new_dt,
            DT (this->lock_,
                count));
@@ -214,7 +224,7 @@ MIF_Scheduler::update_scheduling_segment (const RTScheduling::Current::IdType &/
   if (ready_que_.message_count () > 0)
     {
       DT* run_dt;
-      ACE_Message_Block* msg;
+      ACE_Message_Block* msg = 0;
       ready_que_.dequeue_head (msg);
       run_dt = dynamic_cast<DT*> (msg);
       if ((desired_priority == 100) || run_dt->msg_priority () >= (unsigned int)desired_priority)
@@ -249,8 +259,8 @@ MIF_Scheduler::end_scheduling_segment (const RTScheduling::Current::IdType &guid
 
   if (ready_que_.message_count () > 0)
     {
-      DT* run_dt;
-      ACE_Message_Block* msg;
+      DT* run_dt = 0;
+      ACE_Message_Block* msg = 0;
       ready_que_.dequeue_head (msg);
       run_dt = dynamic_cast<DT*> (msg);
       lock_.acquire ();
@@ -322,19 +332,23 @@ MIF_Scheduler::send_request (PortableInterceptor::ClientRequestInfo_ptr request_
                   priority,
                   ACE_DEFAULT_THREAD_PRIORITY));
 
-      current_->the_priority (priority + 1);
+      RTCORBA::Priority rtpriority;
+      RTCORBA::PriorityMapping* pm = this->mapping_manager_->mapping ();
+      if (pm->to_CORBA(priority + 1, rtpriority))
+        {
+          current_->the_priority (rtpriority);
 
-      ACE_Thread::self (current);
-      if (ACE_Thread::getprio (current, priority) == -1)
-        return;
+          ACE_Thread::self (current);
+          if (ACE_Thread::getprio (current, priority) == -1)
+            return;
 
-      ACE_DEBUG ((LM_DEBUG,
-                  "Bumped thread priority is %d\n",
-                  priority));
+          ACE_DEBUG ((LM_DEBUG,
+                      "Bumped thread priority is %d\n",
+                      priority));
+        }
 
-
-      DT* run_dt;
-      ACE_Message_Block* msg;
+      DT* run_dt = 0;
+      ACE_Message_Block* msg = 0;
       ready_que_.dequeue_head (msg);
       run_dt = dynamic_cast<DT*> (msg);
       run_dt->resume ();
@@ -433,8 +447,8 @@ MIF_Scheduler::send_reply (PortableInterceptor::ServerRequestInfo_ptr)
 
   if (ready_que_.message_count () > 0)
     {
-      DT* run_dt;
-      ACE_Message_Block* msg;
+      DT* run_dt = 0;
+      ACE_Message_Block* msg = 0;
       ready_que_.dequeue_head (msg);
       run_dt = dynamic_cast<DT*> (msg);
       lock_.acquire ();
@@ -448,8 +462,8 @@ MIF_Scheduler::send_exception (PortableInterceptor::ServerRequestInfo_ptr)
 {
   if (ready_que_.message_count () > 0)
     {
-      DT* run_dt;
-      ACE_Message_Block* msg;
+      DT* run_dt = 0;
+      ACE_Message_Block* msg = 0;
       ready_que_.dequeue_head (msg);
       run_dt = dynamic_cast<DT*> (msg);
       lock_.acquire ();
@@ -535,7 +549,13 @@ MIF_Scheduler::receive_reply (PortableInterceptor::ClientRequestInfo_ptr)
   if (ACE_Thread::getprio (current, priority) == -1)
     return;
 
-  current_->the_priority (priority - 1);
+  RTCORBA::Priority rtpriority;
+  RTCORBA::PriorityMapping* pm = this->mapping_manager_->mapping ();
+  if (pm->to_CORBA(priority - 1, rtpriority))
+    {
+      current_->the_priority (rtpriority);
+    }
+
   new_dt->suspend ();
   lock_.release ();
 }
@@ -575,7 +595,13 @@ MIF_Scheduler::receive_exception (PortableInterceptor::ClientRequestInfo_ptr)
   if (ACE_Thread::getprio (current, priority) == -1)
     return;
 
-  current_->the_priority (priority - 1);
+  RTCORBA::Priority rtpriority;
+  RTCORBA::PriorityMapping* pm = this->mapping_manager_->mapping ();
+  if (pm->to_CORBA(priority - 1, rtpriority))
+    {
+      current_->the_priority (rtpriority);
+    }
+
   new_dt->suspend ();
   lock_.release ();
 }
@@ -599,7 +625,7 @@ MIF_Scheduler::receive_other (PortableInterceptor::ClientRequestInfo_ptr)
                   guid->get_buffer (),
                   guid->length ());
 
-  DT* new_dt;
+  DT* new_dt = 0;
   ACE_NEW (new_dt,
            DT (this->lock_,
                gu_id));
@@ -615,7 +641,13 @@ MIF_Scheduler::receive_other (PortableInterceptor::ClientRequestInfo_ptr)
   if (ACE_Thread::getprio (current, priority) == -1)
     return;
 
-  current_->the_priority (priority - 1);
+  RTCORBA::Priority rtpriority;
+  RTCORBA::PriorityMapping* pm = this->mapping_manager_->mapping ();
+  if (pm->to_CORBA(priority - 1, rtpriority))
+    {
+      current_->the_priority (rtpriority);
+    }
+
   new_dt->suspend ();
   lock_.release ();
 }
