@@ -1,4 +1,4 @@
-//$Id: POA_Holder.cpp 78500 2007-05-27 14:13:19Z sowayaa $
+//$Id: POA_Holder.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "POA_Holder.h"
 
@@ -22,14 +22,14 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
 
   const ACE_TCHAR *current_arg = 0;
 
-  POA_name_ = arg_shifter.get_current (); // Read the name of the POA
+  POA_name_ = ACE_TEXT_ALWAYS_CHAR(arg_shifter.get_current ()); // Read the name of the POA
   arg_shifter.consume_arg ();
 
   while (arg_shifter.is_anything_left ())
     {
-      if (0 != (current_arg = arg_shifter.get_the_parameter ("-PriorityModel")))
+      if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-PriorityModel"))))
         {
-          if (arg_shifter.cur_arg_strncasecmp ("CLIENT") == 0)
+          if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("CLIENT")) == 0)
             priority_model_ = RTCORBA::CLIENT_PROPAGATED;
           else
             priority_model_ = RTCORBA::SERVER_DECLARED;
@@ -38,7 +38,7 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
           server_priority_ = ACE_OS::atoi (current_arg);
           arg_shifter.consume_arg ();
         }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Lanes")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Lanes"))))
         {
           int lanecount = ACE_OS::atoi (current_arg);
           lanes_.length (lanecount);
@@ -48,7 +48,7 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
           //parse lane values ...
           while (arg_shifter.is_anything_left ())
             {
-              if (arg_shifter.cur_arg_strncasecmp ("-Lane") == 0)
+              if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Lane")) == 0)
                 {
                   arg_shifter.consume_arg ();
 
@@ -74,7 +74,7 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
             } /* while -- lane values */
 
         } /* if -Lanes */
-      else if (arg_shifter.cur_arg_strncasecmp ("-ThreadPool") == 0)
+      else if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-ThreadPool")) == 0)
   {
     ACE_DEBUG ((LM_DEBUG,
           "Thread Pool\n"));
@@ -94,7 +94,7 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
           "Thread Pool Initialized\n"));
 
   }
-      else if (0 != (current_arg = arg_shifter.get_the_parameter ("-Bands")))
+      else if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Bands"))))
         {
     ACE_DEBUG ((LM_DEBUG,
           "Initializing Bands\n"));
@@ -107,7 +107,7 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
           //parse band values ...
           while (arg_shifter.is_anything_left ())
             {
-              if (arg_shifter.cur_arg_strncasecmp ("-Band") == 0)
+              if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Band")) == 0)
                 {
                   arg_shifter.consume_arg ();
 
@@ -120,7 +120,7 @@ POA_Holder::init (ACE_Arg_Shifter& arg_shifter)
                   arg_shifter.consume_arg ();
 
                   //if (TAO_debug_level > 0)
-                  ACE_DEBUG ((LM_DEBUG, "band parsed - %d, %d \n",
+                  ACE_DEBUG ((LM_DEBUG, "band parsed - %d, %d\n",
                               bands_[b_index].low, bands_[b_index].high));
                   b_index++;
                 }
@@ -290,7 +290,7 @@ POA_Holder::activate (RTCORBA::RTORB_ptr rt_orb, PortableServer::POA_ptr parent_
         "Initialized POA Policy\n"));
 
   if (TAO_debug_level > 0)
-    ACE_DEBUG ((LM_DEBUG, "creating POA %s\n", POA_name_.c_str ()));
+    ACE_DEBUG ((LM_DEBUG, "creating POA %C\n", POA_name_.c_str ()));
 
   // Get the POA Manager.
   PortableServer::POAManager_var poa_manager =
