@@ -1,4 +1,4 @@
-//$Id: Starter.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+//$Id: Starter.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Starter.h"
 
@@ -10,7 +10,7 @@ Starter::Starter (CORBA::ORB_ptr orb)
   if (this->naming_client_.init (orb) != 0)
     ACE_ERROR ((LM_ERROR,
     " (%P|%t) Unable to initialize "
-    "the TAO_Naming_Client. \n"));
+    "the TAO_Naming_Client.\n"));
 }
 
 void
@@ -29,7 +29,7 @@ Starter::fire (void)
        iterator != this->synchs_.end ();
        ++iterator)
     {
-      (*iterator).int_id_.in ()->go (base_time.sec ());
+      (*iterator).int_id_.in ()->go (static_cast<CORBA::Long> (base_time.sec ()));
     }
 }
 
@@ -92,7 +92,7 @@ Starter::add_to_synchs (CosNaming::BindingList &binding_list)
         binding_list [i].binding_name [0].id.in ();
 
       ACE_DEBUG ((LM_DEBUG,
-      "Synch Name %s\n",
+      "Synch Name %C\n",
       synch_name.c_str ()));
 
       CosNaming::Name name (1);
@@ -109,7 +109,7 @@ Starter::add_to_synchs (CosNaming::BindingList &binding_list)
         Synch::_narrow (obj.in ());
 
 
-      synch_obj->go (base_time.sec ());
+      synch_obj->go (static_cast<CORBA::Long> (base_time.sec ()));
 
 //        // Add this receiver to the receiver map.
 //        this->synchs_.bind (synch_name,
@@ -119,13 +119,11 @@ Starter::add_to_synchs (CosNaming::BindingList &binding_list)
 
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
-      CORBA::ORB_var orb = CORBA::ORB_init (argc,
-              argv,
-              "");
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
       Starter starter (orb.in ());
 
