@@ -1,4 +1,4 @@
-//Synch_i.cpp,v 1.2 2003/07/24 07:04:16 yamuna Exp
+//$Id: Synch_i.cpp 79327 2007-08-13 12:14:16Z sowayaa $
 
 #include "Synch_i.h"
 
@@ -8,14 +8,12 @@ Synch_i::Synch_i (void)
 }
 
 void
-Synch_i::go (CORBA::Long base_time
-             ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Synch_i::go (CORBA::Long base_time)
 {
   ACE_DEBUG ((LM_DEBUG,
-	      "GO\n"));
+              "GO\n"));
   this->synched_ = 1;
-  this->base_time_.set (base_time, 0);
+  this->base_time_.set (static_cast<time_t>(base_time), 0);
 }
 
 int
