@@ -3,7 +3,7 @@
 /**
  *  @file Task_Stats.h
  *
- *  $Id: Task_Stats.h 75381 2006-11-14 16:17:49Z parsons $
+ *  $Id: Task_Stats.h 82102 2008-06-20 12:24:23Z elliott_c $
  *
  *  Utility Stats class that maintains the readings.
  *
@@ -61,7 +61,7 @@ class RTSCHEDTESTLIB_Export Task_Stats
   void end_time (ACE_hrtime_t time);
 
   /// Record a sample
-  int sample (ACE_UINT32 thr_run_time, int thr_count);
+  int sample (time_t thr_run_time, int thr_count);
 
   void dump_samples (const ACE_TCHAR *file_name, const ACE_TCHAR *msg,
                      ACE_UINT32 scale_factor);
@@ -79,7 +79,7 @@ class RTSCHEDTESTLIB_Export Task_Stats
   ACE_UINT32 samples_count_;
 
   /// The samples : the time of execution. and the recorded exec. time .
-  ACE_UINT32 *thr_run_time_;
+  time_t *thr_run_time_;
   int *thr_count_;
 
   /// The minimum value
