@@ -1,4 +1,4 @@
-// $Id: Broadcaster_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Broadcaster_i.cpp 83322 2008-10-20 09:51:35Z vzykov $
 
 // ===========================================================
 //
@@ -154,8 +154,7 @@ Broadcaster_i::broadcast (const char *text)
         }
       catch (const CORBA::Exception& ex)
         {
-          ex._tao_print_exception (
-            "Failed to send a message\n");
+          ex._tao_print_exception ("Failed to send a message\n");
         }
     }
 }
