@@ -1,4 +1,4 @@
-// $Id: Receiver_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Receiver_i.cpp 83322 2008-10-20 09:51:35Z vzykov $
 
 // ===========================================================
 //
@@ -31,7 +31,7 @@ void
 Receiver_i::message (const char *msg)
 {
   ACE_DEBUG ((LM_DEBUG,
-              ": %s\n",
+              ACE_TEXT (": %C\n"),
               msg));
 }
 
