@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: Server_i.h 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: Server_i.h 83322 2008-10-20 09:51:35Z vzykov $
 
 // ===========================================================
 //
@@ -23,6 +23,7 @@
 
 #include "Broadcaster_i.h"
 #include "tao/Utils/ORB_Manager.h"
+#include "tao/Intrusive_Ref_Count_Handle_T.h"
 
 class Server_i
 {
@@ -32,34 +33,35 @@ class Server_i
 
 public:
   // = Initialization and termination methods.
- Server_i (void);
- // Constructor.
+  Server_i (void);
+  // Constructor.
 
- ~Server_i (void);
- // Destructor.
+  ~Server_i (void);
+  // Destructor.
 
- int init (int argc,
-            char *argv[]);
- // Initialize the server.
+  int init (int argc,
+            ACE_TCHAR *argv[]);
+  // Initialize the server.
 
- int run (void);
- // Run the ORB.
+  int run (void);
+  // Run the ORB.
 
 private:
-  int parse_args (int argc, char *argv[]);
+  int parse_args (int argc, ACE_TCHAR *argv[]);
   // Parses the command line arguments.
 
   int write_IOR (const char *ior);
   // Writes the server ior to a file, for the clients to pick up
   // later.
 
-  const char *ior_file_name_;
+  const ACE_TCHAR *ior_file_name_;
   // The file name to save the ior to.
 
   TAO_ORB_Manager orb_manager_;
   // The tao orb manager object.
 
-  Broadcaster_i broadcaster_i_;
+  typedef TAO_Intrusive_Ref_Count_Handle<Broadcaster_i> Broadcaster_i_var;
+  Broadcaster_i_var broadcaster_i_;
   // The servant object registered with the orb.
 };
 
