@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 83322 2008-10-20 09:51:35Z vzykov $
 
 // ===========================================================
 //
@@ -22,7 +22,6 @@
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
-
   try
     {
       Server_i server_i;
@@ -30,12 +29,12 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       int ret = server_i.init (argc, argv);
       if (ret != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
-                           "\n error in init.\n"),
+                           ACE_TEXT ("\n error in init.\n")),
                           1);
       ret = server_i.run ();
       if (ret != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
-                           "\n error in run.\n"),
+                           ACE_TEXT ("\n error in run.\n")),
                           1);
     }
   catch (const CORBA::Exception& ex)
