@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Echo_Client_i.h 24044 1999-06-07 17:48:56Z schmidt $
+// $Id: Echo_Client_i.h 83322 2008-10-20 09:51:35Z vzykov $
 
 // ============================================================================
 //
@@ -37,14 +37,14 @@ public:
   Echo_Client_i (void);
   // Constructor
 
-  virtual  ~Echo_Client_i (void);
+  ~Echo_Client_i (void);
   // Destructor
 
-  virtual int run (const char *, int, char **);
+  int run (const char *, int, ACE_TCHAR **);
   // Execute the methods
 
 private:
-  Client<Echo, Echo_var> client;
+  Client<Echo> client_;
   // Instantiate the client object.
 };
 
