@@ -1,8 +1,8 @@
-// $Id: Echo_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Echo_i.cpp 83322 2008-10-20 09:51:35Z vzykov $
 
 #include "Echo_i.h"
 
-ACE_RCSID(Echo, Echo_i, "$Id: Echo_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $")
+ACE_RCSID(Echo, Echo_i, "$Id: Echo_i.cpp 83322 2008-10-20 09:51:35Z vzykov $")
 
 // Constructor.
 
@@ -87,8 +87,7 @@ void
 Echo_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
-              "\n%s\n",
-              "The echo server is shutting down"));
+              ACE_TEXT ("\nThe echo server is shutting down\n")));
 
   // Instruct the ORB to shutdown.
   this->orb_->shutdown ();
