@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Grid_Client_i.h 24044 1999-06-07 17:48:56Z schmidt $
+// $Id: Grid_Client_i.h 83322 2008-10-20 09:51:35Z vzykov $
 
 // ============================================================================
 //
@@ -36,17 +36,17 @@ public:
   Grid_Client_i (void);
   // Constructor
 
-  virtual ~Grid_Client_i (void);
+  ~Grid_Client_i (void);
   // Destructor
 
-  virtual int run (const char *, int, char *[]);
+  int run (const char *, int, ACE_TCHAR *[]);
   // Execute the methods.
 
-  virtual int parse_args (int argc, char *argv[]);
+  int parse_args (int argc, ACE_TCHAR *argv[]);
   // Parses the command line arguments.
 
 private:
-  Client<Grid_Factory, Grid_Factory_var> client;
+  Client<Grid_Factory> client_;
   // Instantiate the client object.
 
   CORBA::Short height_;
