@@ -1,4 +1,4 @@
-// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: server.cpp 83322 2008-10-20 09:51:35Z vzykov $
 #include "../Simple_util.h"
 #include "Grid_i.h"
 
@@ -10,8 +10,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
   Server<Grid_Factory_i> server;
 
   ACE_DEBUG ((LM_DEBUG,
-              "\n\tGrid server\n\n"));
-
+              ACE_TEXT ("\n\tGrid server\n\n")));
 
   try
     {
@@ -39,4 +38,3 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
   return 0;
 }
-
