@@ -1,4 +1,4 @@
-//$Id: Time_Date_Client_i.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+//$Id: Time_Date_Client_i.cpp 83322 2008-10-20 09:51:35Z vzykov $
 
 #include "Time_Date_Client_i.h"
 #include "ace/Get_Opt.h"
@@ -20,7 +20,7 @@ Time_Date_Client_i::~Time_Date_Client_i (void)
 
 int
 Time_Date_Client_i::parse_args (int,
-                                char *[])
+                                ACE_TCHAR *[])
 {
   return 0;
 }
@@ -28,7 +28,7 @@ Time_Date_Client_i::parse_args (int,
 int
 Time_Date_Client_i::run (const char *name,
                          int argc,
-                         char *argv[])
+                         ACE_TCHAR *argv[])
 {
   // Initialize the client.
   if (client_.init (name, argc, argv) == -1)
@@ -37,7 +37,6 @@ Time_Date_Client_i::run (const char *name,
   if (this->parse_args (argc, argv) == -1)
     return -1;
 
-
   try
     {
       CORBA::Long l;
@@ -46,7 +45,7 @@ Time_Date_Client_i::run (const char *name,
       client_->bin_date (l);
 
       ACE_DEBUG ((LM_DEBUG,
-                  "(%P|%t) Binary time_date = %d\n",
+                  ACE_TEXT ("(%P|%t) Binary time_date = %d\n"),
                   l));
 
       // Get the time & date in string format.
@@ -54,10 +53,11 @@ Time_Date_Client_i::run (const char *name,
       client_->str_date (str_var.out());
 
       ACE_DEBUG ((LM_DEBUG,
-                  "(%P|%t) String time_date = %s\n",
+                  ACE_TEXT ("(%P|%t) String time_date = %C\n"),
                   str_var.in()));
 
-      client_.shutdown ();
+      if (client_.do_shutdown () == 1)
+        client_->shutdown ();
     }
   catch (const CORBA::UserException& range_ex)
     {
@@ -72,4 +72,3 @@ Time_Date_Client_i::run (const char *name,
 
   return 0;
 }
-
