@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Time_Date_Client_i.h 55067 2004-01-02 09:00:16Z ossama $
+// $Id: Time_Date_Client_i.h 83322 2008-10-20 09:51:35Z vzykov $
 
 // ============================================================================
 //
@@ -39,14 +39,14 @@ public:
   virtual ~Time_Date_Client_i (void);
   // Destructor
 
-  virtual int run (const char *, int, char *[]);
+  virtual int run (const char *, int, ACE_TCHAR *[]);
   // Execute the methods.
 
-  virtual int parse_args (int argc, char *argv[]);
+  virtual int parse_args (int argc, ACE_TCHAR *argv[]);
   // Parses the command line arguments.
 
 private:
-  Client<Time_Date, Time_Date_var> client_;
+  Client<Time_Date> client_;
   // Instantiate the client object.
 };
 
