@@ -1,4 +1,4 @@
-// server.cpp,v 1.9 2005/01/31 04:48:15 ossama Exp
+// $Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $
 
 // ============================================================================
 //
@@ -24,10 +24,10 @@
 
 ACE_RCSID (time_date,
            server,
-           "server.cpp,v 1.9 2005/01/31 04:48:15 ossama Exp")
+           "$Id: server.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   if (ACE_Service_Config::open (argc, argv) == -1
       && errno != ENOENT)
