@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Time_Client_i.h 28943 1999-09-26 21:51:01Z schmidt $
+// $Id: Time_Client_i.h 83322 2008-10-20 09:51:35Z vzykov $
 
 // ============================================================================
 //
@@ -36,16 +36,15 @@ public:
   Time_Client_i (void);
   // Constructor
 
-  virtual ~Time_Client_i (void);
+  ~Time_Client_i (void);
   // Destructor
 
-  virtual int run (const char *,int, char** );
+  int run (const char *, int, ACE_TCHAR**);
   // Execute the methods
 
 private:
-  Client<Time, Time_var> client;
+  Client<Time> client_;
   // Instantiate the client object.
 };
 
-
 #endif /* TIME_CLIENT_I_H */
