@@ -1,9 +1,9 @@
-// $Id: Time_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Time_i.cpp 83322 2008-10-20 09:51:35Z vzykov $
 
 #include "Time_i.h"
 #include "ace/OS_NS_time.h"
 
-ACE_RCSID(Time, Time_i, "$Id: Time_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $")
+ACE_RCSID(Time, Time_i, "$Id: Time_i.cpp 83322 2008-10-20 09:51:35Z vzykov $")
 
 // Constructor
 Time_i::Time_i (void)
@@ -12,14 +12,12 @@ Time_i::Time_i (void)
 }
 
 // Destructor
-
 Time_i::~Time_i (void)
 {
   // no-op
 }
 
 // Set the ORB pointer.
-
 void
 Time_i::orb (CORBA::ORB_ptr o)
 {
@@ -27,7 +25,6 @@ Time_i::orb (CORBA::ORB_ptr o)
 }
 
 // Return the current date/time on the server.
-
 CORBA::Long
 Time_i::current_time (void)
 {
@@ -35,15 +32,12 @@ Time_i::current_time (void)
 }
 
 // Shutdown.
-
 void
-Time_i::shutdown ( )
+Time_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
-              "%s\n",
-              "Time_i is shutting down"));
+              ACE_TEXT ("Time_i is shutting down\n")));
 
   // Instruct the ORB to shutdown.
   this->orb_->shutdown ();
 }
-
