@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Time_i.h 77003 2007-02-12 09:23:36Z johnnyw $
+// $Id: Time_i.h 83322 2008-10-20 09:51:35Z vzykov $
 
 // ============================================================================
 //
@@ -36,14 +36,13 @@ public:
   Time_i (void);
   // Constructor
 
-  ~Time_i (void);
+  virtual ~Time_i (void);
   // Destructor
 
   virtual CORBA::Long current_time (void);
   // Return the current time/date on the server
 
   virtual void shutdown (void);
-
   // Shutdown the server.
 
   void orb (CORBA::ORB_ptr o);
