@@ -1,4 +1,4 @@
-// $Id: DualEC_Sup.cpp 79317 2007-08-11 17:28:39Z sowayaa $
+// $Id: DualEC_Sup.cpp 83030 2008-10-09 19:11:19Z johnnyw $
 
 // ============================================================================
 //
@@ -40,7 +40,7 @@
 
 ACE_RCSID (Event_Supplier,
            DualEC_Sup,
-           "$Id: DualEC_Sup.cpp 79317 2007-08-11 17:28:39Z sowayaa $")
+           "$Id: DualEC_Sup.cpp 83030 2008-10-09 19:11:19Z johnnyw $")
 
 //FUZZ: disable check_for_lack_ACE_OS
 static const char usage [] =
@@ -58,7 +58,7 @@ static const char usage [] =
 "                 [-p to suppress prioritization of operations]\n";
 //FUZZ: enable check_for_lack_ACE_OS
 
-DualEC_Supplier::DualEC_Supplier (int argc, char** argv)
+DualEC_Supplier::DualEC_Supplier (int argc, ACE_TCHAR** argv)
 : nav_pause_ (0, 100000),
   weap_pause_ (0, 100000),
   channel_hi_name_ (1),
@@ -78,8 +78,8 @@ DualEC_Supplier::DualEC_Supplier (int argc, char** argv)
   dump_schedule_headers_ (0),
   use_runtime_schedulers_ (0),
   suppress_priority_ (0),
-  hi_schedule_file_name_ ("DualEC_Runtime_Hi.h"),
-  lo_schedule_file_name_ ("DualEC_Runtime_Lo.h"),
+  hi_schedule_file_name_ (ACE_TEXT("DualEC_Runtime_Hi.h")),
+  lo_schedule_file_name_ (ACE_TEXT("DualEC_Runtime_Lo.h")),
   nav_roll_ (0),
   nav_pitch_ (0)
 {
@@ -890,9 +890,9 @@ DualEC_Supplier::load_schedule_data ()
 // Get command line options.
 
 unsigned int
-DualEC_Supplier::get_options (int argc, char *argv [])
+DualEC_Supplier::get_options (int argc, ACE_TCHAR *argv [])
 {
-  ACE_Get_Opt get_opt (argc, argv, "f:m:b:n:w:dsrp");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("f:m:b:n:w:dsrp"));
   int opt;
   int temp;
 
