@@ -1,4 +1,4 @@
-// $Id: Event_Sup.h 16777 1998-10-20 02:34:57Z levine $
+// $Id: Event_Sup.h 83030 2008-10-09 19:11:19Z johnnyw $
 
 // ============================================================================
 //
@@ -44,7 +44,7 @@ class Event_Supplier
   //    is connected to the event channel
 public:
 
-  Event_Supplier (int argc, char** argv);
+  Event_Supplier (int argc, ACE_TCHAR** argv);
 
   ~Event_Supplier (void);
 
@@ -64,16 +64,16 @@ private:
                           ACE_Unbounded_Queue_Iterator<Schedule_Viewer_Data *> &schedule_iter);
   // just a helper to put all the information into the CORBA::Any
 
-  unsigned int get_options (int argc, char *argv []);
+  unsigned int get_options (int argc, ACE_TCHAR *argv []);
 
   DOVE_Supplier dOVE_Supplier_;
   Navigation navigation_;
   Weapons weapons_;
 
   int argc_;
-  char **argv_;
+  ACE_TCHAR **argv_;
   unsigned long total_messages_;
-  char *input_file_name_;
+  ACE_TCHAR *input_file_name_;
 };
 
 #endif /* EVENT_SUP_H */
