@@ -1,18 +1,16 @@
-// $Id: main.cpp 77421 2007-02-27 12:44:34Z elliott_c $
+// $Id: main.cpp 82083 2008-06-19 14:26:04Z sma $
 
 #include "testC.h"
 #include "tao/IFR_Client/IFR_BasicC.h"
 #include "tao/TypeCodeFactory/TypeCodeFactory_Adapter_Impl.h"
 
-ACE_RCSID(TypeCode_Creation, main, "$Id: main.cpp 77421 2007-02-27 12:44:34Z elliott_c $")
+ACE_RCSID(TypeCode_Creation, main, "$Id: main.cpp 82083 2008-06-19 14:26:04Z sma $")
 
-int main(int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
-      CORBA::ORB_var orb = CORBA::ORB_init (argc,
-                                            argv,
-                                            "");
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
       CORBA::TypeCode_var iface_tc =
         orb->create_interface_tc (CORBA::string_dup ("IDL:iface:1.0"),
