@@ -2,7 +2,7 @@
 /**
  *  @file    corbaname_client.cpp
  *
- *  $Id: corbaname_client.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+ *  $Id: corbaname_client.cpp 83157 2008-10-12 19:22:31Z johnnyw $
  *
  *   This implements a simple CORBA client to tests the
  *   corbaname: style IOR parser
@@ -15,17 +15,14 @@
 #include "corbalocC.h"
 #include "ace/Log_Msg.h"
 
-int main (int argc, char *argv [])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv [])
 {
 
   try
     {
       // First initialize the ORB, that will remove some arguments...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         "" /* the ORB name, it can be anything! */
-                         );
+        CORBA::ORB_init (argc, argv);
 
       if(argc < 2 )
         {
