@@ -1,4 +1,4 @@
-// $Id: ior_corbaloc_client_i.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: ior_corbaloc_client_i.cpp 83157 2008-10-12 19:22:31Z johnnyw $
 
 // ===========================================================
 //
@@ -87,18 +87,13 @@ IOR_corbaloc_Client_i::run (void)
 
 int
 IOR_corbaloc_Client_i::init (int& argc,
-                             char *argv[])
+                             ACE_TCHAR *argv[])
 {
-
   try
     {
-
       // First initialize the ORB, that will remove some arguments...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         "" /* the ORB name, it can be anything! */
-                         );
+        CORBA::ORB_init (argc, argv);
 
       if(argc < 2){
               ACE_DEBUG((LM_DEBUG, "\nUsage:\n  %s [corbaloc URL for NameService]\n", argv[0]));
