@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: ior_corbaloc_client_i.h 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: ior_corbaloc_client_i.h 83031 2008-10-09 19:13:37Z johnnyw $
 
 // ===========================================================
 //
@@ -43,12 +43,12 @@ class IOR_corbaloc_Client_i
   int run (void);
   // Execute the client example code.
 
-  int init (int& argc, char *argv[]);
+  int init (int& argc, ACE_TCHAR *argv[]);
   // Initialize the client communication endpoint with the server.
 
  private:
   /// corbaloc url to test
-  ACE_CString corbaloc_url_;
+  ACE_TString corbaloc_url_;
 
   /// Naming context
   CosNaming::NamingContextExt_var naming_context_;
