@@ -1,4 +1,4 @@
-// status_i.cpp,v 1.1 2002/12/27 19:51:37 bala Exp
+// $Id: status_i.cpp 77003 2007-02-12 09:23:36Z johnnyw $
 
 #include "status_i.h"
 
@@ -9,8 +9,7 @@ corbaloc_Status_i::corbaloc_Status_i ()
 }
 
 CORBA::Boolean
-corbaloc_Status_i::print_status (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+corbaloc_Status_i::print_status (void)
 {
   // If the server received the request from the client, return true
   // == 0;
