@@ -4,7 +4,7 @@
 /**
  *  @file   EventChannelFactory_i.h
  *
- *  EventChannelFactory_i.h,v 1.7 2004/08/16 23:53:11 jtc Exp
+ *  $Id: EventChannelFactory_i.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -29,25 +29,11 @@ public:
     const char * type_id,
     const PortableGroup::Criteria & the_criteria,
     PortableGroup::GenericFactory::FactoryCreationId_out factory_creation_id
-    ACE_ENV_ARG_DECL
-    )
-    ACE_THROW_SPEC ((
-    CORBA::SystemException
-    , PortableGroup::NoFactory
-    , PortableGroup::ObjectNotCreated
-    , PortableGroup::InvalidCriteria
-    , PortableGroup::InvalidProperty
-    , PortableGroup::CannotMeetCriteria
-    )) ;
+    );
 
   virtual void delete_object (
     const PortableGroup::GenericFactory::FactoryCreationId & factory_creation_id
-    ACE_ENV_ARG_DECL
-    )
-    ACE_THROW_SPEC ((
-    CORBA::SystemException
-    , PortableGroup::ObjectNotFound
-    ));
+    );
 
 private:
   CORBA::Object_ptr create_process (
