@@ -1,4 +1,4 @@
-// $Id: FTRTEC_Factory_Service.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: FTRTEC_Factory_Service.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "EventChannelFactory_i.h"
 #include "ace/Task.h"
@@ -7,13 +7,14 @@
 
 ACE_RCSID (Factory_Service,
            FTRTEC_Factory_Service,
-           "$Id: FTRTEC_Factory_Service.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: FTRTEC_Factory_Service.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 namespace {
-  ACE_CString id, kind, output;
+  ACE_CString id, kind;
+  ACE_TString output;
 }
 
-int parse_args(int argc, char* argv[])
+int parse_args(int argc, ACE_TCHAR* argv[])
 {
   ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("i:k:o:"));
   int opt;
@@ -24,10 +25,10 @@ int parse_args(int argc, char* argv[])
     switch (opt)
     {
     case 'i':
-      id = get_opt.opt_arg ();
+      id = ACE_TEXT_ALWAYS_CHAR(get_opt.opt_arg ());
       break;
     case 'k':
-      kind = get_opt.opt_arg ();
+      kind = ACE_TEXT_ALWAYS_CHAR(get_opt.opt_arg ());
       break;
     case 'o':
       output = get_opt.opt_arg ();
@@ -38,10 +39,10 @@ int parse_args(int argc, char* argv[])
     }
   }
 
-  if (result == -1 || (id.length() == 0 && output.length() == 0))
+  if (result == -1 || (id.length () == 0 && output.length () == 0))
   {
     ACE_DEBUG ((LM_DEBUG,
-      ACE_TEXT("Usage: %s \n")
+      ACE_TEXT("Usage: %s\n")
       ACE_TEXT("  [-i id]  set the id that is used to register to the naming service\n")
       ACE_TEXT("  [-k kind] set the kind that is used to register to the naming service\n")
       ACE_TEXT("  [-o filename] set the output file name for the IOR\n")
@@ -52,29 +53,29 @@ int parse_args(int argc, char* argv[])
   return 0;
 }
 
-int main(int argc, ACE_TCHAR* argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
 
   try{
-    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv, "");
+    CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
-    if (parse_args(argc, argv) == -1)
+    if (parse_args (argc, argv) == -1)
       return -1;
 
     CORBA::Object_var obj =
-      orb->resolve_initial_references("RootPOA");
+      orb->resolve_initial_references ("RootPOA");
 
     PortableServer::POA_var poa =
-      PortableServer::POA::_narrow(obj.in());
+      PortableServer::POA::_narrow (obj.in ());
 
-    PortableServer::POAManager_var mgr = poa->the_POAManager();
+    PortableServer::POAManager_var mgr = poa->the_POAManager ();
 
-    mgr->activate();
+    mgr->activate ();
 
-    EventChannelFactory_i servant("factory.cfg", orb.in());
+    EventChannelFactory_i servant ("factory.cfg", orb.in ());
 
     FT::GenericFactory_var event_channel_factory =
-      servant._this();
+      servant._this ();
 
     // register to the Event Service
 
@@ -104,10 +105,10 @@ int main(int argc, ACE_TCHAR* argv[])
       // get the IOR of factory
       CORBA::String_var str = orb->object_to_string(event_channel_factory.in());
 
-      if (ACE_OS::strcmp(output.c_str(), "") != 0)
+      if (ACE_OS::strcmp(output.c_str(), ACE_TEXT("")) != 0)
       {
         FILE *output_file=
-          ACE_OS::fopen (ACE_TEXT_CHAR_TO_TCHAR(output.c_str()),
+          ACE_OS::fopen (output.c_str(),
           ACE_TEXT("w"));
         if (output_file == 0)
           ACE_ERROR_RETURN ((LM_ERROR,
