@@ -3,7 +3,7 @@
 /**
  *  @file    FT_FaultAnalyzer.cpp
  *
- *  FT_FaultAnalyzer.cpp,v 1.2 2003/12/22 01:44:37 wilson_d Exp
+ *  $Id: FT_FaultAnalyzer.cpp 75478 2006-11-22 13:58:29Z jtc $
  *
  *  This file is part of TAO's implementation of Fault Tolerant CORBA.
  *
@@ -15,7 +15,9 @@
 
 ACE_RCSID (FT_FaultAnalyzer,
            FT_FaultAnalyzer,
-           "FT_FaultAnalyzer.cpp,v 1.2 2003/12/22 01:44:37 wilson_d Exp")
+           "$Id: FT_FaultAnalyzer.cpp 75478 2006-11-22 13:58:29Z jtc $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /// Default constructor.
 TAO::FT_FaultAnalyzer::FT_FaultAnalyzer ()
@@ -27,3 +29,4 @@ TAO::FT_FaultAnalyzer::~FT_FaultAnalyzer ()
 {
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
