@@ -4,7 +4,7 @@
 /**
  * @file FT_Property_Validator.h
  *
- * FT_Property_Validator.h,v 1.5 2004/08/16 23:53:11 jtc Exp
+ * $Id: FT_Property_Validator.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  * @author Curt Hibbs <hibbs_c@ociweb.com>
  */
@@ -22,6 +22,8 @@
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   /**
@@ -46,21 +48,13 @@ namespace TAO
     /// first invalid property is encountered.  The remaining properties
     /// will not be validated.
     virtual
-    void validate_property (const PortableGroup::Properties & props
-                            ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException,
-                      PortableGroup::InvalidProperty,
-                      PortableGroup::UnsupportedProperty));
+    void validate_property (const PortableGroup::Properties & props);
 
     /// Validate the given properties/criteria.  All criteria
     /// will be validated regardless of whether or not an invalid
     /// property was encountered.
     virtual
-    void validate_criteria (const PortableGroup::Properties & criteria
-                            ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException,
-                      PortableGroup::InvalidCriteria,
-                      PortableGroup::CannotMeetCriteria));
+    void validate_criteria (const PortableGroup::Properties & criteria);
 
   private:
 
@@ -88,6 +82,8 @@ namespace TAO
 
 } // namespace TAO
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* FT_PROPERTY_VALIDATOR_H */
