@@ -3,7 +3,7 @@
 /**
  *  @file    FT_ReplicationManagerFaultAnalyzer.cpp
  *
- *  $Id: FT_ReplicationManagerFaultAnalyzer.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+ *  $Id: FT_ReplicationManagerFaultAnalyzer.cpp 83216 2008-10-13 18:03:16Z johnnyw $
  *
  *  This file is part of TAO's implementation of Fault Tolerant CORBA.
  *
@@ -24,7 +24,7 @@
 
 ACE_RCSID (FT_ReplicationManagerFaultAnalyzer,
            FT_ReplicationManagerFaultAnalyzer,
-           "$Id: FT_ReplicationManagerFaultAnalyzer.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: FT_ReplicationManagerFaultAnalyzer.cpp 83216 2008-10-13 18:03:16Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -68,9 +68,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::analyze_fault_event (
     for (CORBA::ULong n_prop = 0; n_prop < item_count; ++n_prop)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT(
-          "TAO::FT_ReplicationManagerFaultAnalyzer::analyze_fault_event: "
-          "Property Name: <%s>\n"),
+        ACE_TEXT("TAO::FT_ReplicationManagerFaultAnalyzer::analyze_fault_event: ")
+        ACE_TEXT("Property Name: <%C>\n"),
         filterable[n_prop].name.in()
       ));
     }
@@ -160,9 +159,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_type_id (
   if ((val >>= type_id_value) == 0)
   {
     ACE_ERROR_RETURN ((LM_ERROR,
-      ACE_TEXT (
-        "TAO::FT_ReplicationManagerFaultAnalyzer::get_type_id: "
-        "Could not extract TypeId value from any.\n")),
+      ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_type_id: ")
+      ACE_TEXT("Could not extract TypeId value from any.\n")),
       -1);
   }
 
@@ -179,9 +177,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_object_group_id (
   if ((val >>= temp_id) == 0)
   {
     ACE_ERROR_RETURN ((LM_ERROR,
-      ACE_TEXT (
-        "TAO::FT_ReplicationManagerFaultAnalyzer::get_object_group_id: "
-        "Could not extract ObjectGroupId value from any.\n")),
+      ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_object_group_id: ")
+      ACE_TEXT("Could not extract ObjectGroupId value from any.\n")),
       -1);
   }
   id = temp_id;
@@ -195,9 +192,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_location (
   if ((val >>= temp_loc) == 0)
   {
     ACE_ERROR_RETURN ((LM_ERROR,
-      ACE_TEXT (
-        "TAO::FT_ReplicationManagerFaultAnalyzer::get_location: "
-        "Could not extract Location value from fault event.\n")),
+      ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_location: ")
+      ACE_TEXT("Could not extract Location value from fault event.\n")),
       -1);
   }
   // Make a deep copy of the Location.
@@ -227,9 +223,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_membership_style (
     if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::get_membership_style: "
-          "MembershipStyle is <%d>:\n"),
+        ACE_TEXT("TAO::FT_ReplicationManagerFaultAnalyzer::get_membership_style: ")
+        ACE_TEXT("MembershipStyle is <%d>:\n"),
         membership_style
       ));
     }
@@ -258,9 +253,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_replication_style (
     if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::get_replication_style: "
-          "ReplicationStyle is <%d>:\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_replication_style: ")
+        ACE_TEXT ("ReplicationStyle is <%d>:\n"),
         replication_style
       ));
     }
@@ -289,9 +283,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_minimum_number_members (
     if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::get_minimum_number_members: "
-          "MinimumNumberMembers is <%d>:\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_minimum_number_members: ")
+        ACE_TEXT ("MinimumNumberMembers is <%d>:\n"),
         minimum_number_members
       ));
     }
@@ -320,9 +313,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_initial_number_members (
     if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::get_initial_number_members: "
-          "InitialNumberMembers is <%d>:\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_initial_number_members: ")
+        ACE_TEXT ("InitialNumberMembers is <%d>:\n"),
         initial_number_members
       ));
     }
@@ -351,9 +343,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_factories (
     if ((value >>= temp_factories) == 0)
     {
       ACE_ERROR ((LM_ERROR,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::get_factories: "
-          "Could not extract Factories from properties.\n")
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_factories: ")
+        ACE_TEXT ("Could not extract Factories from properties.\n")
       ));
       result = -1;
     }
@@ -367,9 +358,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::get_factories (
   else
   {
     ACE_ERROR ((LM_ERROR,
-      ACE_TEXT (
-        "TAO::FT_ReplicationManagerFaultAnalyzer::get_factories: "
-        "Could not find Factories property.\n")
+      ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::get_factories: ")
+      ACE_TEXT ("Could not find Factories property.\n")
     ));
     result = -1;
   }
@@ -417,9 +407,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member (
         if (CORBA::is_nil (primary_obj.in()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-            ACE_TEXT (
-              "TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: "
-              "Could not get primary IOR from IOGR.\n")),
+            ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: ")
+            ACE_TEXT ("Could not get primary IOR from IOGR.\n")),
             -1);
         }
 
@@ -430,9 +419,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member (
         if (CORBA::is_nil (failed_obj.in()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-            ACE_TEXT (
-              "TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: "
-              "Could not get IOR of failed member from IOGR.\n")),
+            ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: ")
+            ACE_TEXT ("Could not get IOR of failed member from IOGR.\n")),
             -1);
         }
 
@@ -448,9 +436,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member (
       else  // primary is not set
       {
         ACE_ERROR ((LM_ERROR,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: "
-            "Primary is not set on IOGR.\n")
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: ")
+          ACE_TEXT ("Primary is not set on IOGR.\n")
         ));
         result = -1;
       }
@@ -458,9 +445,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member (
     else // could not get tagged component
     {
       ACE_ERROR ((LM_ERROR,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: "
-          "Could not get tagged component from IOGR.\n")
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: ")
+        ACE_TEXT ("Could not get tagged component from IOGR.\n")
       ));
       result = -1;
     }
@@ -468,8 +454,7 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member (
   catch (const CORBA::Exception& ex)
   {
     ex._tao_print_exception (
-      ACE_TEXT (
-        "TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: "));
+      ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::is_primary_member: "));
     result = -1;
   }
 
@@ -495,9 +480,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
     if (CORBA::is_nil (the_object_group.in()))
     {
       ACE_ERROR ((LM_ERROR,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-          "Could not get ObjectGroup reference from ObjectGroupId: <%Q>.\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+        ACE_TEXT ("Could not get ObjectGroup reference from ObjectGroupId: <%Q>.\n"),
           fault_event_desc.object_group_id
       ));
       throw PortableGroup::ObjectGroupNotFound ();
@@ -524,10 +508,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
     {
       //@@ it seems a shame to fail here.  We should at least remove the failed replica from the group.
       ACE_ERROR_RETURN ((LM_ERROR,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-          "Could not extract MembershipStyle from properties on "
-          "ObjectGroup with id <%Q>.\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+        ACE_TEXT ("Could not extract MembershipStyle from properties on ")
+        ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
         fault_event_desc.object_group_id),
         -1);
     }
@@ -537,9 +520,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 6)
       {
         ACE_DEBUG ((LM_DEBUG,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "MembershipStyleValue = <%d>"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("MembershipStyleValue = <%d>"),
             fault_event_desc.membership_style
         ));
       }
@@ -552,10 +534,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
     {
       //@@ it seems a shame to fail here.  We should at least remove the failed replica from the group.
       ACE_ERROR_RETURN ((LM_ERROR,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-          "Could not extract ReplicationStyle from properties on "
-          "ObjectGroup with id <%Q>.\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+        ACE_TEXT ("Could not extract ReplicationStyle from properties on ")
+        ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
         fault_event_desc.object_group_id),
         -1);
     }
@@ -565,9 +546,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 6)
       {
         ACE_DEBUG ((LM_DEBUG,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "ReplicationStyleValue = <%d>"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("ReplicationStyleValue = <%d>"),
             fault_event_desc.replication_style
         ));
       }
@@ -584,10 +564,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 3)
       {
         ACE_ERROR ((LM_ERROR,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "Could not extract MinimumNumberMembers from properties on "
-            "ObjectGroup with id <%Q>.\n"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("Could not extract MinimumNumberMembers from properties on ")
+          ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
           fault_event_desc.object_group_id));
       }
     }
@@ -597,9 +576,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 6)
       {
         ACE_DEBUG ((LM_DEBUG,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "MinimumNumberMembers = <%d>"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("MinimumNumberMembers = <%d>"),
             fault_event_desc.minimum_number_members
         ));
       }
@@ -616,10 +594,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 3)
       {
         ACE_ERROR ((LM_ERROR,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "Could not extract InitialNumberMembers from properties on "
-            "ObjectGroup with id <%Q>.\n"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("Could not extract InitialNumberMembers from properties on ")
+          ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
           fault_event_desc.object_group_id));
       }
     }
@@ -629,9 +606,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 6)
       {
         ACE_DEBUG ((LM_DEBUG,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "InitialNumberMembers = <%d>"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("InitialNumberMembers = <%d>"),
             fault_event_desc.initial_number_members
         ));
       }
@@ -648,10 +624,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 3)
       {
         ACE_ERROR ((LM_ERROR,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "Could not extract Factories from properties on "
-            "ObjectGroup with id <%Q>.\n"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("Could not extract Factories from properties on ")
+          ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
           fault_event_desc.object_group_id));
        }
     }
@@ -660,10 +635,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 6)
       {
         ACE_DEBUG ((LM_DEBUG,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "Got Factories from properties on "
-            "ObjectGroup with id <%Q>.\n"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("Got Factories from properties on ")
+          ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
             fault_event_desc.object_group_id
         ));
       }
@@ -682,10 +656,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
     if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-          "Checking to see if failed replica was the primary for "
-          "ObjectGroup with id <%Q>.\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+        ACE_TEXT ("Checking to see if failed replica was the primary for ")
+        ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
           fault_event_desc.object_group_id
       ));
     }
@@ -717,10 +690,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
       if (TAO_debug_level > 6)
       {
         ACE_DEBUG ((LM_DEBUG,
-          ACE_TEXT (
-            "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-            "Setting new primary for "
-            "ObjectGroup with id <%Q>.\n"),
+          ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+          ACE_TEXT ("Setting new primary for ")
+          ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
             fault_event_desc.object_group_id
         ));
       }
@@ -746,10 +718,9 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure (
     if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: "
-          "Potentially adding new members to "
-          "ObjectGroup with id <%Q>.\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::single_replica_failure: ")
+        ACE_TEXT ("Potentially adding new members to ")
+        ACE_TEXT ("ObjectGroup with id <%Q>.\n"),
           fault_event_desc.object_group_id
       ));
     }
@@ -818,9 +789,8 @@ int TAO::FT_ReplicationManagerFaultAnalyzer::set_new_primary (
     else
     {
       ACE_ERROR_RETURN ((LM_ERROR,
-        ACE_TEXT (
-          "TAO::FT_ReplicationManagerFaultAnalyzer::set_new_primary: "
-          "No locations remaining in ObjectGroup with id <%Q>.\n"),
+        ACE_TEXT ("TAO::FT_ReplicationManagerFaultAnalyzer::set_new_primary: ")
+        ACE_TEXT ("No locations remaining in ObjectGroup with id <%Q>.\n"),
           fault_event_desc.object_group_id),
         -1);
     }
