@@ -3,7 +3,7 @@
 /**
  *  @file    FT_ReplicationManager_Main.cpp
  *
- *  FT_ReplicationManager_Main.cpp,v 1.3 2004/04/01 05:16:45 bala Exp
+ *  $Id: FT_ReplicationManager_Main.cpp 68468 2005-10-04 10:08:08Z jwillemsen $
  *
  *  This file is part of Fault Tolerant CORBA.
  *  This file provides the main routine for a process that
@@ -22,14 +22,3 @@ int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
     server_main("ReplicationManager");
   return server_main.run(argc, argv);
 }
-
-///////////////////////////////////
-// Template instantiation for
-// inept compilers.
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-  template class TAO::Utils::Server_Main<TAO::FT_ReplicationManager>;
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-# pragma instantiate TAO::Utils::Server_Main<TAO::FT_ReplicationManager>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
-
