@@ -3,7 +3,7 @@
 /**
  *  @file    FT_FaultDetectorFactory_i.cpp
  *
- *  $Id: FT_FaultDetectorFactory_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+ *  $Id: FT_FaultDetectorFactory_i.cpp 83040 2008-10-10 08:55:40Z johnnyw $
  *
  *  This file is part of Fault Tolerant CORBA.
  *
@@ -125,9 +125,9 @@ int TAO::FT_FaultDetectorFactory_i::write_ior()
 //////////////////////////////////////////////////////
 // FT_FaultDetectorFactory_i public, non-CORBA methods
 
-int TAO::FT_FaultDetectorFactory_i::parse_args (int argc, char * argv[])
+int TAO::FT_FaultDetectorFactory_i::parse_args (int argc, ACE_TCHAR * argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "d:l:o:qr");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("d:l:o:qr"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -136,13 +136,13 @@ int TAO::FT_FaultDetectorFactory_i::parse_args (int argc, char * argv[])
     {
       case 'd':
       {
-        this->domain_ = CORBA::string_dup (get_opts.opt_arg ());
+        this->domain_ = CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ()));
         break;
       }
       case 'l':
       {
         this->location_.length(1);
-        this->location_[0].id = CORBA::string_dup(get_opts.opt_arg ());
+        this->location_[0].id = CORBA::string_dup(ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ()));
         break;
       }
       case 'o':
@@ -316,7 +316,7 @@ int TAO::FT_FaultDetectorFactory_i::init (CORBA::ORB_ptr orb)
   if (this->ior_output_file_ != 0)
   {
     this->identity_ = "file:";
-    this->identity_ += this->ior_output_file_;
+    this->identity_ += ACE_TEXT_ALWAYS_CHAR(this->ior_output_file_);
     write_ior();
   }
 
