@@ -3,7 +3,7 @@
 /**
  *  @file    FT_Notifier_i.cpp
  *
- *  $Id: FT_Notifier_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+ *  $Id: FT_Notifier_i.cpp 83040 2008-10-10 08:55:40Z johnnyw $
  *
  *  This file is part of Fault Tolerant CORBA.
  *
@@ -145,9 +145,9 @@ int TAO::FT_FaultNotifier_i::write_ior()
 //////////////////////////////////////////////////////
 // FT_FaultNotifier_i public, non-CORBA methods
 
-int TAO::FT_FaultNotifier_i::parse_args (int argc, char * argv[])
+int TAO::FT_FaultNotifier_i::parse_args (int argc, ACE_TCHAR * argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:rq");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:rq"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -419,7 +419,7 @@ int TAO::FT_FaultNotifier_i::init (CORBA::ORB_ptr orb )
     if (this->ior_output_file_ != 0)
     {
       this->identity_ = "file:";
-      this->identity_ += this->ior_output_file_;
+      this->identity_ += ACE_TEXT_ALWAYS_CHAR(this->ior_output_file_);
       result = write_ior();
     }
   }
