@@ -1,4 +1,4 @@
-// $Id: IFR_Service.h 80310 2007-12-19 09:34:44Z vzykov $
+// $Id: IFR_Service.h 82869 2008-09-29 08:02:27Z johnnyw $
 
 // ========================================================================
 //
@@ -42,7 +42,7 @@ public:
 
   /// Initialize the IFR service.
   int init (int argc,
-            char *argv[]);
+            ACE_TCHAR *argv[]);
 
   /// Shut down the IFR Service.
   int fini (void);
