@@ -1,4 +1,4 @@
-// $Id: ifr_adding_visitor_exception.h 78850 2007-07-12 10:50:02Z parsons $
+// $Id: ifr_adding_visitor_exception.h 83731 2008-11-13 21:54:42Z fields_t $
 
 /* -*- c++ -*- */
 // ============================================================================
@@ -62,14 +62,16 @@ public:
   virtual CORBA::IDLType_ptr ir_current (void) const;
   // Lets the visitor one level above acess this value.
 
+private:
+  int add_members (AST_Exception *node, CORBA::ExceptionDef_ptr except_def);
+  // Common code called whether we are creating a new exception
+  // or filling out a forward declaration.
+
 private:
   CORBA::StructMemberSeq members_;
   // Holder for the member list passed to create_struct() or
   // create_exception().
 
-  ACE_Unbounded_Queue<CORBA::Contained_ptr> move_queue_;
-  // IR objects that must be moved into the scope (struct or
-  // exception) where they were declared in the IDL file.
 };
 
 #endif /* TAO_IFR_ADDING_VISITOR_EXCEPTION_H */
