@@ -1,5 +1,5 @@
 /* -*- c++ -*- */
-// $Id: ifr_adding_visitor_operation.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: ifr_adding_visitor_operation.cpp 88245 2009-12-18 19:03:19Z johnnyw $
 
 #include "ast_argument.h"
 #include "ast_exception.h"
@@ -15,7 +15,7 @@
 
 ACE_RCSID (IFR_Service,
            ifr_adding_visitor_operation,
-           "$Id: ifr_adding_visitor_operation.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: ifr_adding_visitor_operation.cpp 88245 2009-12-18 19:03:19Z johnnyw $")
 
 ifr_adding_visitor_operation::ifr_adding_visitor_operation (AST_Decl *scope)
   : ifr_adding_visitor (scope),
@@ -83,7 +83,7 @@ ifr_adding_visitor_operation::visit_operation (AST_Operation *node)
       CORBA::ExceptionDefSeq exceptions (length);
       exceptions.length (length);
 
-      AST_Exception *ex = 0;
+      AST_Type *ex = 0;
       CORBA::ULong i = 0;
 
       for (UTL_ExceptlistActiveIterator ex_iter (excepts);
