@@ -1,4 +1,4 @@
-// $Id: ifr_adding_visitor_structure.h 78850 2007-07-12 10:50:02Z parsons $
+// $Id: ifr_adding_visitor_structure.h 83643 2008-11-10 20:03:04Z parsons $
 
 /* -*- C++ -*- */
 // ============================================================================
@@ -37,8 +37,7 @@ class ifr_adding_visitor_structure : public ifr_adding_visitor
   //    for the case when a struct or exception node is seen in the AST.
   //
 public:
-  ifr_adding_visitor_structure (AST_Decl *scope,
-                                bool is_nested);
+  ifr_adding_visitor_structure (AST_Decl *scope);
 
   virtual ~ifr_adding_visitor_structure (void);
 
@@ -56,17 +55,9 @@ private:
   // or filling out a forward declaration.
 
 private:
-  bool is_nested_;
-  // Is this visitor visiting a struct that was defined inside
-  // a union, an exception, or another struct?
-
   CORBA::StructMemberSeq members_;
   // Holder for the member list passed to create_struct() or
   // create_exception().
-
-  ACE_Unbounded_Queue<CORBA::Contained_ptr> move_queue_;
-  // IR objects that must be moved into the scope (struct or
-  // exception) where they were declared in the IDL file.
 };
 
 #endif /* TAO_IFR_ADDING_VISITOR_STRUCTURE_H */
