@@ -4,7 +4,7 @@
 /**
  *  @file   Activator_Options.h
  *
- *  $Id: Activator_Options.h 78066 2007-04-17 12:03:07Z elliott_c $
+ *  $Id: Activator_Options.h 83040 2008-10-10 08:55:40Z johnnyw $
  *
  *  @brief  Definition of the Options class for the Implementation Repository.
  *
@@ -44,13 +44,14 @@ public:
   // however, the real value is protected -- CAE 4/16/2007
   enum ACTIVATOR_PROCESS
   {
-    ENVIRONMENT_BUFFER = 16 * 1024
+    ENVIRONMENT_BUFFER = 16 * 1024,
+    ENVIRONMENT_MAX_VARS = 512
   };
 
   Activator_Options ();
 
   /// Parse the command-line arguments and initialize the options.
-  int init (int argc, char *argv[]);
+  int init (int argc, ACE_TCHAR *argv[]);
   /// This version should only be used when run as an nt service.
   int init_from_registry();
 
@@ -65,7 +66,7 @@ public:
   unsigned int debug (void) const;
 
   /// Returns the file where the IOR should be stored.
-  const ACE_CString& ior_filename (void) const;
+  const ACE_TString& ior_filename (void) const;
 
   /// The nt service command to run (install/remove)
   SERVICE_COMMAND service_command(void) const;
@@ -79,9 +80,11 @@ public:
 
   int env_buf_len (void) const;
 
+  int max_env_vars (void) const;
+
 private:
   /// Parses and pulls out arguments for the ImR
-  int parse_args (int &argc, char *argv[]);
+  int parse_args (int &argc, ACE_TCHAR *argv[]);
 
   /// Print the usage information.
   void print_usage (void) const;
@@ -98,7 +101,7 @@ private:
   unsigned int debug_;
 
   /// File where the IOR of the server object is stored.
-  ACE_CString ior_output_file_;
+  ACE_TString ior_output_file_;
 
   /// Should we run as a service?
   bool service_;
@@ -112,6 +115,9 @@ private:
 
   /// The default environment buffer length
   int env_buf_len_;
+
+  /// Maximum number of environment variables
+  int max_env_vars_;
 };
 
 #endif
