@@ -3,7 +3,7 @@
 /**
  *  @file   INS_Locator.h
  *
- *  $Id: INS_Locator.h 77878 2007-04-02 17:53:08Z elliott_c $
+ *  $Id: INS_Locator.h 81490 2008-04-28 14:32:24Z johnnyw $
  *
  *  @brief  This class implements the ImR's INS Locator class
  *
@@ -36,7 +36,7 @@ class ImR_Locator_i;
  */
 class INS_Locator
   : public virtual IORTable::Locator,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
   INS_Locator (ImR_Locator_i& loc);
