@@ -1,4 +1,4 @@
-// $Id: ImR_Activator_i.cpp 78858 2007-07-12 23:24:55Z sowayaa $
+// $Id: ImR_Activator_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "ImR_Activator_i.h"
 
@@ -25,6 +25,7 @@ ImR_Activator_i::ImR_Activator_i (void)
 , notify_imr_ (false)
 , name_ (getHostName ())
 , env_buf_len_ (Activator_Options::ENVIRONMENT_BUFFER)
+, max_env_vars_ (Activator_Options::ENVIRONMENT_MAX_VARS)
 {
 }
 
@@ -103,6 +104,7 @@ ImR_Activator_i::init_with_orb (CORBA::ORB_ptr orb, const Activator_Options& opt
   debug_ = opts.debug ();
   notify_imr_ = opts.notify_imr ();
   env_buf_len_ = opts.env_buf_len ();
+  max_env_vars_ = opts.max_env_vars ();
   if (opts.name ().length () > 0)
     {
       name_ = opts.name();
@@ -282,25 +284,31 @@ ImR_Activator_i::start_server(const char* name,
   ACE_Process_Options proc_opts (
                         1,
                         ACE_Process_Options::DEFAULT_COMMAND_LINE_BUF_LEN,
-                        this->env_buf_len_);
-  proc_opts.command_line (cmdline);
+                        this->env_buf_len_, this->max_env_vars_);
+  proc_opts.command_line (ACE_TEXT_CHAR_TO_TCHAR(cmdline));
   proc_opts.working_directory (dir);
   // Win32 does not support the CLOSE_ON_EXEC semantics for sockets
   // the way unix does, so in order to avoid having the child process
   // hold the listen socket open, we force the child to inherit no
   // handles. This includes stdin, stdout, logs, etc.
-  proc_opts.handle_inheritence (0);
+  proc_opts.handle_inheritance (0);
 
-  proc_opts.setenv ("TAO_USE_IMR", "1");
+  // We always enable the unicode environmet buffer on Windows.  This works
+  // around a 32kb environment buffer limitation.  This must come before any of
+  // the setenv() calls, since the first of those will copy the current
+  // process's environment.
+  proc_opts.enable_unicode_environment ();
+
+  proc_opts.setenv (ACE_TEXT("TAO_USE_IMR"), "1");
   if (!CORBA::is_nil (this->locator_.in ()))
     {
       CORBA::String_var ior = orb_->object_to_string (locator_.in ());
-      proc_opts.setenv ("ImplRepoServiceIOR", ior.in());
+      proc_opts.setenv (ACE_TEXT("ImplRepoServiceIOR"), ior.in());
     }
 
   for (CORBA::ULong i = 0; i < env.length (); ++i)
     {
-      proc_opts.setenv (env[i].name.in (), env[i].value.in ());
+      proc_opts.setenv (ACE_TEXT_CHAR_TO_TCHAR(env[i].name.in ()), env[i].value.in ());
     }
 
   int pid = this->process_mgr_.spawn (proc_opts);
@@ -333,7 +341,7 @@ ImR_Activator_i::start_server(const char* name,
 
   if (debug_ > 0)
     {
-      ACE_DEBUG ((LM_DEBUG, "ImR Activator: Successfully started <%s>. \n", name));
+      ACE_DEBUG ((LM_DEBUG, "ImR Activator: Successfully started <%s>, pid=%d\n", name, pid));
     }
 }
 
