@@ -3,7 +3,7 @@
 /**
  *  @file   Iterator.h
  *
- *  Iterator.h,v 1.9 2005/07/04 08:55:12 jwillemsen Exp
+ *  $Id: Iterator.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  *  @brief  This file declares ImR's iterator.
  *
@@ -39,12 +39,9 @@ public:
   virtual CORBA::Boolean next_n (
       CORBA::ULong how_many,
       ImplementationRepository::ServerInformationList_out server_list
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
-  virtual void destroy (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void destroy (void);
 
 private:
   Locator_Repository& repo_;
