@@ -4,7 +4,7 @@
 /**
 *  @file Locator_Repository.h
 *
-*  $Id: Locator_Repository.h 66056 2005-05-23 17:58:35Z michel_j $
+*  $Id: Locator_Repository.h 85171 2009-04-25 06:33:24Z dai_y $
 *
 *  This class implements the Repository for the Implementation Repository.
 *
@@ -54,8 +54,13 @@ public:
   /// Initializes the Server Repository
   int init (const Options& opts);
 
+  int unregister_if_address_reused (const ACE_CString& server_id,
+                                    const ACE_CString& name, 
+                                    const char* partial_ior);
+
   /// Add a new server to the Repository
-  int add_server (const ACE_CString& name,
+  int add_server (const ACE_CString& server_id,
+    const ACE_CString& name,
     const ACE_CString& aname,
     const ACE_CString& startup_command,
     const ImplementationRepository::EnvironmentList& environment_vars,
@@ -108,6 +113,8 @@ private:
   ACE_Auto_Ptr<ACE_Configuration> config_;
   // XML requires the file name
   ACE_CString fname_;
+
+  unsigned int debug_;
 };
 
 
