@@ -1,8 +1,9 @@
-// $Id: Server_Info.cpp 76555 2007-01-24 15:39:09Z johnnyw $
+// $Id: Server_Info.cpp 85171 2009-04-25 06:33:24Z dai_y $
 #include "Server_Info.h"
 
 Server_Info::Server_Info
 (
+ const ACE_CString& serverId,
  const ACE_CString& server_name,
  const ACE_CString& aname,
  const ACE_CString& cmdline,
@@ -14,7 +15,8 @@ Server_Info::Server_Info
  const ACE_CString& server_ior,
  ImplementationRepository::ServerObject_ptr svrobj
  )
- : name (server_name)
+ : server_id (serverId)
+ , name (server_name)
  , activator (aname)
  , cmdline( cmdline)
  , env_vars (env)
