@@ -1,4 +1,4 @@
-// $Id: tao_imr_i.cpp 78894 2007-07-14 14:56:10Z sowayaa $
+// $Id: tao_imr_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "tao_imr_i.h"
 
@@ -36,7 +36,7 @@ TAO_IMR_i::run ()
 }
 
 int
-TAO_IMR_i::init (int argc, char **argv)
+TAO_IMR_i::init (int argc, ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
@@ -220,7 +220,7 @@ TAO_IMR_Op::display_server_information (const ImplementationRepository::ServerIn
     limit - 1,
     locked_out));
   for (CORBA::ULong i = 0; i < info.startup.environment.length (); ++i)
-    ACE_DEBUG ((LM_DEBUG, "Environment Variable: %s=%s \n",
+    ACE_DEBUG ((LM_DEBUG, "Environment Variable: %s=%s\n",
     info.startup.environment[i].name.in (),
     info.startup.environment[i].value.in ()));
 
@@ -280,9 +280,9 @@ TAO_IMR_Op_Activate::parse (int argc, ACE_TCHAR **argv)
     }
 
   // Skip both the program name and the "activate" command
-  ACE_Get_Opt get_opts (argc, argv, "h");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("h"));
 
-  this->server_name_ = argv[1];
+  this->server_name_ = ACE_TEXT_ALWAYS_CHAR(argv[1]);
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -313,7 +313,7 @@ int
 TAO_IMR_Op_Autostart::parse (int argc, ACE_TCHAR **argv)
 {
   // Skip the "autostart" command
-  ACE_Get_Opt get_opts (argc, argv, "h");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("h"));
 
   int c;
 
@@ -359,9 +359,9 @@ TAO_IMR_Op_IOR::parse (int argc, ACE_TCHAR **argv)
     }
 
   // Skip both the program name and the "ior" command
-  ACE_Get_Opt get_opts (argc, argv, "hf:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("hf:"));
 
-  this->server_name_ = argv[1];
+  this->server_name_ = ACE_TEXT_ALWAYS_CHAR(argv[1]);
   if (this->server_name_.length() == 0 || this->server_name_[0] == '-')
     {
       ACE_ERROR((LM_ERROR, "ERROR : name is required.\n"));
@@ -411,12 +411,12 @@ TAO_IMR_Op_List::parse (int argc, ACE_TCHAR **argv)
 
   if (argc > 1 && argv[1][0] != '-')
   {
-    this->server_name_ = argv[1];
+    this->server_name_ = ACE_TEXT_ALWAYS_CHAR(argv[1]);
     server_flag = 2;
   }
 
   // Skip both the program name and the "list" command
-  ACE_Get_Opt get_opts (argc, argv, "vh", server_flag);
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("vh"), server_flag);
 
   int c;
 
@@ -461,9 +461,9 @@ TAO_IMR_Op_Remove::parse (int argc, ACE_TCHAR **argv)
     }
 
   // Skip both the program name and the "remove" command
-  ACE_Get_Opt get_opts (argc, argv, "h");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("h"));
 
-  this->server_name_ = argv[1];
+  this->server_name_ = ACE_TEXT_ALWAYS_CHAR(argv[1]);
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -504,9 +504,9 @@ TAO_IMR_Op_Shutdown::parse (int argc, ACE_TCHAR **argv)
     }
 
   // Skip both the program name and the "shutdown" command
-  ACE_Get_Opt get_opts (argc, argv, "h");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("h"));
 
-  this->server_name_ = argv[1];
+  this->server_name_ = ACE_TEXT_ALWAYS_CHAR(argv[1]);
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -552,7 +552,7 @@ TAO_IMR_Op_ShutdownRepo::parse (int argc, ACE_TCHAR **argv)
     }
 
   // Skip both the program name and the "shutdown-repo" command
-  ACE_Get_Opt get_opts (argc, argv, "ha");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("ha"));
 
   int c;
 
@@ -582,13 +582,13 @@ TAO_IMR_Op_Register::addenv (ACE_TCHAR *opt)
   CORBA::ULong length = this->environment_vars_.length ();
   // Increase the length of the sequence
   this->environment_vars_.length (length + 1);
-  ACE_CString tokens (opt);
-  int index = tokens.find ("=");
+  ACE_TString tokens (opt);
+  int index = tokens.find (ACE_TEXT("="));
   // Insert at position length since that is our new element
   this->environment_vars_ [length].name =
-    CORBA::string_dup (tokens.substr (0, index).c_str ());
+    CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(tokens.substr (0, index).c_str ()));
   this->environment_vars_ [length].value =
-    CORBA::string_dup (tokens.substr (index + 1).c_str ());
+    CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(tokens.substr (index + 1).c_str ()));
 }
 
 void
@@ -622,9 +622,9 @@ TAO_IMR_Op_Register::parse (int argc, ACE_TCHAR **argv)
     }
 
   // Skip both the program name and the "update" command
-  ACE_Get_Opt get_opts (argc, argv, "hc:w:a:e:r:R:l:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("hc:w:a:e:r:R:l:"));
 
-  this->server_name_ = argv[1];
+  this->server_name_ = ACE_TEXT_ALWAYS_CHAR(argv[1]);
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -633,7 +633,7 @@ TAO_IMR_Op_Register::parse (int argc, ACE_TCHAR **argv)
       {
       case 'c':  // Command line arguments
         this->set_command_line_ = true;
-        this->command_line_ = get_opts.opt_arg ();
+        this->command_line_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
         break;
       case 'e':  // set environment variables
         this->set_environment_vars_ = true;
@@ -641,17 +641,17 @@ TAO_IMR_Op_Register::parse (int argc, ACE_TCHAR **argv)
         break;
       case 'w':  // Working Directory
         this->set_working_dir_ = true;
-        this->working_dir_ = get_opts.opt_arg ();
+        this->working_dir_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
         break;
       case 'a':  // Activation Mode
         this->set_activation_ = true;
-        if (ACE_OS::strcasecmp (get_opts.opt_arg (), "NORMAL") == 0)
+        if (ACE_OS::strcasecmp (get_opts.opt_arg (), ACE_TEXT("NORMAL")) == 0)
           this->activation_ = ImplementationRepository::NORMAL;
-        else if (ACE_OS::strcasecmp (get_opts.opt_arg (), "MANUAL") == 0)
+        else if (ACE_OS::strcasecmp (get_opts.opt_arg (), ACE_TEXT("MANUAL")) == 0)
           this->activation_ = ImplementationRepository::MANUAL;
-        else if (ACE_OS::strcasecmp (get_opts.opt_arg (), "PER_CLIENT") == 0)
+        else if (ACE_OS::strcasecmp (get_opts.opt_arg (), ACE_TEXT("PER_CLIENT")) == 0)
           this->activation_ = ImplementationRepository::PER_CLIENT;
-        else if (ACE_OS::strcasecmp (get_opts.opt_arg (), "AUTO_START") == 0)
+        else if (ACE_OS::strcasecmp (get_opts.opt_arg (), ACE_TEXT("AUTO_START")) == 0)
           this->activation_ = ImplementationRepository::AUTO_START;
         else
           ACE_ERROR_RETURN ((LM_ERROR,
@@ -669,7 +669,7 @@ TAO_IMR_Op_Register::parse (int argc, ACE_TCHAR **argv)
         }
         break;
       case 'l': /// hostname of the activator
-        this->activator_ = get_opts.optarg;
+        this->activator_ = ACE_TEXT_ALWAYS_CHAR(get_opts.optarg);
         this->set_activator_ = true;
         break;
       case 'h':  // display help
@@ -697,19 +697,19 @@ TAO_IMR_Op_Activate::run (void)
     {
       this->imr_->activate_server (this->server_name_.c_str ());
       ACE_DEBUG ((LM_DEBUG,
-        "Successfully Activated server <%s>\n",
+        "Successfully Activated server <%C>\n",
         this->server_name_.c_str ()));
     }
   catch (const ImplementationRepository::CannotActivate& ex)
     {
-      ACE_ERROR ((LM_ERROR, "Cannot activate server <%s>, reason: <%s>\n",
+      ACE_ERROR ((LM_ERROR, "Cannot activate server <%C>, reason: <%s>\n",
         this->server_name_.c_str (),
         ex.reason.in ()));
       return TAO_IMR_Op::CANNOT_ACTIVATE;
     }
   catch (const ImplementationRepository::NotFound&)
     {
-      ACE_ERROR ((LM_ERROR, "Could not find server <%s>.\n", this->server_name_.c_str ()));
+      ACE_ERROR ((LM_ERROR, "Could not find server <%C>.\n", this->server_name_.c_str ()));
       return TAO_IMR_Op::NOT_FOUND;
     }
   catch (const PortableServer::ForwardRequest&)
@@ -887,7 +887,7 @@ TAO_IMR_Op_List::run (void)
     }
   catch (const ImplementationRepository::NotFound&)
     {
-      ACE_ERROR ((LM_ERROR, "Could not find server <%s>.\n", this->server_name_.c_str ()));
+      ACE_ERROR ((LM_ERROR, "Could not find server <%C>.\n", this->server_name_.c_str ()));
       return TAO_IMR_Op::NOT_FOUND;
     }
   catch (const CORBA::Exception& ex)
@@ -908,12 +908,12 @@ TAO_IMR_Op_Remove::run (void)
     {
       this->imr_->remove_server (this->server_name_.c_str ());
 
-      ACE_DEBUG ((LM_DEBUG, "Successfully removed server <%s>\n",
+      ACE_DEBUG ((LM_DEBUG, "Successfully removed server <%C>\n",
         this->server_name_.c_str ()));
     }
   catch (const ImplementationRepository::NotFound&)
     {
-      ACE_ERROR ((LM_ERROR, "Could not find server <%s>.\n",
+      ACE_ERROR ((LM_ERROR, "Could not find server <%C>.\n",
         this->server_name_.c_str ()));
       return TAO_IMR_Op::NOT_FOUND;
     }
@@ -940,17 +940,17 @@ TAO_IMR_Op_Shutdown::run (void)
     {
       this->imr_->shutdown_server (this->server_name_.c_str ());
 
-      ACE_DEBUG ((LM_DEBUG, "Successfully shut down server <%s>\n",
+      ACE_DEBUG ((LM_DEBUG, "Successfully shut down server <%C>\n",
         this->server_name_.c_str ()));
     }
   catch (const ImplementationRepository::NotFound&)
     {
-      ACE_ERROR ((LM_ERROR, "Server <%s> already shut down.\n", this->server_name_.c_str ()));
+      ACE_ERROR ((LM_ERROR, "Server <%C> already shut down.\n", this->server_name_.c_str ()));
       return TAO_IMR_Op::NOT_FOUND;
     }
   catch (const CORBA::TIMEOUT&)
     {
-      ACE_DEBUG ((LM_DEBUG, "Timeout waiting for <%s> to shutdown.\n",
+      ACE_DEBUG ((LM_DEBUG, "Timeout waiting for <%C> to shutdown.\n",
         this->server_name_.c_str ()));
     }
   catch (const CORBA::Exception& ex)
@@ -1005,7 +1005,7 @@ TAO_IMR_Op_Register::run (void)
         {
           if (is_add_)
             {
-              ACE_DEBUG((LM_DEBUG, "Server <%s> already registered.\n", this->server_name_.c_str ()));
+              ACE_DEBUG((LM_DEBUG, "Server <%C> already registered.\n", this->server_name_.c_str ()));
               return ALREADY_REGISTERED;
             }
           options = &server_information->startup;
@@ -1014,7 +1014,7 @@ TAO_IMR_Op_Register::run (void)
         {
           if (!is_add_)
           {
-            ACE_DEBUG((LM_DEBUG, "Adding Server <%s> on update command.\n", this->server_name_.c_str ()));
+            ACE_DEBUG((LM_DEBUG, "Adding Server <%C> on update command.\n", this->server_name_.c_str ()));
             is_add_ = true;
           }
           options = &local;
@@ -1044,13 +1044,13 @@ TAO_IMR_Op_Register::run (void)
           char host_name[MAXHOSTNAMELEN + 1];
           ACE_OS::hostname (host_name, MAXHOSTNAMELEN);
           options->activator = CORBA::string_dup (host_name);
-          ACE_DEBUG ((LM_DEBUG, "Updating Server <%s> with default activator of <%s>.\n",
+          ACE_DEBUG ((LM_DEBUG, "Updating Server <%C> with default activator of <%s>.\n",
             this->server_name_.c_str (), options->activator.in ()));
         }
 
       this->imr_->add_or_update_server (this->server_name_.c_str (), *options);
 
-      ACE_DEBUG((LM_DEBUG, "Successfully registered <%s>.\n", this->server_name_.c_str ()));
+      ACE_DEBUG((LM_DEBUG, "Successfully registered <%C>.\n", this->server_name_.c_str ()));
     }
   catch (const CORBA::NO_PERMISSION&)
     {
