@@ -3,7 +3,7 @@
 
 ACE_RCSID (LoadBalancer,
            Monitor_Signal_Handler,
-           "Monitor_Signal_Handler.cpp,v 1.1 2002/10/02 16:56:32 ossama Exp")
+           "$Id: Monitor_Signal_Handler.cpp 76601 2007-01-25 19:59:59Z elliott_c $")
 
 
 TAO_LB_Monitor_Signal_Handler::TAO_LB_Monitor_Signal_Handler (
@@ -21,22 +21,18 @@ TAO_LB_Monitor_Signal_Handler::TAO_LB_Monitor_Signal_Handler (
 int
 TAO_LB_Monitor_Signal_Handler::perform_cleanup (int signum)
 {
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       // Deregister the LoadMonitor from the LoadManager in the PULL
       // load monitoring case.
       if (!CORBA::is_nil (this->load_manager_.in ()))
         {
-          this->load_manager_->remove_load_monitor (this->location_
-                                                    ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->load_manager_->remove_load_monitor (this->location_);
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                           "Caught exception");
+      ex._tao_print_exception ("Caught exception");
 
       ACE_ERROR_RETURN ((LM_ERROR,
                          "Problem during LoadMonitor cleanup "
@@ -44,8 +40,6 @@ TAO_LB_Monitor_Signal_Handler::perform_cleanup (int signum)
                          signum),
                         -1);
     }
-  ACE_ENDTRY;
-  ACE_CHECK_RETURN (-1);
 
   return this->TAO_LB_Signal_Handler::perform_cleanup (signum);
 }
