@@ -7,7 +7,7 @@
 
 ACE_RCSID (Basic_Logging_Service,
            Basic_Logging_Service,
-           "$Id: Basic_Logging_Service.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+           "$Id: Basic_Logging_Service.cpp 83324 2008-10-20 11:41:42Z vzykov $")
 
 
 Basic_Logging_Service::Basic_Logging_Service (void)
@@ -26,11 +26,9 @@ Basic_Logging_Service::~Basic_Logging_Service (void)
 }
 
 void
-Basic_Logging_Service::init_ORB (int& argc, char *argv [])
+Basic_Logging_Service::init_ORB (int& argc, ACE_TCHAR *argv [])
 {
-  this->orb_ = CORBA::ORB_init (argc,
-                                argv,
-                                "");
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
   CORBA::Object_var poa_object =
     this->orb_->resolve_initial_references("RootPOA");
@@ -45,7 +43,7 @@ Basic_Logging_Service::init_ORB (int& argc, char *argv [])
 }
 
 int
-Basic_Logging_Service::parse_args (int argc, char *argv[])
+Basic_Logging_Service::parse_args (int argc, ACE_TCHAR *argv[])
 {
   ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("n:o:p:t:x"));
   int opt;
@@ -55,7 +53,7 @@ Basic_Logging_Service::parse_args (int argc, char *argv[])
       switch (opt)
         {
         case 'n':
-          this->service_name_ = get_opt.opt_arg ();
+          this->service_name_ = ACE_TEXT_ALWAYS_CHAR(get_opt.opt_arg ());
           break;
 
         case 'o':
@@ -93,7 +91,7 @@ Basic_Logging_Service::parse_args (int argc, char *argv[])
 }
 
 int
-Basic_Logging_Service::init (int argc, char *argv[])
+Basic_Logging_Service::init (int argc, ACE_TCHAR *argv[])
 {
   // initialize the ORB.
   this->init_ORB (argc, argv);
@@ -155,7 +153,7 @@ Basic_Logging_Service::init (int argc, char *argv[])
 
       CosNaming::Name name (1);
       name.length (1);
-      name[0].id = CORBA::string_dup (this->service_name_);
+      name[0].id = CORBA::string_dup (this->service_name_.c_str ());
 
       this->naming_->rebind (name,
                              obj.in ());
@@ -217,7 +215,7 @@ Basic_Logging_Service::shutdown (void)
     {
       CosNaming::Name name (1);
       name.length (1);
-      name[0].id = CORBA::string_dup (this->service_name_);
+      name[0].id = CORBA::string_dup (this->service_name_.c_str ());
 
       this->naming_->unbind (name);
     }
