@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: NT_Naming_Server.cpp 78854 2007-07-12 17:10:11Z mesnier_p $
+// $Id: NT_Naming_Server.cpp 87876 2009-12-03 08:03:16Z johnnyw $
 
 // ============================================================================
 //
@@ -27,7 +27,7 @@
 #include "ace/Log_Msg.h"
 
 int
-main (int, char*[])
+ACE_TMAIN(int, ACE_TCHAR *[])
 {
   ACE_ERROR ((LM_INFO,
               "This program is only supported "
@@ -53,15 +53,15 @@ public:
   Options (void);
   ~Options (void);
 
-  int run (int argc, char *argv[]);
+  int run (int argc, ACE_TCHAR *argv[]);
 
 private:
   void parse_args (int argc,
-                   char *argv[]);
+                   ACE_TCHAR *argv[]);
   void print_usage_and_die (void);
 
 private:
-  char progname[128];
+  ACE_TCHAR progname[128];
 
   int opt_install;
   int opt_remove;
@@ -85,7 +85,7 @@ Options::Options (void)
     opt_startup (0)
 {
   ACE_OS::strcpy (progname,
-                  "service");
+                  ACE_TEXT("service"));
   ACE::init ();
 }
 
@@ -98,23 +98,23 @@ void
 Options::print_usage_and_die (void)
 {
   ACE_DEBUG ((LM_INFO,
-              "Usage: %s"
-              " -in -r -s -k -tn -d\n"
-              "  -i: Install this program as an NT service, with specified startup\n"
-              "  -r: Remove this program from the Service Manager\n"
-              "  -s: Start the service\n"
-              "  -k: Kill the service\n"
-              "  -t: Set startup for an existing service\n"
-              "  -d: Debug; run as a regular application\n",
+              ACE_TEXT("Usage: %s")
+              ACE_TEXT(" -in -r -s -k -tn -d\n")
+              ACE_TEXT("  -i: Install this program as an NT service, with specified startup\n")
+              ACE_TEXT("  -r: Remove this program from the Service Manager\n")
+              ACE_TEXT("  -s: Start the service\n")
+              ACE_TEXT("  -k: Kill the service\n")
+              ACE_TEXT("  -t: Set startup for an existing service\n")
+              ACE_TEXT("  -d: Debug; run as a regular application\n"),
               progname,
               0));
   ACE_OS::exit (1);
 }
 
 void
-Options::parse_args (int argc, char *argv[])
+Options::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opt (argc, argv, "i:rskt:d");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("i:rskt:d"));
   int c;
 
   while ((c = get_opt ()) != -1)
@@ -147,7 +147,7 @@ Options::parse_args (int argc, char *argv[])
       default:
         // -i can also be given without a value - if so, it defaults
         // to defined value.
-        if (ACE_OS::strcmp (get_opt.argv ()[get_opt.opt_ind () - 1], "-i") == 0)
+        if (ACE_OS::strcmp (get_opt.argv ()[get_opt.opt_ind () - 1], ACE_TEXT ("-i")) == 0)
           {
             opt_install = 1;
             opt_startup = DEFAULT_SERVICE_INIT_STARTUP;
@@ -169,13 +169,13 @@ ConsoleHandler (DWORD /* ctrlType */)
 
 ACE_NT_SERVICE_DEFINE (service,
                        TAO_NT_Naming_Service,
-                       "TAO NT Naming Service");
+                       ACE_TEXT ("TAO NT Naming Service"));
 
 int
-Options::run (int argc, char* argv[])
+Options::run (int argc, ACE_TCHAR* argv[])
 {
-  SERVICE::instance ()->name ("TAO_NT_Naming_Service",
-                              "TAO NT Naming Service");
+  SERVICE::instance ()->name (ACE_TEXT ("TAO_NT_Naming_Service"),
+                              ACE_TEXT ("TAO NT Naming Service"));
 
   this->parse_args (argc, argv);
 
@@ -220,7 +220,7 @@ Options::run (int argc, char* argv[])
 }
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   return OPTIONS::instance ()->run (argc, argv);
 }
