@@ -4,14 +4,14 @@
 /**
  *  @file    NT_Notify_Service.h
  *
- *  $Id: NT_Notify_Service.h 78785 2007-07-05 06:23:30Z johnnyw $
+ *  $Id: NT_Notify_Service.h 82864 2008-09-29 07:44:18Z johnnyw $
  *
  *  Run the TAO Notify Service as a Windows NT Service.
  *
  *
  *  @author John Tucker <jtucker@infoglide.com>
  *  @author Mike Vitalo <mvitalo@infoglide.com>
- *  @author David Robison <drrobison@openroadsconsulting.com> 
+ *  @author David Robison <drrobison@openroadsconsulting.com>
  */
 //=============================================================================
 
@@ -52,7 +52,7 @@ public:
 
   /// This is a virtual method inherited from ACE_NT_Service.
   virtual int svc (void);
-        
+
   /// Initialize the objects argc_ and argv_ attributes values.
   virtual int init (int argc,
                     ACE_TCHAR *argv[]);
@@ -64,8 +64,8 @@ private:
   int argc_save_;
 
   /// Argument list.
-  char **argv_;
-  char **argv_save_; 
+  ACE_TCHAR **argv_;
+  ACE_TCHAR **argv_save_;
 
   friend class ACE_Singleton<TAO_NT_Notify_Service, MUTEX>;
 };
