@@ -1,4 +1,4 @@
-// PSDL_Datastore.cpp,v 1.8 2005/01/28 15:56:33 jtc Exp
+// $Id: PSDL_Datastore.cpp 68471 2005-10-04 11:38:20Z jwillemsen $
 
 #include "PSDL_Datastore.h"
 #include "PSDL_OctetSeq.h"
@@ -11,7 +11,7 @@
 
 #include "ace/Auto_Ptr.h"
 
-ACE_RCSID (PSS, PSDL_Datastore, "PSDL_Datastore.cpp,v 1.8 2005/01/28 15:56:33 jtc Exp")
+ACE_RCSID (PSS, PSDL_Datastore, "$Id: PSDL_Datastore.cpp 68471 2005-10-04 11:38:20Z jwillemsen $")
 
 TAO_PSDL_Datastore::TAO_PSDL_Datastore ()
   : allocator_ (0),
@@ -194,35 +194,3 @@ TAO_PSDL_Datastore::create_index_helper (void *buffer)
   this->obj_ref_map_ = new(buffer) NAME_OBJ_REF_MAP(this->allocator_) ;
   return 0;
 }
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)  || \
-    defined (ACE_HAS_GNU_REPO)
-
-template class ACE_Hash_Map_With_Allocator<TAO_PSDL_String, TAO_PSDL_OctetSeq>;
-template class ACE_Hash_Map_Manager<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Manager_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Entry<TAO_PSDL_String, TAO_PSDL_OctetSeq>;
-template class ACE_Hash<TAO_PSDL_String>;
-template class ACE_Equal_To<TAO_PSDL_String>;
-template class ACE_Hash_Map_Iterator_Base_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Reverse_Iterator<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Reverse_Iterator_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>;
-template class ACE_Auto_Basic_Ptr<ACE_Hash_Map_With_Allocator<TAO_PSDL_String,  TAO_PSDL_OctetSeq>::ITERATOR>;
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_Hash_Map_With_Allocator<TAO_PSDL_String, TAO_PSDL_OctetSeq>
-#pragma instantiate ACE_Hash_Map_Manager<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Manager_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Entry<TAO_PSDL_String, TAO_PSDL_OctetSeq>
-#pragma instantiate ACE_Hash<TAO_PSDL_String>
-#pragma instantiate ACE_Equal_To<TAO_PSDL_String>
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Null_Mutex>
-#pragma instantiate ACE_Auto_Basic_Ptr<ACE_Hash_Map_With_Allocator<TAO_PSDL_String,  TAO_PSDL_OctetSeq>::ITERATOR>
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<TAO_PSDL_String, TAO_PSDL_OctetSeq, ACE_Hash<TAO_PSDL_String>, ACE_Equal_To<TAO_PSDL_String>, ACE_Null_Mutex>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
