@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// PSDL_Node.h,v 1.1 2002/07/25 15:25:51 pgontla Exp
+// $Id: PSDL_Node.h 72142 2006-04-19 10:24:02Z jwillemsen $
 //
 // ============================================================================
 //
@@ -36,7 +36,7 @@
 class TAO_PSDL_Node_Visitor;
 class TAO_PSDL_Scope_Visitor;
 
-class TAO_String_Manager;
+class TAO::String_Manager;
 
 class TAO_PSDL_Export TAO_PSDL_Node
 {
