@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: PSDL_Scope.cpp 80189 2007-12-04 15:42:36Z sowayaa $
+// $Id: PSDL_Scope.cpp 83311 2008-10-17 17:57:03Z johnnyw $
 
 #include "PSDL_Scope.h"
 #include "PSDL_Root_Scope.h"
@@ -12,7 +12,7 @@
 #include "PSDL_Stream.h"
 #include "ace/OS_NS_ctype.h"
 
-ACE_RCSID (PSS, PSDL_Scope, "$Id: PSDL_Scope.cpp 80189 2007-12-04 15:42:36Z sowayaa $")
+ACE_RCSID (PSS, PSDL_Scope, "$Id: PSDL_Scope.cpp 83311 2008-10-17 17:57:03Z johnnyw $")
 
 #undef INCREMENT
 #define INCREMENT 40
@@ -640,13 +640,6 @@ TAO_PSDL_Scope::header_initialization (TAO_PSDL_Stream *ps_sh)
 
   ps_sh->nl ();
 
-  *ps_sh << "#if defined (__BORLANDC__)";
-  ps_sh->nl ();
-  *ps_sh << "#pragma option push -w-rvl -w-rch -w-ccc -w-inl";
-  ps_sh->nl ();
-  *ps_sh << "#endif /* __BORLANDC__ */";
-  ps_sh->nl ();
-
   ps_sh->nl ();
 
 }
@@ -677,13 +670,6 @@ TAO_PSDL_Scope::stub_initialization (TAO_PSDL_Stream *ps_si)
 
   ps_si->nl ();
 
-  *ps_si << "#if defined (__BORLANDC__)";
-  ps_si->nl ();
-  *ps_si << "#pragma option -w-rvl -w-rch -w-ccc -w-aus -w-sig";
-  ps_si->nl ();
-  *ps_si << "#endif /* __BORLANDC__ */";
-  ps_si->nl ();
-
   ps_si->nl ();
 
   *ps_si << "#if !defined (__ACE_INLINE__)";
