@@ -1,10 +1,10 @@
 // -*- C++ -*-
-// PSDL_Type_Dcl_Visitor.cpp,v 1.2 2005/01/02 12:43:20 jwillemsen Exp
+// $Id: PSDL_Type_Dcl_Visitor.cpp 62978 2005-01-02 12:43:20Z jwillemsen $
 
 #include "PSDL_Type_Dcl_Visitor.h"
 #include "PSDL_Stream.h"
 
-ACE_RCSID (PSS, PSDL_Type_Dcl_Visitor, "PSDL_Type_Dcl_Visitor.cpp,v 1.2 2005/01/02 12:43:20 jwillemsen Exp")
+ACE_RCSID (PSS, PSDL_Type_Dcl_Visitor, "$Id: PSDL_Type_Dcl_Visitor.cpp 62978 2005-01-02 12:43:20Z jwillemsen $")
 
 TAO_PSDL_Type_Dcl_Visitor::TAO_PSDL_Type_Dcl_Visitor (void)
 {
