@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// Clerk_i.h,v 1.17 2005/03/14 15:59:16 jtc Exp
+// $Id: Clerk_i.h 76589 2007-01-25 18:04:11Z elliott_c $
 
 // ============================================================================
 //
@@ -51,11 +51,10 @@ public:
   // Set of available Time servers.
 
   int init (int argc,
-            ACE_TCHAR *argv[]
-            ACE_ENV_ARG_DECL);
+            ACE_TCHAR *argv[]);
   // Initialize the Clerk state - parsing arguments and waiting.
 
-  int run (ACE_ENV_SINGLE_ARG_DECL);
+  int run (void);
   // Run the orb.
 
 private:
