@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// CosEventChannelFactory_i.h,v 1.16 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: CosEventChannelFactory_i.h 77020 2007-02-12 13:56:49Z johnnyw $
 
 // ============================================================================
 //
@@ -42,8 +42,7 @@ class TAO_CosEventChannelFactory_i :
 
   int init (PortableServer::POA_ptr poa,
             const char* child_poa_name,
-            CosNaming::NamingContext_ptr naming = CosNaming::NamingContext::_nil ()
-            ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+            CosNaming::NamingContext_ptr naming = CosNaming::NamingContext::_nil ());
   // This method creates a child poa with <poa> as the
   // parent. It also accepts a Naming_Context which is used to register
   // the event channels if specified.
@@ -58,7 +57,7 @@ class TAO_CosEventChannelFactory_i :
   //    doesn't have to be exposed through the IDL interface. Anyway,
   //    there must be a way to cleanup any resources created by the
   //    factory, and you must avoid CORBA calls in the destructor,
-  //    first because you won't have an ACE_ENV_SINGLE_ARG_PARAMETER and second because
+  //    first because you won't have an and second because
   //    exceptions in destructors are evil.
   // @@ Pradeep: anyway you can just use exceptions and not return -1?
 
@@ -67,44 +66,23 @@ class TAO_CosEventChannelFactory_i :
     (
      const char * channel_id,
      CORBA::Boolean store_in_naming_service
-     ACE_ENV_ARG_DECL
-     )
-    ACE_THROW_SPEC ((
-        CORBA::SystemException,
-        CosEventChannelFactory::DuplicateChannel,
-        CosEventChannelFactory::BindFailed
-      ));
+     );
 
   virtual void destroy
     (
      const char * channel_id,
      CORBA::Boolean unbind_from_naming_service
-     ACE_ENV_ARG_DECL
-     )
-    ACE_THROW_SPEC ((
-        CORBA::SystemException,
-        CosEventChannelFactory::NoSuchChannel
-      ));
+     );
 
   virtual CosEventChannelAdmin::EventChannel_ptr find
     (
      const char * channel_id
-     ACE_ENV_ARG_DECL
-     )
-    ACE_THROW_SPEC ((
-        CORBA::SystemException,
-        CosEventChannelFactory::NoSuchChannel
-      ));
+     );
 
   virtual char * find_channel_id
     (
      CosEventChannelAdmin::EventChannel_ptr channel
-     ACE_ENV_ARG_DECL
-     )
-    ACE_THROW_SPEC ((
-        CORBA::SystemException,
-        CosEventChannelFactory::NoSuchChannel
-      ));
+     );
  protected:
 
   PortableServer::POA_var poa_;
