@@ -1,11 +1,11 @@
 // -*- C++ -*-
-// $Id: FactoryDriver.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: FactoryDriver.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "FactoryDriver.h"
 #include "tao/debug.h"
 #include "ace/Get_Opt.h"
 
-FactoryDriver::FactoryDriver (const char* name)
+FactoryDriver::FactoryDriver (const ACE_TCHAR* name)
   :factoryName_ (name),
    child_poa_name_ ("CosEC_ChildPOA"),
    factory_servant_ (0)
@@ -19,9 +19,9 @@ FactoryDriver::~FactoryDriver (void)
 }
 
 int
-FactoryDriver::parse_args (int argc, char *argv [])
+FactoryDriver::parse_args (int argc, ACE_TCHAR *argv [])
 {
-  ACE_Get_Opt get_opts (argc, argv, "dr:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dr:"));
   int c = 0;
 
   while ((c = get_opts ()) != -1)
@@ -50,13 +50,11 @@ FactoryDriver::parse_args (int argc, char *argv [])
 }
 
 int
-FactoryDriver::start (int argc, char *argv [])
+FactoryDriver::start (int argc, ACE_TCHAR *argv [])
 {
   try
     {
-      orb_ = CORBA::ORB_init (argc,
-                              argv,
-                              "");
+      orb_ = CORBA::ORB_init (argc, argv);
 
       if (this->parse_args (argc, argv) == -1)
         return -1;
@@ -88,7 +86,7 @@ FactoryDriver::start (int argc, char *argv [])
       if (naming_client_.init (orb_.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "(%P|%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           1);
 
       CosNaming::NamingContext_var context =
@@ -99,7 +97,7 @@ FactoryDriver::start (int argc, char *argv [])
                                   context.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "(%P|%t) Unable to initialize "
-                           "the factory. \n"),
+                           "the factory.\n"),
                           1);
 
       // activate the factory in the root poa.
@@ -117,7 +115,7 @@ FactoryDriver::start (int argc, char *argv [])
 
       CosNaming::Name name (1);
       name.length (1);
-      name[0].id = CORBA::string_dup (factoryName_);
+      name[0].id = CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(factoryName_));
       naming_client_->rebind (name,
                               factory_.in ());
 
