@@ -1,4 +1,4 @@
-// ProxyPushSupplier_i.cpp,v 1.6 2005/07/04 09:26:24 jwillemsen Exp
+// $Id: ProxyPushSupplier_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 //
 #include "orbsvcs/RtecEventChannelAdminC.h"
 #include "orbsvcs/CosEventChannelAdminC.h"
@@ -30,13 +30,10 @@ public:
   ~TAO_CosEC_PushConsumerWrapper (void);
   // Destructor.
 
-  virtual void push (const RtecEventComm::EventSet & data
-                     ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void push (const RtecEventComm::EventSet & data);
   // This method is called by the RTEvent Channel to supply data.
 
-  virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_push_consumer (void);
   // Disconnects the consumer from the event channel.
 
 private:
@@ -61,48 +58,36 @@ TAO_CosEC_PushConsumerWrapper::~TAO_CosEC_PushConsumerWrapper ()
 }
 
 void
-TAO_CosEC_PushConsumerWrapper::push (const RtecEventComm::EventSet& set
-                                     ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CosEC_PushConsumerWrapper::push (const RtecEventComm::EventSet& set)
 {
   for (CORBA::ULong i = 0;
        i < set.length ();
        ++i)
     {
-      ACE_TRY
+      try
         {
-          this->consumer_->push (set[i].data.any_value
-                                 ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->consumer_->push (set[i].data.any_value);
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception&)
         {
           // Ignore the exception...
         }
-      ACE_ENDTRY;
     }
 }
 
 void
-TAO_CosEC_PushConsumerWrapper::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CosEC_PushConsumerWrapper::disconnect_push_consumer (void)
 {
   // Deactivate the supplier proxy.
-  this->consumer_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->consumer_->disconnect_push_consumer ();
 
   PortableServer::POA_var poa =
-    this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->_default_POA ();
 
   PortableServer::ObjectId_var id =
-    poa->servant_to_id (this
-                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    poa->servant_to_id (this);
 
-  poa->deactivate_object (id.in ()
-                          ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  poa->deactivate_object (id.in ());
 
   // @@ If we keep a list remember to remove this object from the
   // list.
@@ -124,64 +109,48 @@ TAO_CosEC_ProxyPushSupplier_i::~TAO_CosEC_ProxyPushSupplier_i (void)
 }
 
 void
-TAO_CosEC_ProxyPushSupplier_i::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CosEC_ProxyPushSupplier_i::disconnect_push_supplier (void)
 {
-  this->pps_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->pps_->disconnect_push_supplier ();
 
   // Deactivate the supplier proxy
   PortableServer::POA_var poa =
-    this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->_default_POA ();
 
   PortableServer::ObjectId_var id =
-    poa->servant_to_id (this
-                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    poa->servant_to_id (this);
 
-  poa->deactivate_object (id.in ()
-                          ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  poa->deactivate_object (id.in ());
 
   // @@ If we keep a list remember to remove this object from the
   // list.
 }
 
 void
-TAO_CosEC_ProxyPushSupplier_i::connect_push_consumer (CosEventComm::PushConsumer_ptr push_consumer
-                                                      ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException,
-                       CosEventChannelAdmin::AlreadyConnected,
-                       CosEventChannelAdmin::TypeError))
+TAO_CosEC_ProxyPushSupplier_i::connect_push_consumer (CosEventComm::PushConsumer_ptr push_consumer)
 {
   if (this->connected ())
-    ACE_THROW (CosEventChannelAdmin::AlreadyConnected ());
+    throw CosEventChannelAdmin::AlreadyConnected ();
 
   if (push_consumer == CosEventComm::PushConsumer::_nil())
-    ACE_THROW (CORBA::BAD_PARAM ());
+    throw CORBA::BAD_PARAM ();
 
   TAO_CosEC_PushConsumerWrapper *wrapper;
   ACE_NEW_THROW_EX (wrapper,
                     TAO_CosEC_PushConsumerWrapper (push_consumer),
                     CORBA::NO_MEMORY ());
-  ACE_CHECK;
 
   auto_ptr <TAO_CosEC_PushConsumerWrapper> auto_wrapper (wrapper);
 
   // @@ This code is not exception safe.
   RtecEventComm::PushConsumer_ptr  rtecpushconsumer =
-    auto_wrapper.get ()->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    auto_wrapper.get ()->_this ();
 
   // give the ownership to the POA.
-  auto_wrapper.get ()->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  auto_wrapper.get ()->_remove_ref ();
 
   this->pps_->connect_push_consumer (rtecpushconsumer,
-                                     this->qos_
-                                     ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                     this->qos_);
 
   this->wrapper_ = auto_wrapper.release ();
 }
@@ -192,10 +161,3 @@ TAO_CosEC_ProxyPushSupplier_i::connected (void)
   return this->wrapper_ == 0 ? 0 : 1;
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-  template class ACE_Auto_Basic_Ptr<TAO_CosEC_PushConsumerWrapper>;
-  template class auto_ptr<TAO_CosEC_PushConsumerWrapper>;
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-# pragma instantiate ACE_Auto_Basic_Ptr<TAO_CosEC_PushConsumerWrapper>
-# pragma instantiate auto_ptr<TAO_CosEC_PushConsumerWrapper>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
