@@ -1,11 +1,11 @@
 /* -*- C++ -*- */
-// $Id: Basic.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: Basic.cpp 82975 2008-10-08 11:01:24Z johnnyw $
 
 #include "Basic.h"
 #include "CosEvent_Utilities.h"
 
 int
-main (int argc, char *argv [])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   Basic basic;
 
@@ -42,7 +42,7 @@ Basic::~Basic (void)
 }
 
 void
-Basic::init (int argc, char *argv[])
+Basic::init (int argc, ACE_TCHAR *argv[])
 {
   this->init_ORB (argc, argv);
 
@@ -50,11 +50,9 @@ Basic::init (int argc, char *argv[])
 }
 
 void
-Basic::init_ORB  (int argc, char *argv [])
+Basic::init_ORB  (int argc, ACE_TCHAR *argv [])
 {
-  this->orb_ = CORBA::ORB_init (argc,
-                                argv,
-                                "");
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
   CORBA::Object_var poa_object  =
     this->orb_->resolve_initial_references("RootPOA");
