@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: Supplier.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: Supplier.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Supplier.h"
 #include "ace/Get_Opt.h"
@@ -11,9 +11,9 @@ Supplier::Supplier ()
 }
 
 int
-Supplier::parse_args (int argc, char *argv [])
+Supplier::parse_args (int argc, ACE_TCHAR *argv [])
 {
-  ACE_Get_Opt get_opt (argc, argv, "n:c:");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("n:c:"));
   int opt;
 
   while ((opt = get_opt ()) != EOF)
@@ -21,7 +21,7 @@ Supplier::parse_args (int argc, char *argv [])
       switch (opt)
         {
         case 'n':
-          this->service_name = get_opt.opt_arg ();
+          this->service_name_ = get_opt.opt_arg ();
           break;
 
         case 'c':
@@ -33,7 +33,7 @@ Supplier::parse_args (int argc, char *argv [])
           ACE_DEBUG ((LM_DEBUG,
                       "Usage: %s "
                       " -n <COS Event Service name>"
-                      " \n",
+                      "\n",
                       argv[0]));
           return -1;
         }
@@ -142,7 +142,7 @@ Supplier::run (void)
 }
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   Supplier supp;
 
