@@ -1,6 +1,6 @@
 // file      : RolyPoly/ORB_Initializer.h
 // author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
-// cvs-id    : $Id: ORB_Initializer.h 77020 2007-02-12 13:56:49Z johnnyw $
+// cvs-id    : $Id: ORB_Initializer.h 81490 2008-04-28 14:32:24Z johnnyw $
 
 #ifndef ORB_INITIALIZER_H
 #define ORB_INITIALIZER_H
@@ -10,7 +10,7 @@
 
 class ORB_Initializer :
   public virtual PortableInterceptor::ORBInitializer,
-  public virtual TAO_Local_RefCounted_Object
+  public virtual ::CORBA::LocalObject
 {
 public:
 
