@@ -1,9 +1,10 @@
 // file      : RolyPoly/RolyPoly_i.cpp
 // author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
-// cvs-id    : RolyPoly_i.cpp,v 1.2 2003/12/22 01:44:37 wilson_d Exp
+// cvs-id    : $Id: RolyPoly_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #include "RolyPoly_i.h"
 #include "StateUpdate.h"
+#include "tao/AnyTypeCode/Any.h"
 
 RolyPoly_i::RolyPoly_i (CORBA::ORB_ptr orb)
   : number_ (0)
@@ -38,9 +39,7 @@ set_state (CORBA::Any const& state)
 
 
 CORBA::Short
-RolyPoly_i::number (char *&str
-                ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+RolyPoly_i::number (char *&str)
 {
   CORBA::string_free (str);
 
@@ -62,10 +61,9 @@ RolyPoly_i::number (char *&str
 }
 
 void
-RolyPoly_i::shutdown (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+RolyPoly_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG, "Server is shutting down.\n"));
 
-  this->orb_->shutdown (0 ACE_ENV_ARG_PARAMETER);
+  this->orb_->shutdown (0);
 }
