@@ -1,6 +1,6 @@
 // file      : RolyPoly/client.cpp
 // author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
-// cvs-id    : $Id: client.cpp 76601 2007-01-25 19:59:59Z elliott_c $
+// cvs-id    : $Id: client.cpp 82975 2008-10-08 11:01:24Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "ace/OS_NS_unistd.h"
@@ -19,9 +19,9 @@ typedef ACE_Unbounded_Queue<ACE_SString> IOR_QUEUE;
 IOR_QUEUE ior_strs;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -29,7 +29,7 @@ parse_args (int argc, char *argv[])
     {
     case 'k':
       {
-      ACE_SString ior(get_opts.opt_arg ());
+      ACE_SString ior(ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ()));
       if (ior_strs.enqueue_tail (ior) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "Unable to enqueue IOR: %s\n",
@@ -51,7 +51,7 @@ parse_args (int argc, char *argv[])
 }
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   int status = 0;
 
