@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// Manager_i.h,v 1.2 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Manager_i.h 77020 2007-02-12 13:56:49Z johnnyw $
 #ifndef MANAGERI_H_
 #define MANAGERI_H_
 
@@ -18,14 +18,11 @@ public:
 
   virtual ~Manager_i (void);
 
-  virtual CORBA::Long registerServer ()
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CORBA::Long registerServer ();
 
-  virtual void startRetry (CORBA::Long count)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void startRetry (CORBA::Long count);
 
-  virtual CORBA::Long endRetry ()
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CORBA::Long endRetry ();
 
 private:
 
