@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// Messenger_i.h,v 1.2 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Messenger_i.h 77087 2007-02-13 07:37:15Z johnnyw $
 #ifndef MESSENGERI_H_
 #define MESSENGERI_H_
 
@@ -24,10 +24,9 @@ public:
       ::CORBA::Long iter,
       ::CORBA::Long obj,
       ::CORBA::Long req
-   ) ACE_THROW_SPEC ((CORBA::SystemException));
+   );
 
-  virtual void shutdownOrb ()
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdownOrb ();
 
   bool acknowledgeHit();
 
