@@ -1,4 +1,4 @@
-//$Id: TestClient.h 71935 2006-04-04 22:10:27Z zhangw $
+//$Id: TestClient.h 88080 2009-12-10 14:55:15Z dbudko $
 #include "tao/ORB.h"
 
 #include "ace/Task.h"
@@ -10,14 +10,14 @@
 class TestClient : public ACE_Task_Base, public ACE_Capabilities
 {
 public:
-  TestClient(CORBA::ORB_ptr orb, int argc, char* argv[]);
+  TestClient (CORBA::ORB_ptr orb, int argc, ACE_TCHAR *argv[]);
 
   virtual ~TestClient();
 
   void run();
 
 private:
-  int parseCommands(int argc, char* argv[]);
+  int parseCommands (int argc, ACE_TCHAR *argv[]);
   void buildIORList();
   void pause(int milliseconds);
   virtual int svc();
@@ -25,7 +25,7 @@ private:
   CORBA::ORB_var     orb_;
   std::vector<ACE_TString> iors_;
 
-  char               pauseType_;
+  ACE_TCHAR          pauseType_;
   int                startupPause_;
   int                threadCount_;
   int                instance_;
@@ -35,4 +35,5 @@ private:
   bool               shutdownOrb_;
   bool               expectHolding_;
   bool               expectNoProfile_;
+  const ACE_TCHAR    *iorFile_;
 };
