@@ -1,16 +1,16 @@
-//$Id: client_main.cpp 66056 2005-05-23 17:58:35Z michel_j $
+//$Id: client_main.cpp 82176 2008-06-25 13:56:32Z sma $
 #include "TestClient.h"
 
 #include <ace/streams.h>
 
-int main(int argc, char* argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
   {
-    CORBA::ORB_var orb = CORBA::ORB_init(argc, argv);
+    CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
     {
-      TestClient client(orb.in(), argc, argv);
+      TestClient client (orb.in (), argc, argv);
       client.run();
     }
 
