@@ -1,4 +1,4 @@
-// $Id: controller.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: controller.cpp 82176 2008-06-25 13:56:32Z sma $
 // This is a simple test of an ImR using the corba interfaces
 
 #include "service_configC.h"
@@ -10,27 +10,26 @@
 using namespace CORBA;
 
 namespace {
-
-  ACE_CString directive;
+  ACE_TString directive;
 
   void showusage() {
     ACE_DEBUG((LM_DEBUG, "Usage: controller [-r | -c \"service_configurator_directive\"]\n"
       "(e.g. dynamic mysvc Service_Object * MySvc:_make_MySvc() \"-arg1 one\"\n\n"));
   }
 
-  bool parse_args(int argc, char* argv[]) {
+  bool parse_args (int argc, ACE_TCHAR *argv[]) {
     if (argc != 2 && argc != 3) {
       ACE_ERROR((LM_ERROR, "Controller: wrong number of arguments. %d\n", argc - 1));
       return false;
     }
     for (int i = 1; i < argc; ++i) {
-      ACE_CString s(argv[i]);
-      if (s == "-h" || s == "-help" || s == "--help" || s == "-?")
+      ACE_TString s (argv[i]);
+      if (s == ACE_TEXT ("-h") || s == ACE_TEXT ("-help") || s == ACE_TEXT ("--help") || s == ACE_TEXT ("-?"))
         return false;
-      if (s == "-r") {
+      if (s == ACE_TEXT ("-r")) {
         return true;
       }
-      if (s == "-c" && ++i < argc) {
+      if (s == ACE_TEXT ("-c") && ++i < argc) {
         directive = argv[i];
         return true;
       }
@@ -39,13 +38,11 @@ namespace {
   }
 }
 
-int main(int argc, char* argv[]) {
-
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[]) {
   try {
+    ORB_var orb = ORB_init (argc, argv);
 
-    ORB_var orb = ORB_init(argc, argv);
-
-    if (! parse_args(argc, argv)) {
+    if (! parse_args (argc, argv)) {
       showusage();
       return 1;
     }
@@ -58,7 +55,7 @@ int main(int argc, char* argv[]) {
 
     if (directive.length() > 0) {
       ACE_DEBUG((LM_DEBUG, "Controller: sending directive <%s>...\n", directive.c_str()));
-      sc->process_directive(directive.c_str());
+      sc->process_directive (ACE_TEXT_ALWAYS_CHAR (directive.c_str()));
     } else {
       ACE_DEBUG((LM_DEBUG, "Controller: reloading config file...\n"));
       sc->reconfigure();
