@@ -1,4 +1,4 @@
-// $Id: test.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: test.cpp 84219 2009-01-22 20:17:39Z mitza $
 // This is a simple test of an ImR using the corba interfaces
 
 #include "testC.h"
@@ -10,7 +10,7 @@
 #include <string>
 
 #define assertTrue(CONDITION) \
-    if (CONDITION == false) { \
+    if (!(CONDITION)) { \
       ACE_CString str ("Error : "#CONDITION" "__FILE__":"); \
       char line[32]; \
       ACE_OS::sprintf (line, "%d", __LINE__); \
@@ -20,7 +20,7 @@
 using namespace CORBA;
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -33,7 +33,7 @@ main (int argc, char* argv[])
 
       Long n = test->get ();
       Long m = test->get ();
-      assertTrue (m == n + 1);
+      assertTrue (m == (n + 1));
 
       ACE_DEBUG ((LM_DEBUG, "All tests ran successfully.\n"));
 
