@@ -9,7 +9,7 @@
 
 ACE_RCSID (LoadBalancing,
            ORBInitializer,
-           "ORBInitializer.cpp,v 1.2 2005/02/18 09:07:07 jwillemsen Exp")
+           "$Id: ORBInitializer.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 
 ORBInitializer::ORBInitializer (void)
@@ -20,17 +20,13 @@ ORBInitializer::ORBInitializer (void)
 
 void
 ORBInitializer::pre_init (
-    PortableInterceptor::ORBInitInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ORBInitInfo_ptr)
 {
 }
 
 void
 ORBInitializer::post_init (
-    PortableInterceptor::ORBInitInfo_ptr info
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ORBInitInfo_ptr info)
 {
 
   ACE_NEW_THROW_EX (this->interceptor_,
@@ -40,14 +36,11 @@ ORBInitializer::post_init (
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK;
 
   PortableInterceptor::ServerRequestInterceptor_var sr_interceptor =
     this->interceptor_;
 
-  info->add_server_request_interceptor (sr_interceptor.in ()
-                                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  info->add_server_request_interceptor (sr_interceptor.in ());
 
   PortableInterceptor::ServerRequestInterceptor_ptr reject_interceptor;
   ACE_NEW_THROW_EX (reject_interceptor,
@@ -57,14 +50,11 @@ ORBInitializer::post_init (
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK;
 
   PortableInterceptor::ServerRequestInterceptor_var safe_reject_interceptor =
     reject_interceptor;
 
-  info->add_server_request_interceptor (safe_reject_interceptor.in ()
-                                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  info->add_server_request_interceptor (safe_reject_interceptor.in ());
 }
 
 
