@@ -4,7 +4,7 @@
 /**
  *  @file RPS_Monitor.h
  *
- *  RPS_Monitor.h,v 1.3 2005/07/04 08:55:12 jwillemsen Exp
+ *  $Id: RPS_Monitor.h 80166 2007-12-03 13:53:49Z sowayaa $
  *
  *  @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -50,9 +50,7 @@ public:
   /**
    * The returned "Location" is a sequence of length 1.
    */
-  virtual CosLoadBalancing::Location * the_location (
-      ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CosLoadBalancing::Location * the_location ();
 
   /// Return the average CPU load at the location which this
   /// LoadMonitor resides.
@@ -61,9 +59,7 @@ public:
    *         equal to CosLoadBalancing::LoadAverage, and the average CPU
    *         load.
    */
-  virtual CosLoadBalancing::LoadList * loads (
-      ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CosLoadBalancing::LoadList * loads ();
 
   //@}
 
@@ -85,7 +81,7 @@ private:
 
   ACE_Time_Value last_time_;
 
-  ACE_SYNCH_MUTEX lock_;
+  TAO_SYNCH_MUTEX lock_;
 };
 
 #include /**/ "ace/post.h"
