@@ -1,5 +1,5 @@
 //
-// StockFactory.cpp,v 1.2 2004/02/18 09:23:19 jwillemsen Exp
+// $Id: StockFactory.cpp 78900 2007-07-15 13:05:48Z sowayaa $
 //
 
 #include "StockFactory.h"
@@ -15,20 +15,18 @@ StockFactory::StockFactory (CORBA::ORB_ptr orb, int number)
 
 Test::Stock_ptr
 StockFactory::get_stock (const char *symbol)
-    throw (Test::Invalid_Stock_Symbol)
 {
   cout << "Server Number is " << number_ << endl;
-  if (strcmp (symbol, "RHAT") == 0) {
+  if (ACE_OS::strcmp (symbol, "RHAT") == 0) {
     return this->rhat_._this ();
-  } else if (strcmp (symbol, "MSFT") == 0) {
+  } else if (ACE_OS::strcmp (symbol, "MSFT") == 0) {
     return this->msft_._this ();
   }
   throw Test::Invalid_Stock_Symbol ();
 }
 
 void
-StockFactory::shutdown (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+StockFactory::shutdown (void)
 {
-  this->orb_->shutdown (0 ACE_ENV_ARG_PARAMETER);
+  this->orb_->shutdown (0);
 }
