@@ -4,7 +4,7 @@
 /**
  *  @file   RTEvent_Supplier.h
  *
- *  $Id: RTEvent_Supplier.h 77020 2007-02-12 13:56:49Z johnnyw $
+ *  $Id: RTEvent_Supplier.h 82735 2008-09-16 12:12:29Z johnnyw $
  *
  *  An example of using the RTEvent_Logging_Service.
  *
@@ -38,7 +38,7 @@ public:
   Supplier (void);
   // Constructor
 
-  int run (int argc, char* argv[]);
+  int run (int argc, ACE_TCHAR* argv[]);
   // Run the test
 
   // = The RtecEventComm::PushSupplier methods
