@@ -1,6 +1,6 @@
 // file      : Agent.cpp
 // author    : Boris Kolpackov <boris@dre.vanderbilt.edu>
-// cvs-id    : $Id: Agent.cpp 79084 2007-07-30 13:13:45Z elliott_c $
+// cvs-id    : $Id: Agent.cpp 83342 2008-10-21 12:53:19Z vzykov $
 
 #include <ace/streams.h>
 #if defined(ACE_USES_OLD_IOSTREAMS)
@@ -35,8 +35,7 @@ using namespace CosNotifyComm;
 using namespace CosNotification;
 using namespace CosNotifyChannelAdmin;
 
-class Agent : public POA_CosNotifyComm::StructuredPushConsumer,
-              public PortableServer::RefCountServantBase
+class Agent : public POA_CosNotifyComm::StructuredPushConsumer
 {
 public:
   Agent (char const* space_craft_name,
@@ -74,7 +73,7 @@ public:
     if (ACE_OS::thr_create (&tracker_thunk,
                             this,
                             THR_JOINABLE,
-                            &thread_) != 0) 
+                            &thread_) != 0)
       ACE_OS::abort ();
   }
 
@@ -198,7 +197,7 @@ private:
 };
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   try
   {
@@ -262,10 +261,10 @@ main (int argc, char* argv[])
     // Find which space craft we are on.
     //
     ACE_INET_Addr addr;
-    char const* space_craft_name = 0;
+    const ACE_TCHAR *space_craft_name = 0;
 
     if (argc < 3)
-      space_craft_name = "a";  // Default to spacecraft "a".
+      space_craft_name = ACE_TEXT("a");  // Default to spacecraft "a".
     else
       space_craft_name = argv[2];
 
@@ -302,7 +301,9 @@ main (int argc, char* argv[])
 
     // Start the agent.
     //
-    Agent agent (space_craft_name, argv[1], channel.in ());
+    Agent agent (ACE_TEXT_ALWAYS_CHAR(space_craft_name),
+                 ACE_TEXT_ALWAYS_CHAR(argv[1]),
+                 channel.in ());
 
     orb->run ();
 
