@@ -1,8 +1,8 @@
-/* -*- C++ -*- $Id: Filter.cpp 77020 2007-02-12 13:56:49Z johnnyw $ */
+/* -*- C++ -*- $Id: Filter.cpp 84563 2009-02-23 08:13:54Z johnnyw $ */
 
 #include "Filter.h"
 
-ACE_RCSID(Filter, Filter, "$Id: Filter.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
+ACE_RCSID(Filter, Filter, "$Id: Filter.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 #define NOTIFY_FACTORY_NAME "NotifyEventChannelFactory"
 #define NAMING_SERVICE_NAME "NameService"
@@ -29,7 +29,7 @@ FilterClient::~FilterClient ()
 }
 
 void
-FilterClient::init (int argc, char *argv [])
+FilterClient::init (int argc, ACE_TCHAR *argv [])
 {
   init_ORB (argc, argv);
 
@@ -68,12 +68,9 @@ FilterClient::done (void)
 }
 
 void
-FilterClient::init_ORB (int argc,
-                      char *argv [])
+FilterClient::init_ORB (int argc, ACE_TCHAR *argv [])
 {
-  this->orb_ = CORBA::ORB_init (argc,
-                                argv,
-                                "");
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
   CORBA::Object_ptr poa_object  =
     this->orb_->resolve_initial_references("RootPOA");
@@ -355,7 +352,7 @@ Filter_StructuredPushConsumer::push_structured_event
 
 
     ACE_DEBUG ((LM_DEBUG,
-                "%s received event, %d\n", my_name_.fast_rep (), val));
+                "%C received event, %d\n", my_name_.fast_rep (), val));
 
     ACE_DEBUG ((LM_DEBUG,"event count %d\n", g_result_count.value ()));
 
@@ -426,7 +423,7 @@ Filter_StructuredPushSupplier::send_event
   ACE_ASSERT (!CORBA::is_nil (this->proxy_consumer_.in ()));
 
   ACE_DEBUG ((LM_DEBUG,
-              "%s is sending an event \n", my_name_.fast_rep ()));
+              "%C is sending an event\n", my_name_.fast_rep ()));
 
   proxy_consumer_->push_structured_event (event);
 }
