@@ -1,10 +1,10 @@
 // -*- C++ -*-
-// $Id: main.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: main.cpp 80730 2008-02-25 22:22:44Z sowayaa $
 
 #include "Filter.h"
 
 int
-main (int argc, char *argv [])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   FilterClient client;
 
