@@ -2,7 +2,7 @@
 /**
  *  @file Supplier_Client.h
  *
- *  $Id: Supplier_Client.h 76555 2007-01-24 15:39:09Z johnnyw $
+ *  $Id: Supplier_Client.h 82975 2008-10-08 11:01:24Z johnnyw $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -29,7 +29,7 @@ class TAO_Notify_Lanes_Supplier;
 class TAO_Notify_Lanes_Supplier_Client : public ACE_Task_Base
 {
 public:
-  /// Constuctor
+  /// Constructor
   TAO_Notify_Lanes_Supplier_Client (TAO_Notify_ORB_Objects& orb_objects);
 
   /// Destructor
@@ -42,7 +42,7 @@ public:
   void run (void);
 
   /// Parse Args
-  int parse_args (int argc, char *argv[]);
+  int parse_args (int argc, ACE_TCHAR *argv[]);
 
   /// The thread entry point.
   virtual int svc (void);
@@ -64,7 +64,7 @@ protected:
   int consumer_count_;
 
   /// Name of the file to write the supplier ior to.
-  ACE_CString ior_file_name_;
+  ACE_TString ior_file_name_;
 };
 
 #include /**/ "ace/post.h"
