@@ -1,7 +1,7 @@
-/* -*- C++ -*- $Id: Subscribe.cpp 77020 2007-02-12 13:56:49Z johnnyw $ */
+/* -*- C++ -*- $Id: Subscribe.cpp 82975 2008-10-08 11:01:24Z johnnyw $ */
 #include "Subscribe.h"
 
-ACE_RCSID(Notify, Subscribe, "$Id: Subscribe.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
+ACE_RCSID(Notify, Subscribe, "$Id: Subscribe.cpp 82975 2008-10-08 11:01:24Z johnnyw $")
 
 #define NOTIFY_FACTORY_NAME "NotifyEventChannelFactory"
 #define NAMING_SERVICE_NAME "NameService"
@@ -31,7 +31,7 @@ Subscribe::~Subscribe ()
 }
 
 void
-Subscribe::init (int argc, char *argv [])
+Subscribe::init (int argc, ACE_TCHAR *argv [])
 {
   init_ORB (argc, argv);
   resolve_naming_service ();
@@ -63,12 +63,9 @@ Subscribe::done (void)
 }
 
 void
-Subscribe::init_ORB (int argc,
-                      char *argv [])
+Subscribe::init_ORB (int argc, ACE_TCHAR *argv [])
 {
-  this->orb_ = CORBA::ORB_init (argc,
-                                argv,
-                                "");
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
   CORBA::Object_ptr poa_object  =
     this->orb_->resolve_initial_references("RootPOA");
