@@ -1,10 +1,10 @@
-// $Id: Consumer.cpp 78665 2007-06-29 19:33:48Z johnnyw $
+// $Id: Consumer.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Consumer.h"
 
 ACE_RCSID (Notify,
            TAO_Notify_ThreadPool_Consumer,
-           "$Id: Consumer.cpp 78665 2007-06-29 19:33:48Z johnnyw $")
+           "$Id: Consumer.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 #include "tao/debug.h"
 
@@ -169,9 +169,9 @@ TAO_Notify_ThreadPool_Consumer::dump_throughput (void)
 {
   ACE_UINT32 gsf = ACE_High_Res_Timer::global_scale_factor ();
 
-  ACE_DEBUG ((LM_DEBUG, "(%P,%t) Consumer %d \n", proxy_supplier_id_));
+  ACE_DEBUG ((LM_DEBUG, "(%P,%t) Consumer %d\n", proxy_supplier_id_));
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          t_last_ - t_first_,
                                          this->max_events_);
 }
