@@ -2,7 +2,7 @@
 /**
  *  @file Consumer_Client.h
  *
- *  $Id: Consumer_Client.h 76555 2007-01-24 15:39:09Z johnnyw $
+ *  $Id: Consumer_Client.h 82735 2008-09-16 12:12:29Z johnnyw $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -32,7 +32,7 @@ class TAO_Notify_ThreadPool_Consumer;
 class TAO_Notify_ThreadPool_Consumer_Client  : public ACE_Task_Base
 {
 public:
-  /// Constuctor
+  /// Constructor
   TAO_Notify_ThreadPool_Consumer_Client (TAO_Notify_ORB_Objects& orb_objects);
 
   /// Destructor
@@ -45,7 +45,7 @@ public:
   void run (void);
 
   /// Parse Args
-  int parse_args (int argc, char *argv[]);
+  int parse_args (int argc, ACE_TCHAR *argv[]);
 
   /// The thread entry point.
   virtual int svc (void);
