@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// Gateway_ObjRef_Factory.h,v 1.6 2003/03/18 23:31:17 ossama Exp
+// $Id: Gateway_ObjRef_Factory.h 77020 2007-02-12 13:56:49Z johnnyw $
 
 #ifndef GATEWAY_OBJREF_FACTORY_H
 #define GATEWAY_OBJREF_FACTORY_H
@@ -26,9 +26,7 @@ public:
 
   virtual CORBA::Object_ptr make_object (
       const char *repository_id,
-      const PortableInterceptor::ObjectId &id
-      ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+      const PortableInterceptor::ObjectId &id);
 
 private:
 
