@@ -1,4 +1,4 @@
-// Object_Factory_i.cpp,v 1.8 2005/02/18 09:07:07 jwillemsen Exp
+// $Id: Object_Factory_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #include "Object_Factory_i.h"
 #include "tao/PortableServer/Root_POA.h"
@@ -14,13 +14,10 @@ Object_Factory_i::Object_Factory_i (CORBA::ORB_ptr orb,
 
 CORBA::Object_ptr
 Object_Factory_i::create_object (const char *interface_repository_id,
-                                 CORBA::Object_ptr gatewayed_object
-                                 ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                 CORBA::Object_ptr gatewayed_object)
 {
   CORBA::String_var stringified_object =
-    this->orb_->object_to_string (gatewayed_object ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CORBA::Object::_nil ());
+    this->orb_->object_to_string (gatewayed_object);
 
   const PortableServer::ObjectId_var id =
     PortableServer::string_to_ObjectId (stringified_object.in ());
@@ -31,7 +28,6 @@ Object_Factory_i::create_object (const char *interface_repository_id,
   ACE_UNUSED_ARG(interface_repository_id);
 /*
   TAO_POA *poa = dynamic_cast <TAO_POA *> (this->gateway_poa_);
-  ACE_CHECK_RETURN (CORBA::Object::_nil ());
 
   PortableInterceptor::ObjectReferenceTemplate *ort_template =
     poa->get_adapter_template();
@@ -41,9 +37,8 @@ Object_Factory_i::create_object (const char *interface_repository_id,
 
   CORBA::Object_ptr object_ptr =
     ort->make_object (interface_repository_id,
-                      *obj_id
-                      ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CORBA::Object::_nil ());*/
+                      *obj_id);
+*/
 
   return CORBA::Object::_nil();
 }
