@@ -1,4 +1,4 @@
-// $Id: Server_IORInterceptor_ORBInitializer.h 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: Server_IORInterceptor_ORBInitializer.h 81490 2008-04-28 14:32:24Z johnnyw $
 
 #ifndef SERVER_IOR_INTERCEPTOR_ORB_INITIALIZER_H
 #define SERVER_IOR_INTERCEPTOR_ORB_INITIALIZER_H
@@ -19,7 +19,7 @@
 
 class Server_IORInterceptor_ORBInitializer
   : public virtual PortableInterceptor::ORBInitializer,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
  public:
 
