@@ -1,4 +1,4 @@
-// $Id: gateway_server.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: gateway_server.cpp 82853 2008-09-28 11:40:48Z johnnyw $
 
 #include "Object_Factory_i.h"
 #include "Gateway_i.h"
@@ -6,12 +6,12 @@
 #include "ace/Get_Opt.h"
 #include "ace/OS_NS_stdio.h"
 
-const char *ior_output_file = 0;
+const ACE_TCHAR *ior_output_file = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -34,7 +34,7 @@ parse_args (int argc, char *argv[])
 }
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   try
     {
