@@ -1,4 +1,4 @@
-// $Id: Simple_Naming.cpp 76601 2007-01-25 19:59:59Z elliott_c $
+// $Id: Simple_Naming.cpp 82847 2008-09-28 11:26:15Z johnnyw $
 
 // ============================================================================
 //
@@ -21,14 +21,14 @@
 #include "Simple_Naming_i.h"
 #include "ace/Get_Opt.h"
 
-ACE_RCSID (PSS, client, "$Id: Simple_Naming.cpp 76601 2007-01-25 19:59:59Z elliott_c $")
+ACE_RCSID (PSS, client, "$Id: Simple_Naming.cpp 82847 2008-09-28 11:26:15Z johnnyw $")
 
-const char *ior_output_file = "simple_naming.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("simple_naming.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -52,15 +52,12 @@ parse_args (int argc, char *argv[])
 }
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   try
     {
       // Initialize the ORB.
-      CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         "");
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
       if (parse_args (argc, argv) == -1)
         return -1;
