@@ -1,4 +1,4 @@
-// Simple_Naming_i.cpp,v 1.2 2002/07/26 16:24:54 pgontla Exp
+// $Id: Simple_Naming_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #include "Simple_Naming_i.h"
 #include "orbsvcs/PSS/PSDL_Code_Gen.h"
@@ -20,28 +20,22 @@ Naming_Context_i::~Naming_Context_i ()
 
 int
 Naming_Context_i::bind (const char *n,
-                        const char *obj
-                        ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                        const char *obj)
 {
   // Save the binding to database.
   int result =
-    this->code_gen_->set_name_obj_ref (n, obj ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (-1);
+    this->code_gen_->set_name_obj_ref (n, obj);
 
   return result;
 }
 
 char *
-Naming_Context_i::find (const char *n
-                        ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Naming_Context_i::find (const char *n)
 {
   // Get the Stringified object reference corresponding to
   // 'n'
   CORBA::String_var obj_ref =
-    this->code_gen_->get_obj_ref (n ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+    this->code_gen_->get_obj_ref (n);
 
   return CORBA::string_dup (obj_ref.in ());
 }
