@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Simple_Naming_i.h,v 1.2 2003/07/21 23:51:30 dhinton Exp
+// $Id: Simple_Naming_i.h 77020 2007-02-12 13:56:49Z johnnyw $
 
 // ============================================================================
 //
@@ -36,13 +36,9 @@ class Naming_Context_i : public virtual POA_Simple_Naming::Naming_Context
   ~Naming_Context_i (void);
 
   virtual int bind (const char *n,
-                    const char *obj
-                    ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                    const char *obj);
 
-  virtual char *find (const char *n
-                      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual char *find (const char *n);
 
 private:
 
