@@ -2,7 +2,7 @@
 /**
  *  @file   Gateway.h
  *
- *  $Id: Gateway.h 59567 2004-08-16 23:53:17Z jtc $
+ *  $Id: Gateway.h 82735 2008-09-16 12:12:29Z johnnyw $
  *
  *  @author Johnny Willemsen  (jwillemsen@remedy.nl)
  *
@@ -29,10 +29,10 @@ public:
   Gateway (void);
 
   /// Run the test
-  int run (int argc, char* argv[]);
+  int run (int argc, ACE_TCHAR* argv[]);
 
 private:
-  int parse_args (int argc, char *argv[]);
+  int parse_args (int argc, ACE_TCHAR *argv[]);
 };
 
 #endif /* GATEWAY_H */
