@@ -1,4 +1,4 @@
-// $Id: Service.cpp 77818 2007-03-27 18:00:41Z wotte $
+// $Id: Service.cpp 83070 2008-10-10 13:51:48Z johnnyw $
 
 #include "orbsvcs/Sched/Reconfig_Scheduler.h"
 #include "orbsvcs/Runtime_Scheduler.h"
@@ -21,7 +21,7 @@
 #include "ace/OS_NS_strings.h"
 #include "ace/Thread.h"
 
-ACE_RCSID(EC_Examples, Service, "$Id: Service.cpp 77818 2007-03-27 18:00:41Z wotte $")
+ACE_RCSID(EC_Examples, Service, "$Id: Service.cpp 83070 2008-10-10 13:51:48Z johnnyw $")
 
 namespace
 {
@@ -32,20 +32,20 @@ namespace
 inline RtecScheduler::Period_t time_val_to_period (const ACE_Time_Value &tv)
 {
   //100s of nanoseconds
-  return (tv.sec () * 1000000 + tv.usec ())*10;
+  return static_cast<RtecScheduler::Period_t> (tv.sec () * 1000000 + tv.usec ())*10;
 }
 
-int parse_args (int argc, char *argv[]);
+int parse_args (int argc, ACE_TCHAR *argv[]);
 
 typedef TAO_Reconfig_Scheduler<TAO_RMS_FAIR_Reconfig_Sched_Strategy, TAO_SYNCH_MUTEX> RECONFIG_RMS_SCHED_TYPE;
 
 typedef TAO_Reconfig_Scheduler<TAO_MUF_FAIR_Reconfig_Sched_Strategy, TAO_SYNCH_MUTEX> RECONFIG_MUF_SCHED_TYPE;
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   ACE_UNUSED_ARG (config_run);
-  
+
   //TAO_EC_Default_Factory::init_svcs ();
 
   TAO_EC_Kokyu_Factory::init_svcs ();
@@ -352,7 +352,7 @@ main (int argc, char* argv[])
                                             dependencies.in (),
                                             configs.in (),
                                             unsafe_anomalies,
-                                            "schedule.out");
+                                            ACE_TEXT("schedule.out"));
 
       // Obtain the range of valid priorities in the current
       // platform, the scheduler hard-code this values in the
@@ -377,7 +377,7 @@ main (int argc, char* argv[])
                                             dependencies.in (),
                                             configs.in (),
                                             anomalies.in (),
-                                            "schedule.out");
+                                            ACE_TEXT("schedule.out"));
 
       // ****************************************************************
       ACE_DEBUG ((LM_DEBUG, "Pushing events\n"));
@@ -439,9 +439,9 @@ main (int argc, char* argv[])
 
 // ****************************************************************
 
-int parse_args (int argc, char *argv[])
+int parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "cs:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("cs:"));
   int c;
 
   while ((c = get_opts ()) != -1)
