@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: Supplier.h 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: Supplier.h 82735 2008-09-16 12:12:29Z johnnyw $
 //
 // ============================================================================
 //
@@ -36,7 +36,7 @@ public:
   Supplier (void);
   // Constructor
 
-  int run (int argc, char* argv[]);
+  int run (int argc, ACE_TCHAR* argv[]);
   // Run the test
 
   // = The RtecEventComm::PushSupplier methods
