@@ -1,4 +1,4 @@
-// test_i.h,v 1.3 2002/01/29 20:20:47 okellogg Exp
+// $Id: test_i.h 77020 2007-02-12 13:56:49Z johnnyw $
 
 // ============================================================================
 //
@@ -31,19 +31,16 @@ public:
   // ctor
 
   // = The Simple_Server methods.
-  void send_line (const char *line
-                  ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void send_line (const char *line);
 
-  void shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void shutdown (void);
 
 private:
   CORBA::ORB_var orb_;
 };
 
 #if defined(__ACE_INLINE__)
-#include "test_i.i"
+#include "test_i.inl"
 #endif /* __ACE_INLINE__ */
 
 #endif /* TAO_SEND_FILE_TEST_I_H */
