@@ -1,4 +1,4 @@
-// $Id: Endpoint_Strategy_T.cpp 78820 2007-07-07 20:06:46Z sowayaa $
+// $Id: Endpoint_Strategy_T.cpp 82895 2008-10-01 12:18:57Z johnnyw $
 
 #ifndef TAO_AV_ENDPOINT_STRATEGY_T_CPP
 #define TAO_AV_ENDPOINT_STRATEGY_T_CPP
@@ -340,7 +340,10 @@ TAO_AV_Endpoint_Reactive_Strategy_B<T_StreamEndpoint, T_VDev, T_MediaCtrl>::crea
 template <class T_StreamEndpoint_B, class T_VDev , class T_MediaCtrl>
 TAO_AV_Child_Process <T_StreamEndpoint_B, T_VDev, T_MediaCtrl>::TAO_AV_Child_Process ()
   : stream_endpoint_name_ (0),
-    pid_ (-1)
+    pid_ (-1),
+    stream_endpoint_(0),
+    vdev_ (0),
+    media_ctrl_ (0)
 {
   this->pid_ = ACE_OS::getpid ();
   if (this->pid_ == 0)
@@ -353,7 +356,7 @@ TAO_AV_Child_Process <T_StreamEndpoint_B, T_VDev, T_MediaCtrl>::TAO_AV_Child_Pro
 template <class T_StreamEndpoint_B, class T_VDev , class T_MediaCtrl>
 int
 TAO_AV_Child_Process  <T_StreamEndpoint_B, T_VDev, T_MediaCtrl>::init (int argc,
-                                                                       char **argv,
+                                                                       ACE_TCHAR **argv,
                                                                        CORBA::ORB_ptr orb,
                                                                        PortableServer::POA_ptr poa)
 {
@@ -412,7 +415,7 @@ TAO_AV_Child_Process <T_StreamEndpoint, T_VDev, T_MediaCtrl>::activate_with_poa
 template <class T_StreamEndpoint, class T_VDev , class T_MediaCtrl>
 int
 TAO_AV_Child_Process  <T_StreamEndpoint, T_VDev, T_MediaCtrl>::activate_objects (int /*argc*/,
-                                                                                 char ** /*argv*/)
+                                                                                 ACE_TCHAR ** /*argv*/)
 {
   try
     {
