@@ -1,4 +1,4 @@
-// $Id: FlowSpec_Entry.cpp 78820 2007-07-07 20:06:46Z sowayaa $
+// $Id: FlowSpec_Entry.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 //------------------------------------------------------------
 // TAO_FlowSpec_Entry
@@ -68,7 +68,7 @@ TAO_FlowSpec_Entry::TAO_FlowSpec_Entry (const char *flowname,
    clean_up_control_address_ (0),
    address_str_ (),
    format_ (format_name),
-   direction_str_ (direction ),
+   direction_str_ (), // This is initialized in the call to set_direction()
    flowname_ ( flowname ),
    carrier_protocol_ ( carrier_protocol ),
    flow_protocol_ ( flow_protocol ),
@@ -93,8 +93,8 @@ TAO_FlowSpec_Entry::TAO_FlowSpec_Entry (const char *flowname,
    role_ (TAO_AV_INVALID_ROLE)
 {
   this->set_protocol ();
-  this->set_direction (this->direction_str_.c_str());
-  this->parse_flow_protocol_string (this->flow_protocol_.c_str() );
+  this->set_direction (direction);
+  this->parse_flow_protocol_string (this->flow_protocol_.c_str());
 }
 
 TAO_FlowSpec_Entry::TAO_FlowSpec_Entry (const char *flowname,
@@ -102,14 +102,13 @@ TAO_FlowSpec_Entry::TAO_FlowSpec_Entry (const char *flowname,
                                         const char *format_name,
                                         const char *flow_protocol,
                                         const char *address)
-                                        //const char *peer_address)
   :address_ (0),
    clean_up_address_ (0),
    control_address_ (0),
    clean_up_control_address_ (0),
    address_str_ ( address ),
    format_ ( format_name ),
-   direction_str_ ( direction ),
+   direction_str_ (), // This is initialized in the call to set_direction()
    flowname_ ( flowname ),
    carrier_protocol_ (),
    flow_protocol_ ( flow_protocol ),
@@ -134,7 +133,7 @@ TAO_FlowSpec_Entry::TAO_FlowSpec_Entry (const char *flowname,
 {
   this->parse_flow_protocol_string (this->flow_protocol_.c_str() );
   this->parse_address (this->address_str_.c_str(), TAO_AV_Core::TAO_AV_DATA);
-  this->set_direction (this->direction_str_.c_str());
+  this->set_direction (direction);
 }
 
 // Destructor.
@@ -206,7 +205,7 @@ TAO_FlowSpec_Entry::set_protocol (void)
       if (TAO_debug_level > 0)
         ACE_DEBUG ((LM_DEBUG, "TAO_FlowSpec_Entry::set_protocol address is not 0\n"));
       ACE_INET_Addr *inet_addr = dynamic_cast<ACE_INET_Addr*> (this->address_);
-      char buf[BUFSIZ];
+      ACE_TCHAR buf[BUFSIZ];
       inet_addr->addr_to_string (buf,BUFSIZ);
       if (TAO_debug_level > 0)
         ACE_DEBUG ((LM_DEBUG,"TAO_FlowSpec_Entry::set_protocol:%s %x\n",buf, inet_addr->get_ip_address ()));
@@ -349,7 +348,7 @@ TAO_FlowSpec_Entry::parse_address (const char *address,
       else
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "AV BOTH %s \n",
+                      "AV BOTH %s\n",
                       protocol_tokenizer[1]));
 
           TAO_Tokenizer address_tokenizer (protocol_tokenizer[1], ':');
@@ -361,7 +360,6 @@ TAO_FlowSpec_Entry::parse_address (const char *address,
 
           if (this->protocol_ == TAO_AV_Core::TAO_AV_SCTP_SEQ)
             {
-
               ACE_DEBUG ((LM_DEBUG,
                           "Number of local sec addresses = %d\n",
                           port_tokenizer.num_tokens () - 1));
@@ -470,14 +468,14 @@ TAO_FlowSpec_Entry::get_local_addr_str (void)
     {
     case AF_INET:
       {
-        char *buf;
+        ACE_TCHAR *buf = 0;
         ACE_NEW_RETURN (buf,
-                        char [BUFSIZ],
+                        ACE_TCHAR [BUFSIZ],
                         0);
 
         ACE_INET_Addr *inet_addr = dynamic_cast<ACE_INET_Addr *> (this->local_addr_);
         inet_addr->addr_to_string (buf,BUFSIZ);
-        ACE_CString cstring (buf, 0, false);
+        ACE_CString cstring (ACE_TEXT_ALWAYS_CHAR(buf), 0, false);
 
         return cstring.rep ();
       }
@@ -597,10 +595,10 @@ TAO_Forward_FlowSpec_Entry::parse (const char *flowSpec_entry)
       this->delete_peer_addr_ = true;
       this->peer_addr_ = addr;
 
-      char buf [BUFSIZ];
+      ACE_TCHAR buf [BUFSIZ];
       addr->addr_to_string (buf, BUFSIZ);
       ACE_DEBUG ((LM_DEBUG,
-                  "Peer Address %s \n",
+                  "Peer Address %s\n",
                   buf));
 
     }
@@ -637,7 +635,7 @@ TAO_Forward_FlowSpec_Entry::entry_to_string (void)
   if (this->flowname_.length() == 0)
     return "";
 
-  char address [BUFSIZ];
+  ACE_TCHAR address [BUFSIZ];
   ACE_CString address_str;
   ACE_CString peer_address_str;
 
@@ -664,7 +662,7 @@ TAO_Forward_FlowSpec_Entry::entry_to_string (void)
         default:
           break;
         }
-      ACE_CString cstring (address);
+      ACE_CString cstring (ACE_TEXT_ALWAYS_CHAR(address));
 
       address_str = this->carrier_protocol_;
       address_str += "=";
@@ -749,7 +747,7 @@ TAO_Forward_FlowSpec_Entry::entry_to_string (void)
           break;
         }
 
-          ACE_CString cstring (address);
+          ACE_CString cstring (ACE_TEXT_ALWAYS_CHAR(address));
 
           //peer_address_str = this->carrier_protocol_;
           //peer_address_str += "=";
@@ -924,7 +922,7 @@ TAO_Reverse_FlowSpec_Entry::entry_to_string (void)
   if (this->flowname_.length() == 0)
     return "";
 
-  char address [BUFSIZ];
+  ACE_TCHAR address [BUFSIZ];
   ACE_CString address_str;
   if (this->address_ != 0)
     {
@@ -946,7 +944,7 @@ TAO_Reverse_FlowSpec_Entry::entry_to_string (void)
         default:
           break;
         }
-      ACE_CString cstring (address);
+      ACE_CString cstring (ACE_TEXT_ALWAYS_CHAR(address));
 
       address_str = this->carrier_protocol_;
       address_str += "=";
