@@ -1,4 +1,4 @@
-// $Id: QoS_UDP.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: QoS_UDP.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 
 #include "orbsvcs/AV/QoS_UDP.h"
@@ -490,14 +490,13 @@ TAO_AV_UDP_QoS_Flow_Handler::set_remote_address (ACE_Addr *address)
 
   if (TAO_debug_level > 0)
     {
-        char buf [BUFSIZ];
-	ACE_INET_Addr *remote_addr = dynamic_cast<ACE_INET_Addr*> (address);
-	remote_addr->addr_to_string (buf,
-				     BUFSIZ);
+      ACE_TCHAR buf [BUFSIZ];
+      ACE_INET_Addr *remote_addr = dynamic_cast<ACE_INET_Addr*> (address);
+      remote_addr->addr_to_string (buf, BUFSIZ);
 
-	ACE_DEBUG ((LM_DEBUG,
-		    "(%N,%l) TAO_AV_UDP_QoS_Flow_Handler::set_remote_address %s\n",
-		    buf));
+      ACE_DEBUG ((LM_DEBUG,
+                  "(%N,%l) TAO_AV_UDP_QoS_Flow_Handler::set_remote_address %s\n",
+                  buf));
     }
 
 
@@ -527,9 +526,9 @@ TAO_AV_UDP_QoS_Flow_Handler::set_remote_address (ACE_Addr *address)
 
       ACE_INET_Addr* src_addr;
       ACE_NEW_RETURN (src_addr,
-		      ACE_INET_Addr (local_addr.get_port_number (),
-				     local_addr.get_host_name ()),
-		      -1);
+                      ACE_INET_Addr (local_addr.get_port_number (),
+                      local_addr.get_host_name ()),
+                      -1);
 
       this->qos_session_->source_addr (src_addr);
 
@@ -702,7 +701,7 @@ TAO_AV_UDP_QoS_Transport::send (const char *buf,
     ACE_DEBUG ((LM_DEBUG,
                 "(%N,%l) TAO_AV_UDP_QoS_Transport::send "));
 
-  char addr [BUFSIZ];
+  ACE_TCHAR addr [BUFSIZ];
   this->peer_addr_.addr_to_string (addr,BUFSIZ);
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG,
@@ -794,7 +793,7 @@ TAO_AV_UDP_QoS_Acceptor::activate_svc_handler (TAO_AV_UDP_QoS_Flow_Handler *hand
 
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG,
-                "(%N,%l) Acceptor Svc Handler QOS ENABLED \n"));
+                "(%N,%l) Acceptor Svc Handler QOS ENABLED\n"));
 
   TAO_AV_UDP_QoS_Session_Helper helper;
 
@@ -831,7 +830,7 @@ TAO_AV_UDP_QoS_Acceptor::open (TAO_Base_StreamEndPoint *endpoint,
   ACE_INET_Addr *inet_addr = (ACE_INET_Addr *) entry->address ();
 //   inet_addr->set (inet_addr->get_port_number (),
 //                   inet_addr->get_host_name ());
-  char buf[BUFSIZ];
+  ACE_TCHAR buf[BUFSIZ];
   inet_addr->addr_to_string (buf,
                              BUFSIZ);
   if (TAO_debug_level > 0)
@@ -954,7 +953,7 @@ TAO_AV_UDP_QoS_Acceptor::open_i (ACE_INET_Addr *inet_addr)
       dest_addr.set  (local_addr->get_port_number (),
                       local_addr->get_host_name ());
 
-      char dest_buf [BUFSIZ];
+      ACE_TCHAR dest_buf [BUFSIZ];
       dest_addr.addr_to_string (dest_buf,
                                 BUFSIZ);
 
@@ -1041,7 +1040,7 @@ TAO_AV_UDP_QoS_Acceptor::open_i (ACE_INET_Addr *inet_addr)
   catch (const CORBA::Exception&)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "(%N,%l) Negotiator Not Found \n"));
+                  "(%N,%l) Negotiator Not Found\n"));
     }
 
   this->endpoint_->set_flow_handler (this->flowname_.c_str (),flow_handler);
@@ -1055,7 +1054,7 @@ TAO_AV_UDP_QoS_Acceptor::open_i (ACE_INET_Addr *inet_addr)
 
   if (TAO_debug_level > 0)
     {
-      char buf [BUFSIZ];
+      ACE_TCHAR buf [BUFSIZ];
       local_addr->addr_to_string (buf,
                                   BUFSIZ);
       ACE_DEBUG ((LM_DEBUG,
@@ -1173,8 +1172,8 @@ TAO_AV_UDP_QoS_Connector::connect (TAO_FlowSpec_Entry *entry,
     }
   else
     ACE_NEW_RETURN (local_addr,
-		    ACE_INET_Addr ("0"),
-		    -1);
+                    ACE_INET_Addr ("0"),
+                    -1);
 
   TAO_AV_Flow_Handler *flow_handler = 0;
 
@@ -1234,7 +1233,7 @@ TAO_AV_UDP_QoS_Connector::connect (TAO_FlowSpec_Entry *entry,
       session_addr = inet_addr;
     }
 
-  char sess_buf [BUFSIZ];
+  ACE_TCHAR sess_buf [BUFSIZ];
   session_addr->addr_to_string (sess_buf,
                                 BUFSIZ);
 
@@ -1267,9 +1266,9 @@ TAO_AV_UDP_QoS_Connector::connect (TAO_FlowSpec_Entry *entry,
       //this->qos_session_->source_port (local_addr->get_port_number ());
       ACE_INET_Addr* src_addr;
       ACE_NEW_RETURN (src_addr,
-		      ACE_INET_Addr (local_addr->get_port_number (),
-				     local_addr->get_host_name ()),
-		      -1);
+                      ACE_INET_Addr (local_addr->get_port_number (),
+                      local_addr->get_host_name ()),
+                      -1);
 
       this->qos_session_->source_addr (src_addr);
 
@@ -1347,7 +1346,7 @@ TAO_AV_UDP_QoS_Connector::connect (TAO_FlowSpec_Entry *entry,
 
   if (TAO_debug_level > 0)
     {
-      char buf[BUFSIZ];
+      ACE_TCHAR buf[BUFSIZ];
       local_addr->addr_to_string (buf,
                                   BUFSIZ);
 
@@ -1445,7 +1444,7 @@ TAO_AV_UDP_QoS_Factory::make_connector (void)
 
 int
 TAO_AV_UDP_QoS_Factory::init (int /* argc */,
-                              char * /* argv */ [])
+                              ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
@@ -1467,7 +1466,7 @@ TAO_AV_UDP_QoS_Flow_Factory::~TAO_AV_UDP_QoS_Flow_Factory (void)
 
 int
 TAO_AV_UDP_QoS_Flow_Factory::init (int /* argc */,
-                                   char * /* argv */ [])
+                                   ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
