@@ -32,7 +32,7 @@
  * SUCH DAMAGE.
  */
 
-// $Id: RTP.cpp 78820 2007-07-07 20:06:46Z sowayaa $
+// $Id: RTP.cpp 82940 2008-10-06 18:20:19Z johnnyw $
 
 #include "orbsvcs/AV/RTP.h"
 #include "orbsvcs/AV/RTCP.h"
@@ -726,7 +726,7 @@ TAO_AV_RTP_Flow_Factory::~TAO_AV_RTP_Flow_Factory (void)
 
 int
 TAO_AV_RTP_Flow_Factory::init (int /* argc */,
-                                char * /* argv */ [])
+                               ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
