@@ -3,7 +3,7 @@
 //=============================================================================
 /**
  *  @file   Resource_Factory.h
- *  $Id: Resource_Factory.h 69284 2005-11-10 06:47:24Z ossama $
+ *  $Id: Resource_Factory.h 82869 2008-09-29 08:02:27Z johnnyw $
  *
  *  @author Yamuna Krishnamurthy
  */
@@ -31,11 +31,11 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  *        The AV Streams resource factory loads the
  *        pluggable transport and flow protocol factories
  *        in the corresponding factory sets.
- *  
+ *
  *
  */
 class TAO_AV_Export TAO_AV_Resource_Factory
-: public ACE_Service_Object 
+: public ACE_Service_Object
 {
 public:
 
@@ -44,8 +44,8 @@ public:
    */
   //@{
   /// Dynamic linking hook
-  virtual int init (int argc, char *argv[]) = 0;
-  
+  virtual int init (int argc, ACE_TCHAR *argv[]) = 0;
+
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
