@@ -1,4 +1,4 @@
-// $Id: SCTP_SEQ.cpp 71526 2006-03-14 06:14:35Z jtc $
+// $Id: SCTP_SEQ.cpp 84029 2008-12-15 18:19:21Z johnnyw $
 
 #include "orbsvcs/AV/SCTP_SEQ.h"
 
@@ -8,6 +8,7 @@
 #include "ace/Multihomed_INET_Addr.h"
 #include "tao/debug.h"
 #include "ace/Arg_Shifter.h"
+#include "ace/os_include/os_netdb.h"
 
 ACE_RCSID (AV,
            SCTP_SEQ,
@@ -91,7 +92,7 @@ TAO_AV_SCTP_SEQ_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *
             {
               n = this->handler_->peer ().sendv_n ((const iovec *) iov,
                                                    iovcnt);
-	      //&timeout);
+                                                   //&timeout);
               if (n < 1)
                 return n;
 
@@ -117,16 +118,16 @@ TAO_AV_SCTP_SEQ_Transport::send (const ACE_Message_Block *mblk, ACE_Time_Value *
 
 ssize_t
 TAO_AV_SCTP_SEQ_Transport::send (const char *buf,
-				 size_t len,
-				 ACE_Time_Value *)
+                                 size_t len,
+                                 ACE_Time_Value *)
 {
   return this->handler_->peer ().send_n (buf, len);
 }
 
 ssize_t
 TAO_AV_SCTP_SEQ_Transport::send (const iovec *iov,
-				 int iovcnt,
-				 ACE_Time_Value *)
+                                 int iovcnt,
+                                 ACE_Time_Value *)
 {
   return this->handler_->peer ().sendv_n (iov,
                                           iovcnt);
@@ -134,17 +135,17 @@ TAO_AV_SCTP_SEQ_Transport::send (const iovec *iov,
 
 ssize_t
 TAO_AV_SCTP_SEQ_Transport::recv (char *buf,
-                          size_t len,
-                          ACE_Time_Value *)
+                                 size_t len,
+                                 ACE_Time_Value *)
 {
   return this->handler_->peer ().recv (buf, len);
 }
 
 ssize_t
 TAO_AV_SCTP_SEQ_Transport::recv (char *buf,
-                            size_t len,
-                            int flags,
-                            ACE_Time_Value *)
+                                 size_t len,
+                                 int flags,
+                                 ACE_Time_Value *)
 {
   return this->handler_->peer ().recv (buf,
                                        len,
@@ -153,8 +154,8 @@ TAO_AV_SCTP_SEQ_Transport::recv (char *buf,
 
 ssize_t
 TAO_AV_SCTP_SEQ_Transport::recv (iovec *iov,
-                            int iovcnt,
-                            ACE_Time_Value *)
+                                 int iovcnt,
+                                 ACE_Time_Value *)
 {
   return handler_->peer ().recvv_n (iov, iovcnt);
 }
@@ -165,18 +166,19 @@ TAO_AV_SCTP_SEQ_Transport::recv (iovec *iov,
 
 int
 TAO_AV_SCTP_SEQ_Base_Acceptor::acceptor_open (TAO_AV_SCTP_SEQ_Acceptor *acceptor,
-					      ACE_Reactor *reactor,
-					      const ACE_INET_Addr &local_addr,
-					      TAO_FlowSpec_Entry *entry)
+                                              ACE_Reactor *reactor,
+                                              const ACE_INET_Addr &local_addr,
+                                              TAO_FlowSpec_Entry *entry)
 {
   ACE_DEBUG ((LM_DEBUG,
-	      "In base acceptor open"));
+              "In base acceptor open"));
 
   this->acceptor_ = acceptor;
   this->reactor_ = reactor;
   this->entry_ = entry;
 
-  ACE_UINT32 local_ip_addr [entry->num_local_sec_addrs ()];
+  ACE_Auto_Array_Ptr<ACE_UINT32> local_ip_addr
+    (new ACE_UINT32[entry->num_local_sec_addrs ()]);
   ACE_INET_Addr ip_addr;
   char** addrs = entry->get_local_sec_addr ();
   for (int i = 0; i < entry->num_local_sec_addrs (); i++)
@@ -184,29 +186,26 @@ TAO_AV_SCTP_SEQ_Base_Acceptor::acceptor_open (TAO_AV_SCTP_SEQ_Acceptor *acceptor
       ACE_CString addr_str (addrs[i]);
       addr_str += ":";
       ip_addr.set (addr_str.c_str ());
-      local_ip_addr [i] = ip_addr.get_ip_address ();
+      local_ip_addr[i] = ip_addr.get_ip_address ();
     }
 
 
   ACE_Multihomed_INET_Addr multi_addr;
   multi_addr.set (local_addr.get_port_number (),
-		  local_addr.get_ip_address (),
-		  1,
-		  local_ip_addr,
-		  entry->num_local_sec_addrs ());
+                  local_addr.get_ip_address (),
+                  1,
+                  local_ip_addr.get(),
+                  entry->num_local_sec_addrs ());
 
   char buf[BUFSIZ];
-  multi_addr.addr_to_string (buf,
-			     BUFSIZ);
+  multi_addr.addr_to_string (buf, BUFSIZ);
 
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG,
                 "TAO_AV_SCTP_SEQ_Base_Acceptor::open: %s",
-                buf
-                ));
+                buf));
 
-  int result = this->open (multi_addr,reactor);
-  if (result < 0)
+  if (this->open (multi_addr,reactor) < 0)
     ACE_ERROR_RETURN ((LM_ERROR,"TAO_AV_SCTP_SEQ_Base_Acceptor::open failed\n"),-1);
 
   return 0;
@@ -215,7 +214,7 @@ TAO_AV_SCTP_SEQ_Base_Acceptor::acceptor_open (TAO_AV_SCTP_SEQ_Acceptor *acceptor
 int
 TAO_AV_SCTP_SEQ_Base_Acceptor::make_svc_handler (TAO_AV_SCTP_SEQ_Flow_Handler *&handler)
 {
-  int result = this->acceptor_->make_svc_handler (handler);
+  int const result = this->acceptor_->make_svc_handler (handler);
   if (result < 0)
     return result;
   handler->reactor (this->reactor_);
@@ -241,8 +240,7 @@ TAO_AV_SCTP_SEQ_Acceptor::make_svc_handler (TAO_AV_SCTP_SEQ_Flow_Handler *&sctp_
 {
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG,
-                "TAO_AV_SCTP_SEQ_Acceptor::make_svc_handler\n"
-                ));
+                "TAO_AV_SCTP_SEQ_Acceptor::make_svc_handler\n"));
 
   if (this->endpoint_ != 0)
     {
@@ -266,10 +264,10 @@ TAO_AV_SCTP_SEQ_Acceptor::make_svc_handler (TAO_AV_SCTP_SEQ_Flow_Handler *&sctp_
 
 int
 TAO_AV_SCTP_SEQ_Acceptor::open (TAO_Base_StreamEndPoint *endpoint,
-				TAO_AV_Core *av_core,
-				TAO_FlowSpec_Entry *entry,
-				TAO_AV_Flow_Protocol_Factory *factory,
-				TAO_AV_Core::Flow_Component flow_comp)
+                                TAO_AV_Core *av_core,
+                                TAO_FlowSpec_Entry *entry,
+                                TAO_AV_Flow_Protocol_Factory *factory,
+                                TAO_AV_Core::Flow_Component flow_comp)
 {
   this->flow_protocol_factory_ = factory;
 
@@ -287,22 +285,20 @@ TAO_AV_SCTP_SEQ_Acceptor::open (TAO_Base_StreamEndPoint *endpoint,
   ACE_INET_Addr *inet_addr = (ACE_INET_Addr *) address;
 
   char buf[BUFSIZ];
-  inet_addr->addr_to_string (buf,
-                             BUFSIZ);
+  inet_addr->addr_to_string (buf, BUFSIZ);
 
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG,
                 "TAO_AV_SCTP_SEQ_Acceptor::open: %s",
-                buf
-                ));
+                buf));
 
   //Add code for reading multihomed addresses and pass the multihomed
   //addr to the following method. ACE_Multihomed_addr derives from
   //ACE_INET_Addr, hence this should not be an issue.
   int result = this->acceptor_.acceptor_open (this,
-					      av_core->reactor (),
-					      *inet_addr,
-					      entry);
+                                              av_core->reactor (),
+                                              *inet_addr,
+                                              entry);
   if (result < 0)
     ACE_ERROR_RETURN ((LM_ERROR,
                        "TAO_AV_SCTP_SEQ_Acceptor::open failed"),
@@ -314,10 +310,10 @@ TAO_AV_SCTP_SEQ_Acceptor::open (TAO_Base_StreamEndPoint *endpoint,
 
 int
 TAO_AV_SCTP_SEQ_Acceptor::open_default (TAO_Base_StreamEndPoint *endpoint,
-					TAO_AV_Core *av_core,
-					TAO_FlowSpec_Entry *entry,
-					TAO_AV_Flow_Protocol_Factory *factory,
-					TAO_AV_Core::Flow_Component flow_comp)
+                                        TAO_AV_Core *av_core,
+                                        TAO_FlowSpec_Entry *entry,
+                                        TAO_AV_Flow_Protocol_Factory *factory,
+                                        TAO_AV_Core::Flow_Component flow_comp)
 {
   this->flow_protocol_factory_ = factory;
   this->av_core_ = av_core;
@@ -334,9 +330,9 @@ TAO_AV_SCTP_SEQ_Acceptor::open_default (TAO_Base_StreamEndPoint *endpoint,
                   -1);
 
   int result = this->acceptor_.acceptor_open (this,
-					      av_core->reactor (),
-					      *address,
-					      entry);
+                                              av_core->reactor (),
+                                              *address,
+                                              entry);
 
 
   if (result < 0)
@@ -375,13 +371,12 @@ TAO_AV_SCTP_SEQ_Acceptor::close (void)
 
 int
 TAO_AV_SCTP_SEQ_Base_Connector::connector_open (TAO_AV_SCTP_SEQ_Connector *connector,
-						ACE_Reactor *reactor)
+                                                ACE_Reactor *reactor)
 {
   this->connector_ = connector;
   this->reactor_ = reactor;
 
-  int result = this->open (reactor);
-  if (result < 0)
+  if (this->open (reactor) < 0)
     ACE_ERROR_RETURN ((LM_ERROR,"TAO_AV_SCTP_SEQ_Base_Connector::open failed\n"),-1);
   return 0;
 }
@@ -399,13 +394,13 @@ TAO_AV_SCTP_SEQ_Base_Connector::make_svc_handler (TAO_AV_SCTP_SEQ_Flow_Handler *
 
 int
 TAO_AV_SCTP_SEQ_Base_Connector::connector_connect (TAO_AV_SCTP_SEQ_Flow_Handler *&handler,
-						   const ACE_Multihomed_INET_Addr &remote_addr,
-						   const ACE_Multihomed_INET_Addr &local_addr)
+                                                   const ACE_Multihomed_INET_Addr &remote_addr,
+                                                   const ACE_Multihomed_INET_Addr &local_addr)
 {
   int result = this->connect (handler,
-			      remote_addr,
-			      0,
-			      local_addr);
+                              remote_addr,
+                              0,
+                              local_addr);
 
   if (result < 0)
     ACE_ERROR_RETURN ((LM_ERROR,"TAO_AV_SCTP_SEQ_Base_Connector::connect failed\n"),-1);
@@ -456,9 +451,8 @@ TAO_AV_SCTP_SEQ_Connector::make_svc_handler (TAO_AV_SCTP_SEQ_Flow_Handler *&sctp
 
 int
 TAO_AV_SCTP_SEQ_Connector::open (TAO_Base_StreamEndPoint *endpoint,
-				 TAO_AV_Core *av_core,
-				 TAO_AV_Flow_Protocol_Factory *factory)
-
+                                 TAO_AV_Core *av_core,
+                                 TAO_AV_Flow_Protocol_Factory *factory)
 {
   this->endpoint_ = endpoint;
   this->flow_protocol_factory_ = factory;
@@ -471,8 +465,8 @@ TAO_AV_SCTP_SEQ_Connector::open (TAO_Base_StreamEndPoint *endpoint,
 
 int
 TAO_AV_SCTP_SEQ_Connector::connect (TAO_FlowSpec_Entry *entry,
-				    TAO_AV_Transport *&transport,
-				    TAO_AV_Core::Flow_Component flow_comp)
+                                    TAO_AV_Transport *&transport,
+                                    TAO_AV_Core::Flow_Component flow_comp)
 {
   this->entry_ = entry;
   if (flow_comp == TAO_AV_Core::TAO_AV_CONTROL)
@@ -485,10 +479,10 @@ TAO_AV_SCTP_SEQ_Connector::connect (TAO_FlowSpec_Entry *entry,
 
   ACE_Multihomed_INET_Addr remote_multi_addr;
   remote_multi_addr.set (inet_addr->get_port_number (),
-			 inet_addr->get_ip_address (),
-			 1,
-			 0,
-			 0);
+                         inet_addr->get_ip_address (),
+                         1,
+                         0,
+                         0);
 
   ACE_Multihomed_INET_Addr local_addr; //This can be a multihomed address
   ACE_INET_Addr *addr;
@@ -499,11 +493,12 @@ TAO_AV_SCTP_SEQ_Connector::connect (TAO_FlowSpec_Entry *entry,
   else
     {
       ACE_NEW_RETURN (addr,
-		      ACE_INET_Addr ("0"),
-		      -1);
+                      ACE_INET_Addr ("0"),
+                      -1);
     }
 
-  ACE_UINT32 local_ip_addr [entry->num_peer_sec_addrs ()];
+  ACE_Auto_Array_Ptr<ACE_UINT32> local_ip_addr
+    (new ACE_UINT32[entry->num_peer_sec_addrs ()]);
   ACE_INET_Addr ip_addr;
   char** addrs = entry->get_peer_sec_addr ();
   for (int i = 0; i < entry->num_peer_sec_addrs (); i++)
@@ -511,26 +506,26 @@ TAO_AV_SCTP_SEQ_Connector::connect (TAO_FlowSpec_Entry *entry,
       ACE_CString addr_str (addrs[i]);
       addr_str += ":";
       ip_addr.set (addr_str.c_str ());
-      local_ip_addr [i] = ip_addr.get_ip_address ();
+      local_ip_addr[i] = ip_addr.get_ip_address ();
     }
 
   if (entry->num_peer_sec_addrs () != 0)
     local_addr.set (addr->get_port_number (),
-		    addr->get_ip_address (),
-		    1,
-		    local_ip_addr,
-		    entry->num_peer_sec_addrs ());
+                    addr->get_ip_address (),
+                    1,
+                    local_ip_addr.get(),
+                    entry->num_peer_sec_addrs ());
   else
     local_addr.set (addr->get_port_number (),
-		    addr->get_ip_address (),
-		    1,
-		    0,
-		    entry->num_peer_sec_addrs ());
+                    addr->get_ip_address (),
+                    1,
+                    0,
+                    entry->num_peer_sec_addrs ());
 
 
   int result = this->connector_.connector_connect (handler,
-						   remote_multi_addr,
-						   local_addr);
+                                                   remote_multi_addr,
+                                                   local_addr);
 
   if (result < 0)
     ACE_ERROR_RETURN ((LM_ERROR,"TAO_AV_SCTP_SEQ_connector::connect failed\n"),-1);
@@ -540,36 +535,36 @@ TAO_AV_SCTP_SEQ_Connector::connect (TAO_FlowSpec_Entry *entry,
   if (TAO_debug_level > 0)
     {
       ACE_DEBUG ((LM_DEBUG,
-		  "Local Addrs\n"));
+                  "Local Addrs\n"));
       char buf [BUFSIZ];
       size_t size = BUFSIZ;
       ACE_INET_Addr *peer_addrs = 0;
       ACE_NEW_RETURN (peer_addrs,ACE_INET_Addr [size], -1);
       handler->peer ().get_local_addrs (peer_addrs, size);
       for (unsigned int i=0; i < size;i++)
-	{
-	  peer_addrs [i].addr_to_string (buf,
-					 BUFSIZ);
-	  ACE_DEBUG ((LM_DEBUG,
-		      "%s %d\n",
-		      buf,
-		      size));
-	}
+        {
+          peer_addrs [i].addr_to_string (buf,
+                                         BUFSIZ);
+          ACE_DEBUG ((LM_DEBUG,
+                      "%s %d\n",
+                      buf,
+                      size));
+        }
 
       ACE_DEBUG ((LM_DEBUG,
-		  "Remote Addrs\n"));
+                  "Remote Addrs\n"));
 
       size = BUFSIZ;
       handler->peer ().get_remote_addrs (peer_addrs, size);
       for (unsigned int i=0; i < size;i++)
-	{
-	  peer_addrs [i].addr_to_string (buf,
-					 BUFSIZ);
-	  ACE_DEBUG ((LM_DEBUG,
-		      "%s %d\n",
-		      buf,
-		      size));
-	}
+        {
+          peer_addrs [i].addr_to_string (buf,
+                                         BUFSIZ);
+          ACE_DEBUG ((LM_DEBUG,
+                      "%s %d\n",
+                      buf,
+                      size));
+        }
       //delete peer_addrs;
     }
 
@@ -630,8 +625,7 @@ TAO_AV_SCTP_SEQ_Factory::make_connector (void)
 
 
 int
-TAO_AV_SCTP_SEQ_Factory::init (int,
-			       char *[])
+TAO_AV_SCTP_SEQ_Factory::init (int, ACE_TCHAR *[])
 {
 
   return 0;
@@ -657,7 +651,7 @@ TAO_AV_SCTP_SEQ_Object::handle_input (void)
 
 int
 TAO_AV_SCTP_SEQ_Object::send_frame (ACE_Message_Block *frame,
-				    TAO_AV_frame_info * /*frame_info*/)
+                                    TAO_AV_frame_info * /*frame_info*/)
 {
   int result = this->transport_->send (frame);
   return result;
@@ -665,15 +659,15 @@ TAO_AV_SCTP_SEQ_Object::send_frame (ACE_Message_Block *frame,
 
 int
 TAO_AV_SCTP_SEQ_Object::send_frame (const iovec *iov,
-				    int iovcnt,
-				    TAO_AV_frame_info * /*frame_info*/)
+                                    int iovcnt,
+                                    TAO_AV_frame_info * /*frame_info*/)
 {
   return this->transport_->send (iov,iovcnt);
 }
 
 int
 TAO_AV_SCTP_SEQ_Object::send_frame (const char*buf,
-				    size_t len)
+                                    size_t len)
 {
   int result = this->transport_->send (buf, len, 0);
   return result;
@@ -681,7 +675,7 @@ TAO_AV_SCTP_SEQ_Object::send_frame (const char*buf,
 
 
 TAO_AV_SCTP_SEQ_Object::TAO_AV_SCTP_SEQ_Object (TAO_AV_Callback *callback,
-						TAO_AV_Transport *transport)
+                                                TAO_AV_Transport *transport)
   :TAO_AV_Protocol_Object (callback,transport)
 {
   // @@ Is this a good size?
@@ -743,9 +737,9 @@ TAO_AV_SCTP_SEQ_Flow_Handler::change_qos (AVStreams::QoS qos)
       if( ACE_OS::strcmp( qos.QoSParams[i].property_name.in(), "Diffserv_Codepoint") == 0)
         {
           qos.QoSParams[i].property_value >>= dscp;
-	  ACE_DEBUG ((LM_DEBUG,
-		      "DSCP %d\n",
-		      dscp));
+          ACE_DEBUG ((LM_DEBUG,
+                      "DSCP %d\n",
+                      dscp));
           dscp_flag=1;
           // DSCP value can only be 6 bits wide
           if(!((dscp >= 0) && (dscp <= 63)))
@@ -777,23 +771,23 @@ TAO_AV_SCTP_SEQ_Flow_Handler::change_qos (AVStreams::QoS qos)
       int tos;
       tos = (int)(dscp << 2);
       if(ecn)
-	{
-	  tos |= ecn;
-	}
+        {
+          tos |= ecn;
+        }
       ret = this->peer ().set_option(IPPROTO_IP, IP_TOS, (int *)&tos , (int)sizeof(tos));
 
       if(TAO_debug_level > 0)
-	{
-	  ACE_DEBUG((LM_DEBUG, "(%N,%l) set tos: ret: %d %d\n", tos, ret));
-	}
+        {
+          ACE_DEBUG((LM_DEBUG, "(%N,%l) set tos: ret: %d %d\n", tos, ret));
+        }
     }
 
   if(TAO_debug_level > 0)
     {
       if(ret < 0 )
-	{
-	  ACE_DEBUG((LM_DEBUG, "(%N,%l) errno: %p\n"));
-	}
+        {
+          ACE_DEBUG((LM_DEBUG, "(%N,%l) errno: %p\n"));
+        }
     }
   return ret;
 }
@@ -827,8 +821,8 @@ TAO_AV_SCTP_SEQ_Flow_Handler::open (void * /*arg*/)
   if (TAO_debug_level > 0)
     if (TAO_debug_level > 0)
       ACE_DEBUG ((LM_DEBUG,
-		  "(%P|%t) connection to server <%s> on %d\n",
-		  server, this->peer ().get_handle ()));
+                  "(%P|%t) connection to server <%s> on %d\n",
+                  server, this->peer ().get_handle ()));
 
   this->peer ().disable (ACE_NONBLOCK);
 
@@ -852,7 +846,7 @@ TAO_AV_SCTP_SEQ_Flow_Handler::handle_input (ACE_HANDLE /*fd*/)
 
 int
 TAO_AV_SCTP_SEQ_Flow_Handler::handle_timeout (const ACE_Time_Value &tv,
-                                               const void *arg)
+                                              const void *arg)
 {
   return TAO_AV_Flow_Handler::handle_timeout (tv,arg);
 }
@@ -871,7 +865,7 @@ TAO_AV_SCTP_SEQ_Flow_Factory::~TAO_AV_SCTP_SEQ_Flow_Factory (void)
 
 int
 TAO_AV_SCTP_SEQ_Flow_Factory::init (int /* argc */,
-                               char * /* argv */ [])
+                                    ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
@@ -886,9 +880,9 @@ TAO_AV_SCTP_SEQ_Flow_Factory::match_protocol (const char *flow_string)
 
 TAO_AV_Protocol_Object*
 TAO_AV_SCTP_SEQ_Flow_Factory::make_protocol_object (TAO_FlowSpec_Entry *entry,
-                                               TAO_Base_StreamEndPoint *endpoint,
-                                               TAO_AV_Flow_Handler *handler,
-                                               TAO_AV_Transport *transport)
+                                                    TAO_Base_StreamEndPoint *endpoint,
+                                                    TAO_AV_Flow_Handler *handler,
+                                                    TAO_AV_Transport *transport)
 {
   TAO_AV_Callback *callback = 0;
   if( endpoint->get_callback (entry->flowname (), callback) ) {
@@ -898,7 +892,7 @@ TAO_AV_SCTP_SEQ_Flow_Factory::make_protocol_object (TAO_FlowSpec_Entry *entry,
   TAO_AV_SCTP_SEQ_Object *object = 0;
   ACE_NEW_RETURN (object,
                   TAO_AV_SCTP_SEQ_Object (callback,
-                                     transport),
+                                          transport),
                   0);
   callback->open (object,
                   handler);
