@@ -1,4 +1,4 @@
-// $Id: TCP.cpp 72661 2006-05-16 14:09:14Z jwillemsen $
+// $Id: TCP.cpp 82940 2008-10-06 18:20:19Z johnnyw $
 
 #include "orbsvcs/AV/TCP.h"
 #include "orbsvcs/AV/AVStreams_i.h"
@@ -163,7 +163,7 @@ TAO_AV_TCP_Factory::~TAO_AV_TCP_Factory (void)
 
 int
 TAO_AV_TCP_Factory::init (int /* argc */,
-                          char * /* argv */ [])
+                          ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
@@ -274,7 +274,7 @@ TAO_AV_TCP_Flow_Factory::~TAO_AV_TCP_Flow_Factory (void)
 
 int
 TAO_AV_TCP_Flow_Factory::init (int /* argc */,
-                               char * /* argv */ [])
+                               ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
@@ -537,7 +537,7 @@ TAO_AV_TCP_Acceptor::open (TAO_Base_StreamEndPoint *endpoint,
   inet_addr->set (inet_addr->get_port_number (),
                   inet_addr->get_host_name ());
 
-  char buf[BUFSIZ];
+  ACE_TCHAR buf[BUFSIZ];
   inet_addr->addr_to_string (buf,
                              BUFSIZ);
 
@@ -598,7 +598,7 @@ TAO_AV_TCP_Acceptor::open_default (TAO_Base_StreamEndPoint *endpoint,
   address->set (address->get_port_number (),
                 address->get_host_name ());
 
-  char buf[BUFSIZ];
+  ACE_TCHAR buf[BUFSIZ];
   address->addr_to_string (buf,BUFSIZ);
 
   if (TAO_debug_level > 0)
@@ -663,7 +663,7 @@ TAO_AV_TCP_Flow_Handler::open (void * /*arg*/)
   if (this->peer ().get_remote_addr (addr) == -1)
     return -1;
 
-  char server[MAXHOSTNAMELEN + 16];
+  ACE_TCHAR server[MAXHOSTNAMELEN + 16];
 
   (void) addr.addr_to_string (server, sizeof (server));
 
