@@ -1,4 +1,4 @@
-// $Id: UDP.cpp 80102 2007-11-27 06:33:52Z johnnyw $
+// $Id: UDP.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "orbsvcs/AV/UDP.h"
 #include "orbsvcs/AV/AVStreams_i.h"
@@ -13,7 +13,7 @@
 
 ACE_RCSID (AV,
            UDP,
-           "$Id: UDP.cpp 80102 2007-11-27 06:33:52Z johnnyw $")
+           "$Id: UDP.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -270,7 +270,7 @@ TAO_AV_UDP_Transport::send (const char *buf,
                             ACE_Time_Value *)
 {
   if (TAO_debug_level > 0) ACE_DEBUG ((LM_DEBUG,"TAO_AV_UDP_Transport::send "));
-  char addr [BUFSIZ];
+  ACE_TCHAR addr [BUFSIZ];
   this->peer_addr_.addr_to_string (addr,BUFSIZ);
   if (TAO_debug_level > 0) ACE_DEBUG ((LM_DEBUG,"to %s\n",addr));
 
@@ -377,14 +377,13 @@ TAO_AV_UDP_Acceptor::open (TAO_Base_StreamEndPoint *endpoint,
 
   if (inet_addr != 0)
     {
-      char buf[BUFSIZ];
-      inet_addr->addr_to_string (buf,
-				 BUFSIZ);
+      ACE_TCHAR buf[BUFSIZ];
+      inet_addr->addr_to_string (buf, BUFSIZ);
 
       if (TAO_debug_level > 0)
-	ACE_DEBUG ((LM_DEBUG,
-		    "TAO_AV_UDP_Acceptor::open: %s\n",
-		    buf));
+        ACE_DEBUG ((LM_DEBUG,
+                    "TAO_AV_UDP_Acceptor::open: %s\n",
+                    buf));
     }
 
   int result = this->open_i (inet_addr, 0);
@@ -461,7 +460,7 @@ TAO_AV_UDP_Acceptor::open_i (ACE_INET_Addr *inet_addr,
                                                        this->entry_->is_multicast (),
                                                        TAO_AV_UDP_Connection_Setup::ACCEPTOR);
 
-	  if (result < 0)
+        if (result < 0)
           {
              ACE_DEBUG((LM_DEBUG,"(%N,%l) Error during connection setup: %d\n", result));
           }
@@ -478,12 +477,13 @@ TAO_AV_UDP_Acceptor::open_i (ACE_INET_Addr *inet_addr,
                     {
                       // RTP port should be even
                       delete local_addr;
+                      local_addr = 0;
                       delete flow_handler;
                       get_new_port = 1;
                     }
                   else
                     {
-                      ACE_INET_Addr *local_control_addr;
+                      ACE_INET_Addr *local_control_addr = 0;
                       TAO_AV_Flow_Handler *control_flow_handler = 0;
 
                       ACE_NEW_RETURN (this->control_inet_address_,
@@ -501,6 +501,7 @@ TAO_AV_UDP_Acceptor::open_i (ACE_INET_Addr *inet_addr,
                         {
                           delete this->control_inet_address_;
                           delete local_addr;
+                          local_addr = 0;
                           delete flow_handler;
                           delete local_control_addr;
                           delete control_flow_handler;
@@ -544,12 +545,15 @@ TAO_AV_UDP_Acceptor::open_i (ACE_INET_Addr *inet_addr,
       this->entry_->control_handler (flow_handler);
     }
 
-  char buf[BUFSIZ];
-  local_addr->addr_to_string (buf,BUFSIZ);
-  if (TAO_debug_level > 0)
-    ACE_DEBUG ((LM_DEBUG,
-                "TAO_AV_UDP_ACCEPTOR::open:%s \n",
-                buf));
+  if (local_addr != 0)
+    {
+      ACE_TCHAR buf[BUFSIZ];
+      local_addr->addr_to_string (buf,BUFSIZ);
+      if (TAO_debug_level > 0)
+        ACE_DEBUG ((LM_DEBUG,
+                    "TAO_AV_UDP_ACCEPTOR::open:%s\n",
+                    buf));
+    }
 
   // call activate svc handler.
   return this->activate_svc_handler (flow_handler);
@@ -642,13 +646,13 @@ TAO_AV_UDP_Connector::connect (TAO_FlowSpec_Entry *entry,
           // assume the ports will be OK
           get_new_port = 0;
 
-	  ACE_Addr *addr;
-	  if ((addr = entry->get_peer_addr ()) != 0)
-	    {
-	      local_addr = dynamic_cast<ACE_INET_Addr*> (addr);
-	      char buf [BUFSIZ];
-	      local_addr->addr_to_string (buf, BUFSIZ);
-	    }
+          ACE_Addr *addr;
+          if ((addr = entry->get_peer_addr ()) != 0)
+            {
+              local_addr = dynamic_cast<ACE_INET_Addr*> (addr);
+              ACE_TCHAR buf [BUFSIZ];
+              local_addr->addr_to_string (buf, BUFSIZ);
+            }
 
           TAO_AV_UDP_Connection_Setup::setup (flow_handler,
                                               inet_addr,
@@ -664,12 +668,13 @@ TAO_AV_UDP_Connector::connect (TAO_FlowSpec_Entry *entry,
                 {
                   // RTP port should be even
                   delete local_addr;
+                  local_addr = 0;
                   delete flow_handler;
                   get_new_port = 1;
                 }
               else
                 {
-                  ACE_INET_Addr *local_control_addr;
+                  ACE_INET_Addr *local_control_addr = 0;
                   TAO_AV_Flow_Handler *control_flow_handler = 0;
 
                   if (entry->is_multicast ())
@@ -679,9 +684,9 @@ TAO_AV_UDP_Connector::connect (TAO_FlowSpec_Entry *entry,
 
                       if (local_addr != 0)
                         {
-                          char buf [BUFSIZ];
-                          ACE_CString addr_str (local_addr->get_host_name ());
-                          addr_str += ":";
+                          ACE_TCHAR buf [BUFSIZ];
+                          ACE_TString addr_str (ACE_TEXT_CHAR_TO_TCHAR(local_addr->get_host_name ()));
+                          addr_str += ACE_TEXT(":");
                           addr_str += ACE_OS::itoa (local_addr->get_port_number () + 1, buf, 10);
                           ACE_NEW_RETURN (local_control_addr,
                                           ACE_INET_Addr (addr_str.c_str ()),
@@ -708,6 +713,7 @@ TAO_AV_UDP_Connector::connect (TAO_FlowSpec_Entry *entry,
                       local_addr->get_port_number () +1)
                     {
                       delete local_addr;
+                      local_addr = 0;
                       delete flow_handler;
                       delete local_control_addr;
                       delete control_flow_handler;
@@ -750,11 +756,14 @@ TAO_AV_UDP_Connector::connect (TAO_FlowSpec_Entry *entry,
       transport = flow_handler->transport ();
     }
 
-  char buf[BUFSIZ];
-  local_addr->addr_to_string (buf,BUFSIZ);
+  if (local_addr != 0)
+    {
+      ACE_TCHAR buf[BUFSIZ];
+      local_addr->addr_to_string (buf,BUFSIZ);
 
-  if (TAO_debug_level > 0)
-    ACE_DEBUG ((LM_DEBUG,"TAO_AV_UDP_CONNECTOR::connect:%s \n",buf));
+      if (TAO_debug_level > 0)
+        ACE_DEBUG ((LM_DEBUG,"TAO_AV_UDP_CONNECTOR::connect:%s\n",buf));
+    }
 
   // call activate svc handler.
   return this->activate_svc_handler (flow_handler);
@@ -887,9 +896,9 @@ TAO_AV_UDP_Connection_Setup::setup (TAO_AV_Flow_Handler *&flow_handler,
       result = handler->get_socket ()->get_local_addr (*local_addr);
 
       local_addr->set (local_addr->get_port_number (),
-		       local_addr->get_host_name ());
+                       local_addr->get_host_name ());
 
-      char buf [BUFSIZ];
+      ACE_TCHAR buf [BUFSIZ];
       local_addr->addr_to_string (buf, BUFSIZ);
 
       if (result < 0)
@@ -945,7 +954,7 @@ TAO_AV_UDP_Factory::make_connector (void)
 
 int
 TAO_AV_UDP_Factory::init (int /* argc */,
-                          char * /* argv */ [])
+                          ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
@@ -1035,7 +1044,7 @@ TAO_AV_UDP_Flow_Factory::~TAO_AV_UDP_Flow_Factory (void)
 
 int
 TAO_AV_UDP_Flow_Factory::init (int /* argc */,
-                               char * /* argv */ [])
+                               ACE_TCHAR * /* argv */ [])
 {
   return 0;
 }
