@@ -1,4 +1,4 @@
-// $Id: sfp.cpp 80173 2007-12-03 16:25:40Z sowayaa $
+// $Id: sfp.cpp 82940 2008-10-06 18:20:19Z johnnyw $
 
 #include "orbsvcs/AV/sfp.h"
 #include "tao/debug.h"
@@ -1232,7 +1232,7 @@ TAO_AV_SFP_Factory::~TAO_AV_SFP_Factory (void)
 
 // Initialization hook from service configurator.
 int
-TAO_AV_SFP_Factory::init (int /*argc*/, char ** /*argv*/)
+TAO_AV_SFP_Factory::init (int /*argc*/, ACE_TCHAR ** /*argv*/)
 {
   return 0;
 }
