@@ -1,25 +1,23 @@
-/* -*- C++ -*- */
-// Channel_Clients_T.h,v 1.17 2005/05/16 14:45:23 jwillemsen Exp
+// -*- C++ -*-
+
+
+//=============================================================================
+/**
+ *  @file    Channel_Clients_T.h
+ *
+ *  $Id: Channel_Clients_T.h 77053 2007-02-12 18:59:50Z johnnyw $
+ *
+ *  @author Tim Harrison (harrison@cs.wustl.edu) and Douglas Schmidt (schmidt@cs.wustl.edu)
+ *
+ *  These classes allow applications to be consumer, suppliers, and
+ *  consumer suppliers, as well as being active objects.  This is
+ *  accomplished with adapters to prevent the use of multiple
+ *  inheritence (which is this root of all evil.)
+ *
+ *
+ */
+//=============================================================================
 
-// ============================================================================
-//
-// = LIBRARY
-//    ace
-//
-// = FILENAME
-//    Channel_Clients_T
-//
-// = AUTHOR
-//    Tim Harrison (harrison@cs.wustl.edu) and
-//    Douglas Schmidt (schmidt@cs.wustl.edu)
-//
-// = DESCRIPTION
-//    These classes allow applications to be consumer, suppliers, and
-//    consumer suppliers, as well as being active objects.  This is
-//    accomplished with adapters to prevent the use of multiple
-//    inheritence (which is this root of all evil.)
-//
-// ============================================================================
 
 #ifndef ACE_CHANNEL_CLIENTS_T_H
 #define ACE_CHANNEL_CLIENTS_T_H
@@ -27,6 +25,8 @@
 
 #include "orbsvcs/RtecEventCommS.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class ACE_PushConsumer_Adapter
  *
@@ -42,13 +42,10 @@ public:
   ACE_PushConsumer_Adapter (TARGET *target);
 
   /// Forwards to target_.
-  virtual void push (const RtecEventComm::EventSet& events
-                     ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC (( CORBA::SystemException));
+  virtual void push (const RtecEventComm::EventSet& events);
 
   /// Forwards to target_.
-  virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC (( CORBA::SystemException));
+  virtual void disconnect_push_consumer (void);
 
 private:
   TARGET *target_;
@@ -71,15 +68,16 @@ public:
   ACE_PushSupplier_Adapter (TARGET *target);
 
   /// Forwards to target_.
-  virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC (( CORBA::SystemException));
+  virtual void disconnect_push_supplier (void);
 
 private:
   TARGET *target_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "orbsvcs/Channel_Clients_T.i"
+#include "orbsvcs/Channel_Clients_T.inl"
 #endif /* __ACE_INLINE__ */
 
 #if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
