@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file      CC_LockSet.h
  *
- *  CC_LockSet.h,v 1.25 2004/08/16 23:53:12 jtc Exp
+ *  $Id: CC_LockSet.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *    This class implements the lock set interface from the
  *    concurrency service.
@@ -45,7 +45,7 @@
 #include "ace/Unbounded_Queue.h"
 
 #include "orbsvcs/CosConcurrencyControlS.h"
-#include "concurrency_export.h"
+#include "orbsvcs/Concurrency/concurrency_serv_export.h"
 
 #if defined (lock_held)
 #undef lock_held
@@ -56,6 +56,8 @@
 /// modes are not stated as part of the IDL.
 #define NUMBER_OF_LOCK_MODES 5
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /// Enummeration representing the lock modes. The incoming request is
 /// always converted to this representation. There are two reasons for
 /// this: Firstly the lock modes are ordered from weakest to strongest
@@ -73,7 +75,7 @@ typedef enum {CC_EM=-1, CC_IR=0, CC_R, CC_U, CC_IW, CC_W} CC_LockModeEnum;
  * detailed descriptions apart from the comments in this file At
  * present the lock set is not really a set, but only one lock.
  */
-class TAO_Concurrency_Export CC_LockSet :  public POA_CosConcurrencyControl::LockSet
+class TAO_Concurrency_Serv_Export CC_LockSet :  public POA_CosConcurrencyControl::LockSet
 {
 public:
 
@@ -90,28 +92,18 @@ public:
 
   // = CosConcurrencyControl methods
   /// Acquires this lock. Blocks until lock is obtained
-  virtual void lock (CosConcurrencyControl::lock_mode mode
-                     ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void lock (CosConcurrencyControl::lock_mode mode);
 
   /// Tries to acquire this lock. If it is not possible to acquire the
   /// lock, false is returned
-  virtual CORBA::Boolean try_lock (CosConcurrencyControl::lock_mode mode
-                                   ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CORBA::Boolean try_lock (CosConcurrencyControl::lock_mode mode);
 
   /// Releases this lock.
-  virtual void unlock (CosConcurrencyControl::lock_mode mode
-                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     CosConcurrencyControl::LockNotHeld));
+  virtual void unlock (CosConcurrencyControl::lock_mode mode);
 
   /// Changes the mode of this lock.
   virtual void change_mode (CosConcurrencyControl::lock_mode held_mode,
-                            CosConcurrencyControl::lock_mode new_mode
-                            ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     CosConcurrencyControl::LockNotHeld));
+                            CosConcurrencyControl::lock_mode new_mode);
 
   // = Debugging methods
   /// Dump the state of the object to stdout
@@ -124,7 +116,7 @@ private:
 
   /// Initiatlizes the lock set array and acquires the initial
   /// semaphore.
-  void Init (ACE_ENV_SINGLE_ARG_DECL);
+  void Init (void);
 
   /// Returns true if the held lock and the requested lock are compatible
   CORBA::Boolean compatible (CC_LockModeEnum mr);
@@ -181,7 +173,7 @@ private:
 
   /// Mapping between requested and held lock modes. Used by compatible
   /// (...).  Uses the internal enumeration as indices.
-  static CORBA::Boolean compatible_[NUMBER_OF_LOCK_MODES][NUMBER_OF_LOCK_MODES];
+  static CORBA::Boolean const compatible_[NUMBER_OF_LOCK_MODES][NUMBER_OF_LOCK_MODES];
 
   /// Lock to ensure that race conditions does not occur.
   TAO_SYNCH_MUTEX mlock_;
@@ -190,6 +182,8 @@ private:
   ACE_Unbounded_Queue <CC_LockModeEnum> lock_queue_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* _CC_LOCKSET_H */
