@@ -1,4 +1,4 @@
-// $Id: Concurrency_Loader.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: Concurrency_Loader.cpp 82940 2008-10-06 18:20:19Z johnnyw $
 
 // ================================================================
 // LIBRARY
@@ -16,7 +16,7 @@
 #include "orbsvcs/Concurrency/Concurrency_Loader.h"
 #include "ace/Dynamic_Service.h"
 
-ACE_RCSID (Concurrency, Concurrency_Loader, "$Id: Concurrency_Loader.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+ACE_RCSID (Concurrency, Concurrency_Loader, "$Id: Concurrency_Loader.cpp 82940 2008-10-06 18:20:19Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -29,7 +29,7 @@ TAO_Concurrency_Loader::~TAO_Concurrency_Loader (void)
 }
 
 int
-TAO_Concurrency_Loader::init (int argc, char *argv[])
+TAO_Concurrency_Loader::init (int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -60,7 +60,7 @@ TAO_Concurrency_Loader::fini (void)
 CORBA::Object_ptr
 TAO_Concurrency_Loader::create_object (CORBA::ORB_ptr orb,
                                        int /* argc */,
-                                       char * /* argv */ [])
+                                       ACE_TCHAR * /* argv */ [])
 {
   CORBA::Object_var object =
     orb->resolve_initial_references ("RootPOA");
