@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Concurrency_Utils.h
  *
- *  Concurrency_Utils.h,v 1.14 2004/08/16 23:53:12 jtc Exp
+ *  $Id: Concurrency_Utils.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *    This class implements a Concurrency Server wrapper class which
  *    holds a number of lock sets.  The server must run in the
@@ -23,8 +23,11 @@
 #include /**/ "ace/pre.h"
 
 #include "orbsvcs/CosConcurrencyControlC.h"
-#include "CC_LockSetFactory.h"
-#include "concurrency_export.h"
+#include "orbsvcs/Concurrency/CC_LockSetFactory.h"
+#include "orbsvcs/Concurrency/concurrency_serv_export.h"
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /**
  * @class TAO_Concurrency_Server
@@ -35,7 +38,7 @@
  * This class takes an orb and Poa reference and activates the
  * concurrency service lock set factory object under them.
  */
-class TAO_Concurrency_Export TAO_Concurrency_Server
+class TAO_Concurrency_Serv_Export TAO_Concurrency_Server
 {
 public:
   // = Initialization and termination methods.
@@ -68,5 +71,7 @@ private:
   PortableServer::POA_var poa_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* _CONCURRENCY_SERVER_H */
