@@ -1,4 +1,4 @@
-// $Id: CEC_Default_Factory.cpp 73791 2006-07-27 20:54:56Z wotte $
+// $Id: CEC_Default_Factory.cpp 82864 2008-09-29 07:44:18Z johnnyw $
 
 #include "orbsvcs/CosEvent/CEC_Default_Factory.h"
 #include "orbsvcs/CosEvent/CEC_MT_Dispatching.h"
@@ -42,7 +42,7 @@
 
 ACE_RCSID (CosEvent,
            CEC_Default_Factory,
-           "$Id: CEC_Default_Factory.cpp 73791 2006-07-27 20:54:56Z wotte $")
+           "$Id: CEC_Default_Factory.cpp 82864 2008-09-29 07:44:18Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -477,7 +477,7 @@ TAO_CEC_Default_Factory::create_pulling_strategy (TAO_CEC_EventChannel *ec)
   if (this->pulling_strategy_ == 0)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_);
 
@@ -1283,7 +1283,7 @@ TAO_CEC_Default_Factory::create_consumer_control (TAO_CEC_EventChannel* ec)
   else if (this->consumer_control_ == 1)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_);
 
@@ -1305,7 +1305,7 @@ TAO_CEC_Default_Factory::create_consumer_control (TAO_CEC_TypedEventChannel* ec)
   else if (this->consumer_control_ == 1)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_);
 
@@ -1333,7 +1333,7 @@ TAO_CEC_Default_Factory::create_supplier_control (TAO_CEC_EventChannel* ec)
   else if (this->supplier_control_ == 1)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_);
 
@@ -1355,7 +1355,7 @@ TAO_CEC_Default_Factory::create_supplier_control (TAO_CEC_TypedEventChannel* ec)
   else if (this->supplier_control_ == 1)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_);
 
@@ -1380,7 +1380,8 @@ CORBA::Policy_ptr TAO_CEC_Default_Factory::create_roundtrip_timeout_policy
 {
   //get the existing orb
   int fake_argc = 0;
-  CORBA::ORB_var orb = CORBA::ORB_init (fake_argc, 0, this->orbid_);
+  ACE_TCHAR **fake_argv = 0;
+  CORBA::ORB_var orb = CORBA::ORB_init (fake_argc, fake_argv, this->orbid_);
 
   CORBA::Any value;
   TimeBase::TimeT timet;
