@@ -1,9 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file   CEC_Default_Factory.h
  *
- *  CEC_Default_Factory.h,v 1.16 2005/01/30 08:43:26 ossama Exp
+ *  $Id: CEC_Default_Factory.h 73791 2006-07-27 20:54:56Z wotte $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  */
@@ -15,17 +16,19 @@
 
 #include /**/ "ace/pre.h"
 
-#include "CEC_Factory.h"
+#include "orbsvcs/CosEvent/CEC_Factory.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "CEC_Defaults.h"
+#include "orbsvcs/CosEvent/CEC_Defaults.h"
 
 #include "ace/Service_Config.h"
 #include "ace/Time_Value.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_CEC_Default_Factory
  *
@@ -158,6 +161,9 @@ public:
       create_supplier_control (TAO_CEC_TypedEventChannel*);
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
+  virtual CORBA::Policy_ptr
+  create_roundtrip_timeout_policy (const ACE_Time_Value &timeout);
+
 private:
   /// Parse an argument to set the type of collections used.
   int parse_collection_arg (ACE_TCHAR* opt);
@@ -200,12 +206,21 @@ private:
   ACE_Time_Value consumer_control_timeout_;
   ACE_Time_Value supplier_control_timeout_;
 
+  /// The consumer and supplier operation timeouts.
+  /// Only in effect if the corresponding "reactive control" is enabled.
+  /// Applies the given timeout as the round-trip time policy on the
+  /// object reference.
+  ACE_Time_Value consumer_timeout_;
+  ACE_Time_Value supplier_timeout_;
+
   /// The number of retries before disconnecting a proxy
   unsigned int proxy_disconnect_retries_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "CEC_Default_Factory.i"
+#include "orbsvcs/CosEvent/CEC_Default_Factory.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_STATIC_SVC_DECLARE (TAO_CEC_Default_Factory)
