@@ -1,11 +1,11 @@
-// CEC_Dispatching_Task.h,v 1.17 2004/09/08 19:22:44 jtc Exp
+// $Id: CEC_Dispatching_Task.h 76589 2007-01-25 18:04:11Z elliott_c $
 // -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file   CEC_Dispatching_Task.h
  *
- *  CEC_Dispatching_Task.h,v 1.17 2004/09/08 19:22:44 jtc Exp
+ *  $Id: CEC_Dispatching_Task.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  */
@@ -16,26 +16,27 @@
 #define TAO_CEC_DISPATCHING_TASK_H
 
 #include /**/ "ace/pre.h"
-#include "ace/Task.h"
+
+#include "orbsvcs/CosEvent/event_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "ace/Message_Block.h"
-#include "ace/Lock_Adapter_T.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPushSupplier.h"
 
 #include "tao/Basic_Types.h"
-#include "tao/Objref_VarOut_T.h"
 
-#include "orbsvcs/CosEvent/event_serv_export.h"
-
-#include "CEC_ProxyPushSupplier.h"
+#include "ace/Message_Block.h"
+#include "ace/Lock_Adapter_T.h"
+#include "ace/Task.h"
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-#include "CEC_TypedEvent.h"
+#include "orbsvcs/CosEvent/CEC_TypedEvent.h"
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_CEC_Dispatching_Task
  *
@@ -53,13 +54,11 @@ public:
   virtual int svc (void);
 
   virtual void push (TAO_CEC_ProxyPushSupplier *proxy,
-                     CORBA::Any& event
-                     ACE_ENV_ARG_DECL);
+                     CORBA::Any& event);
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
   virtual void invoke (TAO_CEC_ProxyPushSupplier *proxy,
-                       TAO_CEC_TypedEvent& typed_event
-                       ACE_ENV_ARG_DECL);
+                       TAO_CEC_TypedEvent& typed_event);
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
 private:
@@ -86,7 +85,7 @@ public:
   virtual ~TAO_CEC_Dispatch_Command (void);
 
   /// Command callback
-  virtual int execute (ACE_ENV_SINGLE_ARG_DECL_NOT_USED) = 0;
+  virtual int execute (void) = 0;
 };
 
 // ****************************************************************
@@ -98,7 +97,7 @@ public:
   TAO_CEC_Shutdown_Task_Command (ACE_Allocator *mb_allocator = 0);
 
   /// Command callback
-  virtual int execute (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  virtual int execute (void);
 };
 
 // ****************************************************************
@@ -116,7 +115,7 @@ public:
   virtual ~TAO_CEC_Push_Command (void);
 
   /// Command callback
-  virtual int execute (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  virtual int execute (void);
 
 private:
   /// The proxy
@@ -142,7 +141,7 @@ public:
   virtual ~TAO_CEC_Invoke_Command (void);
 
   /// Command callback
-  virtual int execute (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  virtual int execute (void);
 
 private:
   /// The proxy
@@ -153,8 +152,10 @@ private:
 };
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "CEC_Dispatching_Task.i"
+#include "orbsvcs/CosEvent/CEC_Dispatching_Task.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
