@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// $Id: CEC_DynamicImplementation.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: CEC_DynamicImplementation.cpp 85152 2009-04-23 08:32:53Z johnnyw $
 
 #include "orbsvcs/CosEvent/CEC_DynamicImplementation.h"
 #include "tao/DynamicInterface/Request.h"
@@ -95,7 +95,7 @@ TAO_CEC_DynamicImplementationServer::is_a (CORBA::ServerRequest_ptr request)
   CORBA::NamedValue_ptr nv = list->item (0);
 
   CORBA::Any_ptr ap = nv->value ();
-  const char *value;
+  const char *value = 0;
   *ap >>= value;
 
   if (TAO_debug_level >= 10)
