@@ -1,8 +1,13 @@
-// CEC_MT_Dispatching.cpp,v 1.7 2005/01/05 11:23:13 jwillemsen Exp
+// $Id: CEC_MT_Dispatching.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+
+#include "orbsvcs/CosEvent/CEC_MT_Dispatching.h"
+
+ACE_RCSID(CosEvent, CEC_MT_Dispatching, "$Id: CEC_MT_Dispatching.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 
-#include "CEC_MT_Dispatching.h"
 
-ACE_RCSID(CosEvent, CEC_MT_Dispatching, "CEC_MT_Dispatching.cpp,v 1.7 2005/01/05 11:23:13 jwillemsen Exp")
 
 TAO_CEC_MT_Dispatching::TAO_CEC_MT_Dispatching (int nthreads,
                                                 int thread_creation_flags,
@@ -58,44 +63,42 @@ TAO_CEC_MT_Dispatching::shutdown (void)
 
 void
 TAO_CEC_MT_Dispatching::push (TAO_CEC_ProxyPushSupplier* proxy,
-                              const CORBA::Any& event
-                              ACE_ENV_ARG_DECL)
+                              const CORBA::Any& event)
 {
   CORBA::Any event_copy = event;
-  this->push_nocopy (proxy, event_copy ACE_ENV_ARG_PARAMETER);
+  this->push_nocopy (proxy, event_copy);
 }
 
 void
 TAO_CEC_MT_Dispatching::push_nocopy (TAO_CEC_ProxyPushSupplier* proxy,
-                                     CORBA::Any& event
-                                     ACE_ENV_ARG_DECL)
+                                     CORBA::Any& event)
 {
   // Double checked locking....
   if (this->active_ == 0)
     this->activate ();
 
-  this->task_.push (proxy, event ACE_ENV_ARG_PARAMETER);
+  this->task_.push (proxy, event);
 }
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
 void
 TAO_CEC_MT_Dispatching::invoke (TAO_CEC_ProxyPushSupplier* proxy,
-                                const TAO_CEC_TypedEvent& typed_event
-                                ACE_ENV_ARG_DECL)
+                                const TAO_CEC_TypedEvent& typed_event)
 {
   TAO_CEC_TypedEvent typed_event_copy = typed_event;
-  this->invoke_nocopy (proxy, typed_event_copy ACE_ENV_ARG_PARAMETER);
+  this->invoke_nocopy (proxy, typed_event_copy);
 }
 
 void
 TAO_CEC_MT_Dispatching::invoke_nocopy (TAO_CEC_ProxyPushSupplier* proxy,
-                                       TAO_CEC_TypedEvent& typed_event
-                                       ACE_ENV_ARG_DECL)
+                                       TAO_CEC_TypedEvent& typed_event)
 {
   // Double checked locking....
   if (this->active_ == 0)
     this->activate ();
 
-  this->task_.invoke (proxy, typed_event ACE_ENV_ARG_PARAMETER);
+  this->task_.invoke (proxy, typed_event);
 }
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
+TAO_END_VERSIONED_NAMESPACE_DECL
