@@ -1,23 +1,27 @@
-// CEC_ProxyPullSupplier.cpp,v 1.19 2004/09/01 15:44:21 elliott_c Exp
+// $Id: CEC_ProxyPullSupplier.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
-#include "CEC_ProxyPullSupplier.h"
-#include "CEC_Dispatching.h"
-#include "CEC_EventChannel.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPullSupplier.h"
+#include "orbsvcs/CosEvent/CEC_Dispatching.h"
+#include "orbsvcs/CosEvent/CEC_EventChannel.h"
 
 #include "ace/Reverse_Lock_T.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "CEC_ProxyPullSupplier.i"
+#include "orbsvcs/CosEvent/CEC_ProxyPullSupplier.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (CosEvent,
            CEC_ProxyPullSupplier,
-           "CEC_ProxyPullSupplier.cpp,v 1.19 2004/09/01 15:44:21 elliott_c Exp")
+           "$Id: CEC_ProxyPullSupplier.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 typedef ACE_Reverse_Lock<ACE_Lock> TAO_CEC_Unlock;
 
-TAO_CEC_ProxyPullSupplier::TAO_CEC_ProxyPullSupplier (TAO_CEC_EventChannel* ec)
+TAO_CEC_ProxyPullSupplier::TAO_CEC_ProxyPullSupplier
+(TAO_CEC_EventChannel* ec, const ACE_Time_Value &timeout)
   : event_channel_ (ec),
+    timeout_ (timeout),
     refcount_ (1),
     connected_ (0),
     wait_not_empty_ (queue_lock_)
@@ -39,51 +43,42 @@ TAO_CEC_ProxyPullSupplier::~TAO_CEC_ProxyPullSupplier (void)
 
 void
 TAO_CEC_ProxyPullSupplier::activate (
-    CosEventChannelAdmin::ProxyPullSupplier_ptr &activated_proxy
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    CosEventChannelAdmin::ProxyPullSupplier_ptr &activated_proxy)
 {
   CosEventChannelAdmin::ProxyPullSupplier_var result;
-  ACE_TRY
+  try
     {
-      result = this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      result = this->_this ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       result = CosEventChannelAdmin::ProxyPullSupplier::_nil ();
     }
-  ACE_ENDTRY;
   activated_proxy = result._retn ();
 }
 
 void
-TAO_CEC_ProxyPullSupplier::deactivate (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CEC_ProxyPullSupplier::deactivate (void)
 {
-  ACE_TRY
+  try
     {
       PortableServer::POA_var poa =
-        this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        this->_default_POA ();
       PortableServer::ObjectId_var id =
-        poa->servant_to_id (this ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      poa->deactivate_object (id.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        poa->servant_to_id (this);
+      poa->deactivate_object (id.in ());
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Exceptions here should not be propagated.  They usually
       // indicate that an object is beign disconnected twice, or some
       // race condition, but not a fault that the user needs to know
       // about.
     }
-  ACE_ENDTRY;
 }
 
 void
-TAO_CEC_ProxyPullSupplier::shutdown (ACE_ENV_SINGLE_ARG_DECL)
+TAO_CEC_ProxyPullSupplier::shutdown (void)
 {
   // Save the consumer we where connected to, we need to send a
   // disconnect message to it.
@@ -94,41 +89,35 @@ TAO_CEC_ProxyPullSupplier::shutdown (ACE_ENV_SINGLE_ARG_DECL)
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     consumer = this->consumer_._retn ();
   }
 
-  this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->deactivate ();
 
   if (CORBA::is_nil (consumer.in ()))
     return;
 
-  ACE_TRY
+  try
     {
-      consumer->disconnect_pull_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer->disconnect_pull_consumer ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore exceptions, we must isolate other clients from
       // problems on this one.
     }
-  ACE_ENDTRY;
 }
 
 CORBA::Boolean
 TAO_CEC_ProxyPullSupplier::consumer_non_existent (
-      CORBA::Boolean_out disconnected
-      ACE_ENV_ARG_DECL)
+      CORBA::Boolean_out disconnected)
 {
   CORBA::Object_var consumer;
   {
     ACE_GUARD_THROW_EX (
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
-    ACE_CHECK_RETURN (0);
 
     disconnected = 0;
     if (this->is_connected_i () == 0)
@@ -136,23 +125,22 @@ TAO_CEC_ProxyPullSupplier::consumer_non_existent (
         disconnected = 1;
         return 0;
       }
-    if (CORBA::is_nil (this->consumer_.in ()))
+    if (CORBA::is_nil (this->nopolicy_consumer_.in ()))
       {
         return 0;
       }
-    consumer = CORBA::Object::_duplicate (this->consumer_.in ());
+    consumer = CORBA::Object::_duplicate (this->nopolicy_consumer_.in ());
   }
 
 #if (TAO_HAS_MINIMUM_CORBA == 0)
-  return consumer->_non_existent (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return consumer->_non_existent ();
 #else
   return 0;
 #endif /* TAO_HAS_MINIMUM_CORBA */
 }
 
 void
-TAO_CEC_ProxyPullSupplier::push (const CORBA::Any &event
-                                 ACE_ENV_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPullSupplier::push (const CORBA::Any &event)
 {
   if (this->is_connected () == 0)
     return;
@@ -166,12 +154,10 @@ TAO_CEC_ProxyPullSupplier::push (const CORBA::Any &event
 }
 
 CORBA::Any *
-TAO_CEC_ProxyPullSupplier::pull (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException,
-                       CosEventComm::Disconnected))
+TAO_CEC_ProxyPullSupplier::pull (void)
 {
   if (this->is_connected () == 0)
-    ACE_THROW_RETURN (CosEventComm::Disconnected (), 0);
+    throw CosEventComm::Disconnected ();
 
   ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, queue_lock_, 0);
   while (this->queue_.is_empty ())
@@ -181,19 +167,17 @@ TAO_CEC_ProxyPullSupplier::pull (ACE_ENV_SINGLE_ARG_DECL)
   CORBA::Any any;
   if (this->queue_.dequeue_head (any) != 0)
     {
-      ACE_THROW_RETURN (CORBA::INTERNAL (), 0);
+      throw CORBA::INTERNAL ();
     }
   return new CORBA::Any (any);
 }
 
 CORBA::Any *
-TAO_CEC_ProxyPullSupplier::try_pull (CORBA::Boolean_out has_event
-                                     ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException,CosEventComm::Disconnected))
+TAO_CEC_ProxyPullSupplier::try_pull (CORBA::Boolean_out has_event)
 {
   has_event = 0;
   if (this->is_connected () == 0)
-    ACE_THROW_RETURN (CosEventComm::Disconnected (), 0);
+    throw CosEventComm::Disconnected ();
 
   ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, queue_lock_, 0);
   CORBA::Any any;
@@ -205,7 +189,7 @@ TAO_CEC_ProxyPullSupplier::try_pull (CORBA::Boolean_out has_event
 
   if (this->queue_.dequeue_head (any) != 0)
     {
-      ACE_THROW_RETURN (CORBA::INTERNAL (), 0);
+      throw CORBA::INTERNAL ();
     }
   has_event = 1;
   return new CORBA::Any (any);
@@ -243,28 +227,23 @@ TAO_CEC_ProxyPullSupplier::_decr_refcnt (void)
 
 void
 TAO_CEC_ProxyPullSupplier::connect_pull_consumer (
-      CosEventComm::PullConsumer_ptr pull_consumer
-      ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     CosEventChannelAdmin::AlreadyConnected))
+      CosEventComm::PullConsumer_ptr pull_consumer)
 {
   {
     ACE_GUARD_THROW_EX (
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     if (this->is_connected_i ())
       {
         if (this->event_channel_->consumer_reconnect () == 0)
-          ACE_THROW (CosEventChannelAdmin::AlreadyConnected ());
+          throw CosEventChannelAdmin::AlreadyConnected ();
 
         // Re-connections are allowed....
         this->cleanup_i ();
 
-        this->consumer_ =
-          CosEventComm::PullConsumer::_duplicate (pull_consumer);
+        this->consumer_ = apply_policy (pull_consumer);
         this->connected_ = 1;
 
         TAO_CEC_Unlock reverse_lock (*this->lock_);
@@ -274,27 +253,50 @@ TAO_CEC_ProxyPullSupplier::connect_pull_consumer (
               TAO_CEC_Unlock, ace_mon, reverse_lock,
               CORBA::INTERNAL ());
           // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-          ACE_CHECK;
 
-          this->event_channel_->reconnected (this ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+          this->event_channel_->reconnected (this);
         }
         return;
       }
 
-    this->consumer_ =
-      CosEventComm::PullConsumer::_duplicate (pull_consumer);
+    this->consumer_ = apply_policy (pull_consumer);
     this->connected_ = 1;
   }
 
   // Notify the event channel...
-  this->event_channel_->connected (this ACE_ENV_ARG_PARAMETER);
+  this->event_channel_->connected (this);
+}
+
+CosEventComm::PullConsumer_ptr
+TAO_CEC_ProxyPullSupplier::apply_policy (CosEventComm::PullConsumer_ptr pre)
+{
+  if (CORBA::is_nil (pre)) return pre;
+  this->nopolicy_consumer_ = CosEventComm::PullConsumer::_duplicate (pre);
+#if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
+  CosEventComm::PullConsumer_var post =
+    CosEventComm::PullConsumer::_duplicate (pre);
+  if (this->timeout_ > ACE_Time_Value::zero)
+    {
+      CORBA::PolicyList policy_list;
+      policy_list.length (1);
+      policy_list[0] = this->event_channel_->
+        create_roundtrip_timeout_policy (this->timeout_);
+
+      CORBA::Object_var post_obj = pre->_set_policy_overrides
+        (policy_list, CORBA::ADD_OVERRIDE);
+      post = CosEventComm::PullConsumer::_narrow(post_obj.in ());
+
+      policy_list[0]->destroy ();
+      policy_list.length (0);
+    }
+  return post._retn ();
+#else
+  return CosEventComm::PullConsumer::_duplicate (pre);
+#endif /* TAO_HAS_CORBA_MESSAGING */
 }
 
 void
-TAO_CEC_ProxyPullSupplier::disconnect_pull_supplier (
-      ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CEC_ProxyPullSupplier::disconnect_pull_supplier ()
 {
   CosEventComm::PullConsumer_var consumer;
 
@@ -303,10 +305,9 @@ TAO_CEC_ProxyPullSupplier::disconnect_pull_supplier (
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     if (this->is_connected_i () == 0)
-      ACE_THROW (CORBA::BAD_INV_ORDER ());
+      throw CORBA::BAD_INV_ORDER ();
 
     consumer = this->consumer_._retn ();
 
@@ -314,58 +315,42 @@ TAO_CEC_ProxyPullSupplier::disconnect_pull_supplier (
   }
 
   // Notify the event channel....
-  this->event_channel_->disconnected (this ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->event_channel_->disconnected (this);
 
   if (CORBA::is_nil (consumer.in ()))
     return;
 
   if (this->event_channel_->disconnect_callbacks ())
     {
-      ACE_TRY
+      try
         {
-          consumer->disconnect_pull_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          consumer->disconnect_pull_consumer ();
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception& ex)
         {
           // Ignore exceptions, we must isolate other clients from
           // problems on this one.
-          ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                               "ProxySupplier::disconnect_pull_supplier");
+          ex._tao_print_exception ("ProxySupplier::disconnect_pull_supplier");
         }
-      ACE_ENDTRY;
     }
 }
 
 PortableServer::POA_ptr
-TAO_CEC_ProxyPullSupplier::_default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPullSupplier::_default_POA (void)
 {
   return PortableServer::POA::_duplicate (this->default_POA_.in ());
 }
 
 void
-TAO_CEC_ProxyPullSupplier::_add_ref (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPullSupplier::_add_ref (void)
 {
   this->_incr_refcnt ();
 }
 
 void
-TAO_CEC_ProxyPullSupplier::_remove_ref (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPullSupplier::_remove_ref (void)
 {
   this->_decr_refcnt ();
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_Unbounded_Queue<CORBA::Any>;
-template class ACE_Node<CORBA::Any>;
-template class ACE_Unbounded_Queue_Iterator<CORBA::Any>;
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_Unbounded_Queue<CORBA::Any>
-#pragma instantiate ACE_Node<CORBA::Any>
-#pragma instantiate ACE_Unbounded_Queue_Iterator<CORBA::Any>
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
