@@ -1,4 +1,4 @@
-// CEC_ProxyPushSupplier.cpp,v 1.24 2004/09/01 15:44:21 elliott_c Exp
+// $Id: CEC_ProxyPushSupplier.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
 // Force CORBA::release(CORBA::Request...) prototype to be parsed
 // before TAO_Pseudo_{Var,Out}_T templates.  All required
@@ -6,16 +6,16 @@
 // question when using compilers like g++ 3.4.x.
 #include "tao/DynamicInterface/DII_CORBA_methods.h"
 
-#include "CEC_ProxyPushSupplier.h"
-#include "CEC_Dispatching.h"
-#include "CEC_EventChannel.h"
-#include "CEC_ConsumerControl.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPushSupplier.h"
+#include "orbsvcs/CosEvent/CEC_Dispatching.h"
+#include "orbsvcs/CosEvent/CEC_EventChannel.h"
+#include "orbsvcs/CosEvent/CEC_ConsumerControl.h"
 #include "orbsvcs/ESF/ESF_RefCount_Guard.h"
 #include "orbsvcs/ESF/ESF_Proxy_RefCount_Guard.h"
-#include "tao/debug.h"
+
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-#include "CEC_TypedEvent.h"
-#include "CEC_TypedEventChannel.h"
+#include "orbsvcs/CosEvent/CEC_TypedEvent.h"
+#include "orbsvcs/CosEvent/CEC_TypedEventChannel.h"
 #include "tao/DynamicInterface/Request.h"
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
@@ -23,18 +23,23 @@
 #include "ace/Reverse_Lock_T.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "CEC_ProxyPushSupplier.i"
+#include "orbsvcs/CosEvent/CEC_ProxyPushSupplier.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (CosEvent,
            CEC_ProxyPushSupplier,
-           "CEC_ProxyPushSupplier.cpp,v 1.24 2004/09/01 15:44:21 elliott_c Exp")
+           "$Id: CEC_ProxyPushSupplier.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 typedef ACE_Reverse_Lock<ACE_Lock> TAO_CEC_Unlock;
 
 // TAO_CEC_ProxyPushSupplier Constructure (Un-typed EC)
-TAO_CEC_ProxyPushSupplier::TAO_CEC_ProxyPushSupplier (TAO_CEC_EventChannel* ec)
+TAO_CEC_ProxyPushSupplier::
+TAO_CEC_ProxyPushSupplier (TAO_CEC_EventChannel* ec,
+                           const ACE_Time_Value &timeout)
   : event_channel_ (ec),
+    timeout_ (timeout),
     refcount_ (1)
 {
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
@@ -52,8 +57,11 @@ TAO_CEC_ProxyPushSupplier::TAO_CEC_ProxyPushSupplier (TAO_CEC_EventChannel* ec)
 
 // TAO_CEC_ProxyPushSupplier Constructure (Typed EC)
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-TAO_CEC_ProxyPushSupplier::TAO_CEC_ProxyPushSupplier (TAO_CEC_TypedEventChannel* ec)
-  : typed_event_channel_ (ec),
+TAO_CEC_ProxyPushSupplier::
+TAO_CEC_ProxyPushSupplier (TAO_CEC_TypedEventChannel* ec,
+                           const ACE_Time_Value &timeout)
+  : timeout_ (timeout),
+    typed_event_channel_ (ec),
     refcount_ (1)
 {
   event_channel_ = 0;
@@ -64,74 +72,67 @@ TAO_CEC_ProxyPushSupplier::TAO_CEC_ProxyPushSupplier (TAO_CEC_TypedEventChannel*
   this->default_POA_ =
     this->typed_event_channel_->typed_supplier_poa ();
 
-  this->event_channel_->get_servant_retry_map ().bind (this, 0);
+  this->typed_event_channel_->get_servant_retry_map ().bind (this, 0);
 }
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
 TAO_CEC_ProxyPushSupplier::~TAO_CEC_ProxyPushSupplier (void)
 {
-  this->event_channel_->get_servant_retry_map ().unbind (this);
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
   if (this->is_typed_ec () )
     {
+      this->typed_event_channel_->get_servant_retry_map ().unbind (this);
       this->typed_event_channel_->destroy_supplier_lock (this->lock_);
     }
   else
     {
+      this->event_channel_->get_servant_retry_map ().unbind (this);
       this->event_channel_->destroy_supplier_lock (this->lock_);
     }
 #else
+  this->event_channel_->get_servant_retry_map ().unbind (this);
   this->event_channel_->destroy_supplier_lock (this->lock_);
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 }
 
 void
 TAO_CEC_ProxyPushSupplier::activate (
-    CosEventChannelAdmin::ProxyPushSupplier_ptr &activated_proxy
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    CosEventChannelAdmin::ProxyPushSupplier_ptr &activated_proxy)
 {
   CosEventChannelAdmin::ProxyPushSupplier_var result;
-  ACE_TRY
+  try
     {
-      result = this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      result = this->_this ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       result = CosEventChannelAdmin::ProxyPushSupplier::_nil ();
     }
-  ACE_ENDTRY;
   activated_proxy = result._retn ();
 }
 
 void
-TAO_CEC_ProxyPushSupplier::deactivate (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CEC_ProxyPushSupplier::deactivate (void)
 {
-  ACE_TRY
+  try
     {
       PortableServer::POA_var poa =
-        this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        this->_default_POA ();
       PortableServer::ObjectId_var id =
-        poa->servant_to_id (this ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      poa->deactivate_object (id.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        poa->servant_to_id (this);
+      poa->deactivate_object (id.in ());
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Exceptions here should not be propagated.  They usually
       // indicate that an object is beign disconnected twice, or some
       // race condition, but not a fault that the user needs to know
       // about.
     }
-  ACE_ENDTRY;
 }
 
 void
-TAO_CEC_ProxyPushSupplier::shutdown (ACE_ENV_SINGLE_ARG_DECL)
+TAO_CEC_ProxyPushSupplier::shutdown (void)
 {
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
   if (this->is_typed_ec () )
@@ -144,28 +145,24 @@ TAO_CEC_ProxyPushSupplier::shutdown (ACE_ENV_SINGLE_ARG_DECL)
             ACE_Lock, ace_mon, *this->lock_,
             CORBA::INTERNAL ());
         // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-        ACE_CHECK;
 
         typed_consumer = this->typed_consumer_._retn ();
       }
 
-      this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
+      this->deactivate ();
 
       if (CORBA::is_nil (typed_consumer.in ()))
         return;
 
-      ACE_TRY_EX (typed)
+      try
         {
-          typed_consumer->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK_EX (typed);
+          typed_consumer->disconnect_push_consumer ();
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception&)
         {
           // Ignore exceptions, we must isolate other clients from
           // problems on this one.
         }
-      ACE_ENDTRY;
     } /* this->is_typed_ec */
   else
     {
@@ -180,28 +177,24 @@ TAO_CEC_ProxyPushSupplier::shutdown (ACE_ENV_SINGLE_ARG_DECL)
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     consumer = this->consumer_._retn ();
   }
 
-  this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->deactivate ();
 
   if (CORBA::is_nil (consumer.in ()))
     return;
 
-  ACE_TRY
+  try
     {
-      consumer->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer->disconnect_push_consumer ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore exceptions, we must isolate other clients from
       // problems on this one.
     }
-  ACE_ENDTRY;
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
     } /* ! this->is_typed_ec */
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
@@ -210,8 +203,7 @@ TAO_CEC_ProxyPushSupplier::shutdown (ACE_ENV_SINGLE_ARG_DECL)
 typedef TAO_ESF_Proxy_RefCount_Guard<TAO_CEC_EventChannel,TAO_CEC_ProxyPushSupplier> Destroy_Guard;
 
 void
-TAO_CEC_ProxyPushSupplier::push (const CORBA::Any &event
-                                 ACE_ENV_ARG_DECL)
+TAO_CEC_ProxyPushSupplier::push (const CORBA::Any &event)
 {
   Destroy_Guard auto_destroy (this->refcount_,
                               this->event_channel_,
@@ -230,9 +222,7 @@ TAO_CEC_ProxyPushSupplier::push (const CORBA::Any &event
 
       ACE_GUARD (TAO_CEC_Unlock, ace_mon, reverse_lock);
       this->event_channel_->dispatching ()->push (this,
-                                                  event
-                                                  ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                                  event);
     }
   }
 }
@@ -241,8 +231,7 @@ TAO_CEC_ProxyPushSupplier::push (const CORBA::Any &event
 typedef TAO_ESF_Proxy_RefCount_Guard<TAO_CEC_TypedEventChannel,TAO_CEC_ProxyPushSupplier> Destroy_Guard_Typed;
 
 void
-TAO_CEC_ProxyPushSupplier::invoke (const TAO_CEC_TypedEvent& typed_event
-                                   ACE_ENV_ARG_DECL)
+TAO_CEC_ProxyPushSupplier::invoke (const TAO_CEC_TypedEvent& typed_event)
 {
   Destroy_Guard_Typed auto_destroy (this->refcount_,
                                     this->typed_event_channel_,
@@ -261,17 +250,14 @@ TAO_CEC_ProxyPushSupplier::invoke (const TAO_CEC_TypedEvent& typed_event
 
       ACE_GUARD (TAO_CEC_Unlock, ace_mon, reverse_lock);
       this->typed_event_channel_->dispatching ()->invoke (this,
-                                                          typed_event
-                                                          ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                                          typed_event);
     }
   }
 }
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
 void
-TAO_CEC_ProxyPushSupplier::push_nocopy (CORBA::Any &event
-                                        ACE_ENV_ARG_DECL)
+TAO_CEC_ProxyPushSupplier::push_nocopy (CORBA::Any &event)
 {
   Destroy_Guard auto_destroy (this->refcount_,
                               this->event_channel_,
@@ -290,9 +276,7 @@ TAO_CEC_ProxyPushSupplier::push_nocopy (CORBA::Any &event
 
       ACE_GUARD (TAO_CEC_Unlock, ace_mon, reverse_lock);
       this->event_channel_->dispatching ()->push_nocopy (this,
-                                                         event
-                                                         ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                                         event);
     }
   }
 }
@@ -320,7 +304,7 @@ TAO_CEC_ProxyPushSupplier::_decr_refcnt (void)
 {
   {
     ACE_GUARD_RETURN (ACE_Lock, ace_mon, *this->lock_, 0);
-    this->refcount_--;
+    --this->refcount_;
     if (this->refcount_ != 0)
       return this->refcount_;
   }
@@ -343,15 +327,11 @@ TAO_CEC_ProxyPushSupplier::_decr_refcnt (void)
 
 void
 TAO_CEC_ProxyPushSupplier::connect_push_consumer (
-      CosEventComm::PushConsumer_ptr push_consumer
-      ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     CosEventChannelAdmin::AlreadyConnected,
-                     CosEventChannelAdmin::TypeError))
+      CosEventComm::PushConsumer_ptr push_consumer)
 {
   // Nil PushConsumers are illegal
   if (CORBA::is_nil (push_consumer))
-    ACE_THROW (CORBA::BAD_PARAM ());
+    throw CORBA::BAD_PARAM ();
 
   {
 
@@ -361,7 +341,9 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
       {
         if (TAO_debug_level >= 10)
           {
-            ACE_DEBUG ((LM_DEBUG, "***** connect_push_consumer, Event channel is typed *****\n"));
+            ACE_DEBUG ((LM_DEBUG,
+                        ACE_TEXT ("***** connect_push_consumer, ")
+                        ACE_TEXT ("Event channel is typed *****\n")));
           }
 
         // Temporary for the TypedPushConsumer and it's Typed interface,
@@ -369,34 +351,27 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
         // _is_a (during _narrow) and get_typed_consumer invocations.
         // They are eventually assigned onto this object inside the Guard.
         CosTypedEventComm::TypedPushConsumer_var local_typed_consumer =
-          CosTypedEventComm::TypedPushConsumer::_narrow (push_consumer
-                                                         ACE_ENV_ARG_PARAMETER);
-        ACE_CHECK;
+          CosTypedEventComm::TypedPushConsumer::_narrow (push_consumer);
 
         // Obtain the typed object interface from the consumer
         CORBA::Object_var local_typed_consumer_obj =
-          CORBA::Object::_duplicate (local_typed_consumer->get_typed_consumer (
-                                             ACE_ENV_SINGLE_ARG_PARAMETER) );
-        ACE_CHECK;
+          CORBA::Object::_duplicate (local_typed_consumer->get_typed_consumer () );
 
         {
           ACE_GUARD_THROW_EX (
               ACE_Lock, ace_mon, *this->lock_,
               CORBA::INTERNAL ());
           // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-          ACE_CHECK;
 
           if (this->is_connected_i ())
             {
               if (this->typed_event_channel_->consumer_reconnect () == 0)
-                ACE_THROW (CosEventChannelAdmin::AlreadyConnected ());
+                throw CosEventChannelAdmin::AlreadyConnected ();
 
               // Re-connections are allowed....
               this->cleanup_i ();
 
-              this->typed_consumer_ =
-                CosTypedEventComm::TypedPushConsumer::_duplicate (local_typed_consumer.in () );
-              ACE_CHECK;
+              this->typed_consumer_ = apply_policy (local_typed_consumer.in () );
 
               TAO_CEC_Unlock reverse_lock (*this->lock_);
 
@@ -405,27 +380,22 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
                     TAO_CEC_Unlock, ace_mon, reverse_lock,
                     CORBA::INTERNAL ());
                 // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-                ACE_CHECK;
 
-                this->typed_event_channel_->reconnected (this ACE_ENV_ARG_PARAMETER);
-                ACE_CHECK;
+                this->typed_event_channel_->reconnected (this);
               }
               return;
 
             }
 
-          this->typed_consumer_ =
-            CosTypedEventComm::TypedPushConsumer::_duplicate (local_typed_consumer.in () );
-          ACE_CHECK;
+          this->typed_consumer_ = apply_policy (local_typed_consumer.in () );
 
           // Store the typed object interface from the consumer
           this->typed_consumer_obj_ =
-            CORBA::Object::_duplicate (local_typed_consumer_obj.in () );
-          ACE_CHECK;
+            apply_policy_obj (local_typed_consumer_obj.in () );
         }
 
         // Notify the event channel...
-        this->typed_event_channel_->connected (this ACE_ENV_ARG_PARAMETER);
+        this->typed_event_channel_->connected (this);
 
       } /* this->is_typed_ec */
     else
@@ -434,7 +404,9 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
 
         if (TAO_debug_level >= 10)
           {
-            ACE_DEBUG ((LM_DEBUG, "***** connect_push_consumer, Event channel is un-typed *****\n"));
+            ACE_DEBUG ((LM_DEBUG,
+                        ACE_TEXT ("***** connect_push_consumer, ")
+                        ACE_TEXT ("Event channel is un-typed *****\n")));
           }
 
         {
@@ -443,18 +415,16 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     if (this->is_connected_i ())
       {
         if (this->event_channel_->consumer_reconnect () == 0)
-          ACE_THROW (CosEventChannelAdmin::AlreadyConnected ());
+          throw CosEventChannelAdmin::AlreadyConnected ();
 
         // Re-connections are allowed....
         this->cleanup_i ();
 
-        this->consumer_ =
-          CosEventComm::PushConsumer::_duplicate (push_consumer);
+        this->consumer_ = apply_policy (push_consumer);
 
         TAO_CEC_Unlock reverse_lock (*this->lock_);
 
@@ -463,20 +433,17 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
               TAO_CEC_Unlock, ace_mon, reverse_lock,
               CORBA::INTERNAL ());
           // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-          ACE_CHECK;
 
-          this->event_channel_->reconnected (this ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+          this->event_channel_->reconnected (this);
         }
         return;
       }
 
-    this->consumer_ =
-      CosEventComm::PushConsumer::_duplicate (push_consumer);
+    this->consumer_ = apply_policy (push_consumer);
   }
 
   // Notify the event channel...
-  this->event_channel_->connected (this ACE_ENV_ARG_PARAMETER);
+  this->event_channel_->connected (this);
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
       } /* ! this->is_typed_ec */
@@ -484,10 +451,62 @@ TAO_CEC_ProxyPushSupplier::connect_push_consumer (
   }
 }
 
+CORBA::Object_ptr
+TAO_CEC_ProxyPushSupplier::apply_policy_obj (CORBA::Object_ptr pre)
+{
+#if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
+  CORBA::Object_var post = CORBA::Object::_duplicate (pre);
+  if (this->timeout_ > ACE_Time_Value::zero)
+    {
+      CORBA::PolicyList policy_list;
+      policy_list.length (1);
+      if (this->typed_event_channel_)
+        {
+          policy_list[0] = this->typed_event_channel_->
+            create_roundtrip_timeout_policy (this->timeout_);
+        }
+      else
+        {
+          policy_list[0] = this->event_channel_->
+            create_roundtrip_timeout_policy (this->timeout_);
+        }
+      post = pre->_set_policy_overrides (policy_list, CORBA::ADD_OVERRIDE);
+
+      policy_list[0]->destroy ();
+      policy_list.length (0);
+    }
+  return post._retn ();
+#else
+  return CORBA::Object::_duplicate (pre);
+#endif /* TAO_HAS_CORBA_MESSAGING */
+}
+
+CosEventComm::PushConsumer_ptr
+TAO_CEC_ProxyPushSupplier::apply_policy (CosEventComm::PushConsumer_ptr pre)
+{
+  this->nopolicy_consumer_ = CosEventComm::PushConsumer::_duplicate (pre);
+  CORBA::Object_var post_obj = apply_policy_obj (pre);
+  CosEventComm::PushConsumer_var post =
+    CosEventComm::PushConsumer::_narrow (post_obj.in ());
+  return post._retn ();
+}
+
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+CosTypedEventComm::TypedPushConsumer_ptr
+TAO_CEC_ProxyPushSupplier::apply_policy
+  (CosTypedEventComm::TypedPushConsumer_ptr pre)
+{
+  this->nopolicy_typed_consumer_ =
+    CosTypedEventComm::TypedPushConsumer::_duplicate (pre);
+  CORBA::Object_var post_obj = apply_policy_obj (pre);
+  CosTypedEventComm::TypedPushConsumer_var post =
+    CosTypedEventComm::TypedPushConsumer::_narrow (post_obj.in ());
+  return post._retn ();
+}
+#endif
+
 void
-TAO_CEC_ProxyPushSupplier::disconnect_push_supplier (
-      ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_CEC_ProxyPushSupplier::disconnect_push_supplier ()
 {
   CosEventComm::PushConsumer_var consumer;
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
@@ -499,10 +518,9 @@ TAO_CEC_ProxyPushSupplier::disconnect_push_supplier (
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     if (this->is_connected_i () == 0)
-      ACE_THROW (CORBA::BAD_INV_ORDER ());
+      throw CORBA::BAD_INV_ORDER ();
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
     if (this->is_typed_ec () )
@@ -524,17 +542,14 @@ TAO_CEC_ProxyPushSupplier::disconnect_push_supplier (
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
   if (this->is_typed_ec () )
     {
-      this->typed_event_channel_->disconnected (this ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->typed_event_channel_->disconnected (this);
     }
   else
     {
-      this->event_channel_->disconnected (this ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->event_channel_->disconnected (this);
     }
 #else
-  this->event_channel_->disconnected (this ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->event_channel_->disconnected (this);
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
   // Disconnect callbacks
@@ -543,19 +558,17 @@ TAO_CEC_ProxyPushSupplier::disconnect_push_supplier (
     {
       if (this->typed_event_channel_->disconnect_callbacks ())
         {
-          ACE_TRY_EX (typed)
+          try
             {
-              typed_consumer->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-              ACE_TRY_CHECK_EX (typed);
+              typed_consumer->disconnect_push_consumer ();
             }
-          ACE_CATCHANY
+          catch (const CORBA::Exception& ex)
             {
               // Ignore exceptions, we must isolate other clients from
               // problems on this one.
-              ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                                   "ProxySupplier::disconnect_push_supplier");
+              ex._tao_print_exception (
+                "ProxySupplier::disconnect_push_supplier");
             }
-          ACE_ENDTRY;
         }
     } /* this->is_typed_ec */
   else
@@ -564,19 +577,16 @@ TAO_CEC_ProxyPushSupplier::disconnect_push_supplier (
 
   if (this->event_channel_->disconnect_callbacks ())
     {
-      ACE_TRY
+      try
         {
-          consumer->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          consumer->disconnect_push_consumer ();
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception& ex)
         {
           // Ignore exceptions, we must isolate other clients from
           // problems on this one.
-          ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                               "ProxySupplier::disconnect_push_supplier");
+          ex._tao_print_exception ("ProxySupplier::disconnect_push_supplier");
         }
-      ACE_ENDTRY;
     }
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
@@ -585,8 +595,7 @@ TAO_CEC_ProxyPushSupplier::disconnect_push_supplier (
 }
 
 void
-TAO_CEC_ProxyPushSupplier::push_to_consumer (const CORBA::Any& event
-                                             ACE_ENV_ARG_DECL)
+TAO_CEC_ProxyPushSupplier::push_to_consumer (const CORBA::Any& event)
 {
   CosEventComm::PushConsumer_var consumer;
   {
@@ -594,7 +603,6 @@ TAO_CEC_ProxyPushSupplier::push_to_consumer (const CORBA::Any& event
             ACE_Lock, ace_mon, *this->lock_,
             CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     if (this->is_connected_i () == 0)
       return; // ACE_THROW (CosEventComm::Disconnected ());????
@@ -605,37 +613,31 @@ TAO_CEC_ProxyPushSupplier::push_to_consumer (const CORBA::Any& event
 
   TAO_CEC_ConsumerControl *control =
                this->event_channel_->consumer_control ();
-  ACE_TRY
+  try
     {
-      consumer->push (event ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer->push (event);
 
       // Inform the control that we were able to push something
       control->successful_transmission(this);
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, not_used)
+  catch (const CORBA::OBJECT_NOT_EXIST&)
     {
-      control->consumer_not_exist (this ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      control->consumer_not_exist (this);
     }
-  ACE_CATCH (CORBA::SystemException, sysex)
+  catch (CORBA::SystemException& sysex)
     {
       control->system_exception (this,
-                                 sysex
-                                 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                 sysex);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Shouldn't happen, but does not hurt
     }
-  ACE_ENDTRY;
 }
 
 void
 TAO_CEC_ProxyPushSupplier::reactive_push_to_consumer (
-    const CORBA::Any& event
-    ACE_ENV_ARG_DECL)
+    const CORBA::Any& event)
 {
   CosEventComm::PushConsumer_var consumer;
   {
@@ -650,37 +652,42 @@ TAO_CEC_ProxyPushSupplier::reactive_push_to_consumer (
   TAO_CEC_ConsumerControl *control =
                   this->event_channel_->consumer_control ();
 
-  ACE_TRY
+  try
     {
-      consumer->push (event ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer->push (event);
 
       // Inform the control that we were able to push something
       control->successful_transmission(this);
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, not_used)
+  catch (const CORBA::OBJECT_NOT_EXIST& not_used)
     {
-      control->consumer_not_exist (this ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+       if (TAO_debug_level >= 4)
+        {
+          not_used._tao_print_exception (
+            "during TAO_CEC_ProxyPushSupplier::reactive_push_to_consumer");
+        }
+     control->consumer_not_exist (this);
     }
-  ACE_CATCH (CORBA::SystemException, sysex)
+  catch (CORBA::SystemException& sysex)
     {
+      if (TAO_debug_level >= 4)
+        {
+          sysex._tao_print_exception (
+            "during TAO_CEC_ProxyPushSupplier::reactive_push_to_consumer");
+        }
+
       control->system_exception (this,
-                                 sysex
-                                 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                 sysex);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Shouldn't happen, but does not hurt
     }
-  ACE_ENDTRY;
 }
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
 void
-TAO_CEC_ProxyPushSupplier::invoke_to_consumer (const TAO_CEC_TypedEvent &typed_event
-                                               ACE_ENV_ARG_DECL)
+TAO_CEC_ProxyPushSupplier::invoke_to_consumer (const TAO_CEC_TypedEvent &typed_event)
 {
   CORBA::Object_var typed_consumer_obj;
 
@@ -692,7 +699,6 @@ TAO_CEC_ProxyPushSupplier::invoke_to_consumer (const TAO_CEC_TypedEvent &typed_e
             ACE_Lock, ace_mon, *this->lock_,
             CORBA::INTERNAL ());
     // @@ CosEventChannelAdmin::EventChannel::SYNCHRONIZATION_ERROR ());
-    ACE_CHECK;
 
     if (this->is_connected_i () == 0)
       return; // ACE_THROW (CosEventComm::Disconnected ());????
@@ -701,8 +707,11 @@ TAO_CEC_ProxyPushSupplier::invoke_to_consumer (const TAO_CEC_TypedEvent &typed_e
       CORBA::Object::_duplicate (this->typed_consumer_obj_.in ());
   }
 
+  TAO_CEC_ConsumerControl *control =
+               this->typed_event_channel_->consumer_control ();
+
   // Create the DII request
-  ACE_TRY
+  try
     {
       typed_consumer_obj_->_create_request (0, // ctx
                                             typed_event.operation_,
@@ -711,58 +720,47 @@ TAO_CEC_ProxyPushSupplier::invoke_to_consumer (const TAO_CEC_TypedEvent &typed_e
                                             0, // exception_list,
                                             0, // context_list,
                                             target_request.inout(),
-                                            0
-                                            ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                            0);
 
       // Call the DII invoke for the operation on the target object
-      target_request->invoke (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      target_request->invoke ();
+
+      // Inform the control that we were able to invoke something
+      control->successful_transmission(this);
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, not_used)
+  catch (const CORBA::OBJECT_NOT_EXIST& not_used)
     {
       if (TAO_debug_level >= 4)
         {
-          ACE_PRINT_EXCEPTION (not_used, "during TAO_CEC_ProxyPushSupplier::invoke_to_consumer");
+          not_used._tao_print_exception (
+            "during TAO_CEC_ProxyPushSupplier::invoke_to_consumer");
         }
-
-      TAO_CEC_ConsumerControl *control =
-        this->typed_event_channel_->consumer_control ();
-
-      control->consumer_not_exist (this ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      control->consumer_not_exist (this);
     }
-  ACE_CATCH (CORBA::SystemException, sysex)
+  catch (CORBA::SystemException& sysex)
     {
       if (TAO_debug_level >= 4)
         {
-          ACE_PRINT_EXCEPTION (sysex, "during TAO_CEC_ProxyPushSupplier::invoke_to_consumer");
+          sysex._tao_print_exception (
+            "during TAO_CEC_ProxyPushSupplier::invoke_to_consumer");
         }
-
-      TAO_CEC_ConsumerControl *control =
-        this->typed_event_channel_->consumer_control ();
-
       control->system_exception (this,
-                                 sysex
-                                 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                 sysex);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
       // Shouldn't happen, but does not hurt
       if (TAO_debug_level >= 4)
         {
-          ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                               "ACE_ANY_EXCEPTION raised during TAO_CEC_ProxyPushSupplier::invoke_to_consumer");
+          ex._tao_print_exception (
+            "ex raised during TAO_CEC_ProxyPushSupplier::invoke_to_consumer");
         }
     }
-  ACE_ENDTRY;
 }
 
 void
 TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer (
-    const TAO_CEC_TypedEvent& typed_event
-    ACE_ENV_ARG_DECL)
+    const TAO_CEC_TypedEvent& typed_event)
 {
   CORBA::Object_var typed_consumer_obj;
 
@@ -784,8 +782,11 @@ TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer (
       CORBA::Object::_duplicate (this->typed_consumer_obj_.in ());
   }
 
+  TAO_CEC_ConsumerControl *control =
+                  this->typed_event_channel_->consumer_control ();
+
   // Create the DII request
-  ACE_TRY
+  try
     {
       typed_consumer_obj_->_create_request (0, // ctx
                                             typed_event.operation_,
@@ -794,65 +795,53 @@ TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer (
                                             0, // exception_list,
                                             0, // context_list,
                                             target_request.inout(),
-                                            0
-                                            ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                            0);
 
       // Call the DII invoke for the operation on the target object
-      target_request->invoke (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      target_request->invoke ();
+
+      // Inform the control that we were able to invoke something
+      control->successful_transmission(this);
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, not_used)
+  catch (const CORBA::OBJECT_NOT_EXIST& not_used)
     {
       if (TAO_debug_level >= 4)
         {
-          ACE_PRINT_EXCEPTION (not_used, "during TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer");
+          not_used._tao_print_exception (
+            "during TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer");
         }
-
-      TAO_CEC_ConsumerControl *control =
-        this->typed_event_channel_->consumer_control ();
-
-      control->consumer_not_exist (this ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      control->consumer_not_exist (this);
     }
-  ACE_CATCH (CORBA::SystemException, sysex)
+  catch (CORBA::SystemException& sysex)
     {
       if (TAO_debug_level >= 4)
         {
-          ACE_PRINT_EXCEPTION (sysex, "during TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer");
+          sysex._tao_print_exception (
+            "during TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer");
         }
-
-      TAO_CEC_ConsumerControl *control =
-        this->typed_event_channel_->consumer_control ();
-
       control->system_exception (this,
-                                 sysex
-                                 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                 sysex);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
       if (TAO_debug_level >= 4)
         {
-          ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                               "ACE_ANY_EXCEPTION raised during TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer");
+          ex._tao_print_exception (
+            "ex raised during TAO_CEC_ProxyPushSupplier::reactive_invoke_to_consumer");
         }
     }
-  ACE_ENDTRY;
 }
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
 CORBA::Boolean
 TAO_CEC_ProxyPushSupplier::consumer_non_existent (
-      CORBA::Boolean_out disconnected
-      ACE_ENV_ARG_DECL)
+      CORBA::Boolean_out disconnected)
 {
   CORBA::Object_var consumer;
   {
     ACE_GUARD_THROW_EX (
         ACE_Lock, ace_mon, *this->lock_,
         CORBA::INTERNAL ());
-    ACE_CHECK_RETURN (0);
 
     disconnected = 0;
     if (this->is_connected_i () == 0)
@@ -864,64 +853,49 @@ TAO_CEC_ProxyPushSupplier::consumer_non_existent (
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
     if (this->is_typed_ec () )
       {
-        if (CORBA::is_nil (this->typed_consumer_.in ()))
+        if (CORBA::is_nil (this->nopolicy_typed_consumer_.in ()))
           {
             return 0;
           }
-        consumer = CORBA::Object::_duplicate (this->typed_consumer_.in ());
+        consumer = CORBA::Object::_duplicate
+          (this->nopolicy_typed_consumer_.in ());
       }
     else
       {
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
-    if (CORBA::is_nil (this->consumer_.in ()))
+    if (CORBA::is_nil (this->nopolicy_consumer_.in ()))
       {
         return 0;
       }
-    consumer = CORBA::Object::_duplicate (this->consumer_.in ());
+    consumer = CORBA::Object::_duplicate (this->nopolicy_consumer_.in ());
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
       } /* ! this->is_typed_ec */
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
   }
 
 #if (TAO_HAS_MINIMUM_CORBA == 0)
-  return consumer->_non_existent (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return consumer->_non_existent ();
 #else
   return 0;
 #endif /* TAO_HAS_MINIMUM_CORBA */
 }
 
 PortableServer::POA_ptr
-TAO_CEC_ProxyPushSupplier::_default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPushSupplier::_default_POA (void)
 {
   return PortableServer::POA::_duplicate (this->default_POA_.in ());
 }
 
 void
-TAO_CEC_ProxyPushSupplier::_add_ref (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPushSupplier::_add_ref (void)
 {
   this->_incr_refcnt ();
 }
 
 void
-TAO_CEC_ProxyPushSupplier::_remove_ref (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_CEC_ProxyPushSupplier::_remove_ref (void)
 {
   this->_decr_refcnt ();
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class TAO_ESF_RefCount_Guard<CORBA::ULong>;
-template class TAO_ESF_Proxy_RefCount_Guard<TAO_CEC_EventChannel,TAO_CEC_ProxyPushSupplier>;
-#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-template class TAO_ESF_Proxy_RefCount_Guard<TAO_CEC_TypedEventChannel,TAO_CEC_ProxyPushSupplier>;
-#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate TAO_ESF_RefCount_Guard<CORBA::ULong>
-#pragma instantiate TAO_ESF_Proxy_RefCount_Guard<TAO_CEC_EventChannel,TAO_CEC_ProxyPushSupplier>
-#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-#pragma instantiate TAO_ESF_Proxy_RefCount_Guard<TAO_CEC_TypedEventChannel,TAO_CEC_ProxyPushSupplier>
-#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
