@@ -1,32 +1,42 @@
-// CEC_Reactive_ConsumerControl.cpp,v 1.18 2005/04/18 11:28:33 jwillemsen Exp
+// $Id: CEC_Reactive_ConsumerControl.cpp 76626 2007-01-26 13:50:03Z elliott_c $
 
-#include "CEC_Reactive_ConsumerControl.h"
-#include "CEC_EventChannel.h"
-#include "CEC_ConsumerAdmin.h"
+// Note: This class controls the behaviour of consumers connected to both
+// the Typed and Un-typed Event Channels.  A check must be made in the code
+// to ensure the correct EC is referenced.
+
+#include "orbsvcs/CosEvent/CEC_EventChannel.h"
+#include "orbsvcs/CosEvent/CEC_ConsumerAdmin.h"
+#include "orbsvcs/CosEvent/CEC_Reactive_ConsumerControl.h"
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-#include "CEC_TypedEventChannel.h"
-#include "CEC_TypedConsumerAdmin.h"
+#include "orbsvcs/CosEvent/CEC_TypedEventChannel.h"
+#include "orbsvcs/CosEvent/CEC_TypedConsumerAdmin.h"
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
-#include "CEC_ProxyPushSupplier.h"
-#include "CEC_ProxyPullSupplier.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPushSupplier.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPullSupplier.h"
 
 #include "orbsvcs/Time_Utilities.h"
 
+#if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 #include "tao/Messaging/Messaging.h"
-#include "tao/ORB_Core.h"
+#endif
 
+#include "tao/ORB_Core.h"
+#include "tao/debug.h"
 #include "ace/Reactor.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "CEC_Reactive_ConsumerControl.i"
+#include "orbsvcs/CosEvent/CEC_Reactive_ConsumerControl.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (CosEvent,
            CEC_Reactive_ConsumerControl,
-           "CEC_Reactive_ConsumerControl.cpp,v 1.18 2005/04/18 11:28:33 jwillemsen Exp")
+           "$Id: CEC_Reactive_ConsumerControl.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+// TAO_CEC_Reactive_ConsumerControl constructor for the Un-typed EC
 TAO_CEC_Reactive_ConsumerControl::
      TAO_CEC_Reactive_ConsumerControl (const ACE_Time_Value &rate,
                                        const ACE_Time_Value &timeout,
@@ -38,6 +48,9 @@ TAO_CEC_Reactive_ConsumerControl::
     retries_ (retries),
     adapter_ (this),
     event_channel_ (ec),
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+    typed_event_channel_ (0),
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
     orb_ (CORBA::ORB::_duplicate (orb))
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
    // Initialise timer_id_ to an invalid timer id, so that in case we don't
@@ -49,6 +62,7 @@ TAO_CEC_Reactive_ConsumerControl::
     this->orb_->orb_core ()->reactor ();
 }
 
+// TAO_CEC_Reactive_ConsumerControl constructor for the Typed EC
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
 TAO_CEC_Reactive_ConsumerControl::
      TAO_CEC_Reactive_ConsumerControl (const ACE_Time_Value &rate,
@@ -60,6 +74,7 @@ TAO_CEC_Reactive_ConsumerControl::
     timeout_ (timeout),
     retries_ (retries),
     adapter_ (this),
+    event_channel_ (0),
     typed_event_channel_ (ec),
     orb_ (CORBA::ORB::_duplicate (orb))
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
@@ -78,30 +93,25 @@ TAO_CEC_Reactive_ConsumerControl::~TAO_CEC_Reactive_ConsumerControl (void)
 }
 
 void
-TAO_CEC_Reactive_ConsumerControl::query_consumers (
-      ACE_ENV_SINGLE_ARG_DECL)
+TAO_CEC_Reactive_ConsumerControl::query_consumers ()
 {
   TAO_CEC_Ping_Push_Consumer push_worker (this);
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
   if (this->typed_event_channel_)
     {
-      this->typed_event_channel_->typed_consumer_admin ()->for_each (&push_worker
-                                                                     ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      // Typed EC
+      this->typed_event_channel_->typed_consumer_admin ()->for_each (&push_worker);
     }
   else
     {
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
-  this->event_channel_->consumer_admin ()->for_each (&push_worker
-                                                     ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  // Un-typed EC
+  this->event_channel_->consumer_admin ()->for_each (&push_worker);
 
   TAO_CEC_Ping_Pull_Consumer pull_worker (this);
-  this->event_channel_->consumer_admin ()->for_each (&pull_worker
-                                                     ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->event_channel_->consumer_admin ()->for_each (&pull_worker);
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
     }
@@ -113,6 +123,27 @@ TAO_CEC_Reactive_ConsumerControl::need_to_disconnect (
                                     PortableServer::ServantBase* proxy)
 {
   bool disconnect = true;
+
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+  if (this->typed_event_channel_)
+    {
+      // Typed EC
+      TAO_CEC_TypedEventChannel::ServantRetryMap::ENTRY* entry = 0;
+      if (this->typed_event_channel_->
+          get_servant_retry_map ().find (proxy, entry) == 0)
+        {
+          ++entry->int_id_;
+          if (entry->int_id_ <= this->retries_)
+            {
+              disconnect = false;
+            }
+        }
+    }
+  else
+    {
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
+  // Un-typed EC
   TAO_CEC_EventChannel::ServantRetryMap::ENTRY* entry = 0;
   if (this->event_channel_->
       get_servant_retry_map ().find (proxy, entry) == 0)
@@ -124,6 +155,10 @@ TAO_CEC_Reactive_ConsumerControl::need_to_disconnect (
         }
     }
 
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+    }
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
   return disconnect;
 }
 
@@ -131,12 +166,34 @@ void
 TAO_CEC_Reactive_ConsumerControl::successful_transmission (
                                     PortableServer::ServantBase* proxy)
 {
+
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+  if (this->typed_event_channel_)
+    {
+      // Typed EC
+      TAO_CEC_TypedEventChannel::ServantRetryMap::ENTRY* entry = 0;
+      if (this->typed_event_channel_->
+          get_servant_retry_map ().find (proxy, entry) == 0)
+        {
+          entry->int_id_ = 0;
+        }
+    }
+  else
+    {
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
+  // Un-typed EC
   TAO_CEC_EventChannel::ServantRetryMap::ENTRY* entry = 0;
   if (this->event_channel_->
       get_servant_retry_map ().find (proxy, entry) == 0)
     {
       entry->int_id_ = 0;
     }
+
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+    }
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
 }
 
 void
@@ -144,67 +201,53 @@ TAO_CEC_Reactive_ConsumerControl::handle_timeout (
       const ACE_Time_Value &,
       const void *)
 {
-  ACE_TRY_NEW_ENV
+  try
     {
       // Query the state of the Current object *before* we initiate
       // the iteration...
       CORBA::PolicyTypeSeq types;
       CORBA::PolicyList_var policies =
-        this->policy_current_->get_policy_overrides (types
-                                                     ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        this->policy_current_->get_policy_overrides (types);
 
       // Change the timeout
       this->policy_current_->set_policy_overrides (this->policy_list_,
-                                                   CORBA::ADD_OVERRIDE
-                                                   ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                                   CORBA::ADD_OVERRIDE);
 
-      ACE_TRY_EX (query)
+      try
         {
           // Query the state of the consumers...
-          this->query_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK_EX (query);
+          this->query_consumers ();
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception&)
         {
           // Ignore all exceptions
         }
-      ACE_ENDTRY;
 
       this->policy_current_->set_policy_overrides (policies.in (),
-                                                   CORBA::SET_OVERRIDE
-                                                   ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                                   CORBA::SET_OVERRIDE);
       for (CORBA::ULong i = 0; i != policies->length (); ++i)
         {
-          policies[i]->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          policies[i]->destroy ();
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 
 int
 TAO_CEC_Reactive_ConsumerControl::activate (void)
 {
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
-  ACE_TRY_NEW_ENV
+  try
     {
       // Get the PolicyCurrent object
       CORBA::Object_var tmp =
-        this->orb_->resolve_initial_references ("PolicyCurrent"
-                                                ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        this->orb_->resolve_initial_references ("PolicyCurrent");
 
       this->policy_current_ =
-        CORBA::PolicyCurrent::_narrow (tmp.in ()
-                                       ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CORBA::PolicyCurrent::_narrow (tmp.in ());
 
       // Pre-compute the policy list to the set the right timeout
       // value...
@@ -219,9 +262,7 @@ TAO_CEC_Reactive_ConsumerControl::activate (void)
       this->policy_list_[0] =
         this->orb_->create_policy (
                Messaging::RELATIVE_RT_TIMEOUT_POLICY_TYPE,
-               any
-               ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+               any);
 
       // Only schedule the timer, when the rate is not zero
       if (this->rate_ != ACE_Time_Value::zero)
@@ -237,11 +278,10 @@ TAO_CEC_Reactive_ConsumerControl::activate (void)
          return -1;
       }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       return -1;
     }
-  ACE_ENDTRY;
 #endif /* TAO_HAS_CORBA_MESSAGING */
 
   return 0;
@@ -261,61 +301,64 @@ TAO_CEC_Reactive_ConsumerControl::shutdown (void)
 
 void
 TAO_CEC_Reactive_ConsumerControl::consumer_not_exist (
-      TAO_CEC_ProxyPushSupplier *proxy
-      ACE_ENV_ARG_DECL)
+      TAO_CEC_ProxyPushSupplier *proxy)
 {
-  ACE_TRY
+  try
     {
-      proxy->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      proxy->disconnect_push_supplier ();
+
+      if (TAO_debug_level >= 10)
+        {
+          ACE_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("ProxyPushSupplier disconnected due to consumer_not_exist\n")));
+        }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                           "Reactive_ConsumerControl::consumer_not_exist");
+      ex._tao_print_exception (
+        ACE_TEXT ("Reactive_ConsumerControl::consumer_not_exist"));
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 
 void
 TAO_CEC_Reactive_ConsumerControl::consumer_not_exist (
-      TAO_CEC_ProxyPullSupplier *proxy
-      ACE_ENV_ARG_DECL)
+      TAO_CEC_ProxyPullSupplier *proxy)
 {
-  ACE_TRY
+  try
     {
-      proxy->disconnect_pull_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      proxy->disconnect_pull_supplier ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                           "Reactive_ConsumerControl::consumer_not_exist");
+      ex._tao_print_exception (
+        ACE_TEXT ("Reactive_ConsumerControl::consumer_not_exist"));
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 
 void
 TAO_CEC_Reactive_ConsumerControl::system_exception (
       TAO_CEC_ProxyPushSupplier *proxy,
-      CORBA::SystemException & /* exception */
-      ACE_ENV_ARG_DECL)
+      CORBA::SystemException & /* exception */)
 {
-  ACE_TRY
+  try
     {
       if (this->need_to_disconnect (proxy))
         {
-          proxy->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          proxy->disconnect_push_supplier ();
+
+          if (TAO_debug_level >= 10)
+            {
+              ACE_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("ProxyPushSupplier disconnected due to consumer_not_exist\n")));
+            }
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 
 // ****************************************************************
@@ -338,78 +381,65 @@ TAO_CEC_ConsumerControl_Adapter::handle_timeout (
 // ****************************************************************
 
 void
-TAO_CEC_Ping_Push_Consumer::work (TAO_CEC_ProxyPushSupplier *supplier
-                                  ACE_ENV_ARG_DECL)
+TAO_CEC_Ping_Push_Consumer::work (TAO_CEC_ProxyPushSupplier *supplier)
 {
-  ACE_TRY
+  try
     {
       CORBA::Boolean disconnected;
       CORBA::Boolean non_existent =
-        supplier->consumer_non_existent (disconnected
-                                         ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        supplier->consumer_non_existent (disconnected);
       if (non_existent && !disconnected)
         {
-          this->control_->consumer_not_exist (supplier ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->consumer_not_exist (supplier);
         }
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, ex)
+  catch (const CORBA::OBJECT_NOT_EXIST& )
     {
-      this->control_->consumer_not_exist (supplier ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->control_->consumer_not_exist (supplier);
     }
-  ACE_CATCH (CORBA::TRANSIENT, transient)
+  catch (const CORBA::TRANSIENT& )
     {
       if (this->control_->need_to_disconnect (supplier))
         {
-          this->control_->consumer_not_exist (supplier ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->consumer_not_exist (supplier);
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 
 // ****************************************************************
 
 void
-TAO_CEC_Ping_Pull_Consumer::work (TAO_CEC_ProxyPullSupplier *supplier
-                                  ACE_ENV_ARG_DECL)
+TAO_CEC_Ping_Pull_Consumer::work (TAO_CEC_ProxyPullSupplier *supplier)
 {
-  ACE_TRY
+  try
     {
       CORBA::Boolean disconnected;
       CORBA::Boolean non_existent =
-        supplier->consumer_non_existent (disconnected
-                                         ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        supplier->consumer_non_existent (disconnected);
       if (non_existent && !disconnected)
         {
-          this->control_->consumer_not_exist (supplier ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->consumer_not_exist (supplier);
         }
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, ex)
+  catch (const CORBA::OBJECT_NOT_EXIST& )
     {
-      this->control_->consumer_not_exist (supplier ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->control_->consumer_not_exist (supplier);
     }
-  ACE_CATCH (CORBA::TRANSIENT, transient)
+  catch (const CORBA::TRANSIENT& )
     {
       if (this->control_->need_to_disconnect (supplier))
         {
-          this->control_->consumer_not_exist (supplier ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->consumer_not_exist (supplier);
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
