@@ -1,9 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file   CEC_Reactive_ConsumerControl.h
  *
- *  CEC_Reactive_ConsumerControl.h,v 1.21 2005/03/24 09:22:45 jwillemsen Exp
+ *  $Id: CEC_Reactive_ConsumerControl.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -19,7 +20,11 @@
 
 #include /**/ "ace/pre.h"
 
-#include "CEC_ConsumerControl.h"
+#include "orbsvcs/CosEvent/CEC_ConsumerControl.h"
+
+#if !defined (ACE_LACKS_PRAGMA_ONCE)
+# pragma once
+#endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #include "orbsvcs/ESF/ESF_Worker.h"
 
@@ -27,9 +32,8 @@
 
 #include "ace/Event_Handler.h"
 
-#if !defined (ACE_LACKS_PRAGMA_ONCE)
-# pragma once
-#endif /* ACE_LACKS_PRAGMA_ONCE */
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_CEC_EventChannel;
 
@@ -107,13 +111,10 @@ public:
   // = Documented in TAO_CEC_ConsumerControl
   virtual int activate (void);
   virtual int shutdown (void);
-  virtual void consumer_not_exist (TAO_CEC_ProxyPushSupplier *proxy
-                                   ACE_ENV_ARG_DECL_NOT_USED);
-  virtual void consumer_not_exist (TAO_CEC_ProxyPullSupplier *proxy
-                                   ACE_ENV_ARG_DECL_NOT_USED);
+  virtual void consumer_not_exist (TAO_CEC_ProxyPushSupplier *proxy);
+  virtual void consumer_not_exist (TAO_CEC_ProxyPullSupplier *proxy);
   virtual void system_exception (TAO_CEC_ProxyPushSupplier *proxy,
-                                 CORBA::SystemException &
-                                 ACE_ENV_ARG_DECL_NOT_USED);
+                                 CORBA::SystemException &);
 
   /// Do we need to disconnect this supplier?  The parameter type for
   /// proxy is PortableServer::ServantBase* due to the fact that this
@@ -127,7 +128,7 @@ public:
 private:
   /// Check if the consumers still exists.  It is a helper method for
   /// handle_timeout() to isolate the exceptions.
-  void query_consumers (ACE_ENV_SINGLE_ARG_DECL);
+  void query_consumers (void);
 
 private:
   /// The polling rate
@@ -176,8 +177,7 @@ class TAO_CEC_Ping_Push_Consumer
 public:
   TAO_CEC_Ping_Push_Consumer (TAO_CEC_ConsumerControl *control);
 
-  virtual void work (TAO_CEC_ProxyPushSupplier *supplier
-                     ACE_ENV_ARG_DECL);
+  virtual void work (TAO_CEC_ProxyPushSupplier *supplier);
 
 private:
   TAO_CEC_ConsumerControl *control_;
@@ -191,15 +191,16 @@ class TAO_CEC_Ping_Pull_Consumer
 public:
   TAO_CEC_Ping_Pull_Consumer (TAO_CEC_ConsumerControl *control);
 
-  virtual void work (TAO_CEC_ProxyPullSupplier *supplier
-                     ACE_ENV_ARG_DECL);
+  virtual void work (TAO_CEC_ProxyPullSupplier *supplier);
 
 private:
   TAO_CEC_ConsumerControl *control_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "CEC_Reactive_ConsumerControl.i"
+#include "orbsvcs/CosEvent/CEC_Reactive_ConsumerControl.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
