@@ -1,33 +1,43 @@
-// CEC_Reactive_SupplierControl.cpp,v 1.18 2005/04/18 11:29:20 jwillemsen Exp
+// $Id: CEC_Reactive_SupplierControl.cpp 76626 2007-01-26 13:50:03Z elliott_c $
 
-#include "CEC_Reactive_SupplierControl.h"
-#include "CEC_EventChannel.h"
-#include "CEC_SupplierAdmin.h"
-#include "CEC_ProxyPushConsumer.h"
+// Note: This class controls the behaviour of suppliers connected to both
+// the Typed and Un-typed Event Channels.  A check must be made in the code
+// to ensure the correct EC is referenced.
+
+#include "orbsvcs/CosEvent/CEC_EventChannel.h"
+#include "orbsvcs/CosEvent/CEC_SupplierAdmin.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPushConsumer.h"
+#include "orbsvcs/CosEvent/CEC_Reactive_SupplierControl.h"
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
-#include "CEC_TypedEventChannel.h"
-#include "CEC_TypedSupplierAdmin.h"
-#include "CEC_TypedProxyPushConsumer.h"
+#include "orbsvcs/CosEvent/CEC_TypedEventChannel.h"
+#include "orbsvcs/CosEvent/CEC_TypedSupplierAdmin.h"
+#include "orbsvcs/CosEvent/CEC_TypedProxyPushConsumer.h"
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
-#include "CEC_ProxyPullConsumer.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPullConsumer.h"
 
 #include "orbsvcs/Time_Utilities.h"
 
+#if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 #include "tao/Messaging/Messaging.h"
+#endif
+
 #include "tao/ORB_Core.h"
 
 #include "ace/Reactor.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "CEC_Reactive_SupplierControl.i"
+#include "orbsvcs/CosEvent/CEC_Reactive_SupplierControl.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (CosEvent,
            CEC_Reactive_SupplierControl,
-           "CEC_Reactive_SupplierControl.cpp,v 1.18 2005/04/18 11:29:20 jwillemsen Exp")
+           "$Id: CEC_Reactive_SupplierControl.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+// TAO_CEC_Reactive_SupplierControl constructor for the Un-typed EC
 TAO_CEC_Reactive_SupplierControl::
      TAO_CEC_Reactive_SupplierControl (const ACE_Time_Value &rate,
                                        const ACE_Time_Value &timeout,
@@ -39,6 +49,9 @@ TAO_CEC_Reactive_SupplierControl::
     retries_ (retries),
     adapter_ (this),
     event_channel_ (ec),
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+    typed_event_channel_ (0),
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
     orb_ (CORBA::ORB::_duplicate (orb))
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
    // Initialise timer_id_ to an invalid timer id, so that in case we don't
@@ -50,6 +63,7 @@ TAO_CEC_Reactive_SupplierControl::
     this->orb_->orb_core ()->reactor ();
 }
 
+// TAO_CEC_Reactive_SupplierControl constructor for the Typed EC
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
 TAO_CEC_Reactive_SupplierControl::
      TAO_CEC_Reactive_SupplierControl (const ACE_Time_Value &rate,
@@ -61,6 +75,7 @@ TAO_CEC_Reactive_SupplierControl::
     timeout_ (timeout),
     retries_ (retries),
     adapter_ (this),
+    event_channel_ (0),
     typed_event_channel_ (ec),
     orb_ (CORBA::ORB::_duplicate (orb))
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
@@ -79,31 +94,26 @@ TAO_CEC_Reactive_SupplierControl::~TAO_CEC_Reactive_SupplierControl (void)
 }
 
 void
-TAO_CEC_Reactive_SupplierControl::query_suppliers (
-      ACE_ENV_SINGLE_ARG_DECL)
+TAO_CEC_Reactive_SupplierControl::query_suppliers ()
 {
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
   if (this->typed_event_channel_)
     {
+      // Typed EC
       TAO_CEC_Ping_Typed_Push_Supplier push_worker (this);
 
-      this->typed_event_channel_->typed_supplier_admin ()->for_each (&push_worker
-                                                                     ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->typed_event_channel_->typed_supplier_admin ()->for_each (&push_worker);
     }
   else
     {
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
+  // Un-typed EC
   TAO_CEC_Ping_Push_Supplier push_worker (this);
-  this->event_channel_->supplier_admin ()->for_each (&push_worker
-                                                     ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->event_channel_->supplier_admin ()->for_each (&push_worker);
 
   TAO_CEC_Ping_Pull_Supplier pull_worker (this);
-  this->event_channel_->supplier_admin ()->for_each (&pull_worker
-                                                     ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->event_channel_->supplier_admin ()->for_each (&pull_worker);
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
     }
@@ -115,6 +125,27 @@ TAO_CEC_Reactive_SupplierControl::need_to_disconnect (
                                     PortableServer::ServantBase* proxy)
 {
   bool disconnect = true;
+
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+  if (this->typed_event_channel_)
+    {
+      // Typed EC
+      TAO_CEC_TypedEventChannel::ServantRetryMap::ENTRY* entry = 0;
+      if (this->typed_event_channel_->
+          get_servant_retry_map ().find (proxy, entry) == 0)
+        {
+          ++entry->int_id_;
+          if (entry->int_id_ <= this->retries_)
+            {
+              disconnect = false;
+            }
+        }
+    }
+  else
+    {
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
+  // Un-typed EC
   TAO_CEC_EventChannel::ServantRetryMap::ENTRY* entry = 0;
   if (this->event_channel_->
       get_servant_retry_map ().find (proxy, entry) == 0)
@@ -126,6 +157,10 @@ TAO_CEC_Reactive_SupplierControl::need_to_disconnect (
         }
     }
 
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+    }
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
   return disconnect;
 }
 
@@ -133,12 +168,33 @@ void
 TAO_CEC_Reactive_SupplierControl::successful_transmission (
                                     PortableServer::ServantBase* proxy)
 {
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+  if (this->typed_event_channel_)
+    {
+      // Typed EC
+      TAO_CEC_TypedEventChannel::ServantRetryMap::ENTRY* entry = 0;
+      if (this->typed_event_channel_->
+          get_servant_retry_map ().find (proxy, entry) == 0)
+        {
+          entry->int_id_ = 0;
+        }
+    }
+  else
+    {
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
+  // Un-typed EC
   TAO_CEC_EventChannel::ServantRetryMap::ENTRY* entry = 0;
   if (this->event_channel_->
       get_servant_retry_map ().find (proxy, entry) == 0)
     {
       entry->int_id_ = 0;
     }
+
+#if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
+    }
+#endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
+
 }
 
 void
@@ -146,67 +202,53 @@ TAO_CEC_Reactive_SupplierControl::handle_timeout (
       const ACE_Time_Value &,
       const void *)
 {
-  ACE_TRY_NEW_ENV
+  try
     {
       // Query the state of the Current object *before* we initiate
       // the iteration...
       CORBA::PolicyTypeSeq types;
       CORBA::PolicyList_var policies =
-        this->policy_current_->get_policy_overrides (types
-                                                     ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        this->policy_current_->get_policy_overrides (types);
 
       // Change the timeout
       this->policy_current_->set_policy_overrides (this->policy_list_,
-                                                   CORBA::ADD_OVERRIDE
-                                                   ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                                   CORBA::ADD_OVERRIDE);
 
-      ACE_TRY_EX (query)
+      try
         {
           // Query the state of the suppliers...
-          this->query_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK_EX (query);
+          this->query_suppliers ();
         }
-      ACE_CATCHANY
+      catch (const CORBA::Exception&)
         {
           // Ignore all exceptions
         }
-      ACE_ENDTRY;
 
       this->policy_current_->set_policy_overrides (policies.in (),
-                                                   CORBA::SET_OVERRIDE
-                                                   ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                                   CORBA::SET_OVERRIDE);
       for (CORBA::ULong i = 0; i != policies->length (); ++i)
         {
-          policies[i]->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          policies[i]->destroy ();
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 
 int
 TAO_CEC_Reactive_SupplierControl::activate (void)
 {
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
-  ACE_TRY_NEW_ENV
+  try
     {
       // Get the PolicyCurrent object
       CORBA::Object_var tmp =
-        this->orb_->resolve_initial_references ("PolicyCurrent"
-                                                ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        this->orb_->resolve_initial_references ("PolicyCurrent");
 
       this->policy_current_ =
-        CORBA::PolicyCurrent::_narrow (tmp.in ()
-                                       ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CORBA::PolicyCurrent::_narrow (tmp.in ());
 
       // Pre-compute the policy list to the set the right timeout
       // value...
@@ -221,9 +263,7 @@ TAO_CEC_Reactive_SupplierControl::activate (void)
       this->policy_list_[0] =
         this->orb_->create_policy (
                Messaging::RELATIVE_RT_TIMEOUT_POLICY_TYPE,
-               any
-               ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+               any);
 
       // Only schedule the timer, when the rate is not zero
       if (this->rate_ != ACE_Time_Value::zero)
@@ -239,11 +279,10 @@ TAO_CEC_Reactive_SupplierControl::activate (void)
           return -1;
       }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       return -1;
     }
-  ACE_ENDTRY;
 #endif /* TAO_HAS_CORBA_MESSAGING */
 
   return 0;
@@ -263,76 +302,64 @@ TAO_CEC_Reactive_SupplierControl::shutdown (void)
 
 void
 TAO_CEC_Reactive_SupplierControl::supplier_not_exist (
-      TAO_CEC_ProxyPushConsumer *proxy
-      ACE_ENV_ARG_DECL)
+      TAO_CEC_ProxyPushConsumer *proxy)
 {
-  ACE_TRY
+  try
     {
-      proxy->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      proxy->disconnect_push_consumer ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
 void
 TAO_CEC_Reactive_SupplierControl::supplier_not_exist (
-      TAO_CEC_TypedProxyPushConsumer *proxy
-      ACE_ENV_ARG_DECL)
+      TAO_CEC_TypedProxyPushConsumer *proxy)
 {
-  ACE_TRY
+  try
     {
-      proxy->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      proxy->disconnect_push_consumer ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
 void
 TAO_CEC_Reactive_SupplierControl::supplier_not_exist (
-      TAO_CEC_ProxyPullConsumer *proxy
-      ACE_ENV_ARG_DECL)
+      TAO_CEC_ProxyPullConsumer *proxy)
 {
-  ACE_TRY
+  try
     {
-      proxy->disconnect_pull_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      proxy->disconnect_pull_consumer ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 
 void
 TAO_CEC_Reactive_SupplierControl::system_exception (
       TAO_CEC_ProxyPullConsumer *proxy,
-      CORBA::SystemException & /* exception */
-      ACE_ENV_ARG_DECL)
+      CORBA::SystemException & /* exception */)
 {
-  ACE_TRY
+  try
     {
       if (this->need_to_disconnect (proxy))
         {
-          proxy->disconnect_pull_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          proxy->disconnect_pull_consumer ();
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions..
     }
-  ACE_ENDTRY;
 }
 
 // ****************************************************************
@@ -355,119 +382,99 @@ TAO_CEC_SupplierControl_Adapter::handle_timeout (
 // ****************************************************************
 
 void
-TAO_CEC_Ping_Push_Supplier::work (TAO_CEC_ProxyPushConsumer *consumer
-                                  ACE_ENV_ARG_DECL)
+TAO_CEC_Ping_Push_Supplier::work (TAO_CEC_ProxyPushConsumer *consumer)
 {
-  ACE_TRY
+  try
     {
       CORBA::Boolean disconnected;
       CORBA::Boolean non_existent =
-        consumer->supplier_non_existent (disconnected
-                                         ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        consumer->supplier_non_existent (disconnected);
       if (non_existent && !disconnected)
         {
-          this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->supplier_not_exist (consumer);
         }
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, ex)
+  catch (const CORBA::OBJECT_NOT_EXIST& )
     {
-      this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->control_->supplier_not_exist (consumer);
     }
-  ACE_CATCH (CORBA::TRANSIENT, transient)
+  catch (const CORBA::TRANSIENT& )
     {
       if (this->control_->need_to_disconnect (consumer))
         {
-          this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->supplier_not_exist (consumer);
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 
 // ****************************************************************
 
 #if defined (TAO_HAS_TYPED_EVENT_CHANNEL)
 void
-TAO_CEC_Ping_Typed_Push_Supplier::work (TAO_CEC_TypedProxyPushConsumer *consumer
-                                        ACE_ENV_ARG_DECL)
+TAO_CEC_Ping_Typed_Push_Supplier::work (TAO_CEC_TypedProxyPushConsumer *consumer)
 {
-  ACE_TRY
+  try
     {
       CORBA::Boolean disconnected;
       CORBA::Boolean non_existent =
-        consumer->supplier_non_existent (disconnected
-                                         ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        consumer->supplier_non_existent (disconnected);
       if (non_existent && !disconnected)
         {
-          this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->supplier_not_exist (consumer);
         }
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, ex)
+  catch (const CORBA::OBJECT_NOT_EXIST& )
     {
-      this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->control_->supplier_not_exist (consumer);
     }
-  ACE_CATCH (CORBA::TRANSIENT, transient)
+  catch (const CORBA::TRANSIENT& )
     {
       if (this->control_->need_to_disconnect (consumer))
         {
-          this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->supplier_not_exist (consumer);
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 #endif /* TAO_HAS_TYPED_EVENT_CHANNEL */
 
 // ****************************************************************
 
 void
-TAO_CEC_Ping_Pull_Supplier::work (TAO_CEC_ProxyPullConsumer *consumer
-                                  ACE_ENV_ARG_DECL)
+TAO_CEC_Ping_Pull_Supplier::work (TAO_CEC_ProxyPullConsumer *consumer)
 {
-  ACE_TRY
+  try
     {
       CORBA::Boolean disconnected;
       CORBA::Boolean non_existent =
-        consumer->supplier_non_existent (disconnected
-                                         ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        consumer->supplier_non_existent (disconnected);
       if (non_existent && !disconnected)
         {
-          this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->supplier_not_exist (consumer);
         }
     }
-  ACE_CATCH (CORBA::OBJECT_NOT_EXIST, ex)
+  catch (const CORBA::OBJECT_NOT_EXIST& )
     {
-      this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->control_->supplier_not_exist (consumer);
     }
-  ACE_CATCH (CORBA::TRANSIENT, transient)
+  catch (const CORBA::TRANSIENT& )
     {
       if (this->control_->need_to_disconnect (consumer))
         {
-          this->control_->supplier_not_exist (consumer ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          this->control_->supplier_not_exist (consumer);
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore all exceptions
     }
-  ACE_ENDTRY;
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
