@@ -1,9 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file   CEC_SupplierAdmin.h
  *
- *  CEC_SupplierAdmin.h,v 1.16 2004/09/08 19:22:44 jtc Exp
+ *  $Id: CEC_SupplierAdmin.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -13,7 +14,6 @@
  */
 //=============================================================================
 
-
 #ifndef TAO_CEC_SUPPLIERADMIN_H
 #define TAO_CEC_SUPPLIERADMIN_H
 
@@ -27,9 +27,11 @@
 
 #include "orbsvcs/ESF/ESF_Proxy_Admin.h"
 
-#include "CEC_ProxyPushConsumer.h"
-#include "CEC_ProxyPullConsumer.h"
-#include "event_serv_export.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPushConsumer.h"
+#include "orbsvcs/CosEvent/CEC_ProxyPullConsumer.h"
+#include "orbsvcs/CosEvent/event_serv_export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_CEC_EventChannel;
 
@@ -49,7 +51,7 @@ class TAO_CEC_EventChannel;
  * externally.
  * = TODO
  */
-class TAO_Event_Serv_Export TAO_CEC_SupplierAdmin 
+class TAO_Event_Serv_Export TAO_CEC_SupplierAdmin
   : public POA_CosEventChannelAdmin::SupplierAdmin
 {
 public:
@@ -60,41 +62,31 @@ public:
   virtual ~TAO_CEC_SupplierAdmin (void);
 
   /// For each elements call <worker->work()>.
-  void for_each (TAO_ESF_Worker<TAO_CEC_ProxyPushConsumer> *worker
-                 ACE_ENV_ARG_DECL);
+  void for_each (TAO_ESF_Worker<TAO_CEC_ProxyPushConsumer> *worker);
 
   /// For each elements call <worker->work()>.
-  void for_each (TAO_ESF_Worker<TAO_CEC_ProxyPullConsumer> *worker
-                 ACE_ENV_ARG_DECL);
+  void for_each (TAO_ESF_Worker<TAO_CEC_ProxyPullConsumer> *worker);
 
   /// Keep track of connected consumers.
-  virtual void connected (TAO_CEC_ProxyPushConsumer*
-                          ACE_ENV_ARG_DECL_NOT_USED);
-  virtual void reconnected (TAO_CEC_ProxyPushConsumer*
-                            ACE_ENV_ARG_DECL_NOT_USED);
-  virtual void disconnected (TAO_CEC_ProxyPushConsumer*
-                             ACE_ENV_ARG_DECL_NOT_USED);
-  virtual void connected (TAO_CEC_ProxyPullConsumer*
-                          ACE_ENV_ARG_DECL_NOT_USED);
-  virtual void reconnected (TAO_CEC_ProxyPullConsumer*
-                            ACE_ENV_ARG_DECL_NOT_USED);
-  virtual void disconnected (TAO_CEC_ProxyPullConsumer*
-                             ACE_ENV_ARG_DECL_NOT_USED);
+  virtual void connected (TAO_CEC_ProxyPushConsumer*);
+  virtual void reconnected (TAO_CEC_ProxyPushConsumer*);
+  virtual void disconnected (TAO_CEC_ProxyPushConsumer*);
+  virtual void connected (TAO_CEC_ProxyPullConsumer*);
+  virtual void reconnected (TAO_CEC_ProxyPullConsumer*);
+  virtual void disconnected (TAO_CEC_ProxyPullConsumer*);
 
   /// The event channel is shutting down, inform all the consumers of
   /// this
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  virtual void shutdown (void);
 
   // = The CosEventChannelAdmin::SupplierAdmin methods...
   virtual CosEventChannelAdmin::ProxyPushConsumer_ptr
-      obtain_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-          ACE_THROW_SPEC ((CORBA::SystemException));
+      obtain_push_consumer (void);
   virtual CosEventChannelAdmin::ProxyPullConsumer_ptr
-      obtain_pull_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-          ACE_THROW_SPEC ((CORBA::SystemException));
+      obtain_pull_consumer (void);
 
   // = The PortableServer::ServantBase methods
-  virtual PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL);
+  virtual PortableServer::POA_ptr _default_POA (void);
 
 private:
   /// The Event Channel we belong to
@@ -103,19 +95,21 @@ private:
   /// The push and pull aspects are implemented using these classes
   TAO_ESF_Proxy_Admin<TAO_CEC_EventChannel,
                       TAO_CEC_ProxyPushConsumer,
-                      CosEventChannelAdmin::ProxyPushConsumer> 
+                      CosEventChannelAdmin::ProxyPushConsumer>
     push_admin_;
   TAO_ESF_Proxy_Admin<TAO_CEC_EventChannel,
                       TAO_CEC_ProxyPullConsumer,
-                      CosEventChannelAdmin::ProxyPullConsumer> 
+                      CosEventChannelAdmin::ProxyPullConsumer>
     pull_admin_;
 
   /// Store the default POA.
   PortableServer::POA_var default_POA_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "CEC_SupplierAdmin.i"
+#include "orbsvcs/CosEvent/CEC_SupplierAdmin.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
