@@ -1,9 +1,11 @@
-// CEC_TypedEvent.h,v 1.6 2004/09/08 19:22:44 jtc Exp
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file   CEC_TypedEvent.h
  *
+ *  $Id: CEC_TypedEvent.h 73791 2006-07-27 20:54:56Z wotte $
+ *
  *  @author Jon Astle (jon@astle45.fsnet.co.uk)
  */
 //=============================================================================
@@ -12,17 +14,20 @@
 #define TAO_CEC_TYPEDEVENT_H_
 #include /**/ "ace/pre.h"
 
-#include "event_serv_export.h"
+#include "orbsvcs/CosEvent/event_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/NVList.h"
+#include "tao/AnyTypeCode/NVList.h"
 #include "tao/CORBA_String.h"
 #include "tao/CORBA_methods.h"
 
 // ****************************************************************
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_CEC_TypedEvent
  *
@@ -53,8 +58,10 @@ private:
   CORBA::String_var operation_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "CEC_TypedEvent.i"
+#include "orbsvcs/CosEvent/CEC_TypedEvent.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
