@@ -1,9 +1,10 @@
-// CEC_TypedProxyPushConsumer.h,v 1.8 2004/09/08 19:57:59 jtc Exp
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file   CEC_TypedProxyPushConsumer.h
  *
+ *  $Id: CEC_TypedProxyPushConsumer.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Jon Astle (jon@astle45.fsnet.co.uk)
  *
@@ -23,7 +24,9 @@
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #include "orbsvcs/ESF/ESF_Worker.h"
-#include "event_serv_export.h"
+#include "orbsvcs/CosEvent/event_serv_export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_CEC_TypedEvent;
 class TAO_CEC_TypedEventChannel;
@@ -39,7 +42,8 @@ public:
 
   //Constructor
   TAO_CEC_TypedProxyPushConsumer (
-      TAO_CEC_TypedEventChannel* typed_event_channel
+      TAO_CEC_TypedEventChannel* typed_event_channel,
+      const ACE_Time_Value &timeout
     );
 
   //Destructor
@@ -47,24 +51,20 @@ public:
 
   /// Activate in the POA
   virtual void activate (
-      CosTypedEventChannelAdmin::TypedProxyPushConsumer_ptr &activated_proxy
-      ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+      CosTypedEventChannelAdmin::TypedProxyPushConsumer_ptr &activated_proxy);
 
   /// Deactivate from the POA
-  virtual void deactivate (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void deactivate (void);
 
   /**
    * Invoke the _non_existent() pseudo-operation on the supplier. If
    * it is disconnected then it returns true and sets the
    * <disconnected> flag.
    */
-  CORBA::Boolean supplier_non_existent (CORBA::Boolean_out disconnected
-                                        ACE_ENV_ARG_DECL);
+  CORBA::Boolean supplier_non_existent (CORBA::Boolean_out disconnected);
 
   /// The event channel is shutting down
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  virtual void shutdown (void);
 
   /// Increment and decrement the reference count.
   CORBA::ULong _incr_refcnt (void);
@@ -72,32 +72,22 @@ public:
 
   // = The CosEventChannelAdmin::ProxyPushConsumer methods (abstract overloads)...
   virtual void connect_push_supplier (
-                CosEventComm::PushSupplier_ptr push_supplier
-                ACE_ENV_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException,
-                       CosEventChannelAdmin::AlreadyConnected));
+                CosEventComm::PushSupplier_ptr push_supplier);
 
-  virtual void push (const CORBA::Any& event
-                     ACE_ENV_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void push (const CORBA::Any& event);
 
-  virtual void invoke (const TAO_CEC_TypedEvent& typed_event
-                       ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void invoke (const TAO_CEC_TypedEvent& typed_event);
 
-  virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_push_consumer (void);
 
   // = The CosTypedEventComm::TypedPushConsumer methods (abstract overloads)...
   virtual CORBA::Object_ptr get_typed_consumer (
-      ACE_ENV_SINGLE_ARG_DECL_NOT_USED
-    )
-      ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
   // = The Servant methods
-  virtual PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL);
-  virtual void _add_ref (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS);
-  virtual void _remove_ref (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS);
+  virtual PortableServer::POA_ptr _default_POA (void);
+  virtual void _add_ref (void);
+  virtual void _remove_ref (void);
 
 protected:
   // The guard needs access to the following protected methods.
@@ -109,19 +99,31 @@ protected:
   /// Release the supplier
   void cleanup_i (void);
 
+  /// Assigns the parameter to both supplier_ and nopolicy_supplier_, and
+  /// applies policies (when appropriate) to supplier_.
+  CosEventComm::PushSupplier_ptr apply_policy
+  (CosEventComm::PushSupplier_ptr pre);
+
 private:
   /// The typed supplier admin, used for activation and memory managment.
   TAO_CEC_TypedEventChannel* typed_event_channel_;
 
+  ACE_Time_Value timeout_;
+
   /// The locking strategy.
   ACE_Lock* lock_;
 
   /// The reference count.
   CORBA::ULong refcount_;
 
-  /// The typed supplier....
+  /// The typed supplier -- use apply_policy() instead of assigning directly to
+  /// typed_supplier_.  This will keep typed_supplier_ and
+  /// nopolicy_typed_supplier_ in sync.
   CosEventComm::PushSupplier_var typed_supplier_;
 
+  /// The typed supplier without any policies applied
+  CosEventComm::PushSupplier_var nopolicy_typed_supplier_;
+
   /// The DSI impl
   TAO_CEC_DynamicImplementationServer* dsi_impl_;
 
@@ -183,8 +185,10 @@ private:
   int locked_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "CEC_TypedProxyPushConsumer.i"
+#include "orbsvcs/CosEvent/CEC_TypedProxyPushConsumer.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
