@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   ESF_Shutdown_Proxy.h
  *
- *  ESF_Shutdown_Proxy.h,v 1.5 2002/01/29 20:20:47 okellogg Exp
+ *  $Id: ESF_Shutdown_Proxy.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -13,12 +14,14 @@
 #ifndef TAO_ESF_SHUTDOWN_PROXY_H
 #define TAO_ESF_SHUTDOWN_PROXY_H
 
-#include "ESF_Worker.h"
+#include "orbsvcs/ESF/ESF_Worker.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /// A worker to invoke the shutdown method of each proxy.
 template<class PROXY>
 class TAO_ESF_Shutdown_Proxy : public TAO_ESF_Worker<PROXY>
@@ -26,18 +29,19 @@ class TAO_ESF_Shutdown_Proxy : public TAO_ESF_Worker<PROXY>
 public:
   TAO_ESF_Shutdown_Proxy (void);
 
-  void work (PROXY *proxy
-             ACE_ENV_ARG_DECL);
+  void work (PROXY *proxy);
 };
 
 // ****************************************************************
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "ESF_Shutdown_Proxy.i"
+#include "orbsvcs/ESF/ESF_Shutdown_Proxy.inl"
 #endif /* __ACE_INLINE__ */
 
 #if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
-#include "ESF_Shutdown_Proxy.cpp"
+#include "orbsvcs/ESF/ESF_Shutdown_Proxy.cpp"
 #endif /* ACE_TEMPLATES_REQUIRE_SOURCE */
 
 #if defined (ACE_TEMPLATES_REQUIRE_PRAGMA)
