@@ -1,8 +1,8 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 /**
  *  @file ECG_CDR_Message_Receiver.h
  *
- *  ECG_CDR_Message_Receiver.h,v 1.7 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: ECG_CDR_Message_Receiver.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *  @author Marina Spivak (marina@atdesk.com)
@@ -13,19 +13,20 @@
 
 #include /**/ "ace/pre.h"
 
-#include "ECG_UDP_Out_Endpoint.h"
+#include "orbsvcs/Event/ECG_UDP_Out_Endpoint.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #include "tao/CDR.h"
-#include "tao/Environment.h"
 
 #include "ace/Hash_Map_Manager.h"
 #include "ace/INET_Addr.h"
 #include "ace/Null_Mutex.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_ECG_CDR_Processor
  *
@@ -305,8 +306,10 @@ private:
   size_t min_purge_count_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(__ACE_INLINE__)
-#include "ECG_CDR_Message_Receiver.i"
+#include "orbsvcs/Event/ECG_CDR_Message_Receiver.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
