@@ -1,13 +1,15 @@
-// ECG_Complex_Address_Server.cpp,v 1.6 2004/12/13 18:02:36 elliott_c Exp
+// $Id: ECG_Complex_Address_Server.cpp 78519 2007-05-29 14:54:16Z mesnier_p $
 
-#include "ECG_Complex_Address_Server.h"
+#include "orbsvcs/Event/ECG_Complex_Address_Server.h"
 #include "ace/SString.h"
 #include "ace/streams.h"
 
 #if !defined(__ACE_INLINE__)
-#include "ECG_Complex_Address_Server.i"
+#include "orbsvcs/Event/ECG_Complex_Address_Server.inl"
 #endif /* __ACE_INLINE__ */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_ECG_Complex_Address_Server::TAO_ECG_Complex_Address_Server (
                                               int is_source_mapping)
   : is_source_mapping_ (is_source_mapping)
@@ -122,9 +124,7 @@ TAO_ECG_Complex_Address_Server::add_entry (const char * key,
 void
 TAO_ECG_Complex_Address_Server::get_addr (
                          const RtecEventComm::EventHeader& header,
-                         RtecUDPAdmin::UDP_Addr_out addr
-                         ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                         RtecUDPAdmin::UDP_Addr_out addr)
 {
   CORBA::Long key;
   if (this->is_source_mapping_)
@@ -136,16 +136,58 @@ TAO_ECG_Complex_Address_Server::get_addr (
   if (this->mcast_mapping_.find (key, mapping_entry) == -1)
     {
       // Key was not found in the mapping.  Use default.
+#if defined (ACE_HAS_IPV6)
+      if (this->default_addr_.get_type() == PF_INET6)
+        throw CORBA::DATA_CONVERSION(0, CORBA::COMPLETED_YES);
+#endif /* ACE_HAS_IPV6 */
       addr.ipaddr = this->default_addr_.get_ip_address ();
       addr.port = this->default_addr_.get_port_number ();
     }
   else
     {
+#if defined (ACE_HAS_IPV6)
+      if (mapping_entry->int_id_.get_type() == PF_INET6)
+        throw CORBA::DATA_CONVERSION(0, CORBA::COMPLETED_YES);
+#endif /* ACE_HAS_IPV6 */
       addr.ipaddr = mapping_entry->int_id_.get_ip_address ();
       addr.port = mapping_entry->int_id_.get_port_number ();
     }
 }
 
+void
+TAO_ECG_Complex_Address_Server::get_address (
+                         const RtecEventComm::EventHeader& header,
+                         RtecUDPAdmin::UDP_Address_out addr)
+{
+  CORBA::Long key;
+  if (this->is_source_mapping_)
+    key = header.source;
+  else
+    key = header.type;
+
+  MAP::ENTRY * mapping_entry = 0;
+  ACE_INET_Addr &src_addr =
+    (this->mcast_mapping_.find (key, mapping_entry) == -1) ?
+    this->default_addr_ : mapping_entry->int_id_;
+#if defined (ACE_HAS_IPV6)
+  if (src_addr.get_type() == PF_INET6)
+    {
+      RtecUDPAdmin::UDP_Addr_v6 v6;
+      sockaddr_in6 *in6 =
+        reinterpret_cast<sockaddr_in6 *>(src_addr.get_addr());
+      ACE_OS::memcpy (v6.ipaddr,&in6->sin6_addr,16);
+      v6.port = src_addr.get_port_number();
+      addr.v6_addr (v6);
+      return;
+    }
+#endif /* ACE_HAS_IPV6 */
+  RtecUDPAdmin::UDP_Addr v4;
+  v4.ipaddr = src_addr.get_ip_address();
+  v4.port = src_addr.get_port_number();
+  addr.v4_addr (v4);
+}
+
+
 void
 TAO_ECG_Complex_Address_Server::dump_content (void)
 {
@@ -165,18 +207,4 @@ TAO_ECG_Complex_Address_Server::dump_content (void)
     }
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_Hash_Map_Manager_Ex<CORBA::Long, ACE_INET_Addr, ACE_Hash<CORBA::Long>, ACE_Equal_To<CORBA::Long>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Entry<CORBA::Long, ACE_INET_Addr>;
-template class ACE_Hash_Map_Iterator_Base_Ex<CORBA::Long, ACE_INET_Addr, ACE_Hash<CORBA::Long>, ACE_Equal_To<CORBA::Long>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator<CORBA::Long,ACE_INET_Addr,ACE_Null_Mutex>;
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_Hash_Map_Manager_Ex<CORBA::Long, ACE_INET_Addr, ACE_Hash<CORBA::Long>, ACE_Equal_To<CORBA::Long>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Entry<CORBA::Long, ACE_INET_Addr>
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<CORBA::Long, ACE_INET_Addr, ACE_Hash<CORBA::Long>, ACE_Equal_To<CORBA::Long>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator<CORBA::Long,ACE_INET_Addr,ACE_Null_Mutex>
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
