@@ -1,4 +1,4 @@
-// $Id: ECG_Mcast_Gateway.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: ECG_Mcast_Gateway.cpp 86192 2009-07-23 17:51:06Z johnnyw $
 
 #include "orbsvcs/Event/ECG_Mcast_Gateway.h"
 
@@ -20,7 +20,7 @@
 #include "orbsvcs/Event/ECG_Mcast_Gateway.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, ECG_Mcast_Gateway, "$Id: ECG_Mcast_Gateway.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+ACE_RCSID(Event, ECG_Mcast_Gateway, "$Id: ECG_Mcast_Gateway.cpp 86192 2009-07-23 17:51:06Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -115,7 +115,7 @@ TAO_ECG_Mcast_Gateway::init (int argc, ACE_TCHAR* argv[])
 
           if (arg_shifter.is_parameter_next ())
             {
-              this->address_server_arg_.set (arg_shifter.get_current ());
+              this->address_server_arg_.set (ACE_TEXT_ALWAYS_CHAR(arg_shifter.get_current ()));
               arg_shifter.consume_arg ();
             }
         }
@@ -222,7 +222,7 @@ TAO_ECG_Mcast_Gateway::init (const char * address_server_arg,
   this->handler_type_ = attr.handler_type;
   this->service_type_ = attr.service_type;
   this->ttl_value_ = attr.ttl_value;
-  this->nic_.set (attr.nic.c_str ());
+  this->nic_.set (ACE_TEXT_CHAR_TO_TCHAR(attr.nic.c_str ()));
   this->ip_multicast_loop_ = attr.ip_multicast_loop;
   this->non_blocking_ = attr.non_blocking;
 
@@ -420,7 +420,7 @@ TAO_ECG_Mcast_Gateway::init_handler (TAO_ECG_Dgram_Handler *receiver,
 {
   TAO_ECG_Refcounted_Handler handler;
 
-  const char * nic =
+  const ACE_TCHAR * nic =
     (this->nic_.length ()) ? this->nic_.c_str () : 0;
   const char * address_server_arg =
     (this->address_server_arg_.length ())
@@ -505,7 +505,7 @@ TAO_ECG_Mcast_Gateway::init_sender (
   if (this->consumer_qos_.dependencies.length () > 0)
     {
       // Client supplied consumer qos.  Use it.
-      this->consumer_qos_.is_gateway = 1;
+      this->consumer_qos_.is_gateway = true;
       sender->connect (this->consumer_qos_);
     }
   else
@@ -518,7 +518,7 @@ TAO_ECG_Mcast_Gateway::init_sender (
                                    0);
       RtecEventChannelAdmin::ConsumerQOS & qos =
         const_cast<RtecEventChannelAdmin::ConsumerQOS &> (consumer_qos_factory.get_ConsumerQOS ());
-      qos.is_gateway = 1;
+      qos.is_gateway = true;
 
       sender->connect (qos);
     }
@@ -551,7 +551,7 @@ TAO_ECG_Mcast_Gateway::init_receiver (
                                0, 1);
   RtecEventChannelAdmin::SupplierQOS & qos =
     const_cast<RtecEventChannelAdmin::SupplierQOS &> (supplier_qos_factory.get_SupplierQOS ());
-  qos.is_gateway = 1;
+  qos.is_gateway = true;
 
   receiver->connect (qos);
 
