@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file ECG_Simple_Address_Server.h
  *
- *  ECG_Simple_Address_Server.h,v 1.6 2005/07/04 08:55:12 jwillemsen Exp
+ *  $Id: ECG_Simple_Address_Server.h 78519 2007-05-29 14:54:16Z mesnier_p $
  *
  *  @author Marina Spivak (marina@atdesk.com)
  *
@@ -13,9 +14,11 @@
 #include /**/ "ace/pre.h"
 
 #include "orbsvcs/RtecUDPAdminS.h"
-#include "EC_Lifetime_Utils_T.h"
+#include "orbsvcs/Event/EC_Lifetime_Utils_T.h"
 #include "ace/INET_Addr.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_ECG_Simple_Address_Server
  *
@@ -41,9 +44,9 @@ public:
 
   // = The RtecUDPAdmin::AddrServer methods
   virtual void get_addr (const RtecEventComm::EventHeader& header,
-                         RtecUDPAdmin::UDP_Addr_out addr
-                         ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+                         RtecUDPAdmin::UDP_Addr_out addr);
+  virtual void get_address (const RtecEventComm::EventHeader& header,
+                            RtecUDPAdmin::UDP_Address_out addr6);
 
 protected:
 
@@ -56,8 +59,10 @@ private:
   ACE_INET_Addr addr_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(__ACE_INLINE__)
-#include "ECG_Simple_Address_Server.i"
+#include "orbsvcs/Event/ECG_Simple_Address_Server.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
