@@ -1,10 +1,12 @@
-// ECG_Simple_Mcast_EH.cpp,v 1.4 2005/01/05 11:08:12 jwillemsen Exp
+// $Id: ECG_Simple_Mcast_EH.cpp 80102 2007-11-27 06:33:52Z johnnyw $
 
-#include "ECG_Simple_Mcast_EH.h"
+#include "orbsvcs/Event/ECG_Simple_Mcast_EH.h"
 #include "ace/Log_Msg.h"
 #include "ace/Reactor.h"
 #include "ace/os_include/os_fcntl.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_ECG_Simple_Mcast_EH::TAO_ECG_Simple_Mcast_EH (TAO_ECG_Dgram_Handler *recv)
   : receiver_ (recv)
 {
@@ -35,10 +37,10 @@ TAO_ECG_Simple_Mcast_EH::open (const char * mcast_addr,
                        mcast_addr),
                       -1);
 
-  if (this->dgram_.subscribe (mcast_group, 1, net_if) != 0)
+  if (this->dgram_.join (mcast_group, 1, net_if) != 0)
     ACE_ERROR_RETURN ((LM_ERROR,
                       "Unable to open mcast handler: error "
-                      "subscribing to %s\n",
+                      "joining to %s\n",
                        mcast_addr),
                       -1);
 
@@ -92,3 +94,5 @@ TAO_ECG_Simple_Mcast_EH::handle_input (ACE_HANDLE /* fd */)
 {
   return this->receiver_->handle_input (this->dgram_);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
