@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  * @file ECG_Simple_Mcast_EH.h
  *
- * ECG_Simple_Mcast_EH.h,v 1.5 2005/05/23 10:50:44 jwillemsen Exp
+ * $Id: ECG_Simple_Mcast_EH.h 71541 2006-03-15 07:52:22Z jtc $
  *
  * @author Marina Spivak <marina@atdesk.com>
  *
@@ -17,10 +18,13 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include /**/ "event_serv_export.h"
-#include "ECG_Adapters.h"
+#include /**/ "orbsvcs/Event/event_serv_export.h"
+#include "orbsvcs/Event/ECG_Adapters.h"
 #include "ace/SOCK_Dgram_Mcast.h"
 
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_ECG_Simple_Mcast_EH
  *
@@ -86,5 +90,7 @@ private:
   TAO_ECG_Dgram_Handler* receiver_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_ECG_SIMPLE_Mcast_EH_H */
