@@ -1,14 +1,16 @@
-// ECG_UDP_EH.cpp,v 1.2 2004/12/13 18:02:36 elliott_c Exp
+// $Id: ECG_UDP_EH.cpp 73791 2006-07-27 20:54:56Z wotte $
 
-#include "ECG_UDP_EH.h"
+#include "orbsvcs/Event/ECG_UDP_EH.h"
 #include "ace/Reactor.h"
 #include "ace/INET_Addr.h"
 
 #if !defined(__ACE_INLINE__)
-#include "ECG_UDP_EH.i"
+#include "orbsvcs/Event/ECG_UDP_EH.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, ECG_UDP_EH, "ECG_UDP_EH.cpp,v 1.2 2004/12/13 18:02:36 elliott_c Exp")
+ACE_RCSID(Event, ECG_UDP_EH, "$Id: ECG_UDP_EH.cpp 73791 2006-07-27 20:54:56Z wotte $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_ECG_UDP_EH::TAO_ECG_UDP_EH (TAO_ECG_Dgram_Handler *recv)
   :  receiver_ (recv)
@@ -82,4 +84,6 @@ TAO_ECG_UDP_EH::handle_input (ACE_HANDLE)
   return this->receiver_->handle_input (this->dgram_);
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 // ****************************************************************
