@@ -1,7 +1,7 @@
 /**
  * @file ECG_UDP_Sender.cpp
  *
- * ECG_UDP_Sender.cpp,v 1.13 2004/08/16 23:53:12 jtc Exp
+ * $Id: ECG_UDP_Sender.cpp 78820 2007-07-07 20:06:46Z sowayaa $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  *
@@ -14,15 +14,17 @@
 #include "tao/CDR.h"
 
 #if !defined(__ACE_INLINE__)
-#include "ECG_UDP_Sender.inl"
+#include "orbsvcs/Event/ECG_UDP_Sender.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (Event,
            ECG_UDP_Sender,
-           "ECG_UDP_Sender.cpp,v 1.13 2004/08/16 23:53:12 jtc Exp")
+           "$Id: ECG_UDP_Sender.cpp 78820 2007-07-07 20:06:46Z sowayaa $")
 
 // ****************************************************************
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_ECG_UDP_Sender::~TAO_ECG_UDP_Sender (void)
 {
 }
@@ -30,25 +32,23 @@ TAO_ECG_UDP_Sender::~TAO_ECG_UDP_Sender (void)
 void
 TAO_ECG_UDP_Sender::init (RtecEventChannelAdmin::EventChannel_ptr lcl_ec,
                           RtecUDPAdmin::AddrServer_ptr addr_server,
-                          TAO_ECG_Refcounted_Endpoint endpoint_rptr
-                          ACE_ENV_ARG_DECL)
+                          TAO_ECG_Refcounted_Endpoint endpoint_rptr)
 {
   if (CORBA::is_nil (lcl_ec))
     {
       ACE_ERROR ((LM_ERROR, "TAO_ECG_UDP_Sender::init(): "
                             "<lcl_ec> argument is nil."));
-      ACE_THROW (CORBA::INTERNAL ());
+      throw CORBA::INTERNAL ();
     }
 
   if (CORBA::is_nil (addr_server))
     {
       ACE_ERROR ((LM_ERROR, "TAO_ECG_UDP_Sender::init(): "
                             "address server argument is nil."));
-      ACE_THROW (CORBA::INTERNAL ());
+      throw CORBA::INTERNAL ();
     }
 
-  this->cdr_sender_.init (endpoint_rptr ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->cdr_sender_.init (endpoint_rptr);
 
   this->lcl_ec_ =
     RtecEventChannelAdmin::EventChannel::_duplicate (lcl_ec);
@@ -58,38 +58,37 @@ TAO_ECG_UDP_Sender::init (RtecEventChannelAdmin::EventChannel_ptr lcl_ec,
 }
 
 void
-TAO_ECG_UDP_Sender::connect (const RtecEventChannelAdmin::ConsumerQOS& sub
-                             ACE_ENV_ARG_DECL)
+TAO_ECG_UDP_Sender::connect (const RtecEventChannelAdmin::ConsumerQOS& sub)
 {
   if (CORBA::is_nil (this->lcl_ec_.in ()))
     {
+      //FUZZ: disable check_for_lack_ACE_OS
       ACE_ERROR ((LM_ERROR, "Error initializing TAO_ECG_UDP_Sender: "
                             "init() has not been called before connect()."));
-      ACE_THROW (CORBA::INTERNAL ());
+      //FUZZ: enable check_for_lack_ACE_OS
+
+      throw CORBA::INTERNAL ();
     }
 
   if (sub.dependencies.length () == 0)
     {
       ACE_ERROR ((LM_ERROR, "TAO_ECG_UDP_Sender::connect(): "
                             "0-length subscriptions argument."));
-      ACE_THROW (CORBA::INTERNAL ());
+      throw CORBA::INTERNAL ();
     }
 
   if (CORBA::is_nil (this->supplier_proxy_.in ()))
     {
-      this->new_connect (sub ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->new_connect (sub);
     }
   else
     {
-      this->reconnect (sub ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->reconnect (sub);
     }
 }
 
 void
-TAO_ECG_UDP_Sender::new_connect (const RtecEventChannelAdmin::ConsumerQOS& sub
-                                 ACE_ENV_ARG_DECL)
+TAO_ECG_UDP_Sender::new_connect (const RtecEventChannelAdmin::ConsumerQOS& sub)
 {
   // Activate with poa.
   RtecEventComm::PushConsumer_var consumer_ref;
@@ -99,24 +98,18 @@ TAO_ECG_UDP_Sender::new_connect (const RtecEventChannelAdmin::ConsumerQOS& sub
   activate (consumer_ref,
             poa.in (),
             this,
-            deactivator
-            ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+            deactivator);
 
   // Connect as a consumer to the local EC.
   RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin =
-    this->lcl_ec_->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->lcl_ec_->for_consumers ();
 
   RtecEventChannelAdmin::ProxyPushSupplier_var proxy =
-    consumer_admin->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    consumer_admin->obtain_push_supplier ();
   ECG_Sender_Auto_Proxy_Disconnect new_proxy_disconnect (proxy.in ());
 
   proxy->connect_push_consumer (consumer_ref.in (),
-                                sub
-                                ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                sub);
 
   // Update resource managers.
   this->supplier_proxy_ = proxy._retn ();
@@ -125,43 +118,37 @@ TAO_ECG_UDP_Sender::new_connect (const RtecEventChannelAdmin::ConsumerQOS& sub
 }
 
 void
-TAO_ECG_UDP_Sender::reconnect (const RtecEventChannelAdmin::ConsumerQOS& sub
-                               ACE_ENV_ARG_DECL)
+TAO_ECG_UDP_Sender::reconnect (const RtecEventChannelAdmin::ConsumerQOS& sub)
 {
   // Obtain our object reference from the POA.
   RtecEventComm::PushConsumer_var consumer_ref;
   PortableServer::POA_var poa = this->_default_POA ();
 
-  CORBA::Object_var obj = poa->servant_to_reference (this ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  CORBA::Object_var obj = poa->servant_to_reference (this);
   consumer_ref =
-    RtecEventComm::PushConsumer::_narrow (obj.in () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    RtecEventComm::PushConsumer::_narrow (obj.in ());
 
   if (CORBA::is_nil (consumer_ref.in ()))
     {
-      ACE_THROW (CORBA::INTERNAL ());
+      throw CORBA::INTERNAL ();
     }
 
   // Reconnect.
   this->supplier_proxy_->connect_push_consumer (consumer_ref.in (),
-                                                sub
-                                                ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                                sub);
 }
 
 void
-TAO_ECG_UDP_Sender::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_ECG_UDP_Sender::disconnect_push_consumer (void)
 {
   // Prevent attempts to disconnect.
   this->auto_proxy_disconnect_.disallow_command ();
 
-  this->shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
+  this->shutdown ();
 }
 
 void
-TAO_ECG_UDP_Sender::shutdown (ACE_ENV_SINGLE_ARG_DECL)
+TAO_ECG_UDP_Sender::shutdown (void)
 {
   this->supplier_proxy_ =
     RtecEventChannelAdmin::ProxyPushSupplier::_nil ();
@@ -172,14 +159,11 @@ TAO_ECG_UDP_Sender::shutdown (ACE_ENV_SINGLE_ARG_DECL)
   this->lcl_ec_ = RtecEventChannelAdmin::EventChannel::_nil ();
 
   this->deactivator_.deactivate ();
-  this->cdr_sender_.shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->cdr_sender_.shutdown ();
 }
 
 void
-TAO_ECG_UDP_Sender::push (const RtecEventComm::EventSet &events
-                          ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_ECG_UDP_Sender::push (const RtecEventComm::EventSet &events)
 {
   if (events.length () == 0)
     {
@@ -216,26 +200,41 @@ TAO_ECG_UDP_Sender::push (const RtecEventComm::EventSet &events
       cdr.write_ulong (1);
       if (!(cdr << header)
           || !(cdr << e.data))
-        ACE_THROW (CORBA::MARSHAL ());
+        throw CORBA::MARSHAL ();
 
-      // Grab the right mcast group for this event...
-      RtecUDPAdmin::UDP_Addr udp_addr;
-      this->addr_server_->get_addr (header, udp_addr ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      ACE_INET_Addr inet_addr;
+      try
+        {
+          // Grab the right mcast group for this event...
+          RtecUDPAdmin::UDP_Address_var udp_addr;
 
-      ACE_INET_Addr inet_addr (udp_addr.port,
-                               udp_addr.ipaddr);
+          this->addr_server_->get_address (header, udp_addr.out());
+          switch (udp_addr->_d())
+            {
+            case RtecUDPAdmin::Rtec_inet:
+              inet_addr.set(udp_addr->v4_addr().port,
+                            udp_addr->v4_addr().ipaddr);
+              break;
+            case RtecUDPAdmin::Rtec_inet6:
+#if defined (ACE_HAS_IPV6)
+              inet_addr.set_type(PF_INET6);
+#endif
+              inet_addr.set_address(udp_addr->v6_addr().ipaddr,16,0);
+              inet_addr.set_port_number(udp_addr->v6_addr().port);
+              break;
+            }
+        }
+      catch (const ::CORBA::BAD_OPERATION &)
+        {
+          // server only supports IPv4
+           // Grab the right mcast group for this event...
+          RtecUDPAdmin::UDP_Addr udp_addr;
+          this->addr_server_->get_addr (header, udp_addr);
+          inet_addr.set (udp_addr.port, udp_addr.ipaddr);
+        }
 
-      this->cdr_sender_.send_message (cdr, inet_addr ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->cdr_sender_.send_message (cdr, inet_addr);
     }
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template void activate<TAO_Objref_Var_T<RtecEventComm::PushConsumer> >(TAO_Objref_Var_T<RtecEventComm::PushConsumer>&, PortableServer::POA*, TAO_ServantBase*, TAO_EC_Object_Deactivator& ACE_ENV_ARG_DECL);
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate void activate<TAO_Objref_Var_T<RtecEventComm::PushConsumer> >(TAO_Objref_Var_T<RtecEventComm::PushConsumer>&, PortableServer::POA*, TAO_ServantBase*, TAO_EC_Object_Deactivator& ACE_ENV_ARG_DECL)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
