@@ -1,21 +1,24 @@
-// EC_Basic_Filter_Builder.cpp,v 1.16 2004/08/16 23:53:12 jtc Exp
+// $Id: EC_Basic_Filter_Builder.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
 #include "orbsvcs/Event_Service_Constants.h"
-#include "EC_Basic_Filter_Builder.h"
-#include "EC_Type_Filter.h"
-#include "EC_Conjunction_Filter.h"
-#include "EC_Disjunction_Filter.h"
-#include "EC_And_Filter.h"
-#include "EC_Negation_Filter.h"
-#include "EC_Bitmask_Filter.h"
-#include "EC_Masked_Type_Filter.h"
-#include "EC_Timeout_Filter.h"
+#include "orbsvcs/Event/EC_Basic_Filter_Builder.h"
+#include "orbsvcs/Event/EC_Type_Filter.h"
+#include "orbsvcs/Event/EC_Conjunction_Filter.h"
+#include "orbsvcs/Event/EC_Disjunction_Filter.h"
+#include "orbsvcs/Event/EC_And_Filter.h"
+#include "orbsvcs/Event/EC_Negation_Filter.h"
+#include "orbsvcs/Event/EC_Bitmask_Filter.h"
+#include "orbsvcs/Event/EC_Masked_Type_Filter.h"
+#include "orbsvcs/Event/EC_Timeout_Filter.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "EC_Basic_Filter_Builder.i"
+#include "orbsvcs/Event/EC_Basic_Filter_Builder.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, EC_Basic_Filter_Builder, "EC_Basic_Filter_Builder.cpp,v 1.16 2004/08/16 23:53:12 jtc Exp")
+ACE_RCSID(Event, EC_Basic_Filter_Builder, "$Id: EC_Basic_Filter_Builder.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Basic_Filter_Builder::~TAO_EC_Basic_Filter_Builder (void)
 {
@@ -24,8 +27,7 @@ TAO_EC_Basic_Filter_Builder::~TAO_EC_Basic_Filter_Builder (void)
 TAO_EC_Filter*
 TAO_EC_Basic_Filter_Builder::build (
     TAO_EC_ProxyPushSupplier *supplier,
-    RtecEventChannelAdmin::ConsumerQOS& qos
-    ACE_ENV_ARG_DECL_NOT_USED) const
+    RtecEventChannelAdmin::ConsumerQOS& qos) const
 {
   CORBA::ULong pos = 0;
   return this->recursive_build (supplier, qos, pos);
@@ -196,3 +198,5 @@ TAO_EC_Basic_Filter_Builder::
     }
   return count;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
