@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_ConsumerAdmin.h
  *
- *  EC_ConsumerAdmin.h,v 1.36 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_ConsumerAdmin.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -17,7 +18,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "EC_ProxySupplier.h"
+#include "orbsvcs/Event/EC_ProxySupplier.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -25,12 +26,13 @@
 
 #include "orbsvcs/ESF/ESF_Peer_Admin.h"
 
-#include /**/ "event_serv_export.h"
+#include /**/ "orbsvcs/Event/event_serv_export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_EC_Event_Channel_Base;
 class TAO_EC_ProxyPushConsumer;
 
-
 /**
  * @class TAO_EC_ConsumerAdmin
  *
@@ -61,17 +63,18 @@ public:
 
   // = The RtecEventChannelAdmin::ConsumerAdmin methods...
   virtual RtecEventChannelAdmin::ProxyPushSupplier_ptr
-      obtain_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-          ACE_THROW_SPEC ((CORBA::SystemException));
+      obtain_push_supplier (void);
 
   // = The PortableServer::ServantBase methods
-  virtual PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL);
+  virtual PortableServer::POA_ptr _default_POA (void);
 
 private:
   /// Store the default POA.
   PortableServer::POA_var default_POA_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_EC_CONSUMERADMIN_H */
