@@ -1,4 +1,4 @@
-// $Id: EC_Default_Factory.cpp 75279 2006-11-08 19:17:49Z cleeland $
+// $Id: EC_Default_Factory.cpp 83169 2008-10-12 21:12:39Z johnnyw $
 
 #include "orbsvcs/Event/EC_Default_Factory.h"
 #include "orbsvcs/Event/EC_Reactive_Dispatching.h"
@@ -39,7 +39,7 @@
 #include "orbsvcs/Event/EC_Default_Factory.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, EC_Default_Factory, "$Id: EC_Default_Factory.cpp 75279 2006-11-08 19:17:49Z cleeland $")
+ACE_RCSID(Event, EC_Default_Factory, "$Id: EC_Default_Factory.cpp 83169 2008-10-12 21:12:39Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -56,8 +56,8 @@ TAO_EC_Default_Factory::init_svcs (void)
 }
 
 void
-TAO_EC_Default_Factory::unsupported_option_value (const char * option_name,
-                                                  const char * option_value)
+TAO_EC_Default_Factory::unsupported_option_value (const ACE_TCHAR * option_name,
+                                                  const ACE_TCHAR * option_value)
 {
   ACE_ERROR ((LM_ERROR,
               "EC_Default_Factory - "
@@ -94,7 +94,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("mt")) == 0)
                 this->dispatching_ = 1;
               else
-                  this->unsupported_option_value ("-ECDispatching", opt);
+                  this->unsupported_option_value (ACE_TEXT("-ECDispatching"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -109,13 +109,13 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               // need to parse the flags...ugh
               ACE_TCHAR* opt = ACE_OS::strdup (s);
 
-              ACE_TCHAR* aux;
-              ACE_TCHAR* flags = ACE_OS::strtok_r (opt, ACE_TEXT_CHAR_TO_TCHAR(":"), &aux);
+              ACE_TCHAR* aux = 0;
+              ACE_TCHAR* flags = ACE_OS::strtok_r (opt, ACE_TEXT (":"), &aux);
 
               TAO_EC_Thread_Flags tf(ACE_TEXT_ALWAYS_CHAR (flags)); // parse and set up
               this->dispatching_threads_flags_ = tf.flags ();
 
-              ACE_TCHAR* arg = ACE_OS::strtok_r (0, ACE_TEXT_CHAR_TO_TCHAR(":"), &aux);
+              ACE_TCHAR* arg = ACE_OS::strtok_r (0, ACE_TEXT(":"), &aux);
               if (arg)
                 {
                   long prio = ACE_OS::strtol (arg, 0, 0);
@@ -158,7 +158,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("prefix")) == 0)
                 this->filtering_ = 2;
               else
-                  this->unsupported_option_value ("-ECFiltering", opt);
+                  this->unsupported_option_value (ACE_TEXT("-ECFiltering"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -177,7 +177,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("per-supplier")) == 0)
                 this->supplier_filtering_ = 1;
               else
-                  this->unsupported_option_value ("-ECSupplierFilter", opt);
+                  this->unsupported_option_value (ACE_TEXT("-ECSupplierFilter"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -192,7 +192,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 this->timeout_ = 0;
               else
-                  this->unsupported_option_value ("-ECTimeout", opt);
+                  this->unsupported_option_value (ACE_TEXT("-ECTimeout"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -211,7 +211,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 this->observer_ = 2;
               else
-                  this->unsupported_option_value ("-ECObserver", opt);
+                  this->unsupported_option_value (ACE_TEXT("-ECObserver"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -228,7 +228,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("group")) == 0)
                 this->scheduling_ = 1;
               else
-                  this->unsupported_option_value ("-ECScheduling", opt);
+                  this->unsupported_option_value (ACE_TEXT("-ECScheduling"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -337,7 +337,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("recursive")) == 0)
                 this->consumer_lock_ = 2;
               else
-                this->unsupported_option_value ("-ECProxyConsumerLock", opt);
+                this->unsupported_option_value (ACE_TEXT("-ECProxyConsumerLock"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -356,7 +356,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("recursive")) == 0)
                 this->supplier_lock_ = 2;
               else
-                this->unsupported_option_value ("-ECProxySupplierLock", opt);
+                this->unsupported_option_value (ACE_TEXT("-ECProxySupplierLock"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -385,7 +385,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 this->consumer_control_ = 1;
               else
-                this->unsupported_option_value ("-ECConsumerControl", opt);
+                this->unsupported_option_value (ACE_TEXT("-ECConsumerControl"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -402,7 +402,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
               else if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 this->supplier_control_ = 1;
               else
-                this->unsupported_option_value ("-ECSupplierControl", opt);
+                this->unsupported_option_value (ACE_TEXT("-ECSupplierControl"), opt);
               arg_shifter.consume_arg ();
             }
         }
@@ -482,7 +482,7 @@ TAO_EC_Default_Factory::init (int argc, ACE_TCHAR* argv[])
           arg_shifter.consume_arg ();
           if (arg_shifter.is_parameter_next ())
             {
-              const char* opt = arg_shifter.get_current ();
+              const ACE_TCHAR* opt = arg_shifter.get_current ();
               this->queue_full_service_object_name_.set(opt);
               arg_shifter.consume_arg ();
             }
@@ -533,8 +533,8 @@ TAO_EC_Default_Factory::fini (void)
 // ****************************************************************
 
 TAO_EC_Queue_Full_Service_Object*
-TAO_EC_Default_Factory::find_service_object (const char* wanted,
-                                             const char* fallback)
+TAO_EC_Default_Factory::find_service_object (const ACE_TCHAR* wanted,
+                                             const ACE_TCHAR* fallback)
 {
   TAO_EC_Queue_Full_Service_Object* so = 0;
   so = ACE_Dynamic_Service<TAO_EC_Queue_Full_Service_Object>::instance (wanted);
@@ -674,7 +674,7 @@ TAO_EC_Default_Factory::create_timeout_generator (TAO_EC_Event_Channel_Base *)
   if (this->timeout_ == 0)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_.c_str ());
 
@@ -984,7 +984,7 @@ TAO_EC_Default_Factory::create_consumer_control (TAO_EC_Event_Channel_Base* ec)
   else if (this->consumer_control_ == 1)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_.c_str ());
 
@@ -1008,7 +1008,7 @@ TAO_EC_Default_Factory::create_supplier_control (TAO_EC_Event_Channel_Base* ec)
   else if (this->supplier_control_ == 1)
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv, this->orbid_.c_str ());
 
