@@ -2,7 +2,7 @@
 /**
  *  @file   EC_Defaults.h
  *
- *  $Id: EC_Defaults.h 67867 2005-08-25 16:08:55Z cleeland $
+ *  $Id: EC_Defaults.h 82953 2008-10-07 07:49:56Z johnnyw $
  *
  * In this file we set the compile time defaults for the event
  * channel.
@@ -124,7 +124,7 @@
 #endif /* TAO_EC_DEFAULT_SUPPLIER_CONTROL_PERIOD */
 
 #ifndef TAO_EC_DEFAULT_QUEUE_FULL_SERVICE_OBJECT_NAME
-# define TAO_EC_DEFAULT_QUEUE_FULL_SERVICE_OBJECT_NAME "EC_QueueFullSimpleActions"
+# define TAO_EC_DEFAULT_QUEUE_FULL_SERVICE_OBJECT_NAME ACE_TEXT("EC_QueueFullSimpleActions")
 #endif /* TAO_EC_DEFAULT_QUEUE_FULL_SERVICE_OBJECT_NAME */
 
 #ifndef TAO_EC_DEFAULT_CONSUMER_CONTROL_TIMEOUT
