@@ -1,8 +1,8 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 /**
  *  @file   EC_Factory.h
  *
- *  EC_Factory.h,v 1.26 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Factory.h 75279 2006-11-08 19:17:49Z cleeland $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -17,15 +17,21 @@
 
 #include /**/ "ace/pre.h"
 
-#include /**/ "event_serv_export.h"
+#include /**/ "orbsvcs/Event/event_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/Versioned_Namespace.h"
+
 #include "ace/Service_Object.h"
 
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 class ACE_Lock;
+ACE_END_VERSIONED_NAMESPACE_DECL
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_EC_Event_Channel_Base;
 
@@ -63,6 +69,7 @@ class TAO_RTEvent_Serv_Export TAO_EC_Factory : public ACE_Service_Object
 {
 public:
   /// destructor...
+  TAO_EC_Factory (void);
   virtual ~TAO_EC_Factory (void);
 
   /// Create and destroy the dispatching module.
@@ -156,6 +163,10 @@ public:
       destroy_supplier_control (TAO_EC_SupplierControl*) = 0;
 };
 
+TAO_RTEvent_Serv_Export extern unsigned short TAO_EC_debug_level;
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_EC_FACTORY_H */
