@@ -1,17 +1,19 @@
-// EC_Filter.cpp,v 1.13 2005/02/18 09:07:07 jwillemsen Exp
+// $Id: EC_Filter.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "EC_Filter.h"
-#include "EC_QOS_Info.h"
+#include "orbsvcs/Event/EC_Filter.h"
+#include "orbsvcs/Event/EC_QOS_Info.h"
 
 #include "tao/ORB_Constants.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "EC_Filter.i"
+#include "orbsvcs/Event/EC_Filter.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (Event,
            EC_Filter,
-           "EC_Filter.cpp,v 1.13 2005/02/18 09:07:07 jwillemsen Exp")
+           "$Id: EC_Filter.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Filter::~TAO_EC_Filter (void)
 {
@@ -42,56 +44,48 @@ TAO_EC_Filter::size (void) const
 }
 
 void
-TAO_EC_Filter::get_qos_info (TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL)
+TAO_EC_Filter::get_qos_info (TAO_EC_QOS_Info& qos_info)
 {
   ACE_UNUSED_ARG (qos_info);
-  ACE_THROW (CORBA::NO_IMPLEMENT (TAO::VMCID,
-                                  CORBA::COMPLETED_NO));
+  throw CORBA::NO_IMPLEMENT (TAO::VMCID, CORBA::COMPLETED_NO);
 }
 
 // ****************************************************************
 
 int
 TAO_EC_Null_Filter::filter (const RtecEventComm::EventSet& event,
-                            TAO_EC_QOS_Info& qos_info
-                            ACE_ENV_ARG_DECL)
+                            TAO_EC_QOS_Info& qos_info)
 {
   // This is a leaf, no need to query any children, and we accept all
   // events, so push it.
-  this->push (event, qos_info ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+  this->push (event, qos_info);
   return 1;
 }
 
 int
 TAO_EC_Null_Filter::filter_nocopy (RtecEventComm::EventSet& event,
-                                   TAO_EC_QOS_Info& qos_info
-                                   ACE_ENV_ARG_DECL)
+                                   TAO_EC_QOS_Info& qos_info)
 {
   // This is a leaf, no need to query any children, and we accept all
   // events, so push it.
-  this->push_nocopy (event, qos_info ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+  this->push_nocopy (event, qos_info);
   return 1;
 }
 
 void
 TAO_EC_Null_Filter::push (const RtecEventComm::EventSet& event,
-                          TAO_EC_QOS_Info& qos_info
-                          ACE_ENV_ARG_DECL)
+                          TAO_EC_QOS_Info& qos_info)
 {
   if (this->parent () != 0)
-    this->parent ()->push (event, qos_info ACE_ENV_ARG_PARAMETER);
+    this->parent ()->push (event, qos_info);
 }
 
 void
 TAO_EC_Null_Filter::push_nocopy (RtecEventComm::EventSet& event,
-                                 TAO_EC_QOS_Info& qos_info
-                                 ACE_ENV_ARG_DECL)
+                                 TAO_EC_QOS_Info& qos_info)
 {
   if (this->parent () != 0)
-    this->parent ()->push_nocopy (event, qos_info ACE_ENV_ARG_PARAMETER);
+    this->parent ()->push_nocopy (event, qos_info);
 }
 
 void
@@ -118,17 +112,10 @@ TAO_EC_Null_Filter::can_match (const RtecEventComm::EventHeader&) const
 int
 TAO_EC_Null_Filter::add_dependencies (
       const RtecEventComm::EventHeader &,
-      const TAO_EC_QOS_Info &
-      ACE_ENV_ARG_DECL_NOT_USED)
+      const TAO_EC_QOS_Info &)
 
 {
   return 0;
 }
 
-// ****************************************************************
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
