@@ -1,8 +1,8 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 /**
  *  @file   EC_Filter.h
  *
- *  EC_Filter.h,v 1.25 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Filter.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -19,12 +19,14 @@
 
 #include "orbsvcs/RtecEventCommC.h"
 
-#include /**/ "event_serv_export.h"
+#include /**/ "orbsvcs/Event/event_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_EC_QOS_Info;
 
 /**
@@ -93,11 +95,9 @@ public:
    * EC_ProxyPushSupplier take an event rather than a set?
    */
   virtual int filter (const RtecEventComm::EventSet& event,
-                      TAO_EC_QOS_Info& qos_info
-                      ACE_ENV_ARG_DECL) = 0;
+                      TAO_EC_QOS_Info& qos_info) = 0;
   virtual int filter_nocopy (RtecEventComm::EventSet& event,
-                             TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL) = 0;
+                             TAO_EC_QOS_Info& qos_info) = 0;
 
   /**
    * This is called by the children when they accept an event and
@@ -106,11 +106,9 @@ public:
    * not const then filter can take ownership of the event.
    */
   virtual void push (const RtecEventComm::EventSet& event,
-                     TAO_EC_QOS_Info& qos_info
-                     ACE_ENV_ARG_DECL) = 0;
+                     TAO_EC_QOS_Info& qos_info) = 0;
   virtual void push_nocopy (RtecEventComm::EventSet& event,
-                            TAO_EC_QOS_Info& qos_info
-                            ACE_ENV_ARG_DECL) = 0;
+                            TAO_EC_QOS_Info& qos_info) = 0;
 
   /// Clear any saved state, must reset and assume no events have been
   /// received.
@@ -141,8 +139,7 @@ public:
    * fairly soon.
    */
   virtual int add_dependencies (const RtecEventComm::EventHeader& header,
-                                const TAO_EC_QOS_Info& qos_info
-                                ACE_ENV_ARG_DECL) = 0;
+                                const TAO_EC_QOS_Info& qos_info) = 0;
 
   /**
    * Obtain the QOS information for this filter, the default
@@ -150,8 +147,7 @@ public:
    * support scheduling information implement this method.
    * @return Returns 0 on success and -1 on failure
    */
-  virtual void get_qos_info (TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL);
+  virtual void get_qos_info (TAO_EC_QOS_Info& qos_info);
 
 private:
   /// The parent...
@@ -182,23 +178,18 @@ public:
   // = The TAO_EC_Filter methods, please check the documentation in
   // TAO_EC_Filter.
   virtual int filter (const RtecEventComm::EventSet& event,
-                      TAO_EC_QOS_Info& qos_info
-                      ACE_ENV_ARG_DECL);
+                      TAO_EC_QOS_Info& qos_info);
   virtual int filter_nocopy (RtecEventComm::EventSet& event,
-                             TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL);
+                             TAO_EC_QOS_Info& qos_info);
   virtual void push (const RtecEventComm::EventSet& event,
-                     TAO_EC_QOS_Info& qos_info
-                     ACE_ENV_ARG_DECL);
+                     TAO_EC_QOS_Info& qos_info);
   virtual void push_nocopy (RtecEventComm::EventSet& event,
-                            TAO_EC_QOS_Info& qos_info
-                            ACE_ENV_ARG_DECL);
+                            TAO_EC_QOS_Info& qos_info);
   virtual void clear (void);
   virtual CORBA::ULong max_event_size (void) const;
   virtual int can_match (const RtecEventComm::EventHeader& header) const;
   virtual int add_dependencies (const RtecEventComm::EventHeader& header,
-                                const TAO_EC_QOS_Info &qos_info
-                                ACE_ENV_ARG_DECL);
+                                const TAO_EC_QOS_Info &qos_info);
 };
 
 // ****************************************************************
@@ -212,8 +203,10 @@ public:
 
 // ****************************************************************
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "EC_Filter.i"
+#include "orbsvcs/Event/EC_Filter.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
