@@ -1,4 +1,4 @@
-// $Id: EC_Gateway_IIOP.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: EC_Gateway_IIOP.cpp 86192 2009-07-23 17:51:06Z johnnyw $
 
 #include "orbsvcs/Event/EC_Gateway_IIOP.h"
 #include "orbsvcs/Event/ECG_Defaults.h"
@@ -12,7 +12,7 @@
 
 ACE_RCSID (Event,
            EC_Gateway_IIOP,
-           "$Id: EC_Gateway_IIOP.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: EC_Gateway_IIOP.cpp 86192 2009-07-23 17:51:06Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -24,9 +24,9 @@ TAO_EC_Gateway_IIOP::TAO_EC_Gateway_IIOP (void)
      supplier_info_ (0),
      consumer_info_ (0),
      consumer_ (this),
-     consumer_is_active_ (0),
+     consumer_is_active_ (false),
      supplier_ (this),
-     supplier_is_active_ (0),
+     supplier_is_active_ (false),
      ec_control_ (0),
      factory_ (0),
      use_ttl_ (1),
@@ -73,20 +73,20 @@ TAO_EC_Gateway_IIOP::init_i (RtecEventChannelAdmin::EventChannel_ptr supplier_ec
                              RtecEventChannelAdmin::EventChannel_ptr consumer_ec)
 {
   if (CORBA::is_nil (this->supplier_ec_.in ()) && CORBA::is_nil (this->consumer_ec_.in ()))
-  {
-    this->supplier_ec_ =
-      RtecEventChannelAdmin::EventChannel::_duplicate (supplier_ec);
-    this->consumer_ec_ =
-      RtecEventChannelAdmin::EventChannel::_duplicate (consumer_ec);
+    {
+      this->supplier_ec_ =
+        RtecEventChannelAdmin::EventChannel::_duplicate (supplier_ec);
+      this->consumer_ec_ =
+        RtecEventChannelAdmin::EventChannel::_duplicate (consumer_ec);
 
-	if (ec_control_ == 0)
-     {
-        ec_control_ = factory_->create_consumerec_control(this);
-        ec_control_->activate();
-     }
+      if (ec_control_ == 0)
+        {
+          ec_control_ = factory_->create_consumerec_control(this);
+          ec_control_->activate();
+        }
 
-    return 0;
-  }
+      return 0;
+    }
   else
     ACE_ERROR_RETURN ((LM_ERROR,
                        "TAO_EC_Gateway_IIOP - init_i "
@@ -244,7 +244,7 @@ TAO_EC_Gateway_IIOP::update_consumer_i (
       || CORBA::is_nil (this->supplier_ec_.in ()))
     return;
 
-  // ACE_DEBUG ((LM_DEBUG, "ECG (%t) update_consumer_i \n"));
+  // ACE_DEBUG ((LM_DEBUG, "ECG (%t) update_consumer_i\n"));
 
   this->open_i (c_qos);
 }
@@ -258,7 +258,7 @@ TAO_EC_Gateway_IIOP::open_i (
     this->consumer_ec_->for_suppliers ();
 
   RtecEventChannelAdmin::ConsumerQOS sub = c_qos;
-  sub.is_gateway = 1;
+  sub.is_gateway = true;
 
   // Change the RT_Info in the consumer QoS.
   // On the same loop we discover the subscriptions by event source,
@@ -302,11 +302,10 @@ TAO_EC_Gateway_IIOP::open_i (
 
   if (this->consumer_proxy_map_.current_size () > 0)
     {
-      this->supplier_is_active_ = 1;
+      this->supplier_is_active_ = true;
 
       // Obtain a reference to our supplier personality...
-      RtecEventComm::PushSupplier_var supplier_ref =
-        this->supplier_._this ();
+      RtecEventComm::PushSupplier_var supplier_ref = this->supplier_._this ();
 
       // For each subscription by source build the set of publications
       // (they may several, by type, for instance) and connect to the
@@ -317,7 +316,7 @@ TAO_EC_Gateway_IIOP::open_i (
         {
           RtecEventChannelAdmin::SupplierQOS pub;
           pub.publications.length (sub.dependencies.length () + 1);
-          pub.is_gateway = 1;
+          pub.is_gateway = true;
 
           int c = 0;
 
@@ -357,7 +356,7 @@ TAO_EC_Gateway_IIOP::open_i (
   // then connect to the default consumer proxy.
   RtecEventChannelAdmin::SupplierQOS pub;
   pub.publications.length (sub.dependencies.length () + 1);
-  pub.is_gateway = 1;
+  pub.is_gateway = true;
   int c = 0;
   for (CORBA::ULong k = 0; k < sub.dependencies.length (); ++k)
     {
@@ -384,7 +383,7 @@ TAO_EC_Gateway_IIOP::open_i (
 
   if (c > 0)
     {
-      this->supplier_is_active_ = 1;
+      this->supplier_is_active_ = true;
 
       // Obtain a reference to our supplier personality...
       RtecEventComm::PushSupplier_var supplier_ref =
@@ -407,7 +406,7 @@ TAO_EC_Gateway_IIOP::open_i (
   this->supplier_proxy_ =
     consumer_admin->obtain_push_supplier ();
 
-  this->consumer_is_active_ = 1;
+  this->consumer_is_active_ = true;
   RtecEventComm::PushConsumer_var consumer_ref =
     this->consumer_._this ();
 
@@ -444,7 +443,7 @@ TAO_EC_Gateway_IIOP::disconnect_push_supplier (void)
 void
 TAO_EC_Gateway_IIOP::push (const RtecEventComm::EventSet &events)
 {
-  // ACE_DEBUG ((LM_DEBUG, "TAO_EC_Gateway_IIOP::push (%P|%t) - \n"));
+  // ACE_DEBUG ((LM_DEBUG, "TAO_EC_Gateway_IIOP::push (%P|%t) -\n"));
 
   if (events.length () == 0)
     {
@@ -553,7 +552,7 @@ TAO_EC_Gateway_IIOP::shutdown (void)
       PortableServer::ObjectId_var id =
         poa->servant_to_id (&this->supplier_);
       poa->deactivate_object (id.in ());
-      this->supplier_is_active_ = 0;
+      this->supplier_is_active_ = false;
     }
 
   if (this->consumer_is_active_)
@@ -563,7 +562,7 @@ TAO_EC_Gateway_IIOP::shutdown (void)
       PortableServer::ObjectId_var id =
         poa->servant_to_id (&this->consumer_);
       poa->deactivate_object (id.in ());
-      this->consumer_is_active_ = 0;
+      this->consumer_is_active_ = false;
     }
 
   this->cleanup_consumer_ec_i ();
