@@ -1,11 +1,13 @@
-// EC_Gateway_Sched.cpp,v 1.7 2004/08/16 23:53:13 jtc Exp
+// $Id: EC_Gateway_Sched.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "EC_Gateway_Sched.h"
+#include "orbsvcs/Event/EC_Gateway_Sched.h"
 #include "orbsvcs/Time_Utilities.h"
 
-ACE_RCSID (Event, 
-           EC_Gateway_sched, 
-           "EC_Gateway_Sched.cpp,v 1.7 2004/08/16 23:53:13 jtc Exp")
+ACE_RCSID (Event,
+           EC_Gateway_sched,
+           "$Id: EC_Gateway_Sched.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Gateway_Sched::TAO_EC_Gateway_Sched (void)
   :  TAO_EC_Gateway_IIOP ()
@@ -22,24 +24,21 @@ TAO_EC_Gateway_Sched::init (RtecEventChannelAdmin::EventChannel_ptr supplier_ec,
                            RtecScheduler::Scheduler_ptr supplier_sched,
                            RtecScheduler::Scheduler_ptr consumer_sched,
                            const char* consumer_name,
-                           const char* supplier_name
-                           ACE_ENV_ARG_DECL)
+                           const char* supplier_name)
 {
   ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->lock_);
 
-  this->init_i (supplier_ec, consumer_ec ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->init_i (supplier_ec, consumer_ec);
 
   // @@ Should we throw a system exception here?
   if (CORBA::is_nil (supplier_sched)
       || CORBA::is_nil (consumer_sched)
       || consumer_name == 0
       || supplier_name == 0)
-    ACE_THROW (CORBA::BAD_PARAM ());
+    throw CORBA::BAD_PARAM ();
 
   this->supplier_info_ =
-    supplier_sched->create (supplier_name ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    supplier_sched->create (supplier_name);
 
   // @@ TODO Many things are hard-coded in the RT_Info here.
 
@@ -55,13 +54,10 @@ TAO_EC_Gateway_Sched::init (RtecEventChannelAdmin::EventChannel_ptr supplier_ec,
                        RtecScheduler::VERY_LOW_IMPORTANCE,
                        time,
                        0,
-                       RtecScheduler::OPERATION
-                       ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                       RtecScheduler::OPERATION);
 
   this->consumer_info_ =
-    consumer_sched->create (consumer_name ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    consumer_sched->create (consumer_name);
 
   tv = ACE_Time_Value (0, 500);
   ORBSVCS_Time::Time_Value_to_TimeT (time, tv);
@@ -72,7 +68,7 @@ TAO_EC_Gateway_Sched::init (RtecEventChannelAdmin::EventChannel_ptr supplier_ec,
                        RtecScheduler::VERY_LOW_IMPORTANCE,
                        time,
                        1,
-                       RtecScheduler::REMOTE_DEPENDANT
-                       ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                       RtecScheduler::REMOTE_DEPENDANT);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
