@@ -1,8 +1,8 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 /**
  *  @file   EC_Gateway_Sched.h
  *
- *  EC_Gateway_Sched.h,v 1.10 2004/08/16 23:53:13 jtc Exp
+ *  $Id: EC_Gateway_Sched.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -18,12 +18,14 @@
 #define TAO_EC_GATEWAY_SCHED_H
 #include /**/ "ace/pre.h"
 
-#include "EC_Gateway_IIOP.h"
+#include "orbsvcs/Event/EC_Gateway_IIOP.h"
 #include "orbsvcs/RtecSchedulerC.h"
-#include "sched_event_export.h"
+#include "orbsvcs/Event/sched_event_export.h"
 
 // ****************************************************************
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_EC_Gateway_Sched
  *
@@ -47,9 +49,10 @@ public:
              RtecScheduler::Scheduler_ptr supplier_sched,
              RtecScheduler::Scheduler_ptr consumer_sched,
              const char* consumer_name,
-             const char* supplier_name
-             ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+             const char* supplier_name);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* ACE_EC_GATEWAY_SCHED_H */
