@@ -1,9 +1,9 @@
-// EC_Kokyu_Dispatching.cpp,v 1.18 2005/02/18 09:07:07 jwillemsen Exp
+// $Id: EC_Kokyu_Dispatching.cpp 76626 2007-01-26 13:50:03Z elliott_c $
 
-#include "EC_Kokyu_Dispatching.h"
-#include "EC_Event_Channel_Base.h"
-#include "EC_ProxySupplier.h"
-#include "EC_QOS_Info.h"
+#include "orbsvcs/Event/EC_Kokyu_Dispatching.h"
+#include "orbsvcs/Event/EC_Event_Channel_Base.h"
+#include "orbsvcs/Event/EC_ProxySupplier.h"
+#include "orbsvcs/Event/EC_QOS_Info.h"
 
 #include "orbsvcs/Event_Service_Constants.h"
 #include "orbsvcs/RtecSchedulerC.h"
@@ -15,12 +15,14 @@
 #include "Kokyu/Kokyu.h"
 
 #if     ! defined (__ACE_INLINE__)
-#include "EC_Kokyu_Dispatching.i"
+#include "orbsvcs/Event/EC_Kokyu_Dispatching.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (Event,
            EC_Kokyu_Dispatching,
-           "EC_Kokyu_Dispatching.cpp,v 1.18 2005/02/18 09:07:07 jwillemsen Exp")
+           "$Id: EC_Kokyu_Dispatching.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Kokyu_Dispatching::TAO_EC_Kokyu_Dispatching (TAO_EC_Event_Channel_Base *ec, int sched_policy, int sched_scope)
   :allocator_ (0),
@@ -53,19 +55,16 @@ TAO_EC_Kokyu_Dispatching::activate (void)
 void
 TAO_EC_Kokyu_Dispatching::setup_lanes (void)
 {
-  ACE_DECLARE_NEW_CORBA_ENV;
   // Query the scheduler togetConfig_Infos
   RtecScheduler::Config_Info_Set_var configs;
-  ACE_TRY
+  try
     {
       this->scheduler_->get_config_infos(configs.out());
-      ACE_TRY_CHECK;
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // Ignore exceptions..
     }
-  ACE_ENDTRY;
 
   //might be no Config_Infos in the set (if none passed to scheduler_)
 
@@ -112,19 +111,17 @@ void
 TAO_EC_Kokyu_Dispatching::push (TAO_EC_ProxyPushSupplier* proxy,
                                 RtecEventComm::PushConsumer_ptr consumer,
                                 const RtecEventComm::EventSet& event,
-                                TAO_EC_QOS_Info&     qos_info
-                                ACE_ENV_ARG_DECL)
+                                TAO_EC_QOS_Info&     qos_info)
 {
   RtecEventComm::EventSet event_copy = event;
-  this->push_nocopy (proxy, consumer, event_copy, qos_info ACE_ENV_ARG_PARAMETER);
+  this->push_nocopy (proxy, consumer, event_copy, qos_info);
 }
 
 void
 TAO_EC_Kokyu_Dispatching::push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
                                        RtecEventComm::PushConsumer_ptr consumer,
                                        RtecEventComm::EventSet& event,
-                                       TAO_EC_QOS_Info& qos_info
-                                       ACE_ENV_ARG_DECL)
+                                       TAO_EC_QOS_Info& qos_info)
 {
     if (this->dispatcher_.get () == 0)
         this->setup_lanes ();
@@ -133,8 +130,7 @@ TAO_EC_Kokyu_Dispatching::push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
       this->allocator_->malloc (sizeof (TAO_EC_Kokyu_Push_Command ));
 
     if (buf == 0)
-      ACE_THROW (CORBA::NO_MEMORY (TAO::VMCID,
-                                   CORBA::COMPLETED_NO));
+      throw CORBA::NO_MEMORY (TAO::VMCID, CORBA::COMPLETED_NO);
 
   // Create Dispatch_Command
   TAO_EC_Kokyu_Push_Command *cmd =
@@ -184,37 +180,21 @@ TAO_EC_Kokyu_Push_Command::~TAO_EC_Kokyu_Push_Command(void)
 int
 TAO_EC_Kokyu_Push_Command::execute ()
 {
-  ACE_DECLARE_NEW_CORBA_ENV;
 
-  ACE_TRY
+  try
     {
       //ACE_DEBUG ((LM_DEBUG,
       //            "(%t) Command object executed.\n"));
 
       this->proxy_->push_to_consumer (this->consumer_.in (),
-                                      this->event_
-                                      ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                      this->event_);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       return -1;
     }
-  ACE_ENDTRY;
 
   return 0;
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-#if (! defined (__GNUC__)) || (__GNUC__ > 2) || \
-(__GNUC__ == 2 && defined (__GNUC_MINOR__) && __GNUC_MINOR__ >= 8)
-template class ACE_Array<Kokyu::ConfigInfo>;
-template class ACE_Array_Base<Kokyu::ConfigInfo>;
-#  endif /* __GNUC__ */
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#if (! defined (__GNUC__)) || (__GNUC__ > 2) || \
-(__GNUC__ == 2 && defined (__GNUC_MINOR__) && __GNUC_MINOR__ >= 8)
-#pragma instantiate ACE_Array<Kokyu::ConfigInfo>
-#pragma instantiate ACE_Array_Base<Kokyu::ConfigInfo>;
-#  endif /* __GNUC__ */
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
