@@ -1,10 +1,10 @@
-// EC_Kokyu_Factory.cpp,v 1.7 2004/08/16 23:53:13 jtc Exp
+// $Id: EC_Kokyu_Factory.cpp 73791 2006-07-27 20:54:56Z wotte $
 
-#include "EC_Kokyu_Factory.h"
-#include "EC_Kokyu_Dispatching.h"
-#include "EC_Kokyu_Scheduling.h"
-#include "EC_Kokyu_Filter_Builder.h"
-#include "EC_Event_Channel_Base.h"
+#include "orbsvcs/Event/EC_Kokyu_Factory.h"
+#include "orbsvcs/Event/EC_Kokyu_Dispatching.h"
+#include "orbsvcs/Event/EC_Kokyu_Scheduling.h"
+#include "orbsvcs/Event/EC_Kokyu_Filter_Builder.h"
+#include "orbsvcs/Event/EC_Event_Channel_Base.h"
 #include "orbsvcs/RtecSchedulerC.h"
 
 #include "ace/Arg_Shifter.h"
@@ -12,12 +12,14 @@
 #include "ace/OS_NS_strings.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "EC_Kokyu_Factory.i"
+#include "orbsvcs/Event/EC_Kokyu_Factory.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (Event, 
-           EC_Kokyu_Factory, 
-           "EC_Kokyu_Factory.cpp,v 1.7 2004/08/16 23:53:13 jtc Exp")
+ACE_RCSID (Event,
+           EC_Kokyu_Factory,
+           "$Id: EC_Kokyu_Factory.cpp 73791 2006-07-27 20:54:56Z wotte $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Kokyu_Factory::~TAO_EC_Kokyu_Factory (void)
 {
@@ -39,30 +41,30 @@ TAO_EC_Kokyu_Factory::init (int argc, ACE_TCHAR* argv[])
     {
       const ACE_TCHAR* arg = arg_shifter.get_current ();
 
-      if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECDispatching")) == 0)
+      if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECDispatching")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("reactive")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 {
                   this->dispatching_ = 0;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("mt")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("mt")) == 0)
                 {
                   this->dispatching_ = 1;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("kokyu")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("kokyu")) == 0)
                 {
                   this->dispatching_ = 2;
                 }
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Kokyu_Factory - ")
-                              ACE_LIB_TEXT("unsupported dispatching <%s>\n"),
+                              ACE_TEXT("EC_Kokyu_Factory - ")
+                              ACE_TEXT("unsupported dispatching <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
@@ -73,11 +75,11 @@ TAO_EC_Kokyu_Factory::init (int argc, ACE_TCHAR* argv[])
               if (arg_shifter.is_parameter_next ())
                 {
                   const ACE_TCHAR* opt = arg_shifter.get_current ();
-                  if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("SCHED_FIFO")) == 0)
+                  if (ACE_OS::strcasecmp (opt, ACE_TEXT("SCHED_FIFO")) == 0)
                     {
                       this->disp_sched_policy_ = ACE_SCHED_FIFO;
                     }
-                  else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("SCHED_RR")) == 0)
+                  else if (ACE_OS::strcasecmp (opt, ACE_TEXT("SCHED_RR")) == 0)
                     {
                       this->disp_sched_policy_ = ACE_SCHED_RR;
                     }
@@ -90,13 +92,13 @@ TAO_EC_Kokyu_Factory::init (int argc, ACE_TCHAR* argv[])
                   if (arg_shifter.is_parameter_next ())
                     {
                       const ACE_TCHAR* opt = arg_shifter.get_current ();
-                      if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("SYSTEM")) == 0)
+                      if (ACE_OS::strcasecmp (opt, ACE_TEXT("SYSTEM")) == 0)
                         {
-                          this->disp_sched_policy_ = ACE_SCOPE_THREAD;
+                          this->disp_sched_scope_ = ACE_SCOPE_THREAD;
                         }
-                      else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("PROCESS")) == 0)
+                      else if (ACE_OS::strcasecmp (opt, ACE_TEXT("PROCESS")) == 0)
                         {
-                          this->disp_sched_policy_ = ACE_SCOPE_PROCESS;
+                          this->disp_sched_scope_ = ACE_SCOPE_PROCESS;
                         }
                       arg_shifter.consume_arg ();
                     }
@@ -104,53 +106,53 @@ TAO_EC_Kokyu_Factory::init (int argc, ACE_TCHAR* argv[])
             }
         }
 
-      else if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECFiltering")) == 0)
+      else if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECFiltering")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("null")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("null")) == 0)
                 {
                   this->filtering_ = 0;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("basic")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("basic")) == 0)
                 {
                   this->filtering_ = 1;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("prefix")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("prefix")) == 0)
                 {
                   this->filtering_ = 2;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("kokyu")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("kokyu")) == 0)
                 {
                   this->filtering_ = 3;
                 }
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Kokyu_Factory - ")
-                              ACE_LIB_TEXT("unsupported filtering <%s>\n"),
+                              ACE_TEXT("EC_Kokyu_Factory - ")
+                              ACE_TEXT("unsupported filtering <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
             }
         }
 
-      else if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECTimeout")) == 0)
+      else if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECTimeout")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("reactive")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 {
                   this->timeout_ = 0;
                 }
 #if 0
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("kokyu")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("kokyu")) == 0)
                 {
                   this->timeout_ = 1;
                 }
@@ -158,38 +160,38 @@ TAO_EC_Kokyu_Factory::init (int argc, ACE_TCHAR* argv[])
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Kokyu_Factory - ")
-                              ACE_LIB_TEXT("unsupported timeout <%s>\n"),
+                              ACE_TEXT("EC_Kokyu_Factory - ")
+                              ACE_TEXT("unsupported timeout <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
             }
         }
 
-      else if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECScheduling")) == 0)
+      else if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECScheduling")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("null")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("null")) == 0)
                 {
                   this->scheduling_ = 0;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("group")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("group")) == 0)
                 {
                   this->scheduling_ = 1;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("kokyu")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("kokyu")) == 0)
                 {
                   this->scheduling_ = 2;
                 }
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Kokyu_Factory - ")
-                              ACE_LIB_TEXT("unsupported scheduling <%s>\n"),
+                              ACE_TEXT("EC_Kokyu_Factory - ")
+                              ACE_TEXT("unsupported scheduling <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
@@ -216,8 +218,8 @@ TAO_EC_Dispatching*
 TAO_EC_Kokyu_Factory::create_dispatching (TAO_EC_Event_Channel_Base *ec)
 {
   if (this->dispatching_ == 2)
-    return new TAO_EC_Kokyu_Dispatching (ec, 
-                                         this->disp_sched_policy_, 
+    return new TAO_EC_Kokyu_Dispatching (ec,
+                                         this->disp_sched_policy_,
                                          this->disp_sched_scope_);
   return this->TAO_EC_Default_Factory::create_dispatching (ec);
 }
@@ -257,6 +259,8 @@ TAO_EC_Kokyu_Factory::create_scheduling_strategy (TAO_EC_Event_Channel_Base* ec)
   return this->TAO_EC_Default_Factory::create_scheduling_strategy (ec);
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 // ****************************************************************
 
 ACE_STATIC_SVC_DEFINE (TAO_EC_Kokyu_Factory,
@@ -266,11 +270,3 @@ ACE_STATIC_SVC_DEFINE (TAO_EC_Kokyu_Factory,
                        ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
                        0)
 ACE_FACTORY_DEFINE (TAO_RTKokyuEvent, TAO_EC_Kokyu_Factory)
-
-// ****************************************************************
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
