@@ -1,20 +1,26 @@
-// EC_MT_Dispatching.cpp,v 1.10 2005/01/05 11:08:12 jwillemsen Exp
+// $Id: EC_MT_Dispatching.cpp 77613 2007-03-08 17:59:53Z fields_t $
 
-#include "EC_MT_Dispatching.h"
+#include "orbsvcs/Event/EC_MT_Dispatching.h"
 
-ACE_RCSID(Event, EC_MT_Dispatching, "EC_MT_Dispatching.cpp,v 1.10 2005/01/05 11:08:12 jwillemsen Exp")
+ACE_RCSID(Event, EC_MT_Dispatching, "$Id: EC_MT_Dispatching.cpp 77613 2007-03-08 17:59:53Z fields_t $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_MT_Dispatching::TAO_EC_MT_Dispatching (int nthreads,
                                               int thread_creation_flags,
                                               int thread_priority,
-                                              int force_activate)
+                                              int force_activate,
+                                              TAO_EC_Queue_Full_Service_Object* service_object)
   :  nthreads_ (nthreads),
      thread_creation_flags_ (thread_creation_flags),
      thread_priority_ (thread_priority),
      force_activate_ (force_activate),
-     task_ (&this->thread_manager_),
-     active_ (0)
+     task_(0, service_object),
+     active_ (0),
+     queue_full_service_object_ (service_object)
 {
+  this->task_.open (&this->thread_manager_);
 }
 
 void
@@ -63,23 +69,23 @@ void
 TAO_EC_MT_Dispatching::push (TAO_EC_ProxyPushSupplier* proxy,
                              RtecEventComm::PushConsumer_ptr consumer,
                              const RtecEventComm::EventSet& event,
-                             TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL)
+                             TAO_EC_QOS_Info& qos_info)
 {
   RtecEventComm::EventSet event_copy = event;
-  this->push_nocopy (proxy, consumer, event_copy, qos_info ACE_ENV_ARG_PARAMETER);
+  this->push_nocopy (proxy, consumer, event_copy, qos_info);
 }
 
 void
 TAO_EC_MT_Dispatching::push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
                                     RtecEventComm::PushConsumer_ptr consumer,
                                     RtecEventComm::EventSet& event,
-                                    TAO_EC_QOS_Info&
-                                    ACE_ENV_ARG_DECL)
+                                    TAO_EC_QOS_Info&)
 {
   // Double checked locking....
   if (this->active_ == 0)
     this->activate ();
 
-  this->task_.push (proxy, consumer, event ACE_ENV_ARG_PARAMETER);
+  this->task_.push (proxy, consumer, event);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
