@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_MT_Dispatching.h
  *
- *  EC_MT_Dispatching.h,v 1.14 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_MT_Dispatching.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -16,13 +17,15 @@
 #define TAO_EC_MT_DISPATCHING_H
 #include /**/ "ace/pre.h"
 
-#include "EC_Dispatching.h"
+#include "orbsvcs/Event/EC_Dispatching.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "EC_Dispatching_Task.h"
+#include "orbsvcs/Event/EC_Dispatching_Task.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /**
  * @class TAO_EC_MT_Dispatching
@@ -41,7 +44,8 @@ public:
   TAO_EC_MT_Dispatching (int nthreads,
                          int thread_creation_flags,
                          int thread_priority,
-                         int force_activate);
+                         int force_activate,
+                         TAO_EC_Queue_Full_Service_Object* queue_full_service_object_name);
 
   // = The EC_Dispatching methods.
   virtual void activate (void);
@@ -49,13 +53,11 @@ public:
   virtual void push (TAO_EC_ProxyPushSupplier* proxy,
                      RtecEventComm::PushConsumer_ptr consumer,
                      const RtecEventComm::EventSet& event,
-                     TAO_EC_QOS_Info& qos_info
-                     ACE_ENV_ARG_DECL);
+                     TAO_EC_QOS_Info& qos_info);
   virtual void push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
                             RtecEventComm::PushConsumer_ptr consumer,
                             RtecEventComm::EventSet& event,
-                            TAO_EC_QOS_Info& qos_info
-                            ACE_ENV_ARG_DECL);
+                            TAO_EC_QOS_Info& qos_info);
 
 private:
   /// Use our own thread manager.
@@ -83,7 +85,12 @@ private:
 
   /// Are the threads running?
   int active_;
+
+  /// Service Object information
+  TAO_EC_Queue_Full_Service_Object* queue_full_service_object_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_EC_MT_DISPATCHING_H */
