@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_Null_Factory.h
  *
- *  EC_Null_Factory.h,v 1.21 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Null_Factory.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -16,12 +17,14 @@
 #define TAO_EC_NULL_FACTORY_H
 #include /**/ "ace/pre.h"
 
-#include "EC_Factory.h"
+#include "orbsvcs/Event/EC_Factory.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_EC_Null_Factory
  *
@@ -107,5 +110,7 @@ public:
       destroy_supplier_control (TAO_EC_SupplierControl*);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_EC_NULL_FACTORY_H */
