@@ -1,21 +1,23 @@
-// EC_Per_Supplier_Filter.cpp,v 1.23 2004/08/16 23:53:13 jtc Exp
+// $Id: EC_Per_Supplier_Filter.cpp 76626 2007-01-26 13:50:03Z elliott_c $
 
-#include "EC_Per_Supplier_Filter.h"
-#include "EC_Event_Channel_Base.h"
-#include "EC_ProxySupplier.h"
-#include "EC_ProxyConsumer.h"
-#include "EC_Scheduling_Strategy.h"
-#include "EC_QOS_Info.h"
+#include "orbsvcs/Event/EC_Per_Supplier_Filter.h"
+#include "orbsvcs/Event/EC_Event_Channel_Base.h"
+#include "orbsvcs/Event/EC_ProxySupplier.h"
+#include "orbsvcs/Event/EC_ProxyConsumer.h"
+#include "orbsvcs/Event/EC_Scheduling_Strategy.h"
+#include "orbsvcs/Event/EC_QOS_Info.h"
 
 #include "orbsvcs/ESF/ESF_Proxy_Collection.h"
 
 #include "orbsvcs/Event_Service_Constants.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "EC_Per_Supplier_Filter.i"
+#include "orbsvcs/Event/EC_Per_Supplier_Filter.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, EC_Per_Supplier_Filter, "EC_Per_Supplier_Filter.cpp,v 1.23 2004/08/16 23:53:13 jtc Exp")
+ACE_RCSID(Event, EC_Per_Supplier_Filter, "$Id: EC_Per_Supplier_Filter.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Per_Supplier_Filter::
     TAO_EC_Per_Supplier_Filter (TAO_EC_Event_Channel_Base* ec)
@@ -53,21 +55,18 @@ TAO_EC_Per_Supplier_Filter::unbind (TAO_EC_ProxyPushConsumer* consumer)
 
   this->consumer_ = 0;
 
-  ACE_TRY_NEW_ENV
+  try
     {
-      this->shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->shutdown ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       // @@ Ignore exceptions
     }
-  ACE_ENDTRY;
 }
 
 void
-TAO_EC_Per_Supplier_Filter::connected (TAO_EC_ProxyPushSupplier* supplier
-                                       ACE_ENV_ARG_DECL)
+TAO_EC_Per_Supplier_Filter::connected (TAO_EC_ProxyPushSupplier* supplier)
 {
   ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->lock_);
 
@@ -93,8 +92,7 @@ TAO_EC_Per_Supplier_Filter::connected (TAO_EC_ProxyPushSupplier* supplier
 #if TAO_EC_ENABLE_DEBUG_MESSAGES
           ACE_DEBUG ((LM_DEBUG, "  matched\n"));
 #endif /* TAO_EC_ENABLED_DEBUG_MESSAGES */
-          this->collection_->connected (supplier ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+          this->collection_->connected (supplier);
           return;
         }
 #if TAO_EC_ENABLE_DEBUG_MESSAGES
@@ -104,8 +102,7 @@ TAO_EC_Per_Supplier_Filter::connected (TAO_EC_ProxyPushSupplier* supplier
 }
 
 void
-TAO_EC_Per_Supplier_Filter::reconnected (TAO_EC_ProxyPushSupplier* supplier
-                                         ACE_ENV_ARG_DECL)
+TAO_EC_Per_Supplier_Filter::reconnected (TAO_EC_ProxyPushSupplier* supplier)
 {
   ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->lock_);
 
@@ -126,47 +123,42 @@ TAO_EC_Per_Supplier_Filter::reconnected (TAO_EC_ProxyPushSupplier* supplier
       if (supplier->can_match (event.header))
         {
           //          ACE_DEBUG ((LM_DEBUG, "  matched %x\n", supplier));
-          this->collection_->connected (supplier ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+          this->collection_->connected (supplier);
           return;
         }
     }
-  this->collection_->disconnected (supplier ACE_ENV_ARG_PARAMETER);
+  this->collection_->disconnected (supplier);
 }
 
 void
-TAO_EC_Per_Supplier_Filter::disconnected (TAO_EC_ProxyPushSupplier* supplier
-                                          ACE_ENV_ARG_DECL)
+TAO_EC_Per_Supplier_Filter::disconnected (TAO_EC_ProxyPushSupplier* supplier)
 {
-  this->collection_->disconnected (supplier ACE_ENV_ARG_PARAMETER);
+  this->collection_->disconnected (supplier);
 }
 
 void
-TAO_EC_Per_Supplier_Filter::shutdown (ACE_ENV_SINGLE_ARG_DECL)
+TAO_EC_Per_Supplier_Filter::shutdown (void)
 {
-  this->collection_->shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
+  this->collection_->shutdown ();
 }
 
 void
 TAO_EC_Per_Supplier_Filter::push (const RtecEventComm::EventSet& event,
-                                  TAO_EC_ProxyPushConsumer *consumer
-                                  ACE_ENV_ARG_DECL)
+                                  TAO_EC_ProxyPushConsumer *consumer)
 {
   TAO_EC_Scheduling_Strategy* scheduling_strategy =
     this->event_channel_->scheduling_strategy ();
   scheduling_strategy->schedule_event (event,
                                        consumer,
-                                       this
-                                       ACE_ENV_ARG_PARAMETER);
+                                       this);
 }
 
 void
 TAO_EC_Per_Supplier_Filter::push_scheduled_event (RtecEventComm::EventSet &event,
-                                                  const TAO_EC_QOS_Info &event_info
-                                                  ACE_ENV_ARG_DECL)
+                                                  const TAO_EC_QOS_Info &event_info)
 {
   TAO_EC_Filter_Worker worker (event, event_info);
-  this->collection_->for_each (&worker ACE_ENV_ARG_PARAMETER);
+  this->collection_->for_each (&worker);
 }
 
 CORBA::ULong
@@ -207,3 +199,5 @@ TAO_EC_Per_Supplier_Filter_Builder::destroy (
 {
   delete x;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
