@@ -2,7 +2,7 @@
 /**
  *  @file   EC_Prefix_Filter_Builder.h
  *
- *  EC_Prefix_Filter_Builder.h,v 1.10 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Prefix_Filter_Builder.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -16,12 +16,15 @@
 #define TAO_EC_PREFIX_FILTER_BUILDER_H
 #include /**/ "ace/pre.h"
 
-#include "EC_Filter_Builder.h"
+#include "orbsvcs/Event/EC_Filter_Builder.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_EC_Filter;
 class TAO_EC_Event_Channel_Base;
 
@@ -45,8 +48,7 @@ public:
 
   // = The TAO_EC_Filter_Builder methods...
   TAO_EC_Filter* build (TAO_EC_ProxyPushSupplier *supplier,
-                        RtecEventChannelAdmin::ConsumerQOS& qos
-                        ACE_ENV_ARG_DECL) const;
+                        RtecEventChannelAdmin::ConsumerQOS& qos) const;
 
 private:
   /// Recursively build the filter tree.
@@ -59,8 +61,10 @@ private:
   TAO_EC_Event_Channel_Base* event_channel_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "EC_Prefix_Filter_Builder.i"
+#include "orbsvcs/Event/EC_Prefix_Filter_Builder.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
