@@ -1,16 +1,18 @@
-// EC_Priority_Scheduling.cpp,v 1.7 2005/01/27 19:44:46 jtc Exp
+// $Id: EC_Priority_Scheduling.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "EC_Priority_Scheduling.h"
-#include "EC_QOS_Info.h"
-#include "EC_ProxyConsumer.h"
-#include "EC_ProxySupplier.h"
-#include "EC_Supplier_Filter.h"
+#include "orbsvcs/Event/EC_Priority_Scheduling.h"
+#include "orbsvcs/Event/EC_QOS_Info.h"
+#include "orbsvcs/Event/EC_ProxyConsumer.h"
+#include "orbsvcs/Event/EC_ProxySupplier.h"
+#include "orbsvcs/Event/EC_Supplier_Filter.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "EC_Priority_Scheduling.i"
+#include "orbsvcs/Event/EC_Priority_Scheduling.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, EC_Priority_Scheduling, "EC_Priority_Scheduling.cpp,v 1.7 2005/01/27 19:44:46 jtc Exp")
+ACE_RCSID(Event, EC_Priority_Scheduling, "$Id: EC_Priority_Scheduling.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Priority_Scheduling::~TAO_EC_Priority_Scheduling (void)
 {
@@ -19,8 +21,7 @@ TAO_EC_Priority_Scheduling::~TAO_EC_Priority_Scheduling (void)
 void
 TAO_EC_Priority_Scheduling::add_proxy_supplier_dependencies (
       TAO_EC_ProxyPushSupplier *supplier,
-      TAO_EC_ProxyPushConsumer *consumer
-      ACE_ENV_ARG_DECL)
+      TAO_EC_ProxyPushConsumer *consumer)
 {
   ACE_DEBUG ((LM_DEBUG, "add_proxy_supplier_dependencies - %x %x\n",
               supplier, consumer));
@@ -39,21 +40,17 @@ TAO_EC_Priority_Scheduling::add_proxy_supplier_dependencies (
       this->scheduler_->priority (qos_info.rt_info,
                                   os_priority,
                                   p_subpriority,
-                                  p_priority
-                                   ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                  p_priority);
       qos_info.preemption_priority = p_priority;
 
-      supplier->add_dependencies (header, qos_info ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      supplier->add_dependencies (header, qos_info);
     }
 }
 
 void
 TAO_EC_Priority_Scheduling::schedule_event (const RtecEventComm::EventSet &event,
                                             TAO_EC_ProxyPushConsumer *consumer,
-                                            TAO_EC_Supplier_Filter *filter
-                                            ACE_ENV_ARG_DECL)
+                                            TAO_EC_Supplier_Filter *filter)
 {
   RtecEventChannelAdmin::SupplierQOS qos =
     consumer->publications ();
@@ -83,14 +80,12 @@ TAO_EC_Priority_Scheduling::schedule_event (const RtecEventComm::EventSet &event
           this->scheduler_->priority (qos_info.rt_info,
                                       os_priority,
                                       p_subpriority,
-                                      p_priority
-                                      ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+                                      p_priority);
           qos_info.preemption_priority = p_priority;
         }
 
-      filter->push_scheduled_event (single_event, qos_info
-                                    ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      filter->push_scheduled_event (single_event, qos_info);
     }
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
