@@ -1,17 +1,21 @@
+// -*- C++ -*-
+
 /**
  * @file EC_Proxy_Disconnector.h
  *
  * @author Carlos O'Ryan <coryan@atdesk.com>
  *
- * EC_Proxy_Disconnector.h,v 1.6 2005/05/23 10:50:44 jwillemsen Exp
+ * $Id: EC_Proxy_Disconnector.h 77276 2007-02-21 08:26:36Z johnnyw $
  */
 #ifndef EC_PROXY_DISCONNECTOR__H_
 #define EC_PROXY_DISCONNECTOR__H_
 
-#include /**/ "event_serv_export.h"
+#include /**/ "orbsvcs/Event/event_serv_export.h"
 #include "orbsvcs/RtecEventCommC.h"
 #include "ace/Auto_Functor.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @struct TAO_EC_Supplier_Proxy_Disconnect_Functor
  *
@@ -22,8 +26,7 @@ struct TAO_RTEvent_Serv_Export TAO_EC_Supplier_Proxy_Disconnect_Functor
   typedef  RtecEventComm::PushSupplier_ptr argument;
 
   /// Disconnect from @c supplier
-  void operator() (RtecEventComm::PushSupplier_ptr supplier)
-    ACE_THROW_SPEC (());
+  void operator() (RtecEventComm::PushSupplier_ptr supplier) throw ();
 };
 
 /**
@@ -50,8 +53,7 @@ struct TAO_RTEvent_Serv_Export TAO_EC_Consumer_Proxy_Disconnect_Functor
   typedef  RtecEventComm::PushConsumer_ptr argument;
 
   /// Disconnect from @c consumer
-  void operator() (RtecEventComm::PushConsumer_ptr consumer)
-    ACE_THROW_SPEC (());
+  void operator() (RtecEventComm::PushConsumer_ptr consumer) throw ();
 };
 
 /**
@@ -67,4 +69,6 @@ typedef ACE_Utils::Auto_Functor<
         TAO_EC_Consumer_Proxy_Disconnector;
 
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif // EC_PROXY_DISCONNECTOR__H_
