@@ -1,9 +1,11 @@
-// EC_RTCORBA_Dispatching.cpp,v 1.6 2005/01/05 11:08:12 jwillemsen Exp
+// $Id: EC_RTCORBA_Dispatching.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "EC_RTCORBA_Dispatching.h"
+#include "orbsvcs/Event/EC_RTCORBA_Dispatching.h"
 #include "tao/RTCORBA/Priority_Mapping.h"
 
-ACE_RCSID(Event, EC_RTCORBA_Dispatching, "EC_RTCORBA_Dispatching.cpp,v 1.6 2005/01/05 11:08:12 jwillemsen Exp")
+ACE_RCSID(Event, EC_RTCORBA_Dispatching, "$Id: EC_RTCORBA_Dispatching.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_RTCORBA_Dispatching::
   TAO_EC_RTCORBA_Dispatching (const RTCORBA::ThreadpoolLanes &lanes,
@@ -68,23 +70,20 @@ void
 TAO_EC_RTCORBA_Dispatching::push (TAO_EC_ProxyPushSupplier* proxy,
                              RtecEventComm::PushConsumer_ptr consumer,
                              const RtecEventComm::EventSet& event,
-                             TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL)
+                             TAO_EC_QOS_Info& qos_info)
 {
   RtecEventComm::EventSet event_copy = event;
-  this->push_nocopy (proxy, consumer, event_copy, qos_info ACE_ENV_ARG_PARAMETER);
+  this->push_nocopy (proxy, consumer, event_copy, qos_info);
 }
 
 void
 TAO_EC_RTCORBA_Dispatching::push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
                                          RtecEventComm::PushConsumer_ptr consumer,
                                          RtecEventComm::EventSet& event,
-                                         TAO_EC_QOS_Info&
-                                         ACE_ENV_ARG_DECL)
+                                         TAO_EC_QOS_Info&)
 {
   RTCORBA::Priority current_priority =
-    this->current_->the_priority (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->current_->the_priority ();
 
   for (CORBA::ULong i = 0; i != this->lanes_.length (); ++i)
     {
@@ -94,9 +93,9 @@ TAO_EC_RTCORBA_Dispatching::push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
       // @@ If there were no threads available we may need to create
       // some...
 
-      this->tasks_[i].push (proxy, consumer, event
-                            ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->tasks_[i].push (proxy, consumer, event);
       break;
     }
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
