@@ -1,9 +1,11 @@
-// EC_Reactive_Dispatching.cpp,v 1.3 2005/01/05 11:08:12 jwillemsen Exp
+// $Id: EC_Reactive_Dispatching.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "EC_Reactive_Dispatching.h"
-#include "EC_ProxySupplier.h"
+#include "orbsvcs/Event/EC_Reactive_Dispatching.h"
+#include "orbsvcs/Event/EC_ProxySupplier.h"
 
-ACE_RCSID(Event, EC_Reactive_Dispatching, "EC_Reactive_Dispatching.cpp,v 1.3 2005/01/05 11:08:12 jwillemsen Exp")
+ACE_RCSID(Event, EC_Reactive_Dispatching, "$Id: EC_Reactive_Dispatching.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Reactive_Dispatching::TAO_EC_Reactive_Dispatching (void)
   : TAO_EC_Dispatching ()
@@ -24,18 +26,18 @@ void
 TAO_EC_Reactive_Dispatching::push (TAO_EC_ProxyPushSupplier* proxy,
                                    RtecEventComm::PushConsumer_ptr consumer,
                                    const RtecEventComm::EventSet& event,
-                                   TAO_EC_QOS_Info&
-                                   ACE_ENV_ARG_DECL)
+                                   TAO_EC_QOS_Info&)
 {
-  proxy->reactive_push_to_consumer (consumer, event ACE_ENV_ARG_PARAMETER);
+  proxy->reactive_push_to_consumer (consumer, event);
 }
 
 void
 TAO_EC_Reactive_Dispatching::push_nocopy (TAO_EC_ProxyPushSupplier* proxy,
                                           RtecEventComm::PushConsumer_ptr consumer,
                                           RtecEventComm::EventSet& event,
-                                          TAO_EC_QOS_Info&
-                                          ACE_ENV_ARG_DECL)
+                                          TAO_EC_QOS_Info&)
 {
-  proxy->reactive_push_to_consumer (consumer, event ACE_ENV_ARG_PARAMETER);
+  proxy->reactive_push_to_consumer (consumer, event);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
