@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_Reactive_SupplierControl.h
  *
- *  EC_Reactive_SupplierControl.h,v 1.22 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Reactive_SupplierControl.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -17,7 +18,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "EC_SupplierControl.h"
+#include "orbsvcs/Event/EC_SupplierControl.h"
 
 #include "orbsvcs/ESF/ESF_Worker.h"
 
@@ -30,6 +31,8 @@
 
 #include "ace/Event_Handler.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_EC_Event_Channel_Base;
 
 class TAO_EC_Reactive_SupplierControl;
@@ -96,16 +99,14 @@ public:
   // = Documented in TAO_EC_SupplierControl
   virtual int activate (void);
   virtual int shutdown (void);
-  virtual void supplier_not_exist (TAO_EC_ProxyPushConsumer *proxy
-                                   ACE_ENV_ARG_DECL_NOT_USED);
+  virtual void supplier_not_exist (TAO_EC_ProxyPushConsumer *proxy);
   virtual void system_exception (TAO_EC_ProxyPushConsumer *proxy,
-                                 CORBA::SystemException &
-                                 ACE_ENV_ARG_DECL_NOT_USED);
+                                 CORBA::SystemException &);
 
 private:
   /// Check if the suppliers still exists.  It is a helper method for
   /// handle_timeout() to isolate the exceptions.
-  void query_suppliers (ACE_ENV_SINGLE_ARG_DECL);
+  void query_suppliers (void);
 
 private:
   /// The polling rate
@@ -145,15 +146,16 @@ class TAO_EC_Ping_Supplier : public TAO_ESF_Worker<TAO_EC_ProxyPushConsumer>
 public:
   TAO_EC_Ping_Supplier (TAO_EC_SupplierControl *control);
 
-  virtual void work (TAO_EC_ProxyPushConsumer *consumer
-                     ACE_ENV_ARG_DECL);
+  virtual void work (TAO_EC_ProxyPushConsumer *consumer);
 
 private:
   TAO_EC_SupplierControl *control_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "EC_Reactive_SupplierControl.i"
+#include "orbsvcs/Event/EC_Reactive_SupplierControl.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
