@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_Reactive_Timeout_Generator.h
  *
- *  EC_Reactive_Timeout_Generator.h,v 1.11 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Reactive_Timeout_Generator.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -17,12 +18,14 @@
 
 #include /**/ "ace/pre.h"
 
-#include "EC_Timeout_Generator.h"
+#include "orbsvcs/Event/EC_Timeout_Generator.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_EC_Reactive_Timeout_Generator
  *
@@ -60,6 +63,8 @@ private:
   TAO_EC_Timeout_Adapter event_handler_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_EC_REACTIVE_TIMEOUT_GENERATOR_H */
