@@ -1,10 +1,10 @@
-// EC_Sched_Factory.cpp,v 1.10 2004/08/16 23:53:13 jtc Exp
+// $Id: EC_Sched_Factory.cpp 73791 2006-07-27 20:54:56Z wotte $
 
-#include "EC_Sched_Factory.h"
-#include "EC_Priority_Dispatching.h"
-#include "EC_Priority_Scheduling.h"
-#include "EC_Sched_Filter_Builder.h"
-#include "EC_Event_Channel_Base.h"
+#include "orbsvcs/Event/EC_Sched_Factory.h"
+#include "orbsvcs/Event/EC_Priority_Dispatching.h"
+#include "orbsvcs/Event/EC_Priority_Scheduling.h"
+#include "orbsvcs/Event/EC_Sched_Filter_Builder.h"
+#include "orbsvcs/Event/EC_Event_Channel_Base.h"
 #include "orbsvcs/RtecSchedulerC.h"
 
 #include "ace/Arg_Shifter.h"
@@ -12,10 +12,12 @@
 #include "ace/OS_NS_strings.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "EC_Sched_Factory.i"
+#include "orbsvcs/Event/EC_Sched_Factory.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Event, EC_Sched_Factory, "EC_Sched_Factory.cpp,v 1.10 2004/08/16 23:53:13 jtc Exp")
+ACE_RCSID(Event, EC_Sched_Factory, "$Id: EC_Sched_Factory.cpp 73791 2006-07-27 20:54:56Z wotte $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_EC_Sched_Factory::~TAO_EC_Sched_Factory (void)
 {
@@ -30,83 +32,83 @@ TAO_EC_Sched_Factory::init (int argc, ACE_TCHAR* argv[])
     {
       const ACE_TCHAR* arg = arg_shifter.get_current ();
 
-      if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECDispatching")) == 0)
+      if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECDispatching")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("reactive")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 {
                   this->dispatching_ = 0;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("mt")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("mt")) == 0)
                 {
                   this->dispatching_ = 1;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("priority")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("priority")) == 0)
                 {
                   this->dispatching_ = 2;
                 }
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Sched_Factory - ")
-                              ACE_LIB_TEXT("unsupported dispatching <%s>\n"),
+                              ACE_TEXT("EC_Sched_Factory - ")
+                              ACE_TEXT("unsupported dispatching <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
             }
         }
 
-      else if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECFiltering")) == 0)
+      else if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECFiltering")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("null")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("null")) == 0)
                 {
                   this->filtering_ = 0;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("basic")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("basic")) == 0)
                 {
                   this->filtering_ = 1;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("prefix")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("prefix")) == 0)
                 {
                   this->filtering_ = 2;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("priority")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("priority")) == 0)
                 {
                   this->filtering_ = 3;
                 }
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Sched_Factory - ")
-                              ACE_LIB_TEXT("unsupported filtering <%s>\n"),
+                              ACE_TEXT("EC_Sched_Factory - ")
+                              ACE_TEXT("unsupported filtering <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
             }
         }
 
-      else if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECTimeout")) == 0)
+      else if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECTimeout")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("reactive")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("reactive")) == 0)
                 {
                   this->timeout_ = 0;
                 }
 #if 0
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("priority")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("priority")) == 0)
                 {
                   this->timeout_ = 1;
                 }
@@ -114,38 +116,38 @@ TAO_EC_Sched_Factory::init (int argc, ACE_TCHAR* argv[])
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Sched_Factory - ")
-                              ACE_LIB_TEXT("unsupported timeout <%s>\n"),
+                              ACE_TEXT("EC_Sched_Factory - ")
+                              ACE_TEXT("unsupported timeout <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
             }
         }
 
-      else if (ACE_OS::strcasecmp (arg, ACE_LIB_TEXT("-ECScheduling")) == 0)
+      else if (ACE_OS::strcasecmp (arg, ACE_TEXT("-ECScheduling")) == 0)
         {
           arg_shifter.consume_arg ();
 
           if (arg_shifter.is_parameter_next ())
             {
               const ACE_TCHAR* opt = arg_shifter.get_current ();
-              if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("null")) == 0)
+              if (ACE_OS::strcasecmp (opt, ACE_TEXT("null")) == 0)
                 {
                   this->scheduling_ = 0;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("group")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("group")) == 0)
                 {
                   this->scheduling_ = 1;
                 }
-              else if (ACE_OS::strcasecmp (opt, ACE_LIB_TEXT("priority")) == 0)
+              else if (ACE_OS::strcasecmp (opt, ACE_TEXT("priority")) == 0)
                 {
                   this->scheduling_ = 2;
                 }
               else
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_LIB_TEXT("EC_Sched_Factory - ")
-                              ACE_LIB_TEXT("unsupported scheduling <%s>\n"),
+                              ACE_TEXT("EC_Sched_Factory - ")
+                              ACE_TEXT("unsupported scheduling <%s>\n"),
                               opt));
                 }
               arg_shifter.consume_arg ();
@@ -210,6 +212,8 @@ TAO_EC_Sched_Factory::create_scheduling_strategy (TAO_EC_Event_Channel_Base* ec)
   return this->TAO_EC_Sched_Factory::create_scheduling_strategy (ec);
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 // ****************************************************************
 
 ACE_STATIC_SVC_DEFINE (TAO_EC_Sched_Factory,
@@ -219,11 +223,3 @@ ACE_STATIC_SVC_DEFINE (TAO_EC_Sched_Factory,
                        ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
                        0)
 ACE_FACTORY_DEFINE (TAO_RTSchedEvent, TAO_EC_Sched_Factory)
-
-// ****************************************************************
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
