@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_Timeout_Filter.h
  *
- *  EC_Timeout_Filter.h,v 1.15 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Timeout_Filter.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -17,13 +18,15 @@
 
 #include /**/ "ace/pre.h"
 
-#include "EC_Filter.h"
+#include "orbsvcs/Event/EC_Filter.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "EC_QOS_Info.h"
+#include "orbsvcs/Event/EC_QOS_Info.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_EC_Event_Channel_Base;
 class TAO_EC_ProxyPushSupplier;
@@ -57,35 +60,27 @@ public:
 
   /// Callback from the Timeout_Generator
   void push_to_proxy (const RtecEventComm::EventSet& event,
-                      TAO_EC_QOS_Info& qos_info
-                      ACE_ENV_ARG_DECL);
+                      TAO_EC_QOS_Info& qos_info);
 
   // = The TAO_EC_Filter methods, please check the documentation in
   // TAO_EC_Filter.
   virtual int filter (const RtecEventComm::EventSet& event,
-                      TAO_EC_QOS_Info& qos_info
-                      ACE_ENV_ARG_DECL);
+                      TAO_EC_QOS_Info& qos_info);
   virtual int filter_nocopy (RtecEventComm::EventSet& event,
-                             TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL);
+                             TAO_EC_QOS_Info& qos_info);
   virtual void push (const RtecEventComm::EventSet& event,
-                     TAO_EC_QOS_Info& qos_info
-                     ACE_ENV_ARG_DECL);
+                     TAO_EC_QOS_Info& qos_info);
   virtual void push_nocopy (RtecEventComm::EventSet& event,
-                            TAO_EC_QOS_Info& qos_info
-                            ACE_ENV_ARG_DECL);
+                            TAO_EC_QOS_Info& qos_info);
   virtual void clear (void);
   virtual CORBA::ULong max_event_size (void) const;
   virtual int can_match (const RtecEventComm::EventHeader& header) const;
   virtual int add_dependencies (const RtecEventComm::EventHeader& header,
-                                const TAO_EC_QOS_Info &qos_info
-                                ACE_ENV_ARG_DECL);
+                                const TAO_EC_QOS_Info &qos_info);
 
 private:
-  ACE_UNIMPLEMENTED_FUNC (TAO_EC_Timeout_Filter
-                              (const TAO_EC_Timeout_Filter&))
-  ACE_UNIMPLEMENTED_FUNC (TAO_EC_Timeout_Filter& operator=
-                              (const TAO_EC_Timeout_Filter&))
+  TAO_EC_Timeout_Filter (const TAO_EC_Timeout_Filter&);
+  TAO_EC_Timeout_Filter& operator= (const TAO_EC_Timeout_Filter&);
 
 private:
   /// The event channel.
@@ -108,8 +103,10 @@ private:
   long id_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "EC_Timeout_Filter.i"
+#include "orbsvcs/Event/EC_Timeout_Filter.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
