@@ -1,8 +1,9 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file   EC_Type_Filter.h
  *
- *  EC_Type_Filter.h,v 1.16 2005/05/23 10:50:44 jwillemsen Exp
+ *  $Id: EC_Type_Filter.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  *
@@ -16,13 +17,15 @@
 #define TAO_EC_TYPE_FILTER_H
 #include /**/ "ace/pre.h"
 
-#include "EC_Filter.h"
-#include /**/ "event_serv_export.h"
+#include "orbsvcs/Event/EC_Filter.h"
+#include /**/ "orbsvcs/Event/event_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_EC_Type_Filter
  *
@@ -40,39 +43,33 @@ public:
   // = The TAO_EC_Filter methods, please check the documentation in
   // TAO_EC_Filter.
   virtual int filter (const RtecEventComm::EventSet& event,
-                      TAO_EC_QOS_Info& qos_info
-                      ACE_ENV_ARG_DECL);
+                      TAO_EC_QOS_Info& qos_info);
   virtual int filter_nocopy (RtecEventComm::EventSet& event,
-                             TAO_EC_QOS_Info& qos_info
-                             ACE_ENV_ARG_DECL);
+                             TAO_EC_QOS_Info& qos_info);
   virtual void push (const RtecEventComm::EventSet& event,
-                     TAO_EC_QOS_Info& qos_info
-                     ACE_ENV_ARG_DECL);
+                     TAO_EC_QOS_Info& qos_info);
   virtual void push_nocopy (RtecEventComm::EventSet& event,
-                            TAO_EC_QOS_Info& qos_info
-                            ACE_ENV_ARG_DECL);
+                            TAO_EC_QOS_Info& qos_info);
   virtual void clear (void);
   virtual CORBA::ULong max_event_size (void) const;
   virtual int can_match (const RtecEventComm::EventHeader& header) const;
   virtual int add_dependencies (const RtecEventComm::EventHeader& header,
-                                const TAO_EC_QOS_Info &qos_info
-                                ACE_ENV_ARG_DECL);
+                                const TAO_EC_QOS_Info &qos_info);
 
 private:
-  ACE_UNIMPLEMENTED_FUNC (TAO_EC_Type_Filter
-                              (const TAO_EC_Type_Filter&))
-  ACE_UNIMPLEMENTED_FUNC (TAO_EC_Type_Filter& operator=
-                              (const TAO_EC_Type_Filter&))
+  TAO_EC_Type_Filter (const TAO_EC_Type_Filter&);
+  TAO_EC_Type_Filter& operator= (const TAO_EC_Type_Filter&);
 
   /// Filter an EventSet that contains more than one event.
   int filter_set (const RtecEventComm::EventSet& event,
-                  TAO_EC_QOS_Info& qos_info
-                  ACE_ENV_ARG_DECL);
+                  TAO_EC_QOS_Info& qos_info);
 
 private:
   /// Encapsulate the type/source that we must match.
   RtecEventComm::EventHeader header_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_EC_TYPE_FILTER_H */
