@@ -1,31 +1,29 @@
-// FT_Endpoint_Selector_Factory.cpp,v 1.8 2004/09/03 20:58:18 ossama Exp
+// $Id: FT_Endpoint_Selector_Factory.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
-#include "FT_Endpoint_Selector_Factory.h"
-#include "FT_Invocation_Endpoint_Selectors.h"
+#include "orbsvcs/FaultTolerance/FT_Endpoint_Selector_Factory.h"
+#include "orbsvcs/FaultTolerance/FT_Invocation_Endpoint_Selectors.h"
 #include "tao/SystemException.h"
-#include "tao/Environment.h"
 
 
 ACE_RCSID (FaultTolerance,
            FT_Endpoint_Selector_Factory,
-           "FT_Endpoint_Selector_Factory.cpp,v 1.8 2004/09/03 20:58:18 ossama Exp")
+           "$Id: FT_Endpoint_Selector_Factory.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_FT_Endpoint_Selector_Factory::TAO_FT_Endpoint_Selector_Factory (void)
-  :ft_endpoint_selector_ (0)
+  : ft_endpoint_selector_ (0)
 {
 }
 
 TAO_FT_Endpoint_Selector_Factory::~TAO_FT_Endpoint_Selector_Factory (void)
 {
-  if (this->ft_endpoint_selector_)
-    delete this->ft_endpoint_selector_;
+  delete this->ft_endpoint_selector_;
 }
 
 
 TAO_Invocation_Endpoint_Selector *
-TAO_FT_Endpoint_Selector_Factory::get_selector (
-    ACE_ENV_SINGLE_ARG_DECL)
+TAO_FT_Endpoint_Selector_Factory::get_selector ()
 {
     if (this->ft_endpoint_selector_ == 0)
     {
@@ -40,13 +38,14 @@ TAO_FT_Endpoint_Selector_Factory::get_selector (
           ACE_NEW_THROW_EX (ft_endpoint_selector_,
                             TAO_FT_Invocation_Endpoint_Selector (),
                             CORBA::NO_MEMORY ());
-          ACE_CHECK_RETURN (0);
         }
     }
 
   return this->ft_endpoint_selector_;
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 // ****************************************************************
 
 ACE_STATIC_SVC_DEFINE (TAO_FT_Endpoint_Selector_Factory,
