@@ -4,7 +4,7 @@
 /**
  *  @file     FT_PolicyFactory.h
  *
- *  $Id: FT_PolicyFactory.h 77001 2007-02-12 07:54:49Z johnnyw $
+ *  $Id: FT_PolicyFactory.h 81490 2008-04-28 14:32:24Z johnnyw $
  *
  *  @author  Bala Natarajan <bala@cs.wustl.edu>
  */
@@ -40,7 +40,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// Policy factory for all FTCORBA related policies.
 class TAO_FT_PolicyFactory
   : public PortableInterceptor::PolicyFactory
-  , public TAO_Local_RefCounted_Object
+  , public ::CORBA::LocalObject
 {
 public:
 
