@@ -4,7 +4,7 @@
 /**
  *  @file     FT_ServerPolicyFactory.h
  *
- *  $Id: FT_ServerPolicyFactory.h 77001 2007-02-12 07:54:49Z johnnyw $
+ *  $Id: FT_ServerPolicyFactory.h 81490 2008-04-28 14:32:24Z johnnyw $
  *
  *  @author  Bala Natarajan <bala@cs.wustl.edu>
  */
@@ -38,7 +38,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// Policy factory for all FTCORBA related policies.
 class TAO_FT_ServerPolicyFactory
   : public PortableInterceptor::PolicyFactory
-  , public TAO_Local_RefCounted_Object
+  , public ::CORBA::LocalObject
 {
 public:
 
