@@ -1,14 +1,16 @@
-#include "FT_ServerService_Activate.h"
-#include "FT_ServerORBInitializer.h"
+#include "orbsvcs/FaultTolerance/FT_ServerService_Activate.h"
+#include "orbsvcs/FaultTolerance/FT_ServerORBInitializer.h"
 #include "tao/ORB_Core.h"
 #include "tao/Service_Callbacks.h"
 #include "tao/ORBInitializer_Registry.h"
 #include "ace/Dynamic_Service.h"
 
-ACE_RCSID(FaultTolerance, FT_ServerService_Activate, "FT_ServerService_Activate.cpp,v 1.3 2005/06/14 08:54:59 jwillemsen Exp")
+ACE_RCSID(FaultTolerance, FT_ServerService_Activate, "$Id: FT_ServerService_Activate.cpp 75478 2006-11-22 13:58:29Z jtc $")
 
 static bool initialized = false;
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_FT_ServerService_Activate::TAO_FT_ServerService_Activate (void)
 {
 }
@@ -17,8 +19,6 @@ TAO_FT_ServerService_Activate::~TAO_FT_ServerService_Activate (void)
 {
 }
 
-
-
 int
 TAO_FT_ServerService_Activate::Initializer (void)
 {
@@ -43,6 +43,8 @@ TAO_FT_ServerService_Activate::Initializer (void)
   return 0;
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 ACE_FACTORY_DEFINE (TAO_FT_ServerORB,TAO_FT_ServerService_Activate)
 
 ACE_STATIC_SVC_DEFINE (TAO_FT_ServerService_Activate,
@@ -51,9 +53,3 @@ ACE_STATIC_SVC_DEFINE (TAO_FT_ServerService_Activate,
                        &ACE_SVC_NAME (TAO_FT_ServerService_Activate),
                        ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
                        0)
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-template class ACE_Dynamic_Service<TAO_FT_ServerService_Activate>;
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate ACE_Dynamic_Service<TAO_FT_ServerService_Activate>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
