@@ -1,6 +1,6 @@
-// FTRT_ClientORB_Interceptor.cpp,v 1.11 2005/01/27 19:44:46 jtc Exp
+// $Id: FTRT_ClientORB_Interceptor.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
-#include "FTRT_ClientORB_Interceptor.h"
+#include "orbsvcs/FtRtEvent/ClientORB/FTRT_ClientORB_Interceptor.h"
 #include "tao/MProfile.h"
 #include "tao/Stub.h"
 #include "tao/CDR.h"
@@ -8,7 +8,9 @@
 
 ACE_RCSID (ClientORB,
            FTRT_ClientORB_Interceptor,
-           "FTRT_ClientORB_Interceptor.cpp,v 1.11 2005/01/27 19:44:46 jtc Exp")
+           "$Id: FTRT_ClientORB_Interceptor.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace FTRT {
   const unsigned FT_TRANSACTION_DEPTH = 30;
@@ -27,36 +29,28 @@ FTRT_ClientORB_Interceptor::~FTRT_ClientORB_Interceptor (void)
 }
 
 char *
-FTRT_ClientORB_Interceptor::name (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+FTRT_ClientORB_Interceptor::name (void)
 {
   return CORBA::string_dup (this->myname_);
 }
 
 void
-FTRT_ClientORB_Interceptor::destroy (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+FTRT_ClientORB_Interceptor::destroy (void)
 {
 }
 
 void
 FTRT_ClientORB_Interceptor::send_poll (
-    PortableInterceptor::ClientRequestInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ClientRequestInfo_ptr)
 {
-  // Do Nothing
 }
 
 void
 FTRT_ClientORB_Interceptor::send_request (
-    PortableInterceptor::ClientRequestInfo_ptr ri
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableInterceptor::ForwardRequest))
+    PortableInterceptor::ClientRequestInfo_ptr ri)
 {
   ACE_TRACE("FTRT_ClientORB_Interceptor::send_request");
-  ACE_TRY
+  try
   {
     // Add FT_REQUEST context
     IOP::ServiceContext sc;
@@ -88,38 +82,29 @@ FTRT_ClientORB_Interceptor::send_request (
       }
 #endif /* TAO_NO_COPY_OCTET_SEQUENCES == 1 */
 
-    ri->add_request_service_context (sc, 0 ACE_ENV_ARG_PARAMETER);
-    ACE_TRY_CHECK;
+    ri->add_request_service_context (sc, 0);
   }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
   {
     // Not much can be done anyway. Just keep quiet
   }
-  ACE_ENDTRY;
-  ACE_CHECK;
 }
 
 void
 FTRT_ClientORB_Interceptor::receive_reply (
-    PortableInterceptor::ClientRequestInfo_ptr ri
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ClientRequestInfo_ptr ri)
 {
   ACE_TRACE("FTRT_ClientORB_Interceptor::receive_reply");
 
 
   IOP::ServiceContext_var service_context;
-  ACE_TRY {
+  try{
     service_context =
-      ri->get_reply_service_context(FTRT::FT_FORWARD
-                                    ACE_ENV_ARG_PARAMETER);
-    ACE_TRY_CHECK;
+      ri->get_reply_service_context(FTRT::FT_FORWARD);
   }
-  ACE_CATCHANY {
+  catch (const CORBA::Exception&){
     return;
   }
-  ACE_ENDTRY;
-  ACE_CHECK;
 
 
   const char * buf =
@@ -133,7 +118,7 @@ FTRT_ClientORB_Interceptor::receive_reply (
 
   if (cdr >> obj) {
     // update the target
-     CORBA::Object_var target = ri->target(ACE_ENV_SINGLE_ARG_PARAMETER);
+     CORBA::Object_var target = ri->target();
      target->_stubobj ()->base_profiles ( obj->_stubobj()->base_profiles() );
      ACE_DEBUG((LM_DEBUG, "target object updated\n"));
   }
@@ -141,19 +126,14 @@ FTRT_ClientORB_Interceptor::receive_reply (
 
 void
 FTRT_ClientORB_Interceptor::receive_other (
-    PortableInterceptor::ClientRequestInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableInterceptor::ForwardRequest))
+    PortableInterceptor::ClientRequestInfo_ptr)
 {
 }
 
 void
 FTRT_ClientORB_Interceptor::receive_exception (
-    PortableInterceptor::ClientRequestInfo_ptr ri
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableInterceptor::ForwardRequest))
+    PortableInterceptor::ClientRequestInfo_ptr /* ri */)
 {
-    ACE_UNUSED_ARG(ri);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
