@@ -1,8 +1,8 @@
-// FTRT_ClientORB_Loader.cpp,v 1.7 2005/02/18 09:07:07 jwillemsen Exp
+// $Id: FTRT_ClientORB_Loader.cpp 78858 2007-07-12 23:24:55Z sowayaa $
 
-#include "FTRT_ClientORB_Loader.h"
+#include "orbsvcs/FtRtEvent/ClientORB/FTRT_ClientORB_Loader.h"
 
-#include "FTRT_ClientORB_Initializer.h"
+#include "orbsvcs/FtRtEvent/ClientORB/FTRT_ClientORB_Initializer.h"
 
 #include "tao/debug.h"
 #include "tao/ORB_Constants.h"
@@ -11,9 +11,11 @@
 
 ACE_RCSID (ClientORB,
            FTRT_ClientORB_Loader,
-           "FTRT_ClientORB_Loader.cpp,v 1.7 2005/02/18 09:07:07 jwillemsen Exp")
+           "$Id: FTRT_ClientORB_Loader.cpp 78858 2007-07-12 23:24:55Z sowayaa $")
 
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO_FTRT {
   FTRT_ClientORB_Loader::FTRT_ClientORB_Loader (void)
   {
@@ -41,16 +43,16 @@ namespace TAO_FTRT {
     // Parse any service configurator parameters.
     for (curarg = 0; curarg < argc; curarg++)
       if (ACE_OS::strcasecmp (argv[curarg],
-        ACE_LIB_TEXT("-ORBTransactionDepth")) == 0)
+        ACE_TEXT("-ORBTransactionDepth")) == 0)
       {
         curarg++;
         if (curarg < argc)
-          transaction_depth = atoi(argv[curarg]);
+          transaction_depth = ACE_OS::atoi(argv[curarg]);
       }
 
 
       // Register the ORB initializer.
-      ACE_TRY_NEW_ENV
+      try
       {
         PortableInterceptor::ORBInitializer_ptr temp_orb_initializer =
           PortableInterceptor::ORBInitializer::_nil ();
@@ -64,34 +66,37 @@ namespace TAO_FTRT {
           TAO::VMCID,
           ENOMEM),
           CORBA::COMPLETED_NO));
-        ACE_TRY_CHECK;
         orb_initializer = temp_orb_initializer;
 
-        PortableInterceptor::register_orb_initializer (orb_initializer.in ()
-          ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+        PortableInterceptor::register_orb_initializer (orb_initializer.in ());
       }
-      ACE_CATCHANY
+      catch (const CORBA::Exception& ex)
       {
-        ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-          "Unexpected exception caught while "
-          "initializing the TransactionDepth");
+        ex._tao_print_exception (
+          "Unexpected exception caught while ""initializing the TransactionDepth");
         return 1;
       }
-      ACE_ENDTRY;
 
       return 0;
   }
+}
+
+TAO_END_VERSIONED_NAMESPACE_DECL
 
   /////////////////////////////////////////////////////////////////////
 
-  ACE_FACTORY_DEFINE (TAO_FTRT, FTRT_ClientORB_Loader)
-  ACE_STATIC_SVC_DEFINE (FTRT_ClientORB_Loader,
-    ACE_TEXT ("FTRT_ClientORB_Service"),
-    ACE_SVC_OBJ_T,
-    &ACE_SVC_NAME (FTRT_ClientORB_Loader),
-    ACE_Service_Type::DELETE_THIS
-    | ACE_Service_Type::DELETE_OBJ,
-    0)
-}
+ACE_FACTORY_NAMESPACE_DEFINE (
+  TAO_FTRT,
+  FTRT_ClientORB_Loader,
+  TAO_FTRT::FTRT_ClientORB_Loader)
+
+ACE_STATIC_SVC_DEFINE (
+  FTRT_ClientORB_Loader,
+  ACE_TEXT ("FTRT_ClientORB_Service"),
+  ACE_SVC_OBJ_T,
+  &ACE_SVC_NAME (FTRT_ClientORB_Loader),
+  ACE_Service_Type::DELETE_THIS
+  | ACE_Service_Type::DELETE_OBJ,
+  0)
+
 
