@@ -1,18 +1,19 @@
-// AMI_Replication_Strategy.cpp,v 1.5 2005/01/31 04:04:47 ossama Exp
+// $Id: AMI_Replication_Strategy.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "AMI_Replication_Strategy.h"
-#include "AMI_Primary_Replication_Strategy.h"
+#include "orbsvcs/FtRtEvent/EventChannel/AMI_Replication_Strategy.h"
+#include "orbsvcs/FtRtEvent/EventChannel/AMI_Primary_Replication_Strategy.h"
 
 #include "ace/Auto_Ptr.h"
 
 
 ACE_RCSID (EventChannel,
            AMI_Replication_Strategy,
-           "AMI_Replication_Strategy.cpp,v 1.5 2005/01/31 04:04:47 ossama Exp")
+           "$Id: AMI_Replication_Strategy.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 AMI_Replication_Strategy::AMI_Replication_Strategy(bool mt)
-: mt_(mt)
+  : mt_(mt)
 {
 }
 
@@ -24,8 +25,7 @@ void
 AMI_Replication_Strategy::replicate_request(
   const FTRT::State& state,
   RollbackOperation rollback,
-  const FtRtecEventChannelAdmin::ObjectId& oid
-  ACE_ENV_ARG_DECL_NOT_USED)
+  const FtRtecEventChannelAdmin::ObjectId& oid)
 {
   ACE_UNUSED_ARG(state);
   ACE_UNUSED_ARG(rollback);
@@ -34,8 +34,7 @@ AMI_Replication_Strategy::replicate_request(
 
 void
 AMI_Replication_Strategy::add_member(const FTRT::ManagerInfo & info,
-                                     CORBA::ULong object_group_ref_version
-                                     ACE_ENV_ARG_DECL_NOT_USED)
+                                     CORBA::ULong object_group_ref_version)
 {
   ACE_UNUSED_ARG(info);
   ACE_UNUSED_ARG(object_group_ref_version);
@@ -66,3 +65,5 @@ int  AMI_Replication_Strategy::release (void)
 {
   return 0;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
