@@ -4,7 +4,7 @@
 /**
  *  @file   ConnectionHandler_T.h
  *
- *  ConnectionHandler_T.h,v 1.4 2005/05/16 13:23:15 elliott_c Exp
+ *  $Id: ConnectionHandler_T.h 78894 2007-07-14 14:56:10Z sowayaa $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -19,6 +19,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 template <ACE_PEER_STREAM_1>
 class ConnectionAcceptHandler : public ACE_Svc_Handler <ACE_PEER_STREAM_2, ACE_NULL_SYNCH>
 {
@@ -36,13 +40,17 @@ private:
    ACE_Reactor* reactor_;
 };
 
-#include "FTEC_Group_Manager.h"
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_Group_Manager.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 template <ACE_PEER_STREAM_1>
 class ConnectionDetectHandler : public ACE_Svc_Handler <ACE_PEER_STREAM_2, ACE_NULL_SYNCH>
 {
 public:
-  ConnectionDetectHandler(TAO_FTEC_Fault_Listener* listener = NULL)
+  ConnectionDetectHandler(TAO_FTEC_Fault_Listener* listener = 0)
     : listener_(listener){}
 
     virtual int close (u_long flags = 0);
@@ -53,8 +61,10 @@ private:
   TAO_FTEC_Fault_Listener* listener_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (ACE_TEMPLATES_REQUIRE_SOURCE)
-#include "ConnectionHandler_T.cpp"
+#include "orbsvcs/FtRtEvent/EventChannel/ConnectionHandler_T.cpp"
 #endif /* ACE_TEMPLATES_REQUIRE_SOURCE */
 
 #if defined (ACE_TEMPLATES_REQUIRE_PRAGMA)
