@@ -4,7 +4,7 @@
 /**
  *  @file   FTEC_Become_Primary_Listener.h
  *
- *  FTEC_Become_Primary_Listener.h,v 1.2 2003/10/15 18:06:29 huangming Exp
+ *  $Id: FTEC_Become_Primary_Listener.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -13,7 +13,11 @@
 #ifndef TAO_FTEC_BECOME_PRIMARY_LISTENER_H
 #define TAO_FTEC_BECOME_PRIMARY_LISTENER_H
 
-#include "ftrtec_export.h"
+#include "orbsvcs/FtRtEvent/EventChannel/ftrtec_export.h"
+
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_FTRTEC_Export TAO_FTEC_Become_Primary_Listener
 {
@@ -22,4 +26,6 @@ public:
   virtual void become_primary()=0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif // TAO_FTEC_BECOME_PRIMARY_LISTENER_H
