@@ -4,7 +4,7 @@
 /**
  *  @file   FTEC_ConsumerAdmin.h
  *
- *  FTEC_ConsumerAdmin.h,v 1.6 2004/08/16 23:53:13 jtc Exp
+ *  $Id: FTEC_ConsumerAdmin.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -18,8 +18,10 @@
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #include "orbsvcs/Event/EC_ConsumerAdmin.h"
-#include "FT_ProxyAdmin_T.h"
-#include "ProxySupplierStateWorker.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FT_ProxyAdmin_T.h"
+#include "orbsvcs/FtRtEvent/EventChannel/ProxySupplierStateWorker.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace FtRtecEventChannelAdmin {
   struct ConsumerAdminState;
@@ -59,11 +61,12 @@ public:
 
   // = The RtecEventChannelAdmin::ConsumerAdmin methods...
   virtual RtecEventChannelAdmin::ProxyPushSupplier_ptr
-      obtain_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-          ACE_THROW_SPEC ((CORBA::SystemException));
+      obtain_push_supplier (void);
 
   void disconnect(RtecEventChannelAdmin::ProxyPushSupplier_ptr obj);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_EC_CONSUMERADMIN_H */
