@@ -4,7 +4,7 @@
 /**
  *  @file   FTEC_Event_Channel_Impl.h
  *
- *  FTEC_Event_Channel_Impl.h,v 1.7 2004/08/16 23:53:13 jtc Exp
+ *  $Id: FTEC_Event_Channel_Impl.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -15,14 +15,16 @@
 #include "ace/Synch_T.h"
 #include "orbsvcs/Event/EC_Event_Channel_Base.h"
 #include "orbsvcs/FtRtecEventChannelAdminC.h"
-#include "FTEC_Factory.h"
-#include "FTEC_Group_Manager.h"
-#include "IOGR_Maker.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_Factory.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_Group_Manager.h"
+#include "orbsvcs/FtRtEvent/EventChannel/IOGR_Maker.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_FTEC_ProxyPushSupplier;
 class TAO_FTEC_ProxyPushConsumer;
 class TAO_FTEC_SupplierAdmin;
@@ -42,67 +44,55 @@ public:
   virtual void activate_object (
     CORBA::ORB_var orb,
     const FtRtecEventComm::ObjectId& supplier_admin_oid,
-    const FtRtecEventComm::ObjectId& consumer_admin_oid
-    ACE_ENV_ARG_DECL);
+    const FtRtecEventComm::ObjectId& consumer_admin_oid);
 
 
   // = The RtecEventChannelAdmin::EventChannel methods...
   virtual RtecEventChannelAdmin::ConsumerAdmin_ptr
-      for_consumers (ACE_ENV_SINGLE_ARG_DECL)
-        ACE_THROW_SPEC ((CORBA::SystemException));
+      for_consumers (void);
 
 
   virtual RtecEventChannelAdmin::SupplierAdmin_ptr
-      for_suppliers (ACE_ENV_SINGLE_ARG_DECL)
-        ACE_THROW_SPEC ((CORBA::SystemException));
+      for_suppliers (void);
 
-  void get_state (FtRtecEventChannelAdmin::EventChannelState & s
-                  ACE_ENV_ARG_DECL);
+  void get_state (FtRtecEventChannelAdmin::EventChannelState & s);
 
-  void set_state (const FTRT::State & stat ACE_ENV_ARG_DECL);
+  void set_state (const FTRT::State & stat);
 
-  void set_update (const FTRT::State & s ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException, FTRT::InvalidUpdate));
+  void set_update (const FTRT::State & s);
 
   /// EventChannelFacade Interface
 
    virtual ::FtRtecEventChannelAdmin::ObjectId * connect_push_consumer (
         RtecEventComm::PushConsumer_ptr push_consumer,
         const RtecEventChannelAdmin::ConsumerQOS & qos
-        ACE_ENV_ARG_DECL
       );
 
 
     virtual ::FtRtecEventChannelAdmin::ObjectId * connect_push_supplier (
         RtecEventComm::PushSupplier_ptr push_supplier,
         const RtecEventChannelAdmin::SupplierQOS & qos
-        ACE_ENV_ARG_DECL
       );
 
     virtual void disconnect_push_supplier (
         const FtRtecEventChannelAdmin::ObjectId & oid
-        ACE_ENV_ARG_DECL
       );
 
     virtual void disconnect_push_consumer (
         const FtRtecEventChannelAdmin::ObjectId & oid
-        ACE_ENV_ARG_DECL
       );
 
     virtual void suspend_push_supplier (
         const FtRtecEventChannelAdmin::ObjectId & oid
-        ACE_ENV_ARG_DECL
       );
 
     virtual void resume_push_supplier (
         const FtRtecEventChannelAdmin::ObjectId & oid
-        ACE_ENV_ARG_DECL
       );
 
     virtual void push (
         const FtRtecEventChannelAdmin::ObjectId & oid,
         const RtecEventComm::EventSet & data
-        ACE_ENV_ARG_DECL
       );
 
   ////////////////////////////////////////////
@@ -119,8 +109,7 @@ public:
   TAO_FTEC_ProxyPushConsumer* find_proxy_push_consumer(const FtRtecEventChannelAdmin::ObjectId& id);
 
 
-  CORBA::Object_var make_iogr(CORBA::Object_ptr obj
-                              ACE_ENV_ARG_DECL);
+  CORBA::Object_var make_iogr(CORBA::Object_ptr obj);
 
 protected:
   TAO_FTEC_Basic_Factory* factory();
@@ -128,4 +117,6 @@ private:
   IOGR_Maker iogr_maker_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif
