@@ -1,15 +1,17 @@
-// FTEC_Factory.cpp,v 1.4 2004/08/16 23:53:13 jtc Exp
+// $Id: FTEC_Factory.cpp 71526 2006-03-14 06:14:35Z jtc $
 #include "orbsvcs/Event/EC_Event_Channel.h"
-#include "FTEC_Event_Channel.h"
-#include "FTEC_Factory.h"
-#include "FTEC_ProxySupplier.h"
-#include "FTEC_ProxyConsumer.h"
-#include "FTEC_SupplierAdmin.h"
-#include "FTEC_ConsumerAdmin.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_Event_Channel.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_Factory.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_ProxySupplier.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_ProxyConsumer.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_SupplierAdmin.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_ConsumerAdmin.h"
 
 ACE_RCSID (EventChannel,
            FTEC_Factory,
-           "FTEC_Factory.cpp,v 1.4 2004/08/16 23:53:13 jtc Exp")
+           "$Id: FTEC_Factory.cpp 71526 2006-03-14 06:14:35Z jtc $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_FTEC_Basic_Factory::TAO_FTEC_Basic_Factory (void)
 {
@@ -51,3 +53,4 @@ TAO_FTEC_Basic_Factory::destroy_proxy_push_consumer (TAO_EC_ProxyPushConsumer* p
   delete proxy;
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
