@@ -4,7 +4,7 @@
 /**
  *  @file   FTEC_Group_Manager.h
  *
- *  FTEC_Group_Manager.h,v 1.6 2004/08/16 23:53:13 jtc Exp
+ *  $Id: FTEC_Group_Manager.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -14,12 +14,15 @@
 #define TAO_FTEC_GROUP_MANAGER_H
 
 #include "orbsvcs/FtRtecEventChannelAdminC.h"
-#include "FTEC_Fault_Listener.h"
+#include "orbsvcs/FtRtEvent/EventChannel/FTEC_Fault_Listener.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 struct TAO_FTEC_Group_Manager_Impl;
 
 class TAO_FTEC_Group_Manager : private TAO_FTEC_Fault_Listener
@@ -32,37 +35,29 @@ public:
 
   virtual CORBA::Boolean start (
         FTRT::FaultListener_ptr listener,
-        FTRT::Location_out cur
-        ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+        FTRT::Location_out cur);
 
   void create_group (
     const FTRT::ManagerInfoList & info_list,
-    CORBA::ULong object_group_ref_version
-    ACE_ENV_ARG_DECL);
+    CORBA::ULong object_group_ref_version);
 
   void join_group (
-    const FTRT::ManagerInfo & info
-    ACE_ENV_ARG_DECL);
+    const FTRT::ManagerInfo & info);
 
   void add_member (
     const FTRT::ManagerInfo & info,
-    CORBA::ULong object_group_ref_version
-    ACE_ENV_ARG_DECL);
+    CORBA::ULong object_group_ref_version);
 
   void remove_member (
     const FTRT::Location & crashed_location,
-    CORBA::ULong object_group_ref_version
-    ACE_ENV_ARG_DECL);
+    CORBA::ULong object_group_ref_version);
 
   void replica_crashed (
-    const FTRT::Location & location
-    ACE_ENV_ARG_DECL);
+    const FTRT::Location & location);
 
 private:
   virtual void get_state (
         FtRtecEventChannelAdmin::EventChannelState & s
-        ACE_ENV_ARG_DECL
       )=0;
 
   virtual void connection_closed();
@@ -72,4 +67,6 @@ protected:
   TAO_FTEC_Group_Manager_Impl* impl_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif // TAO_FTEC_GROUP_MANAGER_H
