@@ -4,7 +4,7 @@
 /**
  *  @file   FTEC_ORBInitializer.h
  *
- *  $Id: FTEC_ORBInitializer.h 77001 2007-02-12 07:54:49Z johnnyw $
+ *  $Id: FTEC_ORBInitializer.h 81490 2008-04-28 14:32:24Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -24,7 +24,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class FTEC_ORBInitializer
   : public virtual PortableInterceptor::ORBInitializer
-  , public virtual TAO_Local_RefCounted_Object
+  , public virtual ::CORBA::LocalObject
 {
 public:
   virtual void pre_init (PortableInterceptor::ORBInitInfo_ptr info);
