@@ -1,4 +1,4 @@
-// $Id: Fault_Detector.cpp 71526 2006-03-14 06:14:35Z jtc $
+// $Id: Fault_Detector.cpp 82954 2008-10-07 08:02:58Z johnnyw $
 
 #include "ace/Reactor.h"
 #include "orbsvcs/FtRtEvent/EventChannel/Fault_Detector.h"
@@ -6,7 +6,7 @@
 
 ACE_RCSID (EventChannel,
            Fault_Detector,
-           "$Id: Fault_Detector.cpp 71526 2006-03-14 06:14:35Z jtc $")
+           "$Id: Fault_Detector.cpp 82954 2008-10-07 08:02:58Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -42,7 +42,7 @@ Fault_Detector* Fault_Detector::instance()
   return detector;
 }
 
-int Fault_Detector::init(int argc, char** argv)
+int Fault_Detector::init(int argc, ACE_TCHAR** argv)
 {
   detector = this;
   if (this->parse_conf(argc, argv)==0 &&
@@ -67,7 +67,7 @@ void Fault_Detector::set_listener(TAO_FTEC_Fault_Listener* listener)
   listener_ = listener;
 }
 
-int Fault_Detector::parse_conf(int , char** )
+int Fault_Detector::parse_conf(int , ACE_TCHAR** )
 {
   return 0;
 }
