@@ -4,7 +4,7 @@
 /**
  *  @file   IOGR_Maker.h
  *
- *  IOGR_Maker.h,v 1.7 2005/01/26 23:21:06 huangming Exp
+ *  $Id: IOGR_Maker.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -20,13 +20,14 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class IOGR_Maker
 {
 public:
   IOGR_Maker();
 
-  void init(CORBA::ORB_ptr orb
-            ACE_ENV_ARG_DECL);
+  void init(CORBA::ORB_ptr orb);
 
   /// instance() will only return a valid object after an
   /// instance is explicitly created by client and init() is called.
@@ -34,22 +35,18 @@ public:
 
    /// Create a new object reference by merging the profiles lists in the
    /// supplied list of one or more object references.
-  CORBA::Object_ptr merge_iors(const TAO_IOP::TAO_IOR_Manipulation::IORList&
-                              ACE_ENV_ARG_DECL);
+  CORBA::Object_ptr merge_iors(const TAO_IOP::TAO_IOR_Manipulation::IORList&);
 
    /// Create a new IOGR (with FT_PRIMARY and FT_GROUP components) by merging
    /// the profiles lists in the supplied list of one or more object references.
   CORBA::Object_ptr make_iogr(const TAO_IOP::TAO_IOR_Manipulation::IORList&,
-                              CORBA::ULong object_group_ref_version
-                              ACE_ENV_ARG_DECL);
+                              CORBA::ULong object_group_ref_version);
 
   /// Make an new IOGR with obj as primary.
-  CORBA::Object_ptr forge_iogr(CORBA::Object_ptr obj
-                               ACE_ENV_ARG_DECL);
+  CORBA::Object_ptr forge_iogr(CORBA::Object_ptr obj);
 
   CORBA::Object_ptr ior_replace_key(CORBA::Object_ptr obj,
-                                    const TAO::ObjectKey& key
-                                    ACE_ENV_ARG_DECL);
+                                    const TAO::ObjectKey& key);
 
   bool copy_ft_group_component(CORBA::Object_ptr obj);
 
@@ -60,12 +57,13 @@ public:
   CORBA::ULong get_ref_version() const;
 
 private:
-  void set_tag_components(CORBA::Object_ptr merged, 
+  void set_tag_components(CORBA::Object_ptr merged,
                           CORBA::Object_ptr primary,
-                          FT::TagFTGroupTaggedComponent& ft_tag_component
-                          ACE_ENV_ARG_DECL);
+                          FT::TagFTGroupTaggedComponent& ft_tag_component);
   TAO_IOP::TAO_IOR_Manipulation_var iorm_;
   FT::TagFTGroupTaggedComponent ft_tag_component_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif
