@@ -1,22 +1,23 @@
-// Update_Manager.cpp,v 1.3 2004/05/13 04:58:12 ossama Exp
+// $Id: Update_Manager.cpp 80166 2007-12-03 13:53:49Z sowayaa $
 
-#include "Update_Manager.h"
+#include "orbsvcs/FtRtEvent/EventChannel/Update_Manager.h"
 
 ACE_RCSID (EventChannel,
            Update_Manager,
-           "Update_Manager.cpp,v 1.3 2004/05/13 04:58:12 ossama Exp")
+           "$Id: Update_Manager.cpp 80166 2007-12-03 13:53:49Z sowayaa $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 Update_Manager::Update_Manager(ACE_Auto_Event& evt,
                                int num_backups,
                                int transaction_depth,
                                bool& success)
-: evt_(evt)
-, replied_(num_backups)
-, suicide_condition_(num_backups)
-, num_backups_(num_backups)
-, transaction_level_(transaction_depth)
-, success_(success)
+  : evt_(evt)
+  , replied_(num_backups)
+  , suicide_condition_(num_backups)
+  , num_backups_(num_backups)
+  , transaction_level_(transaction_depth)
+  , success_(success)
 {
   suicide_condition_.flip();
   signal_condition_.resize(transaction_depth, true);
@@ -29,7 +30,7 @@ Update_Manager::~Update_Manager()
 
 void Update_Manager::handle_reply(int id)
 {
-  ACE_Guard<ACE_SYNCH_MUTEX> guard(mutex_);
+  ACE_Guard<TAO_SYNCH_MUTEX> guard(mutex_);
   replied_[id] = true;
 
   if ((replied_ & signal_condition_) == signal_condition_) {
@@ -42,7 +43,7 @@ void Update_Manager::handle_reply(int id)
 
 void Update_Manager::handle_exception(int id)
 {
-  ACE_Guard<ACE_SYNCH_MUTEX> guard(mutex_);
+  ACE_Guard<TAO_SYNCH_MUTEX> guard(mutex_);
   replied_[id] = true;
   ++transaction_level_;
 
@@ -56,3 +57,5 @@ void Update_Manager::handle_exception(int id)
   if (replied_ == suicide_condition_)
     delete this;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
