@@ -4,7 +4,7 @@
 /**
  *  @file   create_persistent_poa.h
  *
- *  create_persistent_poa.h,v 1.4 2005/02/18 09:07:07 jwillemsen Exp
+ *  $Id: create_persistent_poa.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -17,9 +17,13 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 PortableServer::POA_var create_persistent_poa(PortableServer::POA_var root_poa,
                                               PortableServer::POAManager_var mgr,
                                               const char* name,
-                                              CORBA::PolicyList& policy_list
-                                              ACE_ENV_ARG_DECL);
+                                              CORBA::PolicyList& policy_list);
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif
