@@ -1,4 +1,4 @@
-//$Id: Log.cpp 71526 2006-03-14 06:14:35Z jtc $
+//$Id: Log.cpp 82954 2008-10-07 08:02:58Z johnnyw $
 #include "orbsvcs/FtRtEvent/Utils/Log.h"
 
 #if !defined(__ACE_INLINE__)
@@ -17,7 +17,7 @@ unsigned int Log::log_level_;
     if (log_level_ >= log_level) {
       va_list p;
       va_start(p, format);
-      char str[1024];
+      ACE_TCHAR str[1024];
       ACE_OS::vsprintf(str, format, p);
       ACE_DEBUG((LM_DEBUG, str));
       va_end(p);
