@@ -4,7 +4,7 @@
 /**
  *  @file   Log.h
  *
- *  $Id: Log.h 71526 2006-03-14 06:14:35Z jtc $
+ *  $Id: Log.h 82954 2008-10-07 08:02:58Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -31,7 +31,7 @@ namespace TAO_FTRTEC {
     Log (unsigned int log_level, const ACE_TCHAR* format, ...);
     static void level(unsigned int log_level);
     static unsigned int level();
-    static void hexdump(unsigned int log_level, const char* buf, size_t len, const char* msg);
+    static void hexdump(unsigned int log_level, const char* buf, size_t len, const ACE_TCHAR* msg);
   private:
     friend class Trace;
     static unsigned log_level_;
