@@ -3,7 +3,7 @@
 /**
  *  @file   UUID.h
  *
- *  $Id: UUID.h 71526 2006-03-14 06:14:35Z jtc $
+ *  $Id: UUID.h 82907 2008-10-02 11:22:52Z johnnyw $
  *
  *  @author Huang-Ming Huang <hh1@cse.wustl.edu>
  */
@@ -31,6 +31,8 @@
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
+namespace TAO_FtRt
+{
 /**
  * This is an implementation of Global Unique Identifier
  * which follows the document draft-leach-uuids-guids-01.txt. The
@@ -70,7 +72,7 @@ class TAO_FtRtEvent_Export  UUID
      * Construct an UUID from the string representation. Use is_valid() to test if the
      * construction is successful or not.
      */
-    UUID(const char *);
+    UUID(const ACE_TCHAR *);
 
     /* Construct an uuid from the string representation. */
     bool from_string(const char *string_rep);
@@ -112,7 +114,7 @@ class TAO_FtRtEvent_Export  UUID
       unsigned char uuid[BINRARY_LENGTH];
     } rep_;
 };
-
+}
 TAO_END_VERSIONED_NAMESPACE_DECL
 
 #if defined(__ACE_INLINE__)
