@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: HTIOP_Acceptor.cpp 79344 2007-08-14 21:54:46Z mesnier_p $
+// $Id: HTIOP_Acceptor.cpp 87229 2009-10-26 10:54:32Z vzykov $
 
 #include "orbsvcs/HTIOP/HTIOP_Acceptor.h"
 #include "orbsvcs/HTIOP/HTIOP_Profile.h"
@@ -21,7 +21,7 @@
 
 ACE_RCSID(HTIOP,
           TAO_HTIOP_Acceptor,
-          "$Id: HTIOP_Acceptor.cpp 79344 2007-08-14 21:54:46Z mesnier_p $")
+          "$Id: HTIOP_Acceptor.cpp 87229 2009-10-26 10:54:32Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -34,7 +34,7 @@ TAO::HTIOP::Acceptor::Acceptor (ACE::HTBP::Environment *ht_env,
     hostname_in_ior_ (0),
     version_ (TAO_DEF_GIOP_MAJOR, TAO_DEF_GIOP_MINOR),
     orb_core_ (0),
-    base_acceptor_ (),
+    base_acceptor_ (this),
     creation_strategy_ (0),
     concurrency_strategy_ (0),
     accept_strategy_ (0),
@@ -232,12 +232,17 @@ TAO::HTIOP::Acceptor::is_collocated (const TAO_Endpoint *endpoint)
       // http://deuce.doc.wustl.edu/bugzilla/show_bug.cgi?id=1220
       //
       if (endp->port() == this->addrs_[i].get_port_number())
-        if (endp->port() == 0)
-          return (ACE_OS::strcmp (endp->htid(),
-                                  this->addrs_[i].get_htid()) == 0);
-        else
-          return (ACE_OS::strcmp(endp->host(), this->hosts_[i]) == 0);
-      //        return 1;
+        {
+          if (endp->port() == 0)
+            {
+              return (ACE_OS::strcmp (endp->htid(),
+                                      this->addrs_[i].get_htid()) == 0);
+            }
+          else
+            {
+              return (ACE_OS::strcmp(endp->host(), this->hosts_[i]) == 0);
+            }
+        }
     }
 
   return 0;
@@ -331,10 +336,9 @@ TAO::HTIOP::Acceptor::open (TAO_ORB_Core *orb_core,
                                    1) != 0)
         return -1;
       else
-	{
-	  return this->open_i (addr,
-			       reactor);
-	}
+        {
+          return this->open_i (addr, reactor);
+        }
     }
   else if (port_separator_loc == 0)
     {
@@ -406,10 +410,10 @@ TAO::HTIOP::Acceptor::open (TAO_ORB_Core *orb_core,
 
 int
 TAO::HTIOP::Acceptor::open_default (TAO_ORB_Core *orb_core,
-                                  ACE_Reactor *reactor,
-                                  int major,
-                                  int minor,
-                                  const char *options)
+                                    ACE_Reactor *reactor,
+                                    int major,
+                                    int minor,
+                                    const char *options)
 {
   this->orb_core_ = orb_core;
 
@@ -452,7 +456,9 @@ TAO::HTIOP::Acceptor::open_default (TAO_ORB_Core *orb_core,
                       sizeof (char*) * this->endpoint_count_);
 
       ACE::HTBP::ID_Requestor req(ht_env_);
-      this->addrs_[0] = req.get_HTID();
+      ACE_TCHAR *htid = req.get_HTID ();
+      ACE_Auto_Array_Ptr<ACE_TCHAR> guard (htid);
+      this->addrs_[0] = ACE_TEXT_ALWAYS_CHAR (htid);
       return 0;
 
     }
@@ -484,7 +490,7 @@ TAO::HTIOP::Acceptor::open_i (const ACE::HTBP::Addr& addr,
                   -1);
 
   ACE_NEW_RETURN (this->concurrency_strategy_,
-                  CONCURRENCY_STRATEGY (),
+                  CONCURRENCY_STRATEGY (this->orb_core_),
                   -1);
 
   ACE_NEW_RETURN (this->accept_strategy_,
@@ -541,8 +547,8 @@ TAO::HTIOP::Acceptor::open_i (const ACE::HTBP::Addr& addr,
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("(%P|%t) TAO::HTIOP::Acceptor::open_i - ")
-                      ACE_TEXT ("listening on: <%s:%u>\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR(this->hosts_[i]),
+                      ACE_TEXT ("listening on: <%C:%u>\n"),
+                      this->hosts_[i],
                       this->addrs_[i].get_port_number ()));
         }
     }
