@@ -4,7 +4,7 @@
 /**
  *  @file    HTIOP_Acceptor.h
  *
- *  $Id: HTIOP_Acceptor.h 73791 2006-07-27 20:54:56Z wotte $
+ *  $Id: HTIOP_Acceptor.h 87229 2009-10-26 10:54:32Z vzykov $
  *
  *  HTIOP specific acceptor processing
  *
@@ -20,6 +20,7 @@
 
 #include "orbsvcs/HTIOP/HTIOP_Completion_Handler.h"
 #include "orbsvcs/HTIOP/HTIOP_Connection_Handler.h"
+#include "orbsvcs/HTIOP/HTIOP_Acceptor_Impl.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -78,10 +79,10 @@ namespace TAO
       /// Returns the array of endpoints in this acceptor
       const ACE::HTBP::Addr *endpoints (void);
 
-      typedef ACE_Strategy_Acceptor<Completion_Handler, ACE_SOCK_ACCEPTOR> BASE_ACCEPTOR;
-      typedef TAO_Creation_Strategy<Completion_Handler> CREATION_STRATEGY;
-      typedef ACE_Concurrency_Strategy<Completion_Handler> CONCURRENCY_STRATEGY;
-      typedef TAO_Accept_Strategy<Completion_Handler, ACE_SOCK_ACCEPTOR> ACCEPT_STRATEGY;
+      typedef TAO_Strategy_Acceptor<Completion_Handler, ACE_SOCK_ACCEPTOR> BASE_ACCEPTOR;
+      typedef Creation_Strategy<Completion_Handler> CREATION_STRATEGY;
+      typedef Concurrency_Strategy<Completion_Handler> CONCURRENCY_STRATEGY;
+      typedef Accept_Strategy<Completion_Handler, ACE_SOCK_ACCEPTOR> ACCEPT_STRATEGY;
 
       /**
        * The TAO::Acceptor methods, check the documentation in
