@@ -1,4 +1,4 @@
-// $Id: HTIOP_Connection_Handler.cpp 79344 2007-08-14 21:54:46Z mesnier_p $
+// $Id: HTIOP_Connection_Handler.cpp 85817 2009-06-26 20:44:58Z mitza $
 
 #include "orbsvcs/HTIOP/HTIOP_Connection_Handler.h"
 
@@ -23,7 +23,7 @@
 
 ACE_RCSID (HTIOP,
            TAO_HTIOP_Connection_Handler,
-           "$Id: HTIOP_Connection_Handler.cpp 79344 2007-08-14 21:54:46Z mesnier_p $")
+           "$Id: HTIOP_Connection_Handler.cpp 85817 2009-06-26 20:44:58Z mitza $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -139,7 +139,7 @@ TAO::HTIOP::Connection_Handler::open (void*)
     return -1;
 
   this->state_changed (TAO_LF_Event::LFS_SUCCESS,
-		       this->orb_core ()->leader_follower ());
+                       this->orb_core ()->leader_follower ());
 
   return 0;
 }
@@ -206,7 +206,7 @@ int
 TAO::HTIOP::Connection_Handler::close (u_long)
 {
   this->state_changed (TAO_LF_Event::LFS_CONNECTION_CLOSED,
-		       this->orb_core ()->leader_follower ());
+                       this->orb_core ()->leader_follower ());
   this->transport ()->remove_reference ();
   return 0;
 }
@@ -239,8 +239,7 @@ TAO::HTIOP::Connection_Handler::add_transport_to_cache (void)
     this->orb_core ()->lane_resources ().transport_cache ();
 
   // Idle the transport..
-  return cache.cache_idle_transport (&prop,
-                                     this->transport ());
+  return cache.cache_transport (&prop, this->transport ());
 }
 
 int
@@ -263,10 +262,10 @@ TAO::HTIOP::Connection_Handler::process_listen_point_list
       if (TAO_debug_level > 0)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT("(%P|%t) Listening port [%d] on [%s],[%s]\n"),
+                      ACE_TEXT("(%P|%t) Listening port [%d] on [%C],[%C]\n"),
                       listen_point.port,
-                      ACE_TEXT_CHAR_TO_TCHAR(listen_point.host.in ()),
-                      ACE_TEXT_CHAR_TO_TCHAR(listen_point.htid.in())));
+                      listen_point.host.in (),
+                      listen_point.htid.in()));
         }
 
       // Construct an  TAO::HTIOP::Endpoint object
@@ -305,4 +304,10 @@ TAO::HTIOP::Connection_Handler::set_dscp_codepoint (
   return 0;
 }
 
+int
+TAO::HTIOP::Connection_Handler::handle_write_ready (const ACE_Time_Value *t)
+{
+  return ACE::handle_write_ready (this->peer ().get_handle (), t);
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
