@@ -1,4 +1,4 @@
-// $Id: HTIOP_Connector.cpp 78931 2007-07-18 09:59:36Z johnnyw $
+// $Id: HTIOP_Connector.cpp 86601 2009-09-03 10:37:18Z vzykov $
 
 #include "orbsvcs/HTIOP/HTIOP_Connector.h"
 #include "orbsvcs/HTIOP/HTIOP_Profile.h"
@@ -20,7 +20,7 @@
 
 ACE_RCSID (HTIOP,
            TAO_HTIOP_Connector,
-           "$Id: HTIOP_Connector.cpp 78931 2007-07-18 09:59:36Z johnnyw $")
+           "$Id: HTIOP_Connector.cpp 86601 2009-09-03 10:37:18Z vzykov $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -145,22 +145,22 @@ TAO::HTIOP::Connector::make_connection (TAO::Profile_Transport_Resolver *,
 
 
   ACE::HTBP::Session_Id_t session_id;
-  ACE_INET_Addr *proxy;
-  ACE_CString proxy_host;
+  ACE_INET_Addr *proxy = 0;
+  ACE_TString proxy_host;
   unsigned proxy_port;
 
-  int port_set = this->ht_env_->get_proxy_port(proxy_port);
-  int host_set = this->ht_env_->get_proxy_host(proxy_host);
+  int const port_set = this->ht_env_->get_proxy_port(proxy_port);
+  int const host_set = this->ht_env_->get_proxy_host(proxy_host);
   if (port_set != 0 ||
       host_set != 0)
     {
       proxy_port = htiop_endpoint->port();
-      proxy_host = htiop_endpoint->host();
+      proxy_host = ACE_TEXT_CHAR_TO_TCHAR(htiop_endpoint->host());
     }
   else
     {
       ACE::HTBP::ID_Requestor req(ht_env_);
-      session_id.local_ = req.get_HTID();
+      session_id.local_ = ACE_TEXT_ALWAYS_CHAR(req.get_HTID());
     }
 
   if (proxy_port == 0)
@@ -217,6 +217,9 @@ TAO::HTIOP::Connector::make_connection (TAO::Profile_Transport_Resolver *,
   this->connect_creation_strategy_->make_svc_handler (svc_handler);
   // we now have a connection handler that has an unconnected stream
 
+  // Make sure that we always do a remove_reference
+  ACE_Event_Handler_var svc_handler_auto_ptr (svc_handler);
+
   svc_handler->peer().session(session);
   session->handler(svc_handler);
   ACE::HTBP::Channel *outbound = session->outbound();
@@ -233,10 +236,6 @@ TAO::HTIOP::Connector::make_connection (TAO::Profile_Transport_Resolver *,
   // strategy, which does not apply here. Therefore the whole bit of logic
   // of dealing with a failed wait but an unclosed svc_handler is skipped.
 
-
-  // Regardless of success or failure, remove the extra #REFCOUNT#.
-  svc_handler->remove_reference ();
-
   if (closed) // would be result == -1 in IIOP_Connector
     {
       if (TAO_debug_level)
@@ -268,7 +267,7 @@ TAO::HTIOP::Connector::make_connection (TAO::Profile_Transport_Resolver *,
     this->orb_core ()->lane_resources ().
     transport_cache ().cache_transport (&desc, transport);
 
-  if (retval != 0)
+  if (retval == -1)
     {
       svc_handler->close();
       if (TAO_debug_level > 0)
@@ -299,6 +298,7 @@ TAO::HTIOP::Connector::make_connection (TAO::Profile_Transport_Resolver *,
       return 0;
     }
 
+  svc_handler_auto_ptr.release ();
   return transport;
 }
 
