@@ -1,4 +1,4 @@
-// $Id: HTIOP_Transport.cpp 80618 2008-02-12 15:54:34Z johnc $
+// $Id: HTIOP_Transport.cpp 84860 2009-03-17 10:17:38Z johnnyw $
 
 #include "orbsvcs/HTIOP/HTIOP_Transport.h"
 
@@ -23,7 +23,7 @@
 
 ACE_RCSID (HTIOP,
            TAO_HTIOP_Transport,
-           "$Id: HTIOP_Transport.cpp 80618 2008-02-12 15:54:34Z johnc $")
+           "$Id: HTIOP_Transport.cpp 84860 2009-03-17 10:17:38Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -167,7 +167,7 @@ TAO::HTIOP::Transport::send_message (TAO_OutputCDR &stream,
                                      ACE_Time_Value *max_wait_time)
 {
   // Format the message in the stream first
-  if (this->messaging_object_->format_message (stream) != 0)
+  if (this->messaging_object ()->format_message (stream, stub) != 0)
     return -1;
 
   // This guarantees to send all data (bytes) or return an error.
@@ -193,37 +193,6 @@ TAO::HTIOP::Transport::send_message (TAO_OutputCDR &stream,
   return 1;
 }
 
-int
-TAO::HTIOP::Transport::generate_request_header (TAO_Operation_Details &opdetails,
-                                                TAO_Target_Specification &spec,
-                                                TAO_OutputCDR &msg)
-{
-  // Check whether we have a Bi Dir HTIOP policy set, whether the
-  // messaging objects are ready to handle bidirectional connections
-  // and also make sure that we have not recd. or sent any information
-  // regarding this before...
-  if (this->orb_core ()->bidir_giop_policy () &&
-      this->messaging_object_->is_ready_for_bidirectional (msg) &&
-      this->bidirectional_flag () < 0)
-    {
-      this->set_bidir_context_info (opdetails);
-
-      // Set the flag to 1  (i.e., originating side)
-      this->bidirectional_flag (1);
-
-      // At the moment we enable BiDIR giop we have to get a new
-      // request id to make sure that we follow the even/odd rule
-      // for request id's. We only need to do this when enabled
-      // it, after that the Transport Mux Strategy will make sure
-      // that the rule is followed
-      opdetails.request_id (this->tms ()->request_id ());
-    }
-
-  return TAO_Transport::generate_request_header (opdetails,
-                                                 spec,
-                                                 msg);
-}
-
 int
 TAO::HTIOP::Transport::tear_listen_point_list (TAO_InputCDR &cdr)
 {
@@ -248,8 +217,6 @@ TAO::HTIOP::Transport::tear_listen_point_list (TAO_InputCDR &cdr)
 void
 TAO::HTIOP::Transport::set_bidir_context_info (TAO_Operation_Details &opdetails)
 {
-  ACE_UNUSED_ARG (opdetails);
-
   // Get a handle to the acceptor registry
   TAO_Acceptor_Registry &ar =
     this->orb_core ()->lane_resources ().acceptor_registry ();
@@ -264,14 +231,14 @@ TAO::HTIOP::Transport::set_bidir_context_info (TAO_Operation_Details &opdetails)
        acceptor++)
     {
       // Check whether it is a HTIOP acceptor
-      if ((*acceptor)->tag () == OCI_TAG_HTIOP_PROFILE)
+      if ((*acceptor)->tag () == this->tag ())
         {
           if (this->get_listen_point (listen_point_list,
                                       *acceptor) == -1)
             {
               ACE_ERROR ((LM_ERROR,
                           ACE_TEXT("TAO (%P|%t) - TAO::HTIOP::Transport::set_bidir_info, "),
-                          ACE_TEXT("error getting listen_point \n")));
+                          ACE_TEXT("error getting listen_point\n")));
 
               return;
             }
@@ -283,13 +250,12 @@ TAO::HTIOP::Transport::set_bidir_context_info (TAO_Operation_Details &opdetails)
   TAO_OutputCDR cdr;
 
   // Marshall the information into the stream
-  if ((cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER) == 0)
-      || (cdr << listen_point_list) == 0)
+  if (!(cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER))
+      || !(cdr << listen_point_list))
     return;
 
   // Add this info in to the svc_list
-  opdetails.request_service_context ().set_context (IOP::BI_DIR_IIOP,
-                                                    cdr);
+  opdetails.request_service_context ().set_context (IOP::BI_DIR_IIOP, cdr);
 
   return;
 }
@@ -345,7 +311,7 @@ TAO::HTIOP::Transport::get_listen_point (::HTIOP::ListenPointList &lp_list,
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              ACE_TEXT ("(%P|%t) Could not resolve local host")
-                             ACE_TEXT (" name \n")),
+                             ACE_TEXT (" name\n")),
                             -1);
         }
 
