@@ -4,7 +4,7 @@
 /**
  *  @file   HTIOP_Transport.h
  *
- *  $Id: HTIOP_Transport.h 80618 2008-02-12 15:54:34Z johnc $
+ *  $Id: HTIOP_Transport.h 84860 2009-03-17 10:17:38Z johnnyw $
  *
  *  @author Originally by Fred Kuhns <fredk@cs.wustl.edu>
  *  @author Modified by Balachandran Natarajan <bala@cs.wustl.edu>
@@ -111,16 +111,9 @@ namespace TAO
       virtual int send_message (TAO_OutputCDR &stream,
                                 TAO_Stub *stub = 0,
                                 TAO_Message_Semantics message_semantics =
-                                Transport::TAO_TWOWAY_REQUEST,
+                                TAO_TWOWAY_REQUEST,
                                 ACE_Time_Value *max_time_wait = 0);
 
-      // @@ This is probably not needed - Priyanka
-      // This is needed because we want to send additional information
-      // such as session id etc. in the header.
-      virtual int generate_request_header (TAO_Operation_Details &opdetails,
-                                           TAO_Target_Specification &spec,
-                                           TAO_OutputCDR &msg);
-
       virtual int tear_listen_point_list (TAO_InputCDR &cdr);
 
       virtual TAO_Connection_Handler * connection_handler_i (void);
