@@ -1,11 +1,11 @@
-// $Id: AbstractInterfaceDef_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: AbstractInterfaceDef_i.cpp 80714 2008-02-24 19:45:27Z johnnyw $
 
 #include "orbsvcs/IFRService/AbstractInterfaceDef_i.h"
 #include "orbsvcs/IFRService/Repository_i.h"
 
 ACE_RCSID (IFRService,
            AbstractInterfaceDef_i,
-           "$Id: AbstractInterfaceDef_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: AbstractInterfaceDef_i.cpp 80714 2008-02-24 19:45:27Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -45,7 +45,7 @@ TAO_AbstractInterfaceDef_i::is_a_i (const char *interface_id)
 {
   if (ACE_OS::strcmp (interface_id, "IDL:omg.org/CORBA/AbstractBase:1.0") == 0)
     {
-      return 1;
+      return true;
     }
 
   return this->TAO_InterfaceDef_i::is_a_i (interface_id);
