@@ -1,39 +1,39 @@
-/* -*- C++ -*- */
-// ComponentContainer_i.h,v 1.4 2005/03/10 14:08:41 jwillemsen Exp
+// -*- C++ -*-
+
+
+//=============================================================================
+/**
+ *  @file    ComponentContainer_i.h
+ *
+ *  $Id: ComponentContainer_i.h 77031 2007-02-12 15:20:17Z johnnyw $
+ *
+ *  ComponentContainer_i servant class.
+ *
+ *
+ *  @author Jeff Parsons <j.parsons@vanderbilt.edu>
+ */
+//=============================================================================
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO/orbsvcs/orbsvcs/IFRService
-//
-// = FILENAME
-//    ComponentContainer_i.h
-//
-// = DESCRIPTION
-//    ComponentContainer_i servant class.
-//
-// = AUTHOR
-//    Jeff Parsons <j.parsons@vanderbilt.edu>
-//
-// ============================================================================
 
 #ifndef TAO_COMPONENTCONTAINER_I_H
 #define TAO_COMPONENTCONTAINER_I_H
 
-#include "Container_i.h"
-#include "ifr_service_export.h"
+#include "orbsvcs/IFRService/Container_i.h"
+#include "orbsvcs/IFRService/ifr_service_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "IFR_ComponentsS.h"
+#include "orbsvcs/IFRService/IFR_ComponentsS.h"
 
 #if defined(_MSC_VER)
 #pragma warning(push)
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_IFRService_Export TAO_ComponentContainer_i
   : public virtual TAO_Container_i
 {
@@ -56,9 +56,7 @@ public:
       const char *version,
       CORBA::ComponentIR::ComponentDef_ptr base_component,
       const CORBA::InterfaceDefSeq &supports_interfaces
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
   CORBA::ComponentIR::ComponentDef_ptr create_component_i (
       const char *id,
@@ -66,9 +64,7 @@ public:
       const char *version,
       CORBA::ComponentIR::ComponentDef_ptr base_component,
       const CORBA::InterfaceDefSeq &supports_interfaces
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
   virtual CORBA::ComponentIR::HomeDef_ptr create_home (
       const char *id,
@@ -78,9 +74,7 @@ public:
       CORBA::ComponentIR::ComponentDef_ptr managed_component,
       const CORBA::InterfaceDefSeq &supports_interfaces,
       CORBA::ValueDef_ptr primary_key
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
   CORBA::ComponentIR::HomeDef_ptr create_home_i (
       const char *id,
@@ -90,9 +84,7 @@ public:
       CORBA::ComponentIR::ComponentDef_ptr managed_component,
       const CORBA::InterfaceDefSeq &supports_interfaces,
       CORBA::ValueDef_ptr primary_key
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
   virtual CORBA::ComponentIR::EventDef_ptr create_event (
       const char *id,
@@ -105,9 +97,7 @@ public:
       const CORBA::ValueDefSeq &abstract_base_values,
       const CORBA::InterfaceDefSeq &supported_interfaces,
       const CORBA::ExtInitializerSeq &initializers
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
   CORBA::ComponentIR::EventDef_ptr create_event_i (
       const char *id,
@@ -120,17 +110,18 @@ public:
       const CORBA::ValueDefSeq &abstract_base_values,
       const CORBA::InterfaceDefSeq &supported_interfaces,
       const CORBA::ExtInitializerSeq &initializers
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS
-    )
-    ACE_THROW_SPEC ((CORBA::SystemException));
+    );
 
+  /// Called from TAO_IFR_Service_Utils::name_exisits.
   static int same_as_tmp_name (const char *name);
-  // Called from TAO_IFR_Service_Utils::name_exisits.
 
 protected:
   static const char *tmp_name_holder_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+
 #if defined(_MSC_VER)
 #pragma warning(pop)
 #endif /* _MSC_VER */
