@@ -1,27 +1,25 @@
-/* -*- C++ -*- */
-// ComponentModuleDef_i.h,v 1.4 2005/03/10 14:08:41 jwillemsen Exp
+// -*- C++ -*-
+
+
+//=============================================================================
+/**
+ *  @file    ComponentModuleDef_i.h
+ *
+ *  $Id: ComponentModuleDef_i.h 77031 2007-02-12 15:20:17Z johnnyw $
+ *
+ *  ComponentModuleDef_i servant class.
+ *
+ *
+ *  @author Jeff Parsons <j.parsons@vanderbilt.edu>
+ */
+//=============================================================================
 
-// ============================================================================
-//
-// = LIBRARY
-//    TAO/orbsvcs/orbsvcs/IFRService
-//
-// = FILENAME
-//    ComponentModuleDef_i.h
-//
-// = DESCRIPTION
-//    ComponentModuleDef_i servant class.
-//
-// = AUTHOR
-//    Jeff Parsons <j.parsons@vanderbilt.edu>
-//
-// ============================================================================
 
 #ifndef TAO_COMPONENTMODULEDEF_I_H
 #define TAO_COMPONENTMODULEDEF_I_H
 
-#include "ComponentContainer_i.h"
-#include "ifr_service_export.h"
+#include "orbsvcs/IFRService/ComponentContainer_i.h"
+#include "orbsvcs/IFRService/ifr_service_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -32,6 +30,8 @@
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_IFRService_Export TAO_ComponentModuleDef_i
   : public virtual TAO_ComponentContainer_i
 {
@@ -43,13 +43,15 @@ class TAO_IFRService_Export TAO_ComponentModuleDef_i
   //    types.
   //
 public:
+  /// Constructor
   TAO_ComponentModuleDef_i (TAO_Repository_i *repo);
-  // Constructor
 
+  /// Destructor
   virtual ~TAO_ComponentModuleDef_i (void);
-  // Destructor
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(_MSC_VER)
 #pragma warning(pop)
 #endif /* _MSC_VER */
