@@ -1,4 +1,4 @@
-// $Id: Contained_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: Contained_i.cpp 84599 2009-02-25 16:25:48Z vzykov $
 
 #include "orbsvcs/IFRService/concrete_classes.h"
 #include "orbsvcs/IFRService/Repository_i.h"
@@ -9,7 +9,7 @@
 
 ACE_RCSID (IFRService,
            Contained_i,
-           "$Id: Contained_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: Contained_i.cpp 84599 2009-02-25 16:25:48Z vzykov $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -598,9 +598,10 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
         }
         case CORBA::dk_Native:
         {
-          container_impl.create_native_i (new_id.c_str (),
-                                          new_name,
-                                          new_version);
+          CORBA::NativeDef_var new_defn =
+            container_impl.create_native_i (new_id.c_str (),
+                                            new_name,
+                                            new_version);
           break;
         }
         case CORBA::dk_ValueBox:
@@ -613,9 +614,9 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
 
           CORBA::ValueBoxDef_var new_defn =
             container_impl.create_value_box_i (new_id.c_str (),
-                                              new_name,
-                                              new_version,
-                                              otype.in ());
+                                               new_name,
+                                               new_version,
+                                               otype.in ());
 
           ACE_TString new_path =
             TAO_IFR_Service_Utils::reference_to_path (new_defn.in ());
@@ -750,11 +751,12 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
 
           CORBA::Any_var value = impl.value_i ();
 
-          container_impl.create_constant_i (new_id.c_str (),
-                                            new_name,
-                                            new_version,
-                                            type_def.in (),
-                                            value.in ());
+          CORBA::ConstantDef_var new_defn =
+            container_impl.create_constant_i (new_id.c_str (),
+                                              new_name,
+                                              new_version,
+                                              type_def.in (),
+                                              value.in ());
           break;
         }
         case CORBA::dk_Attribute:
@@ -773,11 +775,12 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
               TAO_InterfaceDef_i idef (this->repo_);
               idef.section_key (container_key);
 
-              idef.create_attribute_i (new_id.c_str (),
-                                       new_name,
-                                       new_version,
-                                       type_def.in (),
-                                       mode);
+              CORBA::AttributeDef_var new_defn =
+                idef.create_attribute_i (new_id.c_str (),
+                                         new_name,
+                                         new_version,
+                                         type_def.in (),
+                                         mode);
               break;
             }
           else if (container_dk == CORBA::dk_Value)
@@ -785,11 +788,12 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
               TAO_ValueDef_i vdef (this->repo_);
               vdef.section_key (container_key);
 
-              vdef.create_attribute_i (new_id.c_str (),
-                                       new_name,
-                                       new_version,
-                                       type_def.in (),
-                                       mode);
+              CORBA::AttributeDef_var new_defn =
+                vdef.create_attribute_i (new_id.c_str (),
+                                         new_name,
+                                         new_version,
+                                         type_def.in (),
+                                         mode);
               break;
             }
           else
@@ -824,14 +828,15 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
               TAO_InterfaceDef_i idef (this->repo_);
               idef.section_key (container_key);
 
-              idef.create_operation_i (new_id.c_str (),
-                                       new_name,
-                                       new_version,
-                                       result.in (),
-                                       mode,
-                                       params.in (),
-                                       exceptions.in (),
-                                       contexts.in ());
+              CORBA::OperationDef_var new_defn =
+                idef.create_operation_i (new_id.c_str (),
+                                         new_name,
+                                         new_version,
+                                         result.in (),
+                                         mode,
+                                         params.in (),
+                                         exceptions.in (),
+                                         contexts.in ());
               break;
             }
           else if (container_dk == CORBA::dk_Value)
@@ -839,14 +844,15 @@ TAO_Contained_i::move_i (CORBA::Container_ptr new_container,
               TAO_ValueDef_i vdef (this->repo_);
               impl.section_key (container_key);
 
-              vdef.create_operation_i (new_id.c_str (),
-                                       new_name,
-                                       new_version,
-                                       result.in (),
-                                       mode,
-                                       params.in (),
-                                       exceptions.in (),
-                                       contexts.in ());
+              CORBA::OperationDef_var new_defn =
+                vdef.create_operation_i (new_id.c_str (),
+                                         new_name,
+                                         new_version,
+                                         result.in (),
+                                         mode,
+                                         params.in (),
+                                         exceptions.in (),
+                                         contexts.in ());
               break;
             }
           else
