@@ -1,4 +1,4 @@
-// $Id: Container_i.cpp 80183 2007-12-03 20:39:28Z parsons $
+// $Id: Container_i.cpp 84599 2009-02-25 16:25:48Z vzykov $
 
 #include "orbsvcs/IFRService/Repository_i.h"
 #include "orbsvcs/IFRService/InterfaceDef_i.h"
@@ -17,7 +17,7 @@
 
 ACE_RCSID (IFRService,
            Container_i,
-           "$Id: Container_i.cpp 80183 2007-12-03 20:39:28Z parsons $")
+           "$Id: Container_i.cpp 84599 2009-02-25 16:25:48Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -46,6 +46,13 @@ TAO_Container_i::destroy (void)
 
 void
 TAO_Container_i::destroy_i (void)
+{
+  this->destroy_references_i();
+  this->destroy_defintions_i();
+}
+
+void
+TAO_Container_i::destroy_references_i (void)
 {
   int index = 0;
   int status;
@@ -118,8 +125,14 @@ TAO_Container_i::destroy_i (void)
                                               "refs",
                                               1);
     }
+}
 
-  // Destroy definitions.
+void
+TAO_Container_i::destroy_defintions_i (void)
+{
+  int index = 0;
+  int status;
+  ACE_TString section_name;
 
   ACE_Configuration_Section_Key defns_key;
   status =
@@ -359,6 +372,54 @@ TAO_Container_i::lookup_i (const char *search_name)
                                   break;
                                 }
                             }
+                        }
+                    }
+
+                  if (so_far_so_good)
+                    {
+                      break;
+                    }
+                  else
+                    {
+                      ACE_Configuration_Section_Key members_key;
+                      status =
+                        this->repo_->config ()->open_section (iter_key,
+                                                              "members",
+                                                              0,
+                                                              members_key);
+
+                      if (status == 0)
+                        {
+                          index = 0;
+
+                          while (this->repo_->config ()->enumerate_sections (
+                                                             members_key,
+                                                             index++,
+                                                             section_name
+                                                           )
+                                  == 0)
+                            {
+                              this->repo_->config ()->open_section (
+                                  members_key,
+                                  section_name.c_str (),
+                                  0,
+                                  work_key
+                               );
+
+                              ACE_TString member_name;
+                              this->repo_->config ()->get_string_value (
+                                                          work_key,
+                                                          "name",
+                                                          member_name
+                                                        );
+
+                              // If we're here, name has only one segment.
+                              if (member_name == work_string)
+                                {
+                                  so_far_so_good = 1;
+                                  break;
+                                }
+                            }
 
                           if (so_far_so_good)
                             {
@@ -502,6 +563,20 @@ TAO_Container_i::contents_i (CORBA::DefinitionKind limit_type,
                                     exclude_inherited);
         }
     }
+  else if (def_kind == CORBA::dk_Value)
+    {
+      if (limit_type == CORBA::dk_ValueMember
+          || limit_type == CORBA::dk_all)
+        {
+          TAO_ValueDef_i value (this->repo_);
+          value.section_key (this->section_key_);
+
+          value.value_contents (kind_queue,
+                                path_queue,
+                                limit_type,
+                                exclude_inherited);
+        }
+    }
 
   CORBA::ULong size = static_cast<CORBA::ULong> (kind_queue.size ());
   retval->length (size);
@@ -769,6 +844,7 @@ TAO_Container_i::create_constant_i (const char *id,
       TAO_InputCDR in (out);
       mb = in.steal_contents ();
     }
+  ACE_Auto_Ptr<ACE_Message_Block> safe (mb);
 
   CORBA::TypeCode_var val_tc = value.type ();
 
