@@ -1,4 +1,4 @@
-// $Id: IFR_Service_Utils.cpp 80139 2007-11-30 00:07:49Z parsons $
+// $Id: IFR_Service_Utils.cpp 83519 2008-11-01 14:09:11Z mesnier_p $
 
 #include "orbsvcs/IFRService/IFR_Service_Utils.h"
 #include "orbsvcs/IFRService/IDLType_i.h"
@@ -16,10 +16,11 @@
 #include "tao/Profile.h"
 #include "tao/AnyTypeCode/ValueModifierC.h"
 #include "ace/Auto_Ptr.h"
+#include "ace/OS_NS_fcntl.h"
 
 ACE_RCSID (IFR_Service,
            IFR_Service,
-           "$Id: IFR_Service_Utils.cpp 80139 2007-11-30 00:07:49Z parsons $")
+           "$Id: IFR_Service_Utils.cpp 83519 2008-11-01 14:09:11Z mesnier_p $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -63,24 +64,43 @@ TAO_IFR_Server::init_with_orb (int argc,
 {
   try
     {
-      // Duplicate the ORB.
-      this->orb_ = CORBA::ORB::_duplicate (orb);
-
       // Get the POA from the ORB.
       CORBA::Object_var poa_object =
         orb->resolve_initial_references ("RootPOA");
 
       if (CORBA::is_nil (poa_object.in ()))
         {
-          ACE_ERROR_RETURN ((
-              LM_ERROR,
-              ACE_TEXT ("(%P|%t) Unable to initialize the POA.\n")
-            ),
-            -1
-          );
+          ACE_ERROR_RETURN ((LM_ERROR,
+                             ACE_TEXT ("(%P|%t) IFR_Service::init_with_orb ")
+                             ACE_TEXT ("Unable to initialize the POA.\n")),
+                            -1);
         }
-      this->root_poa_ =
+      PortableServer::POA_var rp =
         PortableServer::POA::_narrow (poa_object.in ());
+      return this->init_with_poa (argc, argv, orb, rp.in(), use_multicast_server);
+    }
+  catch (const CORBA::Exception& ex)
+    {
+      ex._tao_print_exception ("IFR_Service::init_with_orb");
+
+      throw;
+    }
+  return 0;
+}
+
+int
+TAO_IFR_Server::init_with_poa (int argc,
+                               ACE_TCHAR *argv [],
+                               CORBA::ORB_ptr orb,
+                               PortableServer::POA_ptr rp,
+                               int use_multicast_server)
+{
+  try
+    {
+      // Duplicate the ORB.
+      this->orb_ = CORBA::ORB::_duplicate (orb);
+      // Duplicate the provided poa as the new root.
+      this->root_poa_ = PortableServer::POA::_duplicate (rp);
 
       int retval = OPTIONS::instance ()->parse_args (argc,
                                                     argv);
@@ -331,12 +351,23 @@ TAO_IFR_Server::create_repository (void)
   this->orb_->register_initial_reference ("InterfaceRepository",
                                           repo_ref);
 
+  // Write our IOR to a file.
+  
   FILE *output_file_ =
-    ACE_OS::fopen (OPTIONS::instance()->ior_output_file (),
-                   "w");
+    ACE_OS::fopen (OPTIONS::instance ()->ior_output_file (),
+                   ACE_TEXT ("w"));
+                   
+  if (output_file_ == 0)
+    {
+      ACE_ERROR_RETURN ((LM_ERROR,
+                         ACE_TEXT ("TAO_IFR_Server::create_repository - ")
+                         ACE_TEXT ("can't open IOR output ")
+                         ACE_TEXT ("file for writing\n")),
+                        -1);
+    }
 
   ACE_OS::fprintf (output_file_,
-                   "%s",
+                   "%s\n",
                    this->ifr_ior_.in ());
 
   ACE_OS::fclose (output_file_);
@@ -1082,6 +1113,15 @@ TAO_IFR_Service_Utils::fill_valuemember_seq (
 char *
 TAO_IFR_Service_Utils::reference_to_path (CORBA::IRObject_ptr obj)
 {
+  if (CORBA::is_nil (obj))
+    {
+      ACE_DEBUG ((LM_DEBUG,
+                  "reference_to_path - null object; check the include "
+                  "order of IDL\n"));
+
+      throw CORBA::INTF_REPOS ();
+    }
+
   PortableServer::ObjectId object_id;
   TAO::ObjectKey object_key =
     obj->_stubobj ()->profile_in_use ()->object_key ();
