@@ -1,4 +1,4 @@
-// $Id: OperationDef_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: OperationDef_i.cpp 81021 2008-03-19 15:18:20Z pollackj $
 
 #include "orbsvcs/IFRService/OperationDef_i.h"
 #include "orbsvcs/IFRService/Repository_i.h"
@@ -12,7 +12,7 @@
 
 ACE_RCSID (IFRService,
            OperationDef_i,
-           "$Id: OperationDef_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: OperationDef_i.cpp 81021 2008-03-19 15:18:20Z pollackj $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -228,6 +228,17 @@ TAO_OperationDef_i::params_i (void)
         TAO_IFR_Service_Utils::path_to_idltype (type_path,
                                                 this->repo_);
 
+      // We have an undefined interface
+      if (impl == 0)
+        {
+          ACE_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("Encountered undefined parameter type "
+                                "for variable: %s\n"),
+                      name.c_str ()));
+
+          throw CORBA::INTF_REPOS ();
+        }
+
       retval[i].type = impl->type_i ();
 
       CORBA::Object_var obj =
