@@ -1,4 +1,4 @@
-// $Id: Options.cpp 80301 2007-12-18 10:17:14Z vzykov $
+// $Id: Options.cpp 82735 2008-09-16 12:12:29Z johnnyw $
 
 #include "orbsvcs/IFRService/Options.h"
 #include "ace/Get_Opt.h"
@@ -27,7 +27,7 @@ Options::~Options ()
 int
 Options::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:pb:lm:r");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:pb:lm:r"));
   int c;
 
   while ((c = get_opts ()) != -1)
