@@ -1,6 +1,6 @@
-// RecursDef_i.cpp,v 1.3 2005/01/31 03:58:38 ossama Exp
+// $Id: RecursDef_i.cpp 71526 2006-03-14 06:14:35Z jtc $
 
-#include "RecursDef_i.h"
+#include "orbsvcs/IFRService/RecursDef_i.h"
 
 
 ACE_RCSID (IFRService,
@@ -8,6 +8,8 @@ ACE_RCSID (IFRService,
            "RecursDef_i.cpp,v 1.1 2004/10/18 09:00:00 SMA Exp")
 
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 //-----------------------------------------------------------------------------
 // Class TAO_RecursiveDef_OuterScopes is a support class for StructDef_i.h and
 // UnionDef_i.h files. It creates a stack of outer structure definitions, used
@@ -41,3 +43,5 @@ bool TAO_RecursiveDef_OuterScopes::SeenBefore( const ACE_TString &id )
 
 const TAO_RecursiveDef_OuterScopes
   *TAO_RecursiveDef_OuterScopes::pIDsSeenAlready= 0;
+
+TAO_END_VERSIONED_NAMESPACE_DECL
