@@ -1,16 +1,18 @@
-// UsesDef_i.cpp,v 1.8 2005/01/30 08:20:58 ossama Exp
+// $Id: UsesDef_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
-#include "Repository_i.h"
-#include "UsesDef_i.h"
-#include "IFR_Service_Utils_T.h"
+#include "orbsvcs/IFRService/Repository_i.h"
+#include "orbsvcs/IFRService/UsesDef_i.h"
+#include "orbsvcs/IFRService/IFR_Service_Utils_T.h"
+#include "orbsvcs/IFRService/IFR_Service_Utils.h"
 
 #include "ace/SString.h"
 
 
 ACE_RCSID (IFRService,
            UsesDef_i,
-           "UsesDef_i.cpp,v 1.8 2005/01/30 08:20:58 ossama Exp")
+           "$Id: UsesDef_i.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_UsesDef_i::TAO_UsesDef_i (TAO_Repository_i *repo)
   : TAO_IRObject_i (repo),
@@ -23,27 +25,23 @@ TAO_UsesDef_i::~TAO_UsesDef_i (void)
 }
 
 CORBA::DefinitionKind
-TAO_UsesDef_i::def_kind (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::def_kind (void)
 {
   return CORBA::dk_Uses;
 }
 
 CORBA::Contained::Description *
-TAO_UsesDef_i::describe (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::describe (void)
 {
   TAO_IFR_READ_GUARD_RETURN (0);
 
-  this->update_key (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+  this->update_key ();
 
-  return this->describe_i (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return this->describe_i ();
 }
 
 CORBA::Contained::Description *
-TAO_UsesDef_i::describe_i (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::describe_i (void)
 {
   CORBA::ComponentIR::UsesDescription ud;
   TAO_IFR_Desc_Utils<CORBA::ComponentIR::UsesDescription,
@@ -51,17 +49,14 @@ TAO_UsesDef_i::describe_i (ACE_ENV_SINGLE_ARG_DECL)
                                          ud,
                                          this->repo_,
                                          this->section_key_
-                                         ACE_ENV_ARG_PARAMETER
                                        );
-  ACE_CHECK_RETURN (0);
 
   ACE_TString base_type_id;
   this->repo_->config ()->get_string_value (this->section_key_,
                                             "base_type",
                                             base_type_id);
   ud.interface_type = base_type_id.fast_rep ();
-  ud.is_multiple = this->is_multiple_i (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+  ud.is_multiple = this->is_multiple_i ();
 
   CORBA::Contained::Description *retval = 0;
   ACE_NEW_RETURN (retval,
@@ -74,20 +69,17 @@ TAO_UsesDef_i::describe_i (ACE_ENV_SINGLE_ARG_DECL)
 }
 
 CORBA::InterfaceDef_ptr
-TAO_UsesDef_i::interface_type (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::interface_type (void)
 {
   TAO_IFR_READ_GUARD_RETURN (CORBA::InterfaceDef::_nil ());
 
-  this->update_key (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CORBA::InterfaceDef::_nil ());
+  this->update_key ();
 
-  return this->interface_type_i (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return this->interface_type_i ();
 }
 
 CORBA::InterfaceDef_ptr
-TAO_UsesDef_i::interface_type_i (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::interface_type_i (void)
 {
   ACE_TString holder;
   this->repo_->config ()->get_string_value (this->section_key_,
@@ -98,36 +90,27 @@ TAO_UsesDef_i::interface_type_i (ACE_ENV_SINGLE_ARG_DECL)
                                             holder);
   CORBA::Object_var obj =
     TAO_IFR_Service_Utils::path_to_ir_object (holder,
-                                              this->repo_
-                                              ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CORBA::InterfaceDef::_nil ());
+                                              this->repo_);
 
-  return CORBA::InterfaceDef::_narrow (obj.in ()
-                                       ACE_ENV_ARG_PARAMETER);
+  return CORBA::InterfaceDef::_narrow (obj.in ());
 }
 
 void
 TAO_UsesDef_i::interface_type (
     CORBA::InterfaceDef_ptr interface_type
-    ACE_ENV_ARG_DECL
   )
-  ACE_THROW_SPEC ((CORBA::SystemException))
 {
   TAO_IFR_WRITE_GUARD;
 
-  this->update_key (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->update_key ();
 
-  this->interface_type_i (interface_type
-                          ACE_ENV_ARG_PARAMETER);
+  this->interface_type_i (interface_type);
 }
 
 void
 TAO_UsesDef_i::interface_type_i (
     CORBA::InterfaceDef_ptr interface_type
-    ACE_ENV_ARG_DECL_NOT_USED
   )
-  ACE_THROW_SPEC ((CORBA::SystemException))
 {
   this->repo_->config ()->remove_value (this->section_key_,
                                         "base_type");
@@ -159,20 +142,17 @@ TAO_UsesDef_i::interface_type_i (
 }
 
 CORBA::Boolean
-TAO_UsesDef_i::is_multiple (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::is_multiple (void)
 {
   TAO_IFR_READ_GUARD_RETURN (0);
 
-  this->update_key (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+  this->update_key ();
 
-  return this->is_multiple_i (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return this->is_multiple_i ();
 }
 
 CORBA::Boolean
-TAO_UsesDef_i::is_multiple_i (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UsesDef_i::is_multiple_i (void)
 {
   CORBA::ULong val = 0;
   this->repo_->config ()->get_integer_value (this->section_key_,
@@ -184,27 +164,23 @@ TAO_UsesDef_i::is_multiple_i (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 void
 TAO_UsesDef_i::is_multiple (
     CORBA::Boolean is_multiple
-    ACE_ENV_ARG_DECL
   )
-  ACE_THROW_SPEC ((CORBA::SystemException))
 {
   TAO_IFR_WRITE_GUARD;
 
-  this->update_key (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->update_key ();
 
-  this->is_multiple_i (is_multiple
-                       ACE_ENV_ARG_PARAMETER);
+  this->is_multiple_i (is_multiple);
 }
 
 void
 TAO_UsesDef_i::is_multiple_i (
     CORBA::Boolean is_multiple
-    ACE_ENV_ARG_DECL_NOT_USED
   )
-  ACE_THROW_SPEC ((CORBA::SystemException))
 {
   this->repo_->config ()->set_integer_value (this->section_key_,
                                              "is_multiple",
                                              is_multiple);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
