@@ -1,4 +1,4 @@
-#include "LB_CPU_Utilization_Monitor.h"
+#include "orbsvcs/LoadBalancing/LB_CPU_Utilization_Monitor.h"
 #include "tao/ORB_Constants.h"
 #include "ace/OS_NS_time.h"
 #include "ace/OS_NS_stdio.h"
@@ -9,7 +9,9 @@
 
 ACE_RCSID (LoadBalancing,
            LB_CPU_Utilization_Monitor,
-           "LB_CPU_Utilization_Monitor.cpp,v 1.12 2005/03/21 13:47:01 elliott_c Exp")
+           "$Id: LB_CPU_Utilization_Monitor.cpp 78858 2007-07-12 23:24:55Z sowayaa $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 double calc_cpu_loading (void)
 {
@@ -28,17 +30,17 @@ double calc_cpu_loading (void)
 
   double percent_cpu_load = 0.0;
 
-  if ((file_ptr = fopen("/proc/stat", "r")) == 0)
+  if ((file_ptr = ACE_OS::fopen("/proc/stat", "r")) == 0)
           return percent_cpu_load;
 
-  while ((fgets (buf, sizeof (buf), file_ptr)) != 0)
+  while ((ACE_OS::fgets (buf, sizeof (buf), file_ptr)) != 0)
   {
     item = ACE_OS::strtok (buf, " \t\n");
     arg = ACE_OS::strtok (0, "\n");
 
     if (item == 0 || arg == 0)
             continue;
-    if (item[0] == 'c' && strlen (item) == 3)
+    if (item[0] == 'c' && ACE_OS::strlen (item) == 3)
     {
       sscanf (arg, "%lu %lu %lu %lu", &user, &nice, &sys, &idle);
       break;
@@ -47,7 +49,7 @@ double calc_cpu_loading (void)
 
   }
 
-  fclose (file_ptr);
+  ACE_OS::fclose (file_ptr);
 
   delta_idle = idle - prev_idle;
   double total;
@@ -108,8 +110,7 @@ TAO_LB_CPU_Utilization_Monitor::~TAO_LB_CPU_Utilization_Monitor (void)
 }
 
 CosLoadBalancing::Location *
-TAO_LB_CPU_Utilization_Monitor::the_location (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_LB_CPU_Utilization_Monitor::the_location (void)
 {
   CosLoadBalancing::Location * location;
   ACE_NEW_THROW_EX (location,
@@ -119,14 +120,12 @@ TAO_LB_CPU_Utilization_Monitor::the_location (ACE_ENV_SINGLE_ARG_DECL)
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (0);
 
   return location;
 }
 
 CosLoadBalancing::LoadList *
-TAO_LB_CPU_Utilization_Monitor::loads (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_LB_CPU_Utilization_Monitor::loads (void)
 {
   CORBA::Float load = 0;
 
@@ -143,7 +142,6 @@ TAO_LB_CPU_Utilization_Monitor::loads (ACE_ENV_SINGLE_ARG_DECL)
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (0);
 
   CosLoadBalancing::LoadList_var load_list = tmp;
 
@@ -159,8 +157,10 @@ TAO_LB_CPU_Utilization_Monitor::loads (ACE_ENV_SINGLE_ARG_DECL)
 #else
 
   ACE_UNUSED_ARG (load);
-  ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (), 0);
+  throw CORBA::NO_IMPLEMENT ();
 
 #endif  /* linux || sun */
 
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
