@@ -4,7 +4,7 @@
 /**
  *  @file LB_ClientORBInitializer.h
  *
- *  $Id: LB_ClientORBInitializer.h 77001 2007-02-12 07:54:49Z johnnyw $
+ *  $Id: LB_ClientORBInitializer.h 81490 2008-04-28 14:32:24Z johnnyw $
  *
  *  @author  Ossama Othman <ossama@uci.edu>
  */
@@ -45,7 +45,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  */
 class TAO_LB_ClientORBInitializer
   : public virtual PortableInterceptor::ORBInitializer,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
 
