@@ -1,37 +1,31 @@
-#include "LB_ClientRequestInterceptor.h"
+#include "orbsvcs/LoadBalancing/LB_ClientRequestInterceptor.h"
 
 #include "orbsvcs/CosLoadBalancingC.h"
 
 
 ACE_RCSID (LoadBalancing,
            TAO_LB_ClientRequestInterceptor,
-           "LB_ClientRequestInterceptor.cpp,v 1.3 2004/08/16 23:53:13 jtc Exp")
+           "$Id: LB_ClientRequestInterceptor.cpp 78308 2007-05-11 14:30:45Z johnnyw $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 char *
-TAO_LB_ClientRequestInterceptor::name (
-    ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_LB_ClientRequestInterceptor::name ()
 {
   return CORBA::string_dup ("TAO_LB_ClientRequestInterceptor");
 }
 
 void
-TAO_LB_ClientRequestInterceptor::destroy (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_LB_ClientRequestInterceptor::destroy (void)
 {
 }
 
 void
 TAO_LB_ClientRequestInterceptor::send_request (
-    PortableInterceptor::ClientRequestInfo_ptr ri
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableInterceptor::ForwardRequest))
+    PortableInterceptor::ClientRequestInfo_ptr ri)
 {
   /*
-  CORBA::Object_var t = ri->target (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  CORBA::Object_var t = ri->target ();
   */
 
   // A ServiceContext with an empty payload (i.e. zero length
@@ -70,42 +64,31 @@ TAO_LB_ClientRequestInterceptor::send_request (
   */
 
   const CORBA::Boolean replace = 0;
-  ri->add_request_service_context (service_context,
-                                   replace
-                                   ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  ri->add_request_service_context (service_context, replace);
 }
 
 void
 TAO_LB_ClientRequestInterceptor::send_poll (
-    PortableInterceptor::ClientRequestInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ClientRequestInfo_ptr)
 {
 }
 
 void
 TAO_LB_ClientRequestInterceptor::receive_reply (
-    PortableInterceptor::ClientRequestInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ClientRequestInfo_ptr)
 {
 }
 
 void
 TAO_LB_ClientRequestInterceptor::receive_exception (
-    PortableInterceptor::ClientRequestInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableInterceptor::ForwardRequest))
+    PortableInterceptor::ClientRequestInfo_ptr)
 {
 }
 
 void
 TAO_LB_ClientRequestInterceptor::receive_other (
-    PortableInterceptor::ClientRequestInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableInterceptor::ForwardRequest))
+    PortableInterceptor::ClientRequestInfo_ptr)
 {
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
