@@ -4,7 +4,7 @@
 /**
  *  @file LB_LeastLoaded.h
  *
- *  LB_LeastLoaded.h,v 1.16 2005/07/04 08:55:12 jwillemsen Exp
+ *  $Id: LB_LeastLoaded.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  @author Ossama Othman <ossama@uci.edu>
  */
@@ -16,7 +16,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "LB_LoadMap.h"
+#include "orbsvcs/LoadBalancing/LB_LoadMap.h"
 
 # if !defined (ACE_LACKS_PRAGMA_ONCE)
 #   pragma once
@@ -27,6 +27,8 @@
 #include "ace/Synch_Traits.h"
 #include "ace/Thread_Mutex.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO_LB
 {
   /**
@@ -85,49 +87,33 @@ public:
    * Methods required by the CosLoadBalancing::Strategy interface.
    */
   //@{
-  virtual char * name (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual char * name (void);
 
-  virtual CosLoadBalancing::Properties * get_properties (
-      ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CosLoadBalancing::Properties * get_properties ();
 
   virtual void push_loads (
       const PortableGroup::Location & the_location,
-      const CosLoadBalancing::LoadList & loads
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+      const CosLoadBalancing::LoadList & loads);
 
   virtual CosLoadBalancing::LoadList * get_loads (
       CosLoadBalancing::LoadManager_ptr load_manager,
-      const PortableGroup::Location & the_location
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     CosLoadBalancing::LocationNotFound));
+      const PortableGroup::Location & the_location);
 
   virtual CORBA::Object_ptr next_member (
       PortableGroup::ObjectGroup_ptr object_group,
-      CosLoadBalancing::LoadManager_ptr load_manager
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     PortableGroup::ObjectGroupNotFound,
-                     PortableGroup::MemberNotFound));
+      CosLoadBalancing::LoadManager_ptr load_manager);
 
   virtual void analyze_loads (
       PortableGroup::ObjectGroup_ptr object_group,
-      CosLoadBalancing::LoadManager_ptr load_manager
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+      CosLoadBalancing::LoadManager_ptr load_manager);
   //@}
 
   /// Returns the default POA for this servant.
   virtual PortableServer::POA_ptr _default_POA (
-      ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS
     );
 
   /// Initialize the LeastLoaded instance with the given properties.
-  void init (const PortableGroup::Properties & props
-             ACE_ENV_ARG_DECL);
+  void init (const PortableGroup::Properties & props);
 
 protected:
 
@@ -138,8 +124,7 @@ protected:
   /// locations.
   CORBA::Boolean get_location (CosLoadBalancing::LoadManager_ptr load_manager,
                                const PortableGroup::Locations & locations,
-                               PortableGroup::Location & location
-                               ACE_ENV_ARG_DECL);
+                               PortableGroup::Location & location);
 
   /// Return the effective load.
   CORBA::Float effective_load (CORBA::Float previous_load,
@@ -150,14 +135,12 @@ protected:
   void push_loads (
       const PortableGroup::Location & the_location,
       const CosLoadBalancing::LoadList & loads,
-      CosLoadBalancing::Load & effective_load
-      ACE_ENV_ARG_DECL);
+      CosLoadBalancing::Load & effective_load);
 
   /// Utility method to extract a CORBA::Float value from the given
   /// property.
   void extract_float_property (const PortableGroup::Property & property,
-                               CORBA::Float & value
-                               ACE_ENV_ARG_DECL);
+                               CORBA::Float & value);
 
 private:
 
@@ -215,9 +198,11 @@ private:
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 
 #if defined (__ACE_INLINE__)
-#include "LB_LeastLoaded.inl"
+#include "orbsvcs/LoadBalancing/LB_LeastLoaded.inl"
 #endif /* defined INLINE */
 
 #include /**/ "ace/post.h"
