@@ -4,7 +4,7 @@
 /**
  * @file   LB_LoadAlert_Handler.h
  *
- * LB_LoadAlert_Handler.h,v 1.5 2005/07/04 08:55:12 jwillemsen Exp
+ * $Id: LB_LoadAlert_Handler.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  * @author Ossama Othman <ossama@uci.edu>
  */
@@ -26,6 +26,8 @@
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_LB_LoadAlert_Handler
  *
@@ -41,21 +43,15 @@ class TAO_LB_LoadAlert_Handler
 {
 public:
 
-  virtual void enable_alert (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void enable_alert (void);
 
   virtual void enable_alert_excep (
-      CosLoadBalancing::AMI_LoadAlertExceptionHolder *
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+      ::Messaging::ExceptionHolder *);
 
-  virtual void disable_alert (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disable_alert (void);
 
   virtual void disable_alert_excep (
-      CosLoadBalancing::AMI_LoadAlertExceptionHolder *
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+      ::Messaging::ExceptionHolder *);
 
 protected:
 
@@ -65,6 +61,8 @@ protected:
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(_MSC_VER)
 #pragma warning(pop)
 #endif /* _MSC_VER */
