@@ -1,6 +1,6 @@
 // -*- C++ -*-
 
-#include "LB_Random.h"
+#include "orbsvcs/LoadBalancing/LB_Random.h"
 
 #include "tao/ORB_Constants.h"
 #include "ace/OS_NS_time.h"
@@ -8,18 +8,19 @@
 
 ACE_RCSID (LoadBalancing,
            LB_Random,
-           "LB_Random.cpp,v 1.16 2005/02/18 09:07:08 jwillemsen Exp")
+           "$Id: LB_Random.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
 
 #ifdef ACE_HAS_PTHREADS_STD
 static pthread_once_t tao_lb_once_control = PTHREAD_ONCE_INIT;
 #endif  /* ACE_HAS_PTHREADS_STD */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 extern "C" void tao_lb_random_init_routine (void)
 {
   ACE_OS::srand (static_cast<unsigned int> (ACE_OS::time ()));
 }
 
-
 TAO_LB_Random::TAO_LB_Random (PortableServer::POA_ptr poa)
   : poa_ (PortableServer::POA::_duplicate (poa))
 {
@@ -27,15 +28,13 @@ TAO_LB_Random::TAO_LB_Random (PortableServer::POA_ptr poa)
 }
 
 char *
-TAO_LB_Random::name (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_LB_Random::name (void)
 {
   return CORBA::string_dup ("Random");
 }
 
 CosLoadBalancing::Properties *
-TAO_LB_Random::get_properties (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_LB_Random::get_properties (void)
 {
   CosLoadBalancing::Properties * props = 0;
   ACE_NEW_THROW_EX (props,
@@ -45,7 +44,6 @@ TAO_LB_Random::get_properties (ACE_ENV_SINGLE_ARG_DECL)
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (props);
 
   return props;
 }
@@ -53,62 +51,46 @@ TAO_LB_Random::get_properties (ACE_ENV_SINGLE_ARG_DECL)
 void
 TAO_LB_Random::push_loads (
     const PortableGroup::Location & /* the_location */,
-    const CosLoadBalancing::LoadList & /* loads */
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosLoadBalancing::StrategyNotAdaptive))
+    const CosLoadBalancing::LoadList & /* loads */)
 {
-  ACE_THROW (CosLoadBalancing::StrategyNotAdaptive ());
+  throw CosLoadBalancing::StrategyNotAdaptive ();
 }
 
 CosLoadBalancing::LoadList *
 TAO_LB_Random::get_loads (CosLoadBalancing::LoadManager_ptr load_manager,
-                          const PortableGroup::Location & the_location
-                          ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosLoadBalancing::LocationNotFound))
+                          const PortableGroup::Location & the_location)
 {
   if (CORBA::is_nil (load_manager))
-    ACE_THROW_RETURN (CORBA::BAD_PARAM (), 0);
+    throw CORBA::BAD_PARAM ();
 
-  return load_manager->get_loads (the_location
-                                  ACE_ENV_ARG_PARAMETER);
+  return load_manager->get_loads (the_location);
 }
 
 CORBA::Object_ptr
 TAO_LB_Random::next_member (
     PortableGroup::ObjectGroup_ptr object_group,
-    CosLoadBalancing::LoadManager_ptr load_manager
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableGroup::ObjectGroupNotFound,
-                   PortableGroup::MemberNotFound))
+    CosLoadBalancing::LoadManager_ptr load_manager)
 {
   if (CORBA::is_nil (load_manager))
-    ACE_THROW_RETURN (CORBA::BAD_PARAM (), CORBA::Object::_nil ());
+    throw CORBA::BAD_PARAM ();
 
   PortableGroup::Locations_var locations =
-    load_manager->locations_of_members (object_group
-                                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CORBA::Object::_nil ());
+    load_manager->locations_of_members (object_group);
 
   return TAO_LB_Random::_tao_next_member (object_group,
                                           load_manager,
-                                          locations.in ()
-                                          ACE_ENV_ARG_PARAMETER);
+                                          locations.in ());
 }
 
 void
 TAO_LB_Random::analyze_loads (
     PortableGroup::ObjectGroup_ptr /* object_group */,
-    CosLoadBalancing::LoadManager_ptr /* load_manager */
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    CosLoadBalancing::LoadManager_ptr /* load_manager */)
 {
 }
 
 PortableServer::POA_ptr
-TAO_LB_Random::_default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
+TAO_LB_Random::_default_POA (void)
 {
   return PortableServer::POA::_duplicate (this->poa_.in ());
 }
@@ -117,16 +99,11 @@ CORBA::Object_ptr
 TAO_LB_Random::_tao_next_member (
     PortableGroup::ObjectGroup_ptr object_group,
     CosLoadBalancing::LoadManager_ptr load_manager,
-    const PortableGroup::Locations & locations
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   PortableGroup::ObjectGroupNotFound,
-                   PortableGroup::MemberNotFound))
+    const PortableGroup::Locations & locations)
 {
   const CORBA::ULong len = locations.length ();
   if (len == 0)
-    ACE_THROW_RETURN (CORBA::TRANSIENT (),
-                      CORBA::Object::_nil ());
+    throw CORBA::TRANSIENT ();
 
   // Pick a random location in the sequence using the higher order
   // bits (zero based indexing).
@@ -161,8 +138,7 @@ TAO_LB_Random::_tao_next_member (
 //               locations[i][0].id.in ()));
 
   return load_manager->get_member_ref (object_group,
-                                       locations[i]
-                                       ACE_ENV_ARG_PARAMETER);
+                                       locations[i]);
 }
 
 void
@@ -175,3 +151,5 @@ TAO_LB_Random::init (void)
   ::tao_lb_random_init_routine ();
 #endif  /* ACE_HAS_PTHREADS_STD */
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
