@@ -4,7 +4,7 @@
 /**
  *  @file   EventLogConsumer.h
  *
- *  EventLogConsumer.h,v 1.6 2005/03/10 14:08:41 jwillemsen Exp
+ *  $Id: EventLogConsumer.h 80587 2008-02-07 10:50:39Z johnnyw $
  *
  *  The EventLogConsumer connects to the EventLog and logs the events
  *  that are pushed to the EventLog.
@@ -30,13 +30,15 @@
 #include "orbsvcs/Log/Log_i.h"
 #include "orbsvcs/CosEvent/CEC_EventChannel.h"
 
-#include "eventlog_serv_export.h"
+#include "orbsvcs/Log/eventlog_serv_export.h"
 
 #if defined(_MSC_VER)
 #pragma warning(push)
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_LogMgr_i;
 class TAO_EventLog_i;
 class TAO_EventLogFactory_i;
@@ -63,24 +65,16 @@ public:
   ~TAO_Event_LogConsumer (void);
 
   /// Connect to EventLog.
-  void
-    connect (CosEventChannelAdmin::ConsumerAdmin_ptr consumer_admin);
+  void connect (CosEventChannelAdmin::ConsumerAdmin_ptr consumer_admin);
 
 private:
 
   /// Disconnect from EventLog.
-  void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((
-            CORBA::SystemException
-    ));
+  void disconnect_push_consumer (void);
 
   /// This method will call TAO_Log_i::log() to write
   /// the event to the Log.
-  void push (const CORBA::Any& data ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((
-            CORBA::SystemException,
-            CosEventComm::Disconnected
-    ));
+  void push (const CORBA::Any& data);
 
   /// ProxyPushSupplier used to connect to EventLog.
   CosEventChannelAdmin::ProxyPushSupplier_var supplier_proxy_;
@@ -90,6 +84,8 @@ private:
   TAO_EventLog_i *log_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(_MSC_VER)
 #pragma warning(pop)
 #endif /* _MSC_VER */
