@@ -1,17 +1,14 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file   EventLogNotification.h
  *
- *  EventLogNotification.h,v 1.10 2005/03/10 14:08:41 jwillemsen Exp
+ *  $Id: EventLogNotification.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  Methods to enable log-generated events.
  *
- *
  *  @author D A Hanvey <d.hanvey@qub.ac.uk>
- *
- *
  */
 //=============================================================================
 
@@ -30,13 +27,15 @@
 #include "orbsvcs/DsEventLogAdminS.h"
 #include "orbsvcs/CosEvent/CEC_Default_Factory.h"
 #include "orbsvcs/CosEventCommS.h"
-#include "eventlog_serv_export.h"
+#include "orbsvcs/Log/eventlog_serv_export.h"
 
 #if defined(_MSC_VER)
 #pragma warning(push)
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_EventLogNotification
  *
@@ -57,8 +56,7 @@ public:
   ~TAO_EventLogNotification (void);
 
   /// The skeleton methods.
-  virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_push_supplier (void);
 
 protected:
   // = Helper methods
@@ -68,8 +66,7 @@ protected:
   void obtain_proxy_consumer ();
 
   /// Send the event on the event channel.
-  virtual void send_notification (const CORBA::Any& any ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void send_notification (const CORBA::Any& any);
 
 
 private:
@@ -83,6 +80,8 @@ private:
   CosEventChannelAdmin::ProxyPushConsumer_var consumer_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(_MSC_VER)
 #pragma warning(pop)
 #endif /* _MSC_VER */
