@@ -12,7 +12,7 @@
 
 ACE_RCSID (Log,
            Hash_LogRecordStore,
-           "$Id: Hash_LogRecordStore.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: Hash_LogRecordStore.cpp 83517 2008-11-01 12:47:35Z jtc $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -53,7 +53,7 @@ TAO_Hash_LogRecordStore::TAO_Hash_LogRecordStore (
   this->log_qos_[0] = DsLogAdmin::QoSNone;
 
   PortableServer::POA_ptr log_poa =
-	logmgr_i_->log_poa();
+    logmgr_i_->log_poa();
 
   // Create POA for iterators
   TAO::Utils::PolicyList_Destroyer policies (2);
@@ -71,7 +71,7 @@ TAO_Hash_LogRecordStore::TAO_Hash_LogRecordStore (
     log_poa->the_POAManager ();
 
   this->iterator_poa_ =
-	log_poa->create_POA(buf, poa_manager.in(), policies);
+    log_poa->create_POA(buf, poa_manager.in(), policies);
 }
 
 TAO_Hash_LogRecordStore::~TAO_Hash_LogRecordStore (void)
@@ -133,8 +133,7 @@ TAO_Hash_LogRecordStore::log (const DsLogAdmin::LogRecord &const_rec)
   // ACE emulation of U Long Long (for platforms that don't have one)
   // does not define postfix operators
   rec.id = ++maxid_;
-
-  ORBSVCS_Time::Time_Value_to_TimeT(rec.time,ACE_OS::gettimeofday());
+  rec.time = ORBSVCS_Time::to_Absolute_TimeT (ACE_OS::gettimeofday ());
 
   // First, bind the id to the LogRecord in the hash_map
   if (this->rec_map_.bind (rec.id, rec) != 0)
@@ -162,7 +161,7 @@ TAO_Hash_LogRecordStore::log (const DsLogAdmin::LogRecord &const_rec)
 
 int
 TAO_Hash_LogRecordStore::retrieve_i (DsLogAdmin::RecordId id,
-				     DsLogAdmin::LogRecord &rec)
+                                     DsLogAdmin::LogRecord &rec)
 {
   int retval = rec_map_.find (id, rec);
   return retval;
@@ -235,8 +234,8 @@ TAO_Hash_LogRecordStore::purge_old_records (void)
       LOG_RECORD_STORE_ITER iter_end (rec_map_.end ());
 
       for (CORBA::ULongLong i = 0;
-	   iter != iter_end && i < num_records_to_purge;
-	   ++i)
+           iter != iter_end && i < num_records_to_purge;
+           ++i)
         {
           this->remove_i (iter++);
           ++count;
@@ -412,8 +411,8 @@ TAO_Hash_LogRecordStore::query_i (const char *constraint,
       TAO_Hash_Iterator_i *iter_query = 0;
       ACE_NEW_THROW_EX (iter_query,
                         TAO_Hash_Iterator_i (this->iterator_poa_.in (),
-					     this->reactor_,
-					     this,
+                                             this->reactor_,
+                                             this,
                                              iter,
                                              iter_end,
                                              count,
@@ -456,7 +455,7 @@ TAO_Hash_LogRecordStore::retrieve (DsLogAdmin::TimeT from_time,
 {
   // Decide between forward vs backward retrieval.
   char constraint[32];
-  char uint64_formating[32];
+  ACE_TCHAR uint64_formating[32];
 
 #if defined (ACE_LACKS_LONGLONG_T)
   ACE_OS::sprintf (uint64_formating,
@@ -483,7 +482,7 @@ TAO_Hash_LogRecordStore::retrieve (DsLogAdmin::TimeT from_time,
 
 CORBA::ULong
 TAO_Hash_LogRecordStore::match (const char* grammar,
-				const char *constraint)
+                                const char *constraint)
 {
   this->check_grammar (grammar);
 
@@ -513,7 +512,7 @@ TAO_Hash_LogRecordStore::match (const char* grammar,
 
 CORBA::ULong
 TAO_Hash_LogRecordStore::delete_records (const char *grammar,
-					 const char *constraint)
+                                         const char *constraint)
 {
   this->check_grammar (grammar);
 
@@ -569,21 +568,11 @@ TAO_Hash_LogRecordStore::remove_old_records (void)
     return 0;
   }
 
-  TimeBase::TimeT purge_time;
-  ORBSVCS_Time::Time_Value_to_TimeT (purge_time,
-                                     (ACE_OS::gettimeofday() - ACE_Time_Value(this->max_record_life_)));
+  TimeBase::TimeT purge_time (ORBSVCS_Time::to_Absolute_TimeT ((ACE_OS::gettimeofday () - ACE_Time_Value(this->max_record_life_))));
 
-  CORBA::ULongLong p_time = (CORBA::ULongLong) purge_time;
-
-  static char out[256] = "";
-
-  double temp1 =
-    static_cast<double> (ACE_UINT64_DBLCAST_ADAPTER (p_time));
-
-  ACE_OS::sprintf (out, "time < %.0f", temp1);
-
-  // Use an Interpreter to build an expression tree.
-  TAO_Log_Constraint_Interpreter interpreter (out);
+  // As there is no separate timestamp index, we must iterate through
+  // the entire map.  We can't be tempted to think timestamps will be
+  // monotonically increasing with record id.
 
   // Create iterators
   LOG_RECORD_STORE_ITER iter (rec_map_.begin ());
@@ -593,11 +582,8 @@ TAO_Hash_LogRecordStore::remove_old_records (void)
 
   while (iter != iter_end)
     {
-      // Use an evaluator.
-      TAO_Log_Constraint_Visitor evaluator (iter->item ());
-
       // Does it match the constraint?
-      if (interpreter.evaluate (evaluator) == 1)
+      if (iter->item().time < purge_time)
         {
           this->remove_i (iter++);
           ++count;
