@@ -4,7 +4,7 @@
 
 ACE_RCSID (Log,
            Log_Constraint_Interpreter,
-           "$Id: Log_Constraint_Interpreter.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: Log_Constraint_Interpreter.cpp 81621 2008-05-06 12:51:22Z parsons $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -12,18 +12,20 @@ TAO_Log_Constraint_Interpreter::TAO_Log_Constraint_Interpreter (
     const char *constraints
   )
 {
-  if (TAO_ETCL_Interpreter::is_empty_string (constraints))
+  if (ETCL_Interpreter::is_empty_string (constraints))
     {
       // Root is deleted in the TAO_Interpreter's destructor.
       ACE_NEW_THROW_EX (this->root_,
-                        TAO_ETCL_Literal_Constraint ((CORBA::Boolean) 1),
+                        ETCL_Literal_Constraint (true),
                         CORBA::NO_MEMORY ());
     }
   else
   {
       // root_ is set in this base class call.
-      if (TAO_ETCL_Interpreter::build_tree (constraints) != 0)
+      if (ETCL_Interpreter::build_tree (constraints) != 0)
+        {
           throw DsLogAdmin::InvalidConstraint ();
+        }
     }
 }
 
