@@ -1,7 +1,7 @@
 #include "orbsvcs/Log/Log_Constraint_Visitors.h"
 
-#include "orbsvcs/ETCL/ETCL_Constraint.h"
-#include "orbsvcs/ETCL/ETCL_y.h"
+#include "ace/ETCL/ETCL_Constraint.h"
+#include "ace/ETCL/ETCL_y.h"
 
 #include "tao/DynamicAny/DynArray_i.h"
 #include "tao/DynamicAny/DynSequence_i.h"
@@ -16,7 +16,7 @@
 
 ACE_RCSID (Log,
            Log_Constraint_Visitors,
-           "$Id: Log_Constraint_Visitors.cpp 77620 2007-03-08 21:40:54Z shuston $")
+           "$Id: Log_Constraint_Visitors.cpp 84809 2009-03-12 20:38:19Z olli $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -38,23 +38,24 @@ TAO_Log_Constraint_Visitor::TAO_Log_Constraint_Visitor (const DsLogAdmin::LogRec
 #else
   val_time <<= static_cast<ACE_UINT32> (rec.time);
 #endif
-  this->property_lookup_.bind (ACE_CString("time", 0, false), val_time);
+  this->property_lookup_.bind (ACE_CString ("time", 0, false), val_time);
 
-  this->property_lookup_.bind (ACE_CString("info", 0, false), rec.info);
+  this->property_lookup_.bind (ACE_CString ("info", 0, false), rec.info);
 
   // Bind an entry for each item in the record's attribute list.
-  CORBA::Long len = rec.attr_list.length();
+  CORBA::Long len = rec.attr_list.length ();
+  
   for (CORBA::Long i = 0; i < len; ++i)
     {
-      this->property_lookup_.bind (ACE_CString(rec.attr_list[i].name,
-                 0,
-                 false),
-           rec.attr_list[i].value);
+      this->property_lookup_.bind (ACE_CString (rec.attr_list[i].name,
+                                                0,
+                                                false),
+                                   rec.attr_list[i].value);
     }
 }
 
 CORBA::Boolean
-TAO_Log_Constraint_Visitor::evaluate_constraint (TAO_ETCL_Constraint* root)
+TAO_Log_Constraint_Visitor::evaluate_constraint (ETCL_Constraint* root)
 {
   CORBA::Boolean result = 0;
   this->queue_.reset ();
@@ -77,15 +78,16 @@ TAO_Log_Constraint_Visitor::evaluate_constraint (TAO_ETCL_Constraint* root)
 
 int
 TAO_Log_Constraint_Visitor::visit_literal (
-    TAO_ETCL_Literal_Constraint *literal
+    ETCL_Literal_Constraint *literal
   )
 {
-  this->queue_.enqueue_head (*literal);
+  TAO_ETCL_Literal_Constraint lit (literal);
+  this->queue_.enqueue_head (lit);
   return 0;
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_identifier (TAO_ETCL_Identifier *ident)
+TAO_Log_Constraint_Visitor::visit_identifier (ETCL_Identifier *ident)
 {
   int return_value = -1;
   const char *name = ident->value ();
@@ -97,8 +99,8 @@ TAO_Log_Constraint_Visitor::visit_identifier (TAO_ETCL_Identifier *ident)
     {
       if (any.impl() != 0)
         {
-    this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (&any));
-    return_value = 0;
+          this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (&any));
+          return_value = 0;
         }
     }
 
@@ -107,19 +109,29 @@ TAO_Log_Constraint_Visitor::visit_identifier (TAO_ETCL_Identifier *ident)
 
 int
 TAO_Log_Constraint_Visitor::visit_union_value (
-    TAO_ETCL_Union_Value *union_value
+    ETCL_Union_Value *union_value
   )
 {
   switch (union_value->sign ())
   {
     case 0:
-      this->queue_.enqueue_head (*union_value->string ());
+      {
+        TAO_ETCL_Literal_Constraint lit (union_value->string ());
+        this->queue_.enqueue_head (lit);
+      }
       break;
     case -1:
-      this->queue_.enqueue_head (-(*union_value->integer ()));
+      {
+        CORBA::Long value = -(*union_value->integer ());
+        TAO_ETCL_Literal_Constraint lit (value);
+        this->queue_.enqueue_head (lit);
+      }
       break;
     case 1:
-      this->queue_.enqueue_head (*union_value->integer ());
+      {
+        TAO_ETCL_Literal_Constraint lit (union_value->integer ());
+        this->queue_.enqueue_head (lit);
+      }
       break;
     default:
       return -1;
@@ -130,7 +142,7 @@ TAO_Log_Constraint_Visitor::visit_union_value (
 
 int
 TAO_Log_Constraint_Visitor::visit_union_pos (
-    TAO_ETCL_Union_Pos *union_pos
+    ETCL_Union_Pos *union_pos
   )
 {
   try
@@ -147,9 +159,9 @@ TAO_Log_Constraint_Visitor::visit_union_pos (
 
           switch (disc_val.expr_type ())
           {
-            case TAO_ETCL_INTEGER:
-            case TAO_ETCL_SIGNED:
-            case TAO_ETCL_UNSIGNED:
+            case ETCL_INTEGER:
+            case ETCL_SIGNED:
+            case ETCL_UNSIGNED:
               {
                 CORBA::Any disc_any;
                 CORBA::TypeCode_var disc_tc =
@@ -181,10 +193,8 @@ TAO_Log_Constraint_Visitor::visit_union_pos (
                       TAO_InputCDR in_cdr (cdr);
                       TAO::Unknown_IDL_Type *unk = 0;
                       ACE_NEW_RETURN (unk,
-                                      TAO::Unknown_IDL_Type (
-                                          disc_tc.in (),
-                                          in_cdr
-                                        ),
+                                      TAO::Unknown_IDL_Type (disc_tc.in (),
+                                                             in_cdr),
                                       -1);
 
                       disc_any.replace (unk);
@@ -216,7 +226,7 @@ TAO_Log_Constraint_Visitor::visit_union_pos (
 
                 break;
               }
-            case TAO_ETCL_STRING:
+            case ETCL_STRING:
               {
                 const char *name = (const char *) disc_val;
                 CORBA::ULong count =
@@ -248,7 +258,7 @@ TAO_Log_Constraint_Visitor::visit_union_pos (
               return -1;
           }
 
-          TAO_ETCL_Constraint *nested = union_pos->component ();
+          ETCL_Constraint *nested = union_pos->component ();
 
           // If there's no nested component, then we just want the
           // union member value on the queue. Otherwise, we want
@@ -277,7 +287,7 @@ TAO_Log_Constraint_Visitor::visit_union_pos (
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_component_pos (TAO_ETCL_Component_Pos *pos)
+TAO_Log_Constraint_Visitor::visit_component_pos (ETCL_Component_Pos *pos)
 {
   try
     {
@@ -334,7 +344,7 @@ TAO_Log_Constraint_Visitor::visit_component_pos (TAO_ETCL_Component_Pos *pos)
 
       CORBA::Any_var value = member->to_any ();
 
-      TAO_ETCL_Constraint *comp = pos->component ();
+      ETCL_Constraint *comp = pos->component ();
 
       if (comp == 0)
         {
@@ -356,7 +366,7 @@ TAO_Log_Constraint_Visitor::visit_component_pos (TAO_ETCL_Component_Pos *pos)
 
 int
 TAO_Log_Constraint_Visitor::visit_component_assoc (
-  TAO_ETCL_Component_Assoc *assoc)
+  ETCL_Component_Assoc *assoc)
 {
   // @@@ (JP) The spec reserves this type of constraint for NVLists.
   // Since NVLists don't have type codes or Any operators, there's
@@ -379,8 +389,7 @@ TAO_Log_Constraint_Visitor::visit_component_assoc (
       return -1;
     }
 
-  TAO_ETCL_Constraint *comp = assoc->component ();
-  CORBA::Any *any_ptr = 0;
+  ETCL_Constraint *comp = assoc->component ();
 
   if (comp == 0)
     {
@@ -389,6 +398,7 @@ TAO_Log_Constraint_Visitor::visit_component_assoc (
       return 0;
     }
 
+  CORBA::Any *any_ptr = 0;
   ACE_NEW_RETURN (any_ptr,
                   CORBA::Any (any),
                   -1);
@@ -398,7 +408,7 @@ TAO_Log_Constraint_Visitor::visit_component_assoc (
 
 int
 TAO_Log_Constraint_Visitor::visit_component_array (
-    TAO_ETCL_Component_Array *array
+    ETCL_Component_Array *array
   )
 {
   try
@@ -455,7 +465,7 @@ TAO_Log_Constraint_Visitor::visit_component_array (
 
       CORBA::Any_var value = member->to_any ();
 
-      TAO_ETCL_Constraint *comp = array->component ();
+      ETCL_Constraint *comp = array->component ();
 
       if (comp == 0)
         {
@@ -476,7 +486,7 @@ TAO_Log_Constraint_Visitor::visit_component_array (
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_special (TAO_ETCL_Special *special)
+TAO_Log_Constraint_Visitor::visit_special (ETCL_Special *special)
 {
   try
     {
@@ -484,7 +494,7 @@ TAO_Log_Constraint_Visitor::visit_special (TAO_ETCL_Special *special)
 
       switch (special->type ())
       {
-        case TAO_ETCL_LENGTH:
+        case ETCL_LENGTH:
           {
             // If the TCKind is not a sequence or an array, the
             // call to length() will raise an exception, and the
@@ -495,7 +505,7 @@ TAO_Log_Constraint_Visitor::visit_special (TAO_ETCL_Special *special)
             this->queue_.enqueue_head (lit);
             return 0;
           }
-        case TAO_ETCL_DISCRIMINANT:
+        case ETCL_DISCRIMINANT:
           {
             // If the TCKind is not a union, the
             // call to init() will raise an exception, and the
@@ -512,7 +522,7 @@ TAO_Log_Constraint_Visitor::visit_special (TAO_ETCL_Special *special)
             this->queue_.enqueue_head (lit);
             return 0;
           }
-        case TAO_ETCL_TYPE_ID:
+        case ETCL_TYPE_ID:
           {
             const char *name = tc->name ();
 
@@ -520,7 +530,7 @@ TAO_Log_Constraint_Visitor::visit_special (TAO_ETCL_Special *special)
             this->queue_.enqueue_head (lit);
             return 0;
           }
-        case TAO_ETCL_REPOS_ID:
+        case ETCL_REPOS_ID:
           {
             const char *id = tc->id ();
 
@@ -540,7 +550,7 @@ TAO_Log_Constraint_Visitor::visit_special (TAO_ETCL_Special *special)
 
 int
 TAO_Log_Constraint_Visitor::visit_component (
-    TAO_ETCL_Component *component
+    ETCL_Component *component
   )
 {
   // If this component has no sub-component, only an identifier,
@@ -550,7 +560,7 @@ TAO_Log_Constraint_Visitor::visit_component (
   // in our member _var for possible examination at a more
   // nested level, and visit the sub-component.
 
-  TAO_ETCL_Constraint *nested = component->component ();
+  ETCL_Constraint *nested = component->component ();
   int result = component->identifier ()->accept (this);
 
   if (nested == 0 || result != 0)
@@ -561,10 +571,12 @@ TAO_Log_Constraint_Visitor::visit_component (
     {
       TAO_ETCL_Literal_Constraint id;
       this->queue_.dequeue_head (id);
+        
       CORBA::Any *any_ptr = 0;
       ACE_NEW_RETURN (any_ptr,
-                      CORBA::Any (),
+                      CORBA::Any,
                       -1);
+                      
       any_ptr->replace (id);
       any_ptr->impl ()->_add_ref ();
       this->current_member_ = any_ptr;
@@ -573,7 +585,7 @@ TAO_Log_Constraint_Visitor::visit_component (
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_dot (TAO_ETCL_Dot *dot)
+TAO_Log_Constraint_Visitor::visit_dot (ETCL_Dot *dot)
 {
   // If we are here, we know we're headed for a more nested
   // level, so we just visit it, there's nothing else in this
@@ -582,16 +594,16 @@ TAO_Log_Constraint_Visitor::visit_dot (TAO_ETCL_Dot *dot)
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_eval (TAO_ETCL_Eval *eval)
+TAO_Log_Constraint_Visitor::visit_eval (ETCL_Eval *eval)
 {
   // Nothing to do but visit the contained component.
   return eval->component ()->accept (this);
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_default (TAO_ETCL_Default *def)
+TAO_Log_Constraint_Visitor::visit_default (ETCL_Default *def)
 {
-  TAO_ETCL_Constraint *comp = def->component ();
+  ETCL_Constraint *comp = def->component ();
 
   if (comp == 0)
     {
@@ -614,17 +626,17 @@ TAO_Log_Constraint_Visitor::visit_default (TAO_ETCL_Default *def)
       // No default index.
       if (default_index == -1)
         {
-          TAO_ETCL_Literal_Constraint result ((CORBA::Boolean) 0);
+          TAO_ETCL_Literal_Constraint result (false);
           this->queue_.enqueue_head (result);
           return 0;
         }
 
       // Okay, there's a default index, but is it active?
 
-      TAO_ETCL_Literal_Constraint disc;
-      this->queue_.dequeue_head (disc);
+      TAO_ETCL_Literal_Constraint disc_value;
+      this->queue_.dequeue_head (disc_value);
       TAO_ETCL_Literal_Constraint default_index_value (default_index);
-      return (disc == default_index_value);
+      return (disc_value == default_index_value);
     }
   catch (const CORBA::Exception&)
     {
@@ -633,14 +645,13 @@ TAO_Log_Constraint_Visitor::visit_default (TAO_ETCL_Default *def)
 }
 
 int
-TAO_Log_Constraint_Visitor::visit_exist (TAO_ETCL_Exist *exist)
+TAO_Log_Constraint_Visitor::visit_exist (ETCL_Exist *exist)
 {
-  TAO_ETCL_Constraint *component = exist->component ();
+  ETCL_Constraint *component = exist->component ();
 
   if (component->accept (this) == 0)
     {
       TAO_ETCL_Literal_Constraint top;
-
       this->queue_.dequeue_head (top);
 
       const char *value = (const char *) top;
@@ -658,37 +669,37 @@ TAO_Log_Constraint_Visitor::visit_exist (TAO_ETCL_Exist *exist)
 
 int
 TAO_Log_Constraint_Visitor::visit_unary_expr (
-    TAO_ETCL_Unary_Expr *unary_expr
+    ETCL_Unary_Expr *unary_expr
   )
 {
-  TAO_ETCL_Constraint *subexpr = unary_expr->subexpr ();
+  ETCL_Constraint *subexpr = unary_expr->subexpr ();
 
   if (subexpr->accept (this) == 0)
     {
       TAO_ETCL_Literal_Constraint subexpr_result;
-      CORBA::Boolean result = 0;
+      CORBA::Boolean result = false;
       int op_type = unary_expr->type ();
 
       switch (op_type)
       {
-        case TAO_ETCL_NOT:
+        case ETCL_NOT:
           this->queue_.dequeue_head (subexpr_result);
           result = ! (CORBA::Boolean) subexpr_result;
           this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
           return 0;
-        case TAO_ETCL_MINUS:
+        case ETCL_MINUS:
           // The leading '-' was parsed separately, so we have to pull
           // the literal constraint off the queue, apply the class' own
           // unary minus operator, and put it back.
           this->queue_.dequeue_head (subexpr_result);
           this->queue_.enqueue_head (-subexpr_result);
           return 0;
-        case TAO_ETCL_PLUS:
+        case ETCL_PLUS:
           // Leave the literal constraint on the queue. The leading
           // '+' was just syntactic sugar - no action is necessary.
           return 0;
         default:
-          // The parser should never construct a TAO_ETCL_Unary_Constraint
+          // The parser should never construct a ETCL_Unary_Constraint
           // behind any operators except the above three.
           return -1;
       }
@@ -699,7 +710,7 @@ TAO_Log_Constraint_Visitor::visit_unary_expr (
 
 int
 TAO_Log_Constraint_Visitor::visit_binary_expr (
-    TAO_ETCL_Binary_Expr *binary_expr
+    ETCL_Binary_Expr *binary_expr
   )
 {
 
@@ -708,25 +719,25 @@ TAO_Log_Constraint_Visitor::visit_binary_expr (
 
   switch (bin_op_type)
   {
-    case TAO_ETCL_OR:
+    case ETCL_OR:
       return this->visit_or (binary_expr);
-    case TAO_ETCL_AND:
+    case ETCL_AND:
       return this->visit_and (binary_expr);
-    case TAO_ETCL_LT:
-    case TAO_ETCL_LE:
-    case TAO_ETCL_GT:
-    case TAO_ETCL_GE:
-    case TAO_ETCL_EQ:
-    case TAO_ETCL_NE:
-    case TAO_ETCL_PLUS:
-    case TAO_ETCL_MINUS:
-    case TAO_ETCL_MULT:
-    case TAO_ETCL_DIV:
+    case ETCL_LT:
+    case ETCL_LE:
+    case ETCL_GT:
+    case ETCL_GE:
+    case ETCL_EQ:
+    case ETCL_NE:
+    case ETCL_PLUS:
+    case ETCL_MINUS:
+    case ETCL_MULT:
+    case ETCL_DIV:
       return this->visit_binary_op (binary_expr,
                                     bin_op_type);
-    case TAO_ETCL_TWIDDLE:
+    case ETCL_TWIDDLE:
       return this->visit_twiddle (binary_expr);
-    case TAO_ETCL_IN:
+    case ETCL_IN:
       return this->visit_in (binary_expr);
     default:
       return -1;
@@ -735,12 +746,12 @@ TAO_Log_Constraint_Visitor::visit_binary_expr (
 
 int
 TAO_Log_Constraint_Visitor::visit_or (
-    TAO_ETCL_Binary_Expr *binary
+    ETCL_Binary_Expr *binary
   )
 {
   int return_value = -1;
-  CORBA::Boolean result = 0;
-  TAO_ETCL_Constraint *lhs = binary->lhs ();
+  CORBA::Boolean result = false;
+  ETCL_Constraint *lhs = binary->lhs ();
 
   if (lhs->accept (this) == 0)
     {
@@ -751,7 +762,7 @@ TAO_Log_Constraint_Visitor::visit_or (
       // Short-circuiting OR.
       if (result == 0)
         {
-          TAO_ETCL_Constraint *rhs = binary->rhs ();
+          ETCL_Constraint *rhs = binary->rhs ();
 
           if (rhs->accept (this) == 0)
             {
@@ -777,12 +788,12 @@ TAO_Log_Constraint_Visitor::visit_or (
 
 int
 TAO_Log_Constraint_Visitor::visit_and (
-    TAO_ETCL_Binary_Expr *binary
+    ETCL_Binary_Expr *binary
   )
 {
   int return_value = -1;
-  CORBA::Boolean result = 0;
-  TAO_ETCL_Constraint *lhs = binary->lhs ();
+  CORBA::Boolean result = false;
+  ETCL_Constraint *lhs = binary->lhs ();
 
   if (lhs->accept (this) == 0)
     {
@@ -793,7 +804,7 @@ TAO_Log_Constraint_Visitor::visit_and (
       // Short-circuiting AND.
       if (result == 1)
         {
-          TAO_ETCL_Constraint *rhs = binary->rhs ();
+          ETCL_Constraint *rhs = binary->rhs ();
 
           if (rhs->accept (this) == 0)
             {
@@ -819,24 +830,22 @@ TAO_Log_Constraint_Visitor::visit_and (
 
 int
 TAO_Log_Constraint_Visitor::visit_binary_op (
-    TAO_ETCL_Binary_Expr *binary,
+    ETCL_Binary_Expr *binary,
     int op_type
   )
 {
   int return_value = -1;
-  TAO_ETCL_Constraint *lhs = binary->lhs ();
-  CORBA::Boolean result = 0;
+  ETCL_Constraint *lhs = binary->lhs ();
+  CORBA::Boolean result = false;
 
   // Evaluate the constraint
   // Perform an operation on the results of evaluating the left and
   // right branches of this subtree.
   if (lhs->accept (this) == 0)
     {
-
-  // Evaluate the constraint
       TAO_ETCL_Literal_Constraint left_operand;
       this->queue_.dequeue_head (left_operand);
-      TAO_ETCL_Constraint *rhs = binary->rhs ();
+      ETCL_Constraint *rhs = binary->rhs ();
 
       if (rhs->accept (this) == 0)
         {
@@ -846,40 +855,44 @@ TAO_Log_Constraint_Visitor::visit_binary_op (
 
           switch (op_type)
           {
-            case TAO_ETCL_LT:
+            case ETCL_LT:
               result = left_operand < right_operand;
               this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
               break;
-            case TAO_ETCL_LE:
-              result = left_operand <= right_operand;
+            case ETCL_LE:
+              //result = left_operand <= right_operand; // Compile error on LynxOS
+              result = left_operand.operator<= (right_operand);
               this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
               break;
-            case TAO_ETCL_GT:
-              result = left_operand > right_operand;
+            case ETCL_GT:
+              //result = left_operand > right_operand; // Compile error on LynxOS
+              result = left_operand.operator> (right_operand);
               this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
               break;
-            case TAO_ETCL_GE:
-              result = left_operand >= right_operand;
+            case ETCL_GE:
+              //result = left_operand >= right_operand; // Compile error on LynxOS
+              result = left_operand.operator>= (right_operand);
               this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
               break;
-            case TAO_ETCL_EQ:
+            case ETCL_EQ:
               result = left_operand == right_operand;
               this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
               break;
-            case TAO_ETCL_NE:
-              result = left_operand != right_operand;
+            case ETCL_NE:
+              //result = left_operand != right_operand; // Compile error on LynxOS
+              result = left_operand.operator!= (right_operand);
               this->queue_.enqueue_head (TAO_ETCL_Literal_Constraint (result));
               break;
-            case TAO_ETCL_PLUS:
+            case ETCL_PLUS:
               this->queue_.enqueue_head (left_operand + right_operand);
               break;
-            case TAO_ETCL_MINUS:
+            case ETCL_MINUS:
               this->queue_.enqueue_head (left_operand - right_operand);
               break;
-            case TAO_ETCL_MULT:
+            case ETCL_MULT:
               this->queue_.enqueue_head (left_operand * right_operand);
               break;
-            case TAO_ETCL_DIV:
+            case ETCL_DIV:
               this->queue_.enqueue_head (left_operand / right_operand);
               break;
             default:
@@ -893,18 +906,18 @@ TAO_Log_Constraint_Visitor::visit_binary_op (
 
 int
 TAO_Log_Constraint_Visitor::visit_twiddle (
-    TAO_ETCL_Binary_Expr *binary
+    ETCL_Binary_Expr *binary
   )
 {
   int return_value = -1;
-  TAO_ETCL_Constraint *lhs = binary->lhs ();
+  ETCL_Constraint *lhs = binary->lhs ();
 
   // Determine if the left operand is a substring of the right.
   if (lhs->accept (this) == 0)
     {
       TAO_ETCL_Literal_Constraint left;
       this->queue_.dequeue_head (left);
-      TAO_ETCL_Constraint *rhs = binary->rhs ();
+      ETCL_Constraint *rhs = binary->rhs ();
 
       if (rhs->accept (this) == 0)
         {
@@ -923,11 +936,11 @@ TAO_Log_Constraint_Visitor::visit_twiddle (
 
 int
 TAO_Log_Constraint_Visitor::visit_in (
-    TAO_ETCL_Binary_Expr *binary
+    ETCL_Binary_Expr *binary
   )
 {
   int return_value = -1;
-  TAO_ETCL_Constraint *lhs = binary->lhs ();
+  ETCL_Constraint *lhs = binary->lhs ();
 
   // Determine if the left operand is contained in the right.
 
@@ -936,16 +949,21 @@ TAO_Log_Constraint_Visitor::visit_in (
       TAO_ETCL_Literal_Constraint left;
       this->queue_.dequeue_head (left);
 
-      TAO_ETCL_Constraint *rhs = binary->rhs ();
+      ETCL_Constraint *rhs = binary->rhs ();
 
       if (rhs->accept (this) == 0)
         {
           TAO_ETCL_Literal_Constraint bag;
           this->queue_.dequeue_head (bag);
 
-          if (bag.expr_type () == TAO_ETCL_COMPONENT)
+          if (bag.expr_type () == ETCL_COMPONENT)
             {
-              CORBA::Any_var component = new CORBA::Any ();
+              CORBA::Any_ptr any_ptr = 0;
+              ACE_NEW_RETURN (any_ptr,
+                              CORBA::Any,
+                              -1);
+                              
+              CORBA::Any_var component = any_ptr;
               component->replace (bag);
               component->impl ()->_add_ref ();
               CORBA::TCKind kind = CORBA::tk_null;
@@ -999,7 +1017,7 @@ TAO_Log_Constraint_Visitor::visit_in (
 
 int
 TAO_Log_Constraint_Visitor::visit_preference (
-    TAO_ETCL_Preference *
+    ETCL_Preference *
   )
 {
   // According to OMG 00-06-20 section 2.4.1, the Notification Service
@@ -1025,16 +1043,15 @@ TAO_Log_Constraint_Visitor::sequence_does_contain (
       CORBA::Boolean match = this->simple_type_match (item.expr_type (),
                                                       kind);
 
-      if (match == 0)
+      if (!match)
         {
-          return 0;
+          return false;
         }
 
       TAO_DynSequence_i dyn_seq;
       dyn_seq.init (*any);
 
-      DynamicAny::AnySeq_var any_seq =
-        dyn_seq.get_elements ();
+      DynamicAny::AnySeq_var any_seq = dyn_seq.get_elements ();
 
       CORBA::ULong length = any_seq->length ();
 
@@ -1044,16 +1061,16 @@ TAO_Log_Constraint_Visitor::sequence_does_contain (
 
           if (item == element)
             {
-              return 1;
+              return true;
             }
         }
     }
   catch (const CORBA::Exception&)
     {
-      return 0;
+      return false;
     }
 
-  return 0;
+  return false;
 }
 
 CORBA::Boolean
@@ -1072,16 +1089,16 @@ TAO_Log_Constraint_Visitor::array_does_contain (
       CORBA::Boolean match = this->simple_type_match (item.expr_type (),
                                                       kind);
 
-      if (match == 0)
+      if (!match)
         {
-          return 0;
+          return false;
         }
 
+
       TAO_DynArray_i dyn_array;
       dyn_array.init (*any);
 
-      DynamicAny::AnySeq_var any_seq =
-        dyn_array.get_elements ();
+      DynamicAny::AnySeq_var any_seq = dyn_array.get_elements ();
 
       CORBA::ULong length = any_seq->length ();
 
@@ -1091,16 +1108,16 @@ TAO_Log_Constraint_Visitor::array_does_contain (
 
           if (item == element)
             {
-              return 1;
+              return true;
             }
         }
     }
   catch (const CORBA::Exception&)
     {
-      return 0;
+      return false;
     }
 
-  return 0;
+  return false;
 }
 
 CORBA::Boolean
@@ -1131,25 +1148,25 @@ TAO_Log_Constraint_Visitor::struct_does_contain (
           CORBA::Boolean match = this->simple_type_match (item.expr_type (),
                                                           kind);
 
-          if (match == 0)
-            {
-              continue;
-            }
+      if (!match)
+        {
+          return false;
+        }
 
           TAO_ETCL_Literal_Constraint element (&members[i].value);
 
           if (item == element)
             {
-              return 1;
+              return true;
             }
         }
     }
   catch (const CORBA::Exception&)
     {
-      return 0;
+      return false;
     }
 
-  return 0;
+  return false;
 }
 
 CORBA::Boolean
@@ -1176,9 +1193,9 @@ TAO_Log_Constraint_Visitor::union_does_contain (
       CORBA::Boolean match = this->simple_type_match (item.expr_type (),
                                                       kind);
 
-      if (match == 0)
+      if (!match)
         {
-          return 0;
+          return false;
         }
 
       TAO_ETCL_Literal_Constraint element (&member.inout ());
@@ -1187,7 +1204,7 @@ TAO_Log_Constraint_Visitor::union_does_contain (
     }
   catch (const CORBA::Exception&)
     {
-      return 0;
+      return false;
     }
 }
 
@@ -1208,44 +1225,46 @@ TAO_Log_Constraint_Visitor::any_does_contain (
 
 CORBA::Boolean
 TAO_Log_Constraint_Visitor::simple_type_match (int expr_type,
-                                                  CORBA::TCKind tc_kind)
+                                               CORBA::TCKind tc_kind)
 {
   switch (expr_type)
   {
-    case TAO_ETCL_STRING:
+    case ETCL_STRING:
       if (tc_kind != CORBA::tk_string)
         {
-          return 0;
+          return false;
         }
-    case TAO_ETCL_DOUBLE:
+    case ETCL_DOUBLE:
       if (tc_kind != CORBA::tk_double
           && tc_kind != CORBA::tk_float)
         {
-          return 0;
+          return false;
         }
-    case TAO_ETCL_INTEGER:
-    case TAO_ETCL_SIGNED:
+    case ETCL_INTEGER:
+    case ETCL_SIGNED:
       if (tc_kind != CORBA::tk_short
           && tc_kind != CORBA::tk_long
           && tc_kind != CORBA::tk_longlong)
         {
-          return 0;
+          return false;
         }
-    case TAO_ETCL_UNSIGNED:
+    case ETCL_UNSIGNED:
       if (tc_kind != CORBA::tk_ushort
           && tc_kind != CORBA::tk_ulong
           && tc_kind != CORBA::tk_ulonglong)
         {
-          return 0;
+          return false;
         }
-    case TAO_ETCL_BOOLEAN:
+    case ETCL_BOOLEAN:
       if (tc_kind != CORBA::tk_boolean)
         {
-          return 0;
+          return false;
         }
     default:
-      return 0;
+      return false;
   }
+  
+  return true;
 }
 
 const size_t TAO_Log_Constraint_Visitor::property_lookup_size_ = 31;
