@@ -1,17 +1,14 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file   NotifyLogNotification.h
  *
- *  NotifyLogNotification.h,v 1.13 2005/07/04 08:55:12 jwillemsen Exp
+ *  $Id: NotifyLogNotification.h 80587 2008-02-07 10:50:39Z johnnyw $
  *
  *  Methods to enable log-generated events.
  *
- *
  *  @author D A Hanvey <d.hanvey@qub.ac.uk>
- *
- *
  */
 //=============================================================================
 
@@ -30,13 +27,15 @@
 #include "orbsvcs/CosNotifyChannelAdminS.h"
 #include "orbsvcs/CosNotifyCommC.h"
 
-#include "notifylog_serv_export.h"
+#include "orbsvcs/Log/notifylog_serv_export.h"
 
 #if defined(_MSC_VER)
 #pragma warning(push)
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_NotifyLogNotification
  *
@@ -68,27 +67,13 @@ protected:
   // = NotifySubscribe
   virtual void subscription_change (
         const CosNotification::EventTypeSeq & added,
-        const CosNotification::EventTypeSeq & removed
-        ACE_ENV_ARG_DECL
-      )
-      ACE_THROW_SPEC ((
-        CORBA::SystemException,
-        CosNotifyComm::InvalidEventType
-      ));
+        const CosNotification::EventTypeSeq & removed);
 
   // = StructuredPushSupplier method
-    virtual void disconnect_push_supplier (
-        ACE_ENV_SINGLE_ARG_DECL
-      )
-      ACE_THROW_SPEC ((
-        CORBA::SystemException
-      ));
+    virtual void disconnect_push_supplier (void);
 
   /// Send the event on the event channel.
-  virtual void send_notification (const CORBA::Any& any)
-      ACE_THROW_SPEC ((
-        CORBA::SystemException
-      ));
+  virtual void send_notification (const CORBA::Any& any);
 
 private:
   /// A reference to the ORB.
@@ -99,6 +84,8 @@ private:
   CosNotifyChannelAdmin::EventChannel_var event_channel_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(_MSC_VER)
 #pragma warning(pop)
 #endif /* _MSC_VER */
