@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file   Entries.h
  *
- *  Entries.h,v 1.21 2004/09/08 19:22:44 jtc Exp
+ *  $Id: Entries.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author Marina Spivak <marina@cs.wustl.edu>
  */
@@ -24,7 +24,9 @@
 #include "ace/SString.h"
 
 #include "orbsvcs/CosNamingC.h"
-#include "naming_serv_export.h"
+#include "orbsvcs/Naming/naming_serv_export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /**
  * @class TAO_IntId
@@ -131,5 +133,7 @@ public:
   const char * kind (void);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_ENTRIES_H */
