@@ -2,7 +2,7 @@
 /**
  *  @file   Hash_Naming_Context.cpp
  *
- *  $Id: Hash_Naming_Context.cpp 77031 2007-02-12 15:20:17Z johnnyw $
+ *  $Id: Hash_Naming_Context.cpp 85488 2009-06-02 07:22:07Z johnnyw $
  *
  *  @author Marina Spivak <marina@cs.wustl.edu> and Sergio Flores-Gaitan <sergio@cs.wustl.edu>
  */
@@ -15,7 +15,7 @@
 
 ACE_RCSID (Naming,
            Hash_Naming_Context,
-           "$Id: Hash_Naming_Context.cpp 77031 2007-02-12 15:20:17Z johnnyw $")
+           "$Id: Hash_Naming_Context.cpp 85488 2009-06-02 07:22:07Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -81,7 +81,7 @@ TAO_Hash_Naming_Context::get_context (const CosNaming::Name &name)
     {
       // Add the last component of the name, which was stripped before
       // the call to resolve.
-      CORBA::ULong rest_len = ex.rest_of_name.length () + 1;
+      CORBA::ULong const rest_len = ex.rest_of_name.length () + 1;
       ex.rest_of_name.length (rest_len);
       ex.rest_of_name[rest_len - 1] = name[name_len - 1];
 
