@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Persistent_Context_Index.h
  *
- *  Persistent_Context_Index.h,v 1.22 2004/09/08 19:22:44 jtc Exp
+ *  $Id: Persistent_Context_Index.h 76950 2007-02-07 20:56:17Z johnnyw $
  *
  *  @author Marina Spivak <marina@cs.wustl.edu>
  */
@@ -15,12 +15,15 @@
 #define TAO_PERSISTENT_CONTEXT_INDEX_H
 #include /**/ "ace/pre.h"
 
-#include "Persistent_Entries.h"
-#include "naming_serv_export.h"
-#include "nsconf.h"
+#include "orbsvcs/Naming/Persistent_Entries.h"
+#include "orbsvcs/Naming/naming_serv_export.h"
+#include "orbsvcs/Naming/nsconf.h"
 #include "tao/PortableServer/PortableServer.h"
 
-#include "ace/Malloc.h"
+#include "ace/Malloc_T.h"
+#include "ace/MMAP_Memory_Pool.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /**
  * @class TAO_Persistent_Context_Index
@@ -96,9 +99,7 @@ public:
    * i.e., a context with <poa_id>, <counter> and <hash_map> has just
    * been created, and is registering with us.
    */
-  int bind (const char *poa_id,
-            ACE_UINT32 *&counter,
-            CONTEXT *hash_map);
+  int bind (const char *poa_id, ACE_UINT32 *&counter, CONTEXT *hash_map);
 
   /// Remove an entry for the Persistent Naming Context with <poa_id>
   /// from <index_> (i.e., this context has just been destroyed).
@@ -162,5 +163,7 @@ private:
   CosNaming::NamingContext_var root_context_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_PERSISTENT_CONTEXT_INDEX_H */
