@@ -1,22 +1,34 @@
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file   Storable.h
  *
- *  Storable.h,v 1.6 2005/03/21 13:47:01 elliott_c Exp
+ *  $Id: Storable.h 77276 2007-02-21 08:26:36Z johnnyw $
  *
- *  @author Bruce Trask <trask_b@ociweb.com> Chanaka Liyanaarachchi <chanaka@ociweb.com>
+ *  @author Bruce Trask <trask_b@ociweb.com>
+ *  @author Chanaka Liyanaarachchi <chanaka@ociweb.com>
  */
 //=============================================================================
 
 
-#ifndef STORABLE_H
-#define STORABLE_H
+#ifndef TAO_NAMING_STORABLE_H
+#define TAO_NAMING_STORABLE_H
 
+#include "ace/config-all.h"
+
+#if !defined (ACE_LACKS_PRAGMA_ONCE)
+#pragma once
+#endif /* ACE_LACKS_PRAGMA_ONCE */
+
+#include "tao/Versioned_Namespace.h"
 #include "ace/SString.h"
 
-const int szInt =  sizeof(int);
-const int szChar = sizeof(char);
-const int szBool = sizeof(int);
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+static const int szInt =  sizeof(int);
+static const int szChar = sizeof(char);
+static const int szBool = sizeof(int);
 
 class TAO_NS_Persistence_Header
 {
@@ -35,7 +47,7 @@ class TAO_NS_Persistence_Header
 class TAO_NS_Persistence_Record
 {
  public:
-  enum Record_Type {NCONTEXT, OBJREF};
+  enum Record_Type {LOCAL_NCONTEXT, OBJREF, REMOTE_NCONTEXT};
 
   Record_Type type () const;
   void type (Record_Type type);
@@ -65,7 +77,7 @@ class TAO_NS_Persistence_Global
   private:
   unsigned int counter_;
 };
-  
+
 class TAO_Storable_Base
 {
 public:
@@ -110,7 +122,7 @@ public:
   bool fail (void) const;
 
   virtual TAO_Storable_Base& operator << (
-              const TAO_NS_Persistence_Header& header)  = 0;
+              const TAO_NS_Persistence_Header& header) = 0;
 
   virtual TAO_Storable_Base& operator << (
               const TAO_NS_Persistence_Record& record) = 0;
@@ -130,7 +142,7 @@ public:
 private:
   Storable_State state_;
 };
-  
+
 class TAO_Naming_Service_Persistence_Factory
 {
 public:
@@ -144,8 +156,10 @@ public:
                                            const ACE_TCHAR * mode) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "Storable.inl"
+#include "orbsvcs/Naming/Storable.inl"
 #endif /* __ACE_INLINE_ */
 
-#endif
+#endif  /* TAO_NAMING_STORABLE_H */
