@@ -3,7 +3,7 @@
 /**
  *  @file   Storable_Naming_Context.h
  *
- *  Storable_Naming_Context.h,v 1.7 2004/09/08 19:22:44 jtc Exp
+ *  $Id: Storable_Naming_Context.h 77276 2007-02-21 08:26:36Z johnnyw $
  *
  *  @author Bruce Trask <trask_b@ociweb.com>
  */
@@ -14,15 +14,18 @@
 #define TAO_STORABLE_NAMING_CONTEXT_H
 #include /**/ "ace/pre.h"
 
-#include "Hash_Naming_Context.h"
+#include "orbsvcs/Naming/Hash_Naming_Context.h"
 #include "ace/Hash_Map_Manager.h"
+#include "ace/Auto_Ptr.h"
 
-#include "Storable.h"
+#include "orbsvcs/Naming/Storable.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_Naming_Serv_Export TAO_Storable_IntId
 {
 public:
@@ -169,8 +172,7 @@ public:
    * Remove a binding containing <id> and <kind> from the table.
    * Return 0 on success and -1 on failure.
    */
-  virtual int unbind (const char * id,
-                      const char * kind);
+  virtual int unbind (const char * id, const char * kind);
 
   /**
    * Find the binding containing <id> and <kind> in the table, and
@@ -249,8 +251,7 @@ public:
                                size_t context_size,
                                TAO_Naming_Service_Persistence_Factory *factory,
                                const ACE_TCHAR *persistence_directory,
-                               TAO_Storable_Naming_Context **new_context
-                               ACE_ENV_ARG_DECL);
+                               TAO_Storable_Naming_Context **new_context);
 
   // = Methods not implemented in TAO_Hash_Naming_Context.
 
@@ -262,8 +263,7 @@ public:
                               int reentering,
                               TAO_Naming_Service_Persistence_Factory *factory,
                               const ACE_TCHAR *persistence_directory,
-                              int use_redundancy
-                              ACE_ENV_ARG_DECL);
+                              int use_redundancy);
 
 
   /**
@@ -271,7 +271,7 @@ public:
    * same naming server in which the operation was invoked.  The
    * context is not bound.
    */
-  virtual CosNaming::NamingContext_ptr new_context (ACE_ENV_SINGLE_ARG_DECL);
+  virtual CosNaming::NamingContext_ptr new_context (void);
 
   /**
    * Returns at most the requested number of bindings <how_many> in
@@ -281,13 +281,11 @@ public:
    */
   virtual void list (CORBA::ULong how_many,
                      CosNaming::BindingList_out &bl,
-                     CosNaming::BindingIterator_out &bi
-                     ACE_ENV_ARG_DECL);
+                     CosNaming::BindingIterator_out &bi);
 
 
   virtual void rebind (const CosNaming::Name& n,
-                       CORBA::Object_ptr obj
-                       ACE_ENV_ARG_DECL);
+                       CORBA::Object_ptr obj);
 
   /**
    * Create a binding for name <n> and object <obj> in the naming
@@ -299,8 +297,7 @@ public:
    * participate in name resolution later.
    */
   virtual void bind (const CosNaming::Name &n,
-                     CORBA::Object_ptr obj
-                     ACE_ENV_ARG_DECL);
+                     CORBA::Object_ptr obj);
 
 
   /**
@@ -309,8 +306,7 @@ public:
    * compound names are passed to be resolved.
    */
   virtual void bind_context (const CosNaming::Name &n,
-                             CosNaming::NamingContext_ptr nc
-                             ACE_ENV_ARG_DECL);
+                             CosNaming::NamingContext_ptr nc);
 
   /**
    * This is a version of <rebind> specifically for naming contexts,
@@ -318,8 +314,7 @@ public:
    * names are passed.
    */
    virtual void rebind_context (const CosNaming::Name &n,
-                                CosNaming::NamingContext_ptr nc
-                                ACE_ENV_ARG_DECL);
+                                CosNaming::NamingContext_ptr nc);
 
   /**
    * Return object reference that is bound to the name.  Compound name
@@ -328,16 +323,14 @@ public:
    * does not return the type of the object.  Clients are responsible
    * for "narrowing" the object to the appropriate type.
    */
-  virtual CORBA::Object_ptr resolve (const CosNaming::Name &n
-                                     ACE_ENV_ARG_DECL);
+  virtual CORBA::Object_ptr resolve (const CosNaming::Name &n);
 
   /**
    * Remove the name binding from the context.  When compound names
    * are used, unbind is defined as follows: ctx->unbind (<c1; c2;
    * cn>) = (ctx->resolve (<c1; c2; cn-1>))->unbind (<cn>)
    */
-  virtual void unbind (const CosNaming::Name &n
-                       ACE_ENV_ARG_DECL);
+  virtual void unbind (const CosNaming::Name &n);
 
   /**
    * This operation creates a new context and binds it to the name
@@ -346,8 +339,7 @@ public:
    * bound (the name argument excluding the last component).
    */
   virtual CosNaming::NamingContext_ptr bind_new_context (
-                                const CosNaming::Name &n
-                                ACE_ENV_ARG_DECL);
+                                const CosNaming::Name &n);
 
   /**
    * Delete the naming context.  The user should take care to <unbind> any
@@ -357,7 +349,7 @@ public:
    * NOTE: after <destroy> is invoked on a Naming Context, all
    * BindingIterators associated with that Naming Context are also destroyed.
    */
-  virtual void destroy (ACE_ENV_SINGLE_ARG_DECL);
+  virtual void destroy (void);
 
 protected:
 
@@ -416,7 +408,6 @@ protected:
  * <pre>
  * How to use this class:
  *   File_Open_Lock_and_Check flck(this, name_len > 1 ? "r" : "rw");
-     ACE_CHECK;
  * </pre>
  */
 class File_Open_Lock_and_Check
@@ -425,8 +416,7 @@ public:
 
   /// Constructor - we always need the object which we guard.
   File_Open_Lock_and_Check(TAO_Storable_Naming_Context * context,
-                                const char * mode 
-                                ACE_ENV_ARG_DECL);
+                                const char * mode);
 
   /// Destructor
   ~File_Open_Lock_and_Check(void);
@@ -459,12 +449,13 @@ private:
 
   friend class File_Open_Lock_and_Check;
 
-  int load_map(File_Open_Lock_and_Check *flck ACE_ENV_ARG_DECL);
+  int load_map(File_Open_Lock_and_Check *flck);
 
   void Write(TAO_Storable_Base& wrtr);
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 #endif /* TAO_STORABLE_NAMING_CONTEXT_H */
