@@ -1,8 +1,8 @@
-// $Id: CosEC_ProxyPushSupplier.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: CosEC_ProxyPushSupplier.cpp 87253 2009-10-28 23:29:32Z dai_y $
 
 #include "orbsvcs/Notify/Any/CosEC_ProxyPushSupplier.h"
 
-ACE_RCSID (Notify, TAO_Notify_CosEC_ProxyPushSupplier, "$Id: CosEC_ProxyPushSupplier.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+ACE_RCSID (Notify, TAO_Notify_CosEC_ProxyPushSupplier, "$Id: CosEC_ProxyPushSupplier.cpp 87253 2009-10-28 23:29:32Z dai_y $")
 
 #include "tao/debug.h"
 #include "orbsvcs/Notify/Any/PushConsumer.h"
@@ -52,4 +52,29 @@ TAO_Notify_CosEC_ProxyPushSupplier::get_proxy_type_name (void) const
   return "ec_proxy_push_supplier";
 }
 
+void
+TAO_Notify_CosEC_ProxyPushSupplier::validate ()
+{
+  TAO_Notify_Consumer* con = this->consumer ();
+  if (con != 0 && ! con->is_alive (true))
+  {
+    if (TAO_debug_level > 0)
+    {
+      ACE_DEBUG ((LM_DEBUG, 
+                  ACE_TEXT ("(%P|%t) TAO_Notify_CosEC_ProxyPushSupplier::validate(%d)")
+                  ACE_TEXT ("disconnecting \n"), this->id ()));
+    }
+    this->disconnect_push_supplier ();
+  }
+}
+
+void
+TAO_Notify_CosEC_ProxyPushSupplier::configure(
+  TAO_Notify_ConsumerAdmin & /*admin*/,
+  CosNotifyChannelAdmin::ProxyID_out /*proxy_id*/)
+{
+  // Nothing to do.
+  // This virtual method was added to support Notification MC
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
