@@ -1,8 +1,8 @@
-// $Id: PushSupplier.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: PushSupplier.cpp 84685 2009-03-02 22:49:17Z mesnier_p $
 
 #include "orbsvcs/Notify/Any/PushSupplier.h"
 
-ACE_RCSID (Notify, TAO_Notify_PushSupplier, "$Id: PushSupplier.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+ACE_RCSID (Notify, TAO_Notify_PushSupplier, "$Id: PushSupplier.cpp 84685 2009-03-02 22:49:17Z mesnier_p $")
 #include "orbsvcs/Notify/Properties.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -57,4 +57,10 @@ TAO_Notify_PushSupplier::get_ior (void) const
   return result;
 }
 
+CORBA::Object_ptr
+TAO_Notify_PushSupplier::get_supplier (void)
+{
+  return CosEventComm::PushSupplier::_duplicate (this->push_supplier_.in ());
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
