@@ -1,4 +1,4 @@
-// $Id: Consumer.cpp 79324 2007-08-13 11:20:01Z elliott_c $
+// $Id: Consumer.cpp 84685 2009-03-02 22:49:17Z mesnier_p $
 
 #include "orbsvcs/Notify/Consumer.h"
 
@@ -6,16 +6,19 @@
 #include "orbsvcs/Notify/Consumer.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (RT_Notify, TAO_Notify_Consumer, "$Id: Consumer.cpp 79324 2007-08-13 11:20:01Z elliott_c $")
+ACE_RCSID (RT_Notify, TAO_Notify_Consumer, "$Id: Consumer.cpp 84685 2009-03-02 22:49:17Z mesnier_p $")
 
 #include "orbsvcs/Notify/Timer.h"
 #include "orbsvcs/Notify/ProxySupplier.h"
 #include "orbsvcs/Notify/Method_Request_Event.h"
+#include "orbsvcs/Notify/QoSProperties.h"
+#include "orbsvcs/Notify/Properties.h"
 
 #include "orbsvcs/Time_Utilities.h"
 
 #include "tao/debug.h"
 #include "tao/corba.h"
+#include "tao/Messaging/Messaging_TypesC.h"
 
 #include "ace/Bound_Ptr.h"
 #include "ace/Unbounded_Queue.h"
@@ -42,6 +45,10 @@ TAO_Notify_Consumer::TAO_Notify_Consumer (TAO_Notify_ProxySupplier* proxy)
   this->pending_events_.reset( pending_events );
 
   this->timer_.reset( this->proxy ()->timer () );
+
+  // Enable reference counting on the event handler.
+  this->reference_counting_policy ().value (
+    ACE_Event_Handler::Reference_Counting_Policy::ENABLED);
 }
 
 TAO_Notify_Consumer::~TAO_Notify_Consumer ()
@@ -53,6 +60,18 @@ TAO_Notify_Consumer::~TAO_Notify_Consumer ()
   }
 }
 
+CORBA::ULong
+TAO_Notify_Consumer::_incr_refcnt (void)
+{
+  return this->add_reference();
+}
+
+CORBA::ULong
+TAO_Notify_Consumer::_decr_refcnt (void)
+{
+  return this->remove_reference();
+}
+
 TAO_Notify_Proxy*
 TAO_Notify_Consumer::proxy (void)
 {
@@ -149,6 +168,7 @@ TAO_Notify_Consumer::deliver (TAO_Notify_Method_Request_Event * request)
   bool queued = enqueue_if_necessary (request);
   if (!queued)
     {
+      bool from_timeout = false;
       DispatchStatus status = this->dispatch_request (request);
       switch (status)
         {
@@ -173,27 +193,30 @@ TAO_Notify_Consumer::deliver (TAO_Notify_Method_Request_Event * request)
           {
             if (DEBUG_LEVEL  > 0)
               ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("(%P|%t) Consumer %d: Error during "
-                                    "direct dispatch. Discarding event:%d.\n"),
+                          ACE_TEXT ("(%P|%t) Consumer %d: Error during ")
+                          ACE_TEXT ("direct dispatch. Discarding event:%d.\n"),
                           static_cast<int> (this->proxy ()->id ()),
                           request->sequence ()
                           ));
             request->complete ();
             break;
           }
+        case DISPATCH_FAIL_TIMEOUT:
+          from_timeout = true;
+          // Fall through
         case DISPATCH_FAIL:
           {
             if (DEBUG_LEVEL  > 0)
               ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("(%P|%t) Consumer %d: Failed during "
-                                    "direct dispatch :%d. Discarding event.\n"),
+                          ACE_TEXT ("(%P|%t) Consumer %d: Failed during ")
+                          ACE_TEXT ("direct dispatch :%d. Discarding event.\n"),
                           static_cast<int> (this->proxy ()->id ()),
                           request->sequence ()
                           ));
             request->complete ();
             try
               {
-                this->proxy_supplier ()->destroy ();
+                this->proxy_supplier ()->destroy (from_timeout);
               }
             catch (const CORBA::Exception&)
               {
@@ -225,8 +248,8 @@ TAO_Notify_Consumer::dispatch_request (TAO_Notify_Method_Request_Event * request
       if (DEBUG_LEVEL  > 0)
         {
           ACE_DEBUG ((LM_ERROR,
-                      ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push "
-                                "(request) %s\n"),
+                      ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push ")
+                      ACE_TEXT ("(request) %s\n"),
                       static_cast<int> (this->proxy ()->id ()),
                       ex._info ().c_str ()
                       ));
@@ -237,8 +260,8 @@ TAO_Notify_Consumer::dispatch_request (TAO_Notify_Method_Request_Event * request
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push "
-                              "(request) Transient (minor=%d) %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push ")
+                    ACE_TEXT ("(request) Transient (minor=%d) %s\n"),
                     static_cast<int> (this->proxy ()->id ()),
                     ex.minor (),
                     ex._info ().c_str ()
@@ -277,19 +300,19 @@ TAO_Notify_Consumer::dispatch_request (TAO_Notify_Method_Request_Event * request
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %u::push "
-                              "(request) %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %u::push ")
+                    ACE_TEXT ("(request) %s\n"),
                     this->proxy ()->id (),
                     ex._info().c_str ()
                     ));
-      result = DISPATCH_FAIL;
+      result = DISPATCH_FAIL_TIMEOUT;
     }
   catch (const CORBA::COMM_FAILURE& ex)
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %u::push "
-                              "(request) %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %u::push ")
+                    ACE_TEXT ("(request) %s\n"),
                     this->proxy ()->id (),
                     ex._info().c_str ()
                     ));
@@ -300,8 +323,8 @@ TAO_Notify_Consumer::dispatch_request (TAO_Notify_Method_Request_Event * request
       if (DEBUG_LEVEL  > 0)
         {
           ACE_DEBUG ((LM_ERROR,
-                      ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push "
-                                "(request) SystemException %s\n"),
+                      ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push ")
+                      ACE_TEXT ("(request) SystemException %s\n"),
                       static_cast<int> (this->proxy ()->id ()),
                       ex._info ().c_str ()
                       ));
@@ -311,9 +334,9 @@ TAO_Notify_Consumer::dispatch_request (TAO_Notify_Method_Request_Event * request
   catch (const CORBA::Exception&)
     {
       ACE_ERROR ( (LM_ERROR,
-                   ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push "
-                             "(request) Caught unexpected exception "
-                             "pushing event to consumer.\n"),
+                   ACE_TEXT ("(%P|%t) TAO_Notify_Consumer %d::push ")
+                   ACE_TEXT ("(request) Caught unexpected exception ")
+                   ACE_TEXT ("pushing event to consumer.\n"),
                    static_cast<int> (this->proxy ()->id ())
                    ));
       result = DISPATCH_DISCARD;
@@ -322,7 +345,8 @@ TAO_Notify_Consumer::dispatch_request (TAO_Notify_Method_Request_Event * request
   // for persistent events that haven't timed out
   // convert "FAIL" & "DISCARD" to "RETRY"
   // for transient events, convert RETRY to DISCARD (hey, best_effort.)
-  if (result == DISPATCH_FAIL || result == DISPATCH_DISCARD)
+  if (result == DISPATCH_FAIL ||
+      result == DISPATCH_FAIL_TIMEOUT || result == DISPATCH_DISCARD)
     {
       if (request->should_retry ())
         {
@@ -352,8 +376,8 @@ TAO_Notify_Consumer::dispatch_batch (const CosNotification::EventBatch& batch)
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer "
-                              "%d::dispatch_batch() %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer ")
+                    ACE_TEXT ("%d::dispatch_batch() %s\n"),
                     static_cast<int> (this->proxy ()->id ()),
                     ex._info ().c_str ()
                     ));
@@ -363,8 +387,8 @@ TAO_Notify_Consumer::dispatch_batch (const CosNotification::EventBatch& batch)
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer "
-                              "%d::dispatch_batch() Transient (minor=%d) %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer ")
+                    ACE_TEXT ("%d::dispatch_batch() Transient (minor=%d) %s\n"),
                     static_cast<int> (this->proxy ()->id ()),
                     ex.minor (),
                     ex._info ().c_str ()
@@ -403,19 +427,19 @@ TAO_Notify_Consumer::dispatch_batch (const CosNotification::EventBatch& batch)
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer "
-                              "%u::dispatch_batch() %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer ")
+                    ACE_TEXT ("%u::dispatch_batch() %s\n"),
                     this->proxy ()->id (),
                     ex._info().c_str ()
                     ));
-      result = DISPATCH_FAIL;
+      result = DISPATCH_FAIL_TIMEOUT;
     }
   catch (const CORBA::COMM_FAILURE& ex)
     {
       if (DEBUG_LEVEL  > 0)
         ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer "
-                              "%u::dispatch_batch() %s\n"),
+                    ACE_TEXT ("(%P|%t) TAO_Notify_Consumer ")
+                    ACE_TEXT ("%u::dispatch_batch() %s\n"),
                     this->proxy ()->id (),
                     ex._info().c_str ()
                     ));
@@ -426,8 +450,8 @@ TAO_Notify_Consumer::dispatch_batch (const CosNotification::EventBatch& batch)
       if (DEBUG_LEVEL  > 0)
         {
           ACE_DEBUG ((LM_ERROR,
-                      ACE_TEXT ("(%P|%t) TAO_Notify_Consumer "
-                                "%d::dispatch_batch() SystemException %s\n"),
+                      ACE_TEXT ("(%P|%t) TAO_Notify_Consumer ")
+                      ACE_TEXT ("%d::dispatch_batch() SystemException %s\n"),
                       static_cast<int>  (this->proxy ()->id ()),
                       ex._info ().c_str ()
                       ));
@@ -437,9 +461,9 @@ TAO_Notify_Consumer::dispatch_batch (const CosNotification::EventBatch& batch)
   catch (const CORBA::Exception&)
     {
       ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT ("(%P|%t) TAO_Notify_Consumer "
-                            "%d::dispatch_batch() Caught unexpected "
-                            "exception pushing batch to consumer.\n"),
+                  ACE_TEXT ("(%P|%t) TAO_Notify_Consumer ")
+                  ACE_TEXT ("%d::dispatch_batch() Caught unexpected ")
+                  ACE_TEXT ("exception pushing batch to consumer.\n"),
                   static_cast<int> (this->proxy ()->id ())
                   ));
       result = DISPATCH_DISCARD;
@@ -513,8 +537,8 @@ TAO_Notify_Consumer::dispatch_from_queue (Request_Queue & requests, ACE_Guard <T
           {
             if (DEBUG_LEVEL  > 0)
               ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("(%P|%t) Consumer %d: Error during "
-                                    "dispatch. Discarding event:%d.\n"),
+                          ACE_TEXT ("(%P|%t) Consumer %d: Error during ")
+                          ACE_TEXT ("dispatch. Discarding event:%d.\n"),
                           static_cast<int> (this->proxy ()->id ()),
                           request->sequence ()
                           ));
@@ -527,8 +551,8 @@ TAO_Notify_Consumer::dispatch_from_queue (Request_Queue & requests, ACE_Guard <T
           {
             if (DEBUG_LEVEL  > 0)
               ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("(%P|%t) Consumer %d: Failed. "
-                                    "Discarding event %d.\n"),
+                          ACE_TEXT ("(%P|%t) Consumer %d: Failed. ")
+                          ACE_TEXT ("Discarding event %d.\n"),
                           static_cast<int> (this->proxy ()->id ()),
                           request->sequence ()
                           ));
@@ -606,11 +630,15 @@ TAO_Notify_Consumer::schedule_timer (bool is_error)
   if (this->timer_id_ == -1)
     {
       ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT ("TAO_Notify_Consumer %d::schedule_timer () "
-                            "Error scheduling timer.\n"),
+                  ACE_TEXT ("TAO_Notify_Consumer %d::schedule_timer () ")
+                  ACE_TEXT ("Error scheduling timer.\n"),
                   static_cast<int> (this->proxy ()->id ())
                   ));
     }
+  if (this->is_suspended()) // double check to avoid race
+  {
+    this->cancel_timer();
+  }
 }
 
 void
@@ -632,14 +660,17 @@ TAO_Notify_Consumer::cancel_timer (void)
 int
 TAO_Notify_Consumer::handle_timeout (const ACE_Time_Value&, const void*)
 {
-  TAO_Notify_Consumer::Ptr grd (this);
-  this->timer_id_ = -1;  // This must come first, because dispatch_pending may try to resched
-  try
-    {
-      this->dispatch_pending ();
-    }
-  catch (...)
+  if (!this->is_suspended() && this->timer_.isSet() && this->timer_id_ != -1)
     {
+      TAO_Notify_Consumer::Ptr grd (this);
+      this->timer_id_ = -1;  // This must come first, because dispatch_pending may try to resched
+      try
+        {
+          this->dispatch_pending ();
+        }
+      catch (...)
+        {
+        }
     }
 
   return 0;
@@ -648,6 +679,7 @@ TAO_Notify_Consumer::handle_timeout (const ACE_Time_Value&, const void*)
 void
 TAO_Notify_Consumer::shutdown (void)
 {
+  this->suspend();
   if (this->timer_.isSet ())
     {
       this->cancel_timer ();
@@ -700,6 +732,93 @@ TAO_Notify_Consumer::assume_pending_events (TAO_Notify_Consumer& rhs)
       // timer value (unless we have a valid pacing interval).
       this->schedule_timer ();
     }
+  if (this->is_suspended()) // double check to avoid race
+  {
+    this->cancel_timer();
+  }
+}
+
+bool
+TAO_Notify_Consumer::is_alive (bool allow_nil_consumer)
+{
+  bool status = false;
+  CORBA::Object_var consumer = this->get_consumer ();
+  if (CORBA::is_nil (consumer.in ()))
+  {
+    // The consumer may not connected or the consumer did
+    // not provide a callback. In this case, the liveliness
+    // check should return true so it will be validated in 
+    // next period. 
+    if (allow_nil_consumer)
+      return true;
+    else
+      return status;
+  }
+
+  CORBA::PolicyList policy_list;
+  try
+    {
+      bool do_liveliness_check = false;
+      ACE_Time_Value now = ACE_OS::gettimeofday ();
+
+      if (CORBA::is_nil (this->rtt_obj_.in ()))
+      {
+        // We need to determine if the consumer on the other end is still
+        // alive.  Since we may be in an upcall from the owner of the
+        // original consumer, we have to put a timeout on the call in case
+        // the client side is not processing ORB requests at this time.  In
+        // the event that the timeout exception occurs, we will assume that
+        // the original consumer is still around.  If we get any other
+        // exception we will say that the original consumer is not
+        // available anymore.
+        TimeBase::TimeT timeout = 10000000;
+        CORBA::Any timeout_any;
+        timeout_any <<= timeout;
+
+        policy_list.length (1);
+        policy_list[0] = TAO_Notify_PROPERTIES::instance()->orb()->
+                          create_policy (
+                                Messaging::RELATIVE_RT_TIMEOUT_POLICY_TYPE,
+                                timeout_any);
+        rtt_obj_ =
+          consumer->_set_policy_overrides (policy_list,
+                                          CORBA::ADD_OVERRIDE);
+
+        // Clean up the policy that was allocated in the try/catch
+        for (CORBA::ULong i = 0; i < policy_list.length (); i++)
+          policy_list[i]->destroy ();
+
+        do_liveliness_check 
+          = (last_ping_ == ACE_Time_Value::zero ? true 
+          : now - last_ping_.value () >= TAO_Notify_PROPERTIES::instance()->validate_client_delay ());
+      }
+      else
+        do_liveliness_check = 
+          now - last_ping_.value () >= TAO_Notify_PROPERTIES::instance()->validate_client_interval ();
+
+      if (CORBA::is_nil (rtt_obj_.in ()))
+        status = false;
+      else if (do_liveliness_check || allow_nil_consumer)
+      {
+        last_ping_ = now;
+        status = !rtt_obj_->_non_existent ();
+      }
+      else
+        status = true;
+    }
+  catch (CORBA::TIMEOUT&)
+    {
+       status = true;
+    }
+  catch (CORBA::Exception& ex)
+    {
+      if (DEBUG_LEVEL > 0)
+      {        
+        ex._tao_print_exception ("TAO_Notify_Consumer::is_alive: false");
+      }
+    }
+
+  return status;
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
