@@ -1,4 +1,4 @@
-// $Id: EventChannel.cpp 79750 2007-10-04 19:07:26Z johnc $
+// $Id: EventChannel.cpp 84820 2009-03-13 23:39:08Z mesnier_p $
 
 #include "orbsvcs/Notify/EventChannel.h"
 
@@ -17,6 +17,7 @@
 #include "orbsvcs/Notify/Proxy.h"
 #include "orbsvcs/Notify/Event_Manager.h"
 #include "orbsvcs/Notify/POA_Helper.h"
+#include "orbsvcs/Notify/Validate_Worker_T.h"
 
 #include "tao/debug.h"
 //#define DEBUG_LEVEL 9
@@ -24,7 +25,7 @@
 # define DEBUG_LEVEL TAO_debug_level
 #endif //DEBUG_LEVEL
 
-ACE_RCSID(Notify, TAO_Notify_EventChannel, "$Id: EventChannel.cpp 79750 2007-10-04 19:07:26Z johnc $")
+ACE_RCSID(Notify, TAO_Notify_EventChannel, "$Id: EventChannel.cpp 84820 2009-03-13 23:39:08Z mesnier_p $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -47,6 +48,8 @@ TAO_Notify_EventChannel::TAO_Notify_EventChannel (void)
   : ecf_ (0)
   , ca_container_ (0)
   , sa_container_ (0)
+  , default_filter_factory_ (CosNotifyFilter::FilterFactory::_nil ())
+  , default_filter_factory_servant_ (0)
 {
 }
 
@@ -109,10 +112,17 @@ TAO_Notify_EventChannel::init (TAO_Notify_EventChannelFactory* ecf
 
   this->set_admin (initial_admin);
 
-  // Note originally default admins were allocated here, bt this caused problems
-  // attempting to save the topology changes before the Event Channel was completely
-  // constructed and linked to the ECF.
-  // Lazy evaluation also avoids creating unneded admins.
+  PortableServer::POA_var default_poa = 
+    TAO_Notify_PROPERTIES::instance ()->default_poa ();
+
+  this->default_filter_factory_ =
+    TAO_Notify_PROPERTIES::instance()->builder()->build_filter_factory (
+    default_poa.in(), this->default_filter_factory_servant_);
+
+  // Note originally default admins were allocated here, bt this
+  // caused problems attempting to save the topology changes before
+  // the Event Channel was completely constructed and linked to the
+  // ECF.  Lazy evaluation also avoids creating unneded admins.
 }
 
 
@@ -165,6 +175,10 @@ TAO_Notify_EventChannel::init (TAO_Notify::Topology_Parent* parent)
 
   this->set_qos (default_ec_qos);
 
+  PortableServer::POA_var default_poa = TAO_Notify_PROPERTIES::instance ()->default_poa ();
+  this->default_filter_factory_ =
+    TAO_Notify_PROPERTIES::instance()->builder()->build_filter_factory (
+    default_poa.in(), this->default_filter_factory_servant_);
 }
 
 
@@ -188,9 +202,10 @@ TAO_Notify_EventChannel::release (void)
 }
 
 void
-TAO_Notify_EventChannel::cleanup_proxy (CosNotifyChannelAdmin::ProxyID
-                                        , bool )
-{ }
+TAO_Notify_EventChannel::cleanup_proxy (CosNotifyChannelAdmin::ProxyID,
+                                        bool, bool)
+{
+}
 
 int
 TAO_Notify_EventChannel::shutdown (void)
@@ -214,8 +229,7 @@ TAO_Notify_EventChannel::destroy (void)
 {
   TAO_Notify_EventChannel::Ptr guard( this );
 
-  int result = this->shutdown ();
-  if ( result == 1)
+  if (this->shutdown () == 1)
     return;
 
   this->ecf_->remove (this);
@@ -225,6 +239,10 @@ TAO_Notify_EventChannel::destroy (void)
 
   this->sa_container_.reset( 0 );
   this->ca_container_.reset( 0 );
+
+  this->default_filter_factory_ = CosNotifyFilter::FilterFactory::_nil();
+
+  this->default_filter_factory_servant_->destroy();
 }
 
 void
@@ -266,7 +284,8 @@ TAO_Notify_EventChannel::default_consumer_admin (void)
       if (CORBA::is_nil (default_consumer_admin_.in ()))
         {
           CosNotifyChannelAdmin::AdminID id;
-          this->default_consumer_admin_ = this->new_for_consumers (CosNotifyChannelAdmin::OR_OP, id);
+          this->default_consumer_admin_ =
+            this->new_for_consumers (TAO_Notify_PROPERTIES::instance ()->defaultConsumerAdminFilterOp(), id);
           // Wish there was a better way to do this!
           PortableServer::ServantBase * admin_servant =
             this->poa()->reference_to_servant (
@@ -279,6 +298,7 @@ TAO_Notify_EventChannel::default_consumer_admin (void)
             }
         }
     }
+
   return CosNotifyChannelAdmin::ConsumerAdmin::_duplicate (this->default_consumer_admin_.in ());
 }
 
@@ -291,7 +311,8 @@ TAO_Notify_EventChannel::default_supplier_admin (void)
       if (CORBA::is_nil (default_supplier_admin_.in ()))
         {
           CosNotifyChannelAdmin::AdminID id;
-          this->default_supplier_admin_ = this->new_for_suppliers (CosNotifyChannelAdmin::OR_OP, id);
+          this->default_supplier_admin_ =
+            this->new_for_suppliers (TAO_Notify_PROPERTIES::instance ()->defaultSupplierAdminFilterOp(), id);
           PortableServer::ServantBase * admin_servant =
             this->poa()->poa()->reference_to_servant (
               this->default_supplier_admin_.in ());
@@ -306,16 +327,21 @@ TAO_Notify_EventChannel::default_supplier_admin (void)
   return CosNotifyChannelAdmin::SupplierAdmin::_duplicate (this->default_supplier_admin_.in ());
 }
 
-::CosNotifyFilter::FilterFactory_ptr TAO_Notify_EventChannel::default_filter_factory (void)
+::CosNotifyFilter::FilterFactory_ptr
+TAO_Notify_EventChannel::default_filter_factory (void)
 {
-  return this->ecf_->get_default_filter_factory ();
+  return CosNotifyFilter::FilterFactory::_duplicate (this->default_filter_factory_.in ());
+}
+
+TAO_Notify_FilterFactory*
+TAO_Notify_EventChannel::default_filter_factory_servant () const
+{
+  return this->default_filter_factory_servant_;
 }
 
 ::CosNotifyChannelAdmin::ConsumerAdmin_ptr
 TAO_Notify_EventChannel::new_for_consumers (CosNotifyChannelAdmin::InterFilterGroupOperator op,
-                                        CosNotifyChannelAdmin::AdminID_out id
-                                        )
-
+                                        CosNotifyChannelAdmin::AdminID_out id)
 {
   ::CosNotifyChannelAdmin::ConsumerAdmin_var ca =
     TAO_Notify_PROPERTIES::instance()->builder()->build_consumer_admin (this, op, id);
@@ -325,8 +351,7 @@ TAO_Notify_EventChannel::new_for_consumers (CosNotifyChannelAdmin::InterFilterGr
 
 ::CosNotifyChannelAdmin::SupplierAdmin_ptr
 TAO_Notify_EventChannel::new_for_suppliers (CosNotifyChannelAdmin::InterFilterGroupOperator op,
-                                        CosNotifyChannelAdmin::AdminID_out id
-                                        )
+                                        CosNotifyChannelAdmin::AdminID_out id)
 {
   ::CosNotifyChannelAdmin::SupplierAdmin_var sa =
     TAO_Notify_PROPERTIES::instance()->builder()->build_supplier_admin (this, op, id);
@@ -337,6 +362,12 @@ TAO_Notify_EventChannel::new_for_suppliers (CosNotifyChannelAdmin::InterFilterGr
 CosNotifyChannelAdmin::ConsumerAdmin_ptr
 TAO_Notify_EventChannel::get_consumeradmin (CosNotifyChannelAdmin::AdminID id)
 {
+  // because default admins are allocated on-demand, we need to be sure one exists for id 0
+  if (id == 0)
+    {
+       return default_consumer_admin ();
+    }
+
   TAO_Notify_ConsumerAdmin_Find_Worker find_worker;
 
   return find_worker.resolve (id, this->ca_container());
@@ -345,6 +376,12 @@ TAO_Notify_EventChannel::get_consumeradmin (CosNotifyChannelAdmin::AdminID id)
 CosNotifyChannelAdmin::SupplierAdmin_ptr
 TAO_Notify_EventChannel::get_supplieradmin (CosNotifyChannelAdmin::AdminID id)
 {
+  // because default admins are allocated on-demand, we need to be sure one exists for id 0
+  if (id == 0)
+    {
+      return default_supplier_admin ();
+    }
+
   TAO_Notify_SupplierAdmin_Find_Worker find_worker;
 
   return find_worker.resolve (id, this->sa_container());
@@ -400,8 +437,7 @@ TAO_Notify_EventChannel::for_suppliers (void)
 
 void
 TAO_Notify_EventChannel::validate_qos (const CosNotification::QoSProperties & /*required_qos*/,
-                                   CosNotification::NamedPropertyRangeSeq_out /*available_qos*/
-                                   )
+                                   CosNotification::NamedPropertyRangeSeq_out /*available_qos*/)
 {
   throw CORBA::NO_IMPLEMENT ();
 }
@@ -420,6 +456,8 @@ TAO_Notify_EventChannel::save_persistent (TAO_Notify::Topology_Saver& saver)
 
     bool want_all_children = saver.begin_object(
       this->id(), "channel", attrs, changed);
+  
+    this->default_filter_factory_servant_->save_persistent (saver);
 
     TAO_Notify::Save_Persist_Worker<TAO_Notify_ConsumerAdmin> ca_wrk(saver, want_all_children);
 
@@ -465,16 +503,21 @@ TAO_Notify_EventChannel::load_attrs(const TAO_Notify::NVPList& attrs)
 
 TAO_Notify::Topology_Object *
 TAO_Notify_EventChannel::load_child (const ACE_CString &type,
-                                                  CORBA::Long id,
-                                                  const TAO_Notify::NVPList& attrs)
+                                     CORBA::Long id,
+                                     const TAO_Notify::NVPList& attrs)
 {
   TAO_Notify::Topology_Object* result = this;
-  if (type == "consumer_admin")
+  if (type == "filter_factory")
   {
-    if (DEBUG_LEVEL) ACE_DEBUG ((LM_DEBUG,
-      ACE_TEXT ("(%P|%t) EventChannel reload consumer_admin %d\n")
-      , static_cast<int> (id)
-      ));
+    return this->default_filter_factory_servant_;
+  }
+  else if (type == "consumer_admin")
+  {
+    if (DEBUG_LEVEL) 
+      ACE_DEBUG ((LM_DEBUG,
+                  ACE_TEXT ("(%P|%t) EventChannel reload consumer_admin %d\n")
+                  , static_cast<int> (id)
+                  ));
 
     // call special builder method to reload
     TAO_Notify_Builder* bld = TAO_Notify_PROPERTIES::instance()->builder();
@@ -493,10 +536,11 @@ TAO_Notify_EventChannel::load_child (const ACE_CString &type,
   }
   else if (type == "supplier_admin")
   {
-    if (DEBUG_LEVEL) ACE_DEBUG ((LM_DEBUG,
-      ACE_TEXT ("(%P|%t) EventChannel reload supplier_admin %d\n")
-      , static_cast<int> (id)
-      ));
+    if (DEBUG_LEVEL) 
+      ACE_DEBUG ((LM_DEBUG,
+                  ACE_TEXT ("(%P|%t) EventChannel reload supplier_admin %d\n")
+                  , static_cast<int> (id)
+                  ));
     TAO_Notify_Builder* bld = TAO_Notify_PROPERTIES::instance()->builder();
 
     TAO_Notify_SupplierAdmin * sa = bld->build_supplier_admin (
@@ -575,4 +619,17 @@ TAO_Notify_EventChannel::sa_container()
   return *sa_container_;
 }
 
+
+void
+TAO_Notify_EventChannel::validate ()
+{
+  TAO_Notify::Validate_Worker<TAO_Notify_ConsumerAdmin> ca_wrk;
+  this->ca_container().collection()->for_each(&ca_wrk);
+
+  TAO_Notify::Validate_Worker<TAO_Notify_SupplierAdmin> sa_wrk;
+  this->sa_container().collection()->for_each(&sa_wrk);
+}
+
+
+
 TAO_END_VERSIONED_NAMESPACE_DECL
