@@ -4,7 +4,7 @@
 /**
  *  @file    Event_Persistence_Strategy.h
  *
- *  Event_Persistence_Strategy.h,v 1.2 2004/11/19 22:14:53 john_c Exp
+ *  $Id: Event_Persistence_Strategy.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  A factory class that creates a Routing_Slip_Persistence_Manager.
  *
@@ -15,16 +15,18 @@
 #ifndef EVENT_PERSISTENCE_STRATEGY_H
 #define EVENT_PERSISTENCE_STRATEGY_H
 #include /**/ "ace/pre.h"
-#include /**/ "ace/config-all.h"
+
+#include "orbsvcs/Notify/notify_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "notify_serv_export.h"
-
+#include "tao/Versioned_Namespace.h"
 #include "ace/Service_Object.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO_Notify
 {
   class Event_Persistence_Factory;
@@ -43,5 +45,7 @@ namespace TAO_Notify
 
 } // namespace TAO_Notify
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* EVENT_PERSISTENCE_STRATEGY_H */
