@@ -2,7 +2,7 @@
 /**
  *  @file FilterFactory.h
  *
- *  $Id: FilterFactory.h 76589 2007-01-25 18:04:11Z elliott_c $
+ *  $Id: FilterFactory.h 84820 2009-03-13 23:39:08Z mesnier_p $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -23,6 +23,7 @@
 #include "ace/Service_Object.h"
 
 #include "tao/PortableServer/PortableServer.h"
+#include "Topology_Object.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -32,13 +33,19 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  * @brief Service Object to obtain a CosNotifyFilter::FilterFactory reference.
  *
  */
-class /*TAO_Notify_Serv_Export*/ TAO_Notify_FilterFactory : public ACE_Service_Object
+class TAO_Notify_Serv_Export TAO_Notify_FilterFactory 
+  : public ACE_Service_Object, public TAO_Notify::Topology_Object
 {
 public:
+
   /// Factory method to create a FilterFactory reference
   /// The Factory is activated in the default POA. The filters created are activated in the <filter_poa>.
   virtual CosNotifyFilter::FilterFactory_ptr create (
-      PortableServer::POA_var& filter_poa) = 0;
+      PortableServer::POA_ptr filter_poa) = 0;
+  virtual void destroy (void) = 0;
+
+  virtual TAO_Notify_Object::ID get_filter_id (CosNotifyFilter::Filter_ptr filter) = 0;
+  virtual CosNotifyFilter::Filter_ptr get_filter (const TAO_Notify_Object::ID& id) = 0;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
