@@ -1,29 +1,30 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file Method_Request_Dispatch.h
  *
- *  Method_Request_Dispatch.h,v 1.11 2005/07/01 20:12:51 michel_j Exp
+ *  $Id: Method_Request_Dispatch.h 79324 2007-08-13 11:20:01Z elliott_c $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
- *
- *
  */
 
 #ifndef TAO_Notify_DISPATCH_METHOD_REQUEST_H
 #define TAO_Notify_DISPATCH_METHOD_REQUEST_H
 #include /**/ "ace/pre.h"
 
-#include "notify_serv_export.h"
+#include "orbsvcs/Notify/notify_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "Method_Request.h"
-#include "Refcountable.h"
-#include "Method_Request_Event.h"
-#include "ProxySupplier.h"
-#include "Delivery_Request.h"
+#include "orbsvcs/Notify/Method_Request.h"
+#include "orbsvcs/Notify/Refcountable.h"
+#include "orbsvcs/Notify/Method_Request_Event.h"
+#include "orbsvcs/Notify/ProxySupplier.h"
+#include "orbsvcs/Notify/Delivery_Request.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Notify_EventChannelFactory;
 class TAO_InputCDR;
@@ -54,7 +55,7 @@ public:
     TAO_Notify_ProxySupplier* proxy_supplier,
     bool filtering);
 
-  /// Constuct construct from another method request+event
+  /// Constuct from another method request+event
   /// event is passed separately because we may be using a copy
   /// of the one in the previous method request
   TAO_Notify_Method_Request_Dispatch (
@@ -71,13 +72,12 @@ public:
   static TAO_Notify_Method_Request_Dispatch_Queueable * unmarshal (
     TAO_Notify::Delivery_Request_Ptr & delivery_request,
     TAO_Notify_EventChannelFactory &ecf,
-    TAO_InputCDR & cdr
-    ACE_ENV_ARG_DECL);
+    TAO_InputCDR & cdr);
 
 
 protected:
   /// Execute the dispatch operation.
-  int execute_i (ACE_ENV_SINGLE_ARG_DECL);
+  int execute_i (void);
 
 protected:
   /// The Proxy
@@ -119,14 +119,14 @@ public:
   virtual ~TAO_Notify_Method_Request_Dispatch_Queueable ();
 
   /// Execute the Request
-  virtual int execute (ACE_ENV_SINGLE_ARG_DECL);
+  virtual int execute (void);
 
 private:
-  const TAO_Notify_Event::Ptr event_var_;
+  TAO_Notify_Event::Ptr event_var_;
   TAO_Notify_ProxySupplier::Ptr proxy_guard_;
 };
 
-/*******************************************************************************************************/
+/*****************************************************************************/
 
 /**
  * @class TAO_Notify_Method_Request_Dispatch_No_Copy
@@ -139,12 +139,6 @@ class TAO_Notify_Serv_Export TAO_Notify_Method_Request_Dispatch_No_Copy
     , public TAO_Notify_Method_Request
 {
 public:
-  /// Constuct from event
-  TAO_Notify_Method_Request_Dispatch_No_Copy (
-    const TAO_Notify_Event * event,
-    TAO_Notify_ProxySupplier* proxy_supplier,
-    bool filtering);
-
   /// Constuct construct from another method request
   TAO_Notify_Method_Request_Dispatch_No_Copy (
     const TAO_Notify_Method_Request_Event & request,
@@ -155,13 +149,15 @@ public:
   virtual ~TAO_Notify_Method_Request_Dispatch_No_Copy ();
 
   /// Execute the Request
-  virtual int execute (ACE_ENV_SINGLE_ARG_DECL);
+  virtual int execute (void);
 
   /// Create a copy of this method request
-  virtual TAO_Notify_Method_Request_Queueable* copy (ACE_ENV_SINGLE_ARG_DECL);
+  virtual TAO_Notify_Method_Request_Queueable* copy (void);
 };
 
-/*******************************************************************************************************/
+/*****************************************************************************/
+
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 #endif /* TAO_Notify_DISPATCH_METHOD_REQUEST_H */
