@@ -1,19 +1,24 @@
-// $Id: MonitorSupplierAdmin.h 79084 2007-07-30 13:13:45Z elliott_c $
+// $Id: MonitorSupplierAdmin.h 82195 2008-06-26 13:15:30Z parsons $
+
 #ifndef MONITORSUPPLIERADMIN_H
 #define MONITORSUPPLIERADMIN_H
 
 #include /**/ "ace/pre.h"
-#include "orbsvcs/Notify/MonitorControlExt/notify_mc_ext_export.h"
+
+#include "orbsvcs/Notify/SupplierAdmin.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "orbsvcs/Notify/SupplierAdmin.h"
 #include "orbsvcs/Notify/MonitorControlExt/NotifyMonitoringExtS.h"
 
+#if defined (TAO_HAS_MONITOR_FRAMEWORK) && (TAO_HAS_MONITOR_FRAMEWORK == 1)
+
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
+class TAO_MonitorEventChannel;
+
 class TAO_Notify_MC_Ext_Export TAO_MonitorSupplierAdmin:
                   public virtual TAO_Notify_SupplierAdmin,
                   public virtual POA_NotifyMonitoringExt::SupplierAdmin
@@ -25,6 +30,10 @@ public:
   /// Remove the statistics for this event channel
   ~TAO_MonitorSupplierAdmin (void);
 
+  /// Register our statistic and control objects 
+  void register_stats_controls (TAO_MonitorEventChannel* mec,
+                                const ACE_CString& name);
+
   virtual CosNotifyChannelAdmin::ProxyConsumer_ptr
     obtain_named_notification_push_consumer (
         CosNotifyChannelAdmin::ClientType ctype,
@@ -35,9 +44,15 @@ public:
     obtain_notification_push_consumer (
         CosNotifyChannelAdmin::ClientType ctype,
         CosNotifyChannelAdmin::ProxyID_out proxy_id);
+
+private:
+  ACE_CString control_name_;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
 
+#endif /* TAO_HAS_MONITOR_FRAMEWORK==1 */
+
 #include /**/ "ace/post.h"
+
 #endif /* MONITORSUPPLIERADMIN_H */
