@@ -1,8 +1,10 @@
+// -*- C++ -*-
+
 //=============================================================================
 /**
  * @file Notify_EventChannelFactory_i.h
  *
- * Notify_EventChannelFactory_i.h,v 1.26 2004/09/08 19:22:44 jtc Exp
+ * $Id: Notify_EventChannelFactory_i.h 79084 2007-07-30 13:13:45Z elliott_c $
  *
  *  @author Pradeep Gore <pradeep@cs.wustl.edu>
  */
@@ -14,12 +16,14 @@
 #include /**/ "ace/pre.h"
 
 #include "orbsvcs/CosNotifyChannelAdminS.h"
-#include "notify_serv_export.h"
+#include "orbsvcs/Notify/notify_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Notify_EventChannelFactory_i
  *
@@ -31,8 +35,12 @@ class TAO_Notify_Serv_Export TAO_Notify_EventChannelFactory_i
 public:
   /// Create a factory servant and activates it with the default POA.
   /// Also creates a resource factory and assigns it this default_POA.
-  static CosNotifyChannelAdmin::EventChannelFactory_ptr create (PortableServer::POA_ptr default_POA ACE_ENV_ARG_DECL);
+  static CosNotifyChannelAdmin::EventChannelFactory_ptr
+    create (PortableServer::POA_ptr default_POA,
+            const char* factory_name = "EventChannelFactory");
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* NOTIFY_EVENTCHANNELFACTORY_I_H */
