@@ -1,12 +1,12 @@
 // -*- C++ -*-
-// Notify_Extensions.h,v 1.7 2004/09/10 01:03:32 jtc Exp
+// $Id: Notify_Extensions.h 71526 2006-03-14 06:14:35Z jtc $
 
 #ifndef TAO_NOTIFY_EXTENSIONS_H
 #define TAO_NOTIFY_EXTENSIONS_H
 
 #include /**/ "ace/pre.h"
 
-#include "notify_export.h"
+#include "orbsvcs/Notify/notify_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -19,11 +19,15 @@
 #endif /* TAO_EXPORT_MACRO */
 #define TAO_EXPORT_MACRO TAO_Notify_Export
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO_Notify_Extensions
 {
-  TAO_NAMESPACE_STORAGE_CLASS const char *const BlockingPolicy;
+  TAO_NAMESPACE_STORAGE_CLASS const char BlockingPolicy[];
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_NOTIFY_EXTENSIONS_H */
