@@ -1,31 +1,32 @@
-// Object.cpp,v 1.16 2005/07/19 15:21:17 michel_j Exp
+// $Id: Object.cpp 79324 2007-08-13 11:20:01Z elliott_c $
 
-#include "Object.h"
-#include "POA_Helper.h"
-#include "Worker_Task.h"
-#include "Properties.h"
-#include "Builder.h"
-#include "ThreadPool_Task.h"
-#include "Reactive_Task.h"
+#include "orbsvcs/Notify/Object.h"
+#include "orbsvcs/Notify/POA_Helper.h"
+#include "orbsvcs/Notify/Worker_Task.h"
+#include "orbsvcs/Notify/Properties.h"
+#include "orbsvcs/Notify/Builder.h"
+#include "orbsvcs/Notify/ThreadPool_Task.h"
+#include "orbsvcs/Notify/Reactive_Task.h"
 #include "tao/debug.h"
+#include "orbsvcs/Notify/Event_Manager.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "Object.inl"
+#include "orbsvcs/Notify/Object.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Notify, TAO_Notify_Object, "Object.cpp,v 1.16 2005/07/19 15:21:17 michel_j Exp")
-
+ACE_RCSID(Notify, TAO_Notify_Object, "$Id: Object.cpp 79324 2007-08-13 11:20:01Z elliott_c $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Notify_Object::TAO_Notify_Object (void)
-  : poa_ (0)
-  , proxy_poa_ (0)
-  , own_proxy_poa_ (false)
-  , object_poa_ (0)
-  , own_object_poa_ (false)
-  , id_ (0)
-  , own_worker_task_ (false)
-  , shutdown_ (false)
+: poa_ (0)
+, proxy_poa_ (0)
+, own_proxy_poa_ (false)
+, object_poa_ (0)
+, own_object_poa_ (false)
+, id_ (0)
+, own_worker_task_ (false)
+, shutdown_ (false)
 {
   if (TAO_debug_level > 2 )
     ACE_DEBUG ((LM_DEBUG,"object:%x  created\n", this ));
@@ -67,45 +68,42 @@ TAO_Notify_Object::set_event_manager( TAO_Notify_Event_Manager* event_manager )
 }
 
 CORBA::Object_ptr
-TAO_Notify_Object::activate (PortableServer::Servant servant ACE_ENV_ARG_DECL)
+TAO_Notify_Object::activate (PortableServer::Servant servant)
 {
-  return this->poa_->activate (servant, this->id_ ACE_ENV_ARG_PARAMETER);
+  return this->poa_->activate (servant, this->id_);
 }
 
 /// Activate with existing id
 CORBA::Object_ptr
 TAO_Notify_Object::activate (
     PortableServer::Servant servant,
-    CORBA::Long id
-    ACE_ENV_ARG_DECL)
+    CORBA::Long id)
 {
   this->id_ = id;
-  return this->poa_->activate_with_id (servant, this->id_ ACE_ENV_ARG_PARAMETER);
+  return this->poa_->activate_with_id (servant, this->id_);
 }
 
 
 void
-TAO_Notify_Object::deactivate (ACE_ENV_SINGLE_ARG_DECL)
+TAO_Notify_Object::deactivate (void)
 {
-  ACE_TRY
-    {
-      this->poa_->deactivate (this->id_ ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-    }
-  ACE_CATCHANY
-    {
-      // Do not propagate any exceptions
-      if (TAO_debug_level > 2)
+  try
   {
-    ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "(%P|%t)\n");
-    ACE_DEBUG ((LM_DEBUG, "Could not deactivate object %d\n", this->id_));
+    this->poa_->deactivate (this->id_);
   }
+  catch (const CORBA::Exception& ex)
+  {
+    // Do not propagate any exceptions
+    if (TAO_debug_level > 2)
+    {
+      ex._tao_print_exception ("(%P|%t)\n");
+      ACE_DEBUG ((LM_DEBUG, "Could not deactivate object %d\n", this->id_));
     }
-  ACE_ENDTRY;
+  }
 }
 
 int
-TAO_Notify_Object::shutdown (ACE_ENV_SINGLE_ARG_DECL)
+TAO_Notify_Object::shutdown (void)
 {
   {
     ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, this->lock_, 1);
@@ -116,7 +114,7 @@ TAO_Notify_Object::shutdown (ACE_ENV_SINGLE_ARG_DECL)
     this->shutdown_ = 1;
   }
 
-  this->deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
+  this->deactivate ();
 
   this->shutdown_worker_task ();
 
@@ -124,9 +122,9 @@ TAO_Notify_Object::shutdown (ACE_ENV_SINGLE_ARG_DECL)
 }
 
 CORBA::Object_ptr
-TAO_Notify_Object::ref (ACE_ENV_SINGLE_ARG_DECL)
+TAO_Notify_Object::ref (void)
 {
-  return this->poa_->id_to_reference (this->id_ ACE_ENV_ARG_PARAMETER);
+  return this->poa_->id_to_reference (this->id_);
 }
 
 void
@@ -136,70 +134,64 @@ TAO_Notify_Object::shutdown_worker_task (void)
   TAO_Notify_Worker_Task::Ptr task( this->worker_task_ );
   this->worker_task_.reset();
   if ( task.isSet() )
-    {
+  {
     if ( this->own_worker_task_ )
     {
       task->shutdown ();
     }
-    }
+  }
 }
 
 void
 TAO_Notify_Object::destroy_proxy_poa (void)
 {
   if (this->proxy_poa_ != 0)
+  {
+    try
     {
-      ACE_TRY_NEW_ENV
-        {
-          if ( this->proxy_poa_ == this->object_poa_ ) this->object_poa_ = 0;
-          if ( this->proxy_poa_ == this->poa_ ) this->poa_ = 0;
+      if ( this->proxy_poa_ == this->object_poa_ ) this->object_poa_ = 0;
+      if ( this->proxy_poa_ == this->poa_ ) this->poa_ = 0;
 
-          if ( this->own_proxy_poa_ == true )
-          {
-            this->own_proxy_poa_ = false;
-          	ACE_Auto_Ptr< TAO_Notify_POA_Helper > app( object_poa_ );
-          this->proxy_poa_->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
-          }
-          this->proxy_poa_ = 0;
-        }
-      ACE_CATCHANY
-        {
-          if (TAO_debug_level > 2)
-            ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                                 "Proxy shutdown error (%P|%t)\n");
-        }
-      ACE_ENDTRY;
+      if ( this->own_proxy_poa_ == true )
+      {
+        this->own_proxy_poa_ = false;
+        ACE_Auto_Ptr< TAO_Notify_POA_Helper > app( proxy_poa_ );
+        this->proxy_poa_->destroy ();
+      }
+      this->proxy_poa_ = 0;
     }
+    catch (const CORBA::Exception& ex)
+    {
+      if (TAO_debug_level > 2)
+        ex._tao_print_exception ("Proxy shutdown error (%P|%t)\n");
+    }
+  }
 }
 
 void
 TAO_Notify_Object::destroy_object_poa (void)
 {
   if (this->object_poa_ != 0)
+  {
+    try
     {
-      ACE_TRY_NEW_ENV
-        {
-          if ( this->object_poa_ == this->proxy_poa_ ) this->proxy_poa_ = 0;
-          if ( this->object_poa_ == this->poa_ ) this->poa_ = 0;
+      if ( this->object_poa_ == this->proxy_poa_ ) this->proxy_poa_ = 0;
+      if ( this->object_poa_ == this->poa_ ) this->poa_ = 0;
 
-          if ( this->own_object_poa_ == true )
-          {
-            this->own_object_poa_ = false;
-          	ACE_Auto_Ptr< TAO_Notify_POA_Helper > aop( object_poa_ );
-          this->object_poa_->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_TRY_CHECK;
-          }
-          this->object_poa_ = 0;
-        }
-      ACE_CATCHANY
-        {
-          if (TAO_debug_level > 2)
-            ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                                 "Proxy shutdown error (%P|%t)\n");
-        }
-      ACE_ENDTRY;
+      if ( this->own_object_poa_ == true )
+      {
+        this->own_object_poa_ = false;
+        ACE_Auto_Ptr< TAO_Notify_POA_Helper > aop( object_poa_ );
+        this->object_poa_->destroy ();
+      }
+      this->object_poa_ = 0;
     }
+    catch (const CORBA::Exception& ex)
+    {
+      if (TAO_debug_level > 2)
+        ex._tao_print_exception ("Proxy shutdown error (%P|%t)\n");
+    }
+  }
 }
 
 /// Shutdown the current poa.
@@ -219,7 +211,6 @@ TAO_Notify_Object::set_worker_task (TAO_Notify_Worker_Task* worker_task)
   this->worker_task_.reset (worker_task);
 
   this->own_worker_task_ = true;
-
 }
 
 void
@@ -243,6 +234,7 @@ TAO_Notify_Object::set_object_poa (TAO_Notify_POA_Helper* object_poa)
 
   this->own_object_poa_ = true;
 }
+
 void
 TAO_Notify_Object::set_poa (TAO_Notify_POA_Helper* poa)
 {
@@ -250,28 +242,31 @@ TAO_Notify_Object::set_poa (TAO_Notify_POA_Helper* poa)
 }
 
 void
-TAO_Notify_Object::set_qos (const CosNotification::QoSProperties & qos ACE_ENV_ARG_DECL)
+TAO_Notify_Object::set_qos (const CosNotification::QoSProperties & qos)
 {
   CosNotification::PropertyErrorSeq err_seq;
 
   TAO_Notify_QoSProperties new_qos_properties;
 
   if (new_qos_properties.init (qos, err_seq) == -1)
-    ACE_THROW (CORBA::INTERNAL ());
+    throw CORBA::INTERNAL ();
 
   // Apply the appropriate concurrency QoS
   if (new_qos_properties.thread_pool ().is_valid ())
-    {
-      if (new_qos_properties.thread_pool ().value ().static_threads == 0)
-        TAO_Notify_PROPERTIES::instance()->builder()->apply_reactive_concurrency (*this ACE_ENV_ARG_PARAMETER);
-      else
+  {
+    if (new_qos_properties.thread_pool ().value ().static_threads == 0)
+      {
+        TAO_Notify_PROPERTIES::instance()->builder()->apply_reactive_concurrency (*this);
+      }
+    else
+      {
         TAO_Notify_PROPERTIES::instance()->builder()->
-          apply_thread_pool_concurrency (*this, new_qos_properties.thread_pool ().value () ACE_ENV_ARG_PARAMETER);
-    }
+        apply_thread_pool_concurrency (*this, new_qos_properties.thread_pool ().value ());
+      }
+  }
   else if (new_qos_properties.thread_pool_lane ().is_valid ())
     TAO_Notify_PROPERTIES::instance()->builder()->
-      apply_lane_concurrency (*this, new_qos_properties.thread_pool_lane ().value () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    apply_lane_concurrency (*this, new_qos_properties.thread_pool_lane ().value ());
 
   // Update the Thread Task's QoS properties..
   this->worker_task_->update_qos_properties (new_qos_properties);
@@ -281,20 +276,20 @@ TAO_Notify_Object::set_qos (const CosNotification::QoSProperties & qos ACE_ENV_A
 
   // Init the the overall QoS on this object.
   if (new_qos_properties.copy (this->qos_properties_) == -1)
-    ACE_THROW (CORBA::INTERNAL ());
+    throw CORBA::INTERNAL ();
 
   if (err_seq.length () > 0) // Unsupported Property
-    ACE_THROW (CosNotification::UnsupportedQoS (err_seq));
+    throw CosNotification::UnsupportedQoS (err_seq);
 }
 
 CosNotification::QoSProperties*
-TAO_Notify_Object::get_qos (ACE_ENV_SINGLE_ARG_DECL)
+TAO_Notify_Object::get_qos (void)
 {
   CosNotification::QoSProperties_var properties;
 
   ACE_NEW_THROW_EX (properties,
-                    CosNotification::QoSProperties (),
-                    CORBA::NO_MEMORY ());
+    CosNotification::QoSProperties (),
+    CORBA::NO_MEMORY ());
 
   this->qos_properties_.populate (properties);
 
@@ -306,7 +301,9 @@ TAO_Notify_Object::find_qos_property_value (
   const char * name,
   CosNotification::PropertyValue & value) const
 {
-  return this->qos_properties_.find (name, value);
+  // qos_properties_ is essentially a map and the find() method returns
+  // zero on success.  We must convert this to a boolean value.
+  return (this->qos_properties_.find (name, value) == 0);
 }
 
 
@@ -323,35 +320,16 @@ TAO_Notify_Object::timer (void)
   return this->worker_task_->timer ();
 }
 
-namespace {
+namespace
+{
   template<class T>
-    void add_qos_attr(TAO_Notify::NVPList& attrs, const T& prop) {
-      if (prop.is_valid())
-      {
-        attrs.push_back(TAO_Notify::NVP (prop));
-      }
+  void add_qos_attr(TAO_Notify::NVPList& attrs, const T& prop)
+  {
+    if (prop.is_valid())
+    {
+      attrs.push_back(TAO_Notify::NVP (prop));
     }
-// Note : These instantiations have to be here because each namespace {}
-// is unique.
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-template void add_qos_attr<TAO_Notify_Property_Boolean>(
-  TAO_Notify::NVPList&, const TAO_Notify_Property_Boolean&);
-template void add_qos_attr<TAO_Notify_Property_T<int> >(
-  TAO_Notify::NVPList&, const TAO_Notify_Property_T<int>&);
-template void add_qos_attr<TAO_Notify_Property_T<unsigned long long> >(
-  TAO_Notify::NVPList&, const TAO_Notify_Property_T<unsigned long long>&);
-template void add_qos_attr<TAO_Notify_Property_T<short> >(
-  TAO_Notify::NVPList&, const TAO_Notify_Property_T<short>&);
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate void add_qos_attr<TAO_Notify_Property_Boolean>(\
-  TAO_Notify::NVPList&, const TAO_Notify_Property_Boolean&)
-#pragma instantiate void add_qos_attr<TAO_Notify_Property_T<int> >(\
-  TAO_Notify::NVPList&, const TAO_Notify_Property_T<int>&)
-#pragma instantiate void add_qos_attr<TAO_Notify_Property_T<unsigned long long> >(\
-  TAO_Notify::NVPList&, const TAO_Notify_Property_T<unsigned long long>&)
-#pragma instantiate void add_qos_attr<TAO_Notify_Property_T<short> >(\
-  TAO_Notify::NVPList&, const TAO_Notify_Property_T<short>&)
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+  }
 } // namespace
 
 void
@@ -379,3 +357,10 @@ TAO_Notify_Object::load_attrs(const TAO_Notify::NVPList& attrs)
   this->qos_properties_.init ();
 }
 
+TAO_Notify_Worker_Task*
+TAO_Notify_Object::get_worker_task (void)
+{
+  return this->worker_task_.get ();
+}
+
+TAO_END_VERSIONED_NAMESPACE_DECL
