@@ -1,4 +1,4 @@
-// $Id: Properties.cpp 78802 2007-07-05 18:51:19Z johnnyw $
+// $Id: Properties.cpp 84685 2009-03-02 22:49:17Z mesnier_p $
 
 #include "orbsvcs/Notify/Properties.h"
 #include "orbsvcs/NotifyExtC.h"
@@ -10,7 +10,7 @@
 
 ACE_RCSID (Notify,
            TAO_Notify_Properties,
-           "$Id: Properties.cpp 78802 2007-07-05 18:51:19Z johnnyw $")
+           "$Id: Properties.cpp 84685 2009-03-02 22:49:17Z mesnier_p $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -19,10 +19,13 @@ TAO_Notify_Properties::TAO_Notify_Properties (void)
   , builder_ (0)
   , orb_(0)
   , dispatching_orb_ (0)
-  , asynch_updates_ (0)
+  , asynch_updates_ (false)
   , allow_reconnect_ (false)
+  , validate_client_ (false)
   , separate_dispatching_orb_ (false)
   , updates_ (1)
+  , defaultConsumerAdminFilterOp_ (CosNotifyChannelAdmin::OR_OP)
+  , defaultSupplierAdminFilterOp_ (CosNotifyChannelAdmin::OR_OP)
 {
   // In case no conf. file is specified, the EC will default to reactive concurrency.
   NotifyExt::ThreadPoolParams tp_params =
@@ -47,4 +50,11 @@ TAO_Notify_Properties::instance (void)
                                  TAO_SYNCH_MUTEX>::instance ();
 }
 
+void
+TAO_Notify_Properties::close (void)
+{
+  ACE_Unmanaged_Singleton<TAO_Notify_Properties,
+                          TAO_SYNCH_MUTEX>::close ();
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
