@@ -1,23 +1,25 @@
-// Proxy.cpp,v 1.16 2005/07/01 20:12:51 michel_j Exp
+// $Id: Proxy.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
-#include "Proxy.h"
+#include "orbsvcs/Notify/Proxy.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "Proxy.inl"
+#include "orbsvcs/Notify/Proxy.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(RT_Notify, TAO_Notify_Proxy, "Proxy.cpp,v 1.16 2005/07/01 20:12:51 michel_j Exp")
+ACE_RCSID(Notify, TAO_Notify_Proxy, "$Id: Proxy.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
 
-#include "Peer.h"
-#include "Proxy.h"
-#include "Method_Request_Updates.h"
-#include "Worker_Task.h"
-#include "Properties.h"
-#include "POA_Helper.h"
-#include "Topology_Saver.h"
+#include "orbsvcs/Notify/Peer.h"
+#include "orbsvcs/Notify/Proxy.h"
+#include "orbsvcs/Notify/Method_Request_Updates.h"
+#include "orbsvcs/Notify/Worker_Task.h"
+#include "orbsvcs/Notify/Properties.h"
+#include "orbsvcs/Notify/POA_Helper.h"
+#include "orbsvcs/Notify/Topology_Saver.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Notify_Proxy::TAO_Notify_Proxy (void)
-  :updates_off_ (0)
+  : updates_off_ (0)
 {
 }
 
@@ -26,43 +28,41 @@ TAO_Notify_Proxy::~TAO_Notify_Proxy ()
 }
 
 CORBA::Object_ptr
-TAO_Notify_Proxy::activate (PortableServer::Servant servant ACE_ENV_ARG_DECL)
+TAO_Notify_Proxy::activate (PortableServer::Servant servant)
 {
   // Set the POA that we use to return our <ref>
   this->set_primary_as_proxy_poa();
-  return TAO_Notify_Object::activate (servant ACE_ENV_ARG_PARAMETER);
+  return TAO_Notify_Object::activate (servant);
 }
 
 CORBA::Object_ptr
 TAO_Notify_Proxy::activate (PortableServer::Servant servant,
-                            CORBA::Long id
-                            ACE_ENV_ARG_DECL)
+                            CORBA::Long id)
 {
   // Set the POA that we use to return our <ref>
   this->set_primary_as_proxy_poa();
-  return TAO_Notify_Object::activate (servant, id ACE_ENV_ARG_PARAMETER);
+  return TAO_Notify_Object::activate (servant, id);
 }
 
 void
-TAO_Notify_Proxy::deactivate (ACE_ENV_SINGLE_ARG_DECL)
+TAO_Notify_Proxy::deactivate (void)
 {
   ACE_ASSERT (this->proxy_poa() != 0 );
-  this->proxy_poa()->deactivate (this->id() ACE_ENV_ARG_PARAMETER);
+  this->proxy_poa()->deactivate (this->id());
 }
 
 void
-TAO_Notify_Proxy::subscribed_types (TAO_Notify_EventTypeSeq& subscribed_types ACE_ENV_ARG_DECL)
+TAO_Notify_Proxy::subscribed_types (TAO_Notify_EventTypeSeq& subscribed_types)
 {
   ACE_GUARD_THROW_EX (TAO_SYNCH_MUTEX, ace_mon, this->lock_,
                         CORBA::INTERNAL ());
-  ACE_CHECK;
 
   // copy
   subscribed_types = this->subscribed_types_;
 }
 
 void
-TAO_Notify_Proxy::types_changed (const TAO_Notify_EventTypeSeq& added, const TAO_Notify_EventTypeSeq& removed ACE_ENV_ARG_DECL)
+TAO_Notify_Proxy::types_changed (const TAO_Notify_EventTypeSeq& added, const TAO_Notify_EventTypeSeq& removed)
 {
   // return if the updates for this proxy are turned off or
   // if all the updates in the channel are switched off.
@@ -73,19 +73,16 @@ TAO_Notify_Proxy::types_changed (const TAO_Notify_EventTypeSeq& added, const TAO
 
   if (TAO_Notify_PROPERTIES::instance()->asynch_updates () == 1) // if we should send the updates synchronously.
     {
-      this->execute_task (request ACE_ENV_ARG_PARAMETER);
+      this->execute_task (request);
     }
   else // execute in the current thread context.
     {
-      request.execute (ACE_ENV_SINGLE_ARG_PARAMETER);
+      request.execute ();
     }
 }
 
 CosNotification::EventTypeSeq*
-TAO_Notify_Proxy::obtain_types (CosNotifyChannelAdmin::ObtainInfoMode mode, const TAO_Notify_EventTypeSeq& types ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((
-                   CORBA::SystemException
-                   ))
+TAO_Notify_Proxy::obtain_types (CosNotifyChannelAdmin::ObtainInfoMode mode, const TAO_Notify_EventTypeSeq& types)
 {
   CosNotification::EventTypeSeq_var event_type_seq;
 
@@ -94,7 +91,6 @@ TAO_Notify_Proxy::obtain_types (CosNotifyChannelAdmin::ObtainInfoMode mode, cons
                     CORBA::NO_MEMORY ());
 
   ACE_GUARD_THROW_EX (TAO_SYNCH_MUTEX, ace_mon, this->lock_, CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (event_type_seq._retn ());
 
   if (mode == CosNotifyChannelAdmin::ALL_NOW_UPDATES_OFF ||
       mode == CosNotifyChannelAdmin::ALL_NOW_UPDATES_ON)
@@ -126,7 +122,7 @@ TAO_Notify_Proxy::qos_changed (const TAO_Notify_QoSProperties& qos_properties)
 }
 
 void
-TAO_Notify_Proxy::save_persistent (TAO_Notify::Topology_Saver& saver ACE_ENV_ARG_DECL)
+TAO_Notify_Proxy::save_persistent (TAO_Notify::Topology_Saver& saver)
 {
   bool changed = this->children_changed_;
   this->children_changed_ = false;
@@ -138,24 +134,21 @@ TAO_Notify_Proxy::save_persistent (TAO_Notify::Topology_Saver& saver ACE_ENV_ARG
     this->save_attrs(attrs);
 
     const char * type_name = this->get_proxy_type_name ();
-    bool want_all_children = saver.begin_object(this->id(), type_name, attrs, changed ACE_ENV_ARG_PARAMETER);
-    ACE_CHECK;
+    bool want_all_children = saver.begin_object(this->id(), type_name, attrs, changed);
 
     if (want_all_children || this->filter_admin_.is_changed ())
     {
-      this->filter_admin_.save_persistent(saver ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->filter_admin_.save_persistent(saver);
     }
 
     if (want_all_children || this->subscribed_types_.is_changed ())
     {
-      this->subscribed_types_.save_persistent(saver ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->subscribed_types_.save_persistent(saver);
     }
 
     // todo: handle removed children
 
-    saver.end_object(this->id(), type_name ACE_ENV_ARG_PARAMETER);
+    saver.end_object(this->id(), type_name);
   }
 }
 
@@ -166,17 +159,13 @@ TAO_Notify_Proxy::save_attrs (TAO_Notify::NVPList& attrs)
   TAO_Notify_Peer * peer = this->peer();
   if (peer != 0)
   {
-    ACE_CString ior;
-    if (peer->get_ior(ior))
-    {
-      attrs.push_back (TAO_Notify::NVP("PeerIOR", ior));
-    }
+    attrs.push_back (TAO_Notify::NVP("PeerIOR", peer->get_ior()));
   }
 }
 
 TAO_Notify::Topology_Object*
 TAO_Notify_Proxy::load_child (const ACE_CString &type, CORBA::Long id,
-  const TAO_Notify::NVPList& attrs ACE_ENV_ARG_DECL)
+  const TAO_Notify::NVPList& attrs)
 {
   ACE_UNUSED_ARG (id);
   ACE_UNUSED_ARG (attrs);
@@ -187,7 +176,6 @@ TAO_Notify_Proxy::load_child (const ACE_CString &type, CORBA::Long id,
     // in the constructor. we have to clear it out first.
     this->subscribed_types_.reset();
     result = &this->subscribed_types_;
-    ACE_CHECK_RETURN(0);
   }
   else if (type == "filter_admin")
   {
@@ -195,3 +183,5 @@ TAO_Notify_Proxy::load_child (const ACE_CString &type, CORBA::Long id,
   }
   return result;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
