@@ -3,7 +3,7 @@
 /**
  *  @file ProxyConsumer_T.h
  *
- *  $Id: ProxyConsumer_T.h 77001 2007-02-12 07:54:49Z johnnyw $
+ *  $Id: ProxyConsumer_T.h 81422 2008-04-24 12:33:29Z johnnyw $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  */
@@ -26,9 +26,6 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /**
  * @class TAO_Notify_ProxyConsumer_T
- *
- * @brief
- *
  */
 template <class SERVANT_TYPE>
 class TAO_Notify_Serv_Export TAO_Notify_ProxyConsumer_T
@@ -36,7 +33,7 @@ class TAO_Notify_Serv_Export TAO_Notify_ProxyConsumer_T
     public virtual TAO_Notify_ProxyConsumer
 {
 public:
-  /// Constuctor
+  /// Constructor
   TAO_Notify_ProxyConsumer_T (void);
 
   /// Destructor
@@ -49,8 +46,7 @@ public:
   virtual CosNotifyChannelAdmin::SupplierAdmin_ptr MyAdmin (void);
 
   virtual CosNotification::EventTypeSeq * obtain_subscription_types (
-    CosNotifyChannelAdmin::ObtainInfoMode mode
-  );
+    CosNotifyChannelAdmin::ObtainInfoMode mode);
 
   virtual void offer_change (
     const CosNotification::EventTypeSeq & added,
