@@ -1,18 +1,20 @@
-// RT_Builder.cpp,v 1.8 2005/07/01 20:13:01 michel_j Exp
+// $Id: RT_Builder.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "RT_Builder.h"
+#include "orbsvcs/Notify/RT_Builder.h"
 
 #include "ace/Auto_Ptr.h"
 #include "ace/Dynamic_Service.h"
-#include "ETCL_FilterFactory.h"
-#include "RT_POA_Helper.h"
-#include "Properties.h"
+#include "orbsvcs/Notify/ETCL_FilterFactory.h"
+#include "orbsvcs/Notify/RT_POA_Helper.h"
+#include "orbsvcs/Notify/Properties.h"
 #include "orbsvcs/NotifyExtC.h"
-#include "Object.h"
+#include "orbsvcs/Notify/Object.h"
 
 ACE_RCSID (RT_Notify,
            TAO_Notify_RT_Builder,
-           "RT_Builder.cpp,v 1.8 2005/07/01 20:13:01 michel_j Exp")
+           "$Id: RT_Builder.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Notify_RT_Builder::TAO_Notify_RT_Builder (void)
 {
@@ -24,7 +26,7 @@ TAO_Notify_RT_Builder::~TAO_Notify_RT_Builder ()
 
 void
 TAO_Notify_RT_Builder::apply_thread_pool_concurrency (TAO_Notify_Object& object
-                                                       , const NotifyExt::ThreadPoolParams& tp_params ACE_ENV_ARG_DECL)
+                                                       , const NotifyExt::ThreadPoolParams& tp_params)
 {
   TAO_Notify_RT_POA_Helper* proxy_poa = 0;
 
@@ -32,14 +34,12 @@ TAO_Notify_RT_Builder::apply_thread_pool_concurrency (TAO_Notify_Object& object
   ACE_NEW_THROW_EX (proxy_poa,
                     TAO_Notify_RT_POA_Helper (),
                     CORBA::NO_MEMORY ());
-  ACE_CHECK;
 
   ACE_Auto_Ptr<TAO_Notify_POA_Helper> auto_proxy_poa (proxy_poa);
 
   PortableServer::POA_var default_poa = TAO_Notify_PROPERTIES::instance ()->default_poa ();
 
-  proxy_poa->init (default_poa.in (), tp_params ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  proxy_poa->init (default_poa.in (), tp_params);
 
   // Give ownership of proxy_poa
   object.set_proxy_poa (auto_proxy_poa.release ());
@@ -47,7 +47,7 @@ TAO_Notify_RT_Builder::apply_thread_pool_concurrency (TAO_Notify_Object& object
 
 void
 TAO_Notify_RT_Builder::apply_lane_concurrency (TAO_Notify_Object& object
-                                                , const NotifyExt::ThreadPoolLanesParams& tpl_params ACE_ENV_ARG_DECL)
+                                                , const NotifyExt::ThreadPoolLanesParams& tpl_params)
 {
   TAO_Notify_RT_POA_Helper* proxy_poa = 0;
 
@@ -55,16 +55,15 @@ TAO_Notify_RT_Builder::apply_lane_concurrency (TAO_Notify_Object& object
   ACE_NEW_THROW_EX (proxy_poa,
                     TAO_Notify_RT_POA_Helper (),
                     CORBA::NO_MEMORY ());
-  ACE_CHECK;
 
   ACE_Auto_Ptr<TAO_Notify_POA_Helper> auto_proxy_poa (proxy_poa);
 
   PortableServer::POA_var default_poa = TAO_Notify_PROPERTIES::instance ()->default_poa ();
 
-  proxy_poa->init (default_poa.in (), tpl_params ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  proxy_poa->init (default_poa.in (), tpl_params);
 
   // Give ownership of proxy_poa
   object.set_proxy_poa (auto_proxy_poa.release ());
-
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
