@@ -1,14 +1,16 @@
-// Reactive_Task.cpp,v 1.12 2005/07/06 14:50:02 michel_j Exp
+// $Id: Reactive_Task.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
-#include "Reactive_Task.h"
+#include "orbsvcs/Notify/Reactive_Task.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "Reactive_Task.inl"
+#include "orbsvcs/Notify/Reactive_Task.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Notify, TAO_Notify_Reactive_Task, "Reactive_Task.cpp,v 1.12 2005/07/06 14:50:02 michel_j Exp")
+ACE_RCSID(Notify, TAO_Notify_Reactive_Task, "$Id: Reactive_Task.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
 
-#include "Timer_Reactor.h"
+#include "orbsvcs/Notify/Timer_Reactor.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Notify_Reactive_Task::TAO_Notify_Reactive_Task (void)
   :timer_ (0)
@@ -20,7 +22,7 @@ TAO_Notify_Reactive_Task::~TAO_Notify_Reactive_Task ()
 }
 
 void
-TAO_Notify_Reactive_Task::init (ACE_ENV_SINGLE_ARG_DECL)
+TAO_Notify_Reactive_Task::init (void)
 {
   ACE_ASSERT (this->timer_.get() == 0);
 
@@ -43,9 +45,9 @@ TAO_Notify_Reactive_Task::shutdown (void)
 }
 
 void
-TAO_Notify_Reactive_Task::execute (TAO_Notify_Method_Request& method_request ACE_ENV_ARG_DECL)
+TAO_Notify_Reactive_Task::execute (TAO_Notify_Method_Request& method_request)
 {
-  method_request.execute (ACE_ENV_SINGLE_ARG_PARAMETER);
+  method_request.execute ();
 }
 
 TAO_Notify_Timer*
@@ -53,3 +55,5 @@ TAO_Notify_Reactive_Task::timer (void)
 {
   return this->timer_.get();
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
