@@ -1,21 +1,22 @@
-// Routing_Slip.cpp,v 1.8 2005/07/20 16:17:27 michel_j Exp
+// $Id: Routing_Slip.cpp 79324 2007-08-13 11:20:01Z elliott_c $
 
-#include "Routing_Slip.h"
+#include "orbsvcs/Notify/Routing_Slip.h"
 
-#include "Delivery_Request.h"
-#include "Worker_Task.h"
-#include "ProxyConsumer.h"
-#include "ProxySupplier.h"
-#include "Event_Persistence_Strategy.h"
-#include "Routing_Slip_Persistence_Manager.h"
-#include "Routing_Slip_Queue.h"
-#include "Method_Request_Lookup.h"
-#include "Method_Request_Dispatch.h"
+#include "orbsvcs/Notify/Delivery_Request.h"
+#include "orbsvcs/Notify/Worker_Task.h"
+#include "orbsvcs/Notify/ProxyConsumer.h"
+#include "orbsvcs/Notify/ProxySupplier.h"
+#include "orbsvcs/Notify/Event_Persistence_Strategy.h"
+#include "orbsvcs/Notify/Routing_Slip_Persistence_Manager.h"
+#include "orbsvcs/Notify/Routing_Slip_Queue.h"
+#include "orbsvcs/Notify/Method_Request_Lookup.h"
+#include "orbsvcs/Notify/Method_Request_Dispatch.h"
 
 #include "tao/debug.h"
 #include "tao/corba.h"
 
 #include "ace/Dynamic_Service.h"
+#include "ace/Truncate.h"
 
 //#define DEBUG_LEVEL 9
 #ifndef DEBUG_LEVEL
@@ -24,6 +25,8 @@
 
 #define QUEUE_ALLOWED 1
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO_Notify
 {
 ///////////////////////
@@ -51,11 +54,10 @@ size_t Routing_Slip::count_enter_deleting_ = 0;
 size_t Routing_Slip::count_enter_terminal_ = 0;
 
 Routing_Slip_Ptr
-Routing_Slip::create (const TAO_Notify_Event::Ptr& event ACE_ENV_ARG_DECL)
+Routing_Slip::create (const TAO_Notify_Event::Ptr& event)
 {
   Routing_Slip * prs;
   ACE_NEW_THROW_EX (prs, Routing_Slip (event), CORBA::NO_MEMORY ());
-  ACE_CHECK_RETURN (Routing_Slip_Ptr());
   Routing_Slip_Ptr result(prs);
   result->this_ptr_ = result; // let the pointers touch so they use the same ref count
 
@@ -110,17 +112,15 @@ Routing_Slip::create (
   Routing_Slip_Ptr result;
   ACE_Message_Block * event_mb = 0;
   ACE_Message_Block * rs_mb = 0;
-  ACE_DECLARE_NEW_ENV;
-  ACE_TRY
+  try
     {
       if (rspm->reload (event_mb, rs_mb))
       {
         TAO_InputCDR cdr_event (event_mb);
         TAO_Notify_Event::Ptr event (TAO_Notify_Event::unmarshal (cdr_event));
-        if (event.get () != 0)
+        if (event.isSet())
         {
-          result = create (event ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+          result = create (event);
           TAO_InputCDR cdr_rs (rs_mb);
           if ( result->unmarshal (ecf, cdr_rs))
           {
@@ -142,13 +142,12 @@ Routing_Slip::create (
         }
       }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       ACE_ERROR ((LM_ERROR,
         ACE_TEXT ("(%P|%t) Routing_Slip::create: Exception reloading event.\n")
         ));
     }
-  ACE_ENDTRY;
   delete event_mb;
   delete rs_mb;
 
@@ -227,7 +226,7 @@ Routing_Slip::wait_persist ()
 }
 
 void
-Routing_Slip::route (TAO_Notify_ProxyConsumer* pc, bool reliable_channel ACE_ENV_ARG_DECL)
+Routing_Slip::route (TAO_Notify_ProxyConsumer* pc, bool reliable_channel)
 {
   ACE_ASSERT(pc != 0);
 
@@ -263,7 +262,7 @@ Routing_Slip::route (TAO_Notify_ProxyConsumer* pc, bool reliable_channel ACE_ENV
     {
       enter_state_new (guard);
     }
-    else if (this->event_->reliable().value() == CosNotification::Persistent)
+    else if (this->event_->reliable().value() == true)
     {
       enter_state_new (guard);
     }
@@ -272,8 +271,14 @@ Routing_Slip::route (TAO_Notify_ProxyConsumer* pc, bool reliable_channel ACE_ENV
       enter_state_transient (guard);
     }
   }
-  guard.release ();
-  pc->execute_task (method ACE_ENV_ARG_PARAMETER);
+  else
+  {
+    // We only need to release the guard if the state is rssCREATING.
+    // By calling enter_state_*, we are guaranteed that the guard has
+    // been released.
+    guard.release ();
+  }
+  pc->execute_task (method);
 }
 #if 0 // forward
 void
@@ -286,6 +291,7 @@ Routing_Slip::forward (TAO_Notify_ProxySupplier* ps, bool filter)
   Routing_Slip_Guard guard (this->internals_);
 
   enter_state_transient (guard);
+  guard.acquire();
   size_t request_id = delivery_requests_.size ();
 
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
@@ -329,8 +335,7 @@ Routing_Slip::forward (TAO_Notify_ProxySupplier* ps, bool filter)
 void
 Routing_Slip::dispatch (
   TAO_Notify_ProxySupplier* ps,
-  bool filter
-  ACE_ENV_ARG_DECL)
+  bool filter)
 {
   // cannot be the first action
   ACE_ASSERT (this->state_ != rssCREATING);
@@ -362,8 +367,7 @@ Routing_Slip::dispatch (
                     this->sequence_,
                     static_cast<int> (request_id),
                     ps->id()));
-      ps->execute_task (method ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      ps->execute_task (method);
     }
   else
     {
@@ -467,6 +471,7 @@ Routing_Slip::at_front_of_persist_queue ()
         ACE_TEXT ("(%P|%t) Routing Slip #%d: COMPLETE_WHILE_NEW Reached front of queue\n"),
         this->sequence_
         ));
+      guard.release ();
       this->persistent_queue_.complete ();
       enter_state_terminal (guard);
       break;
@@ -557,6 +562,7 @@ Routing_Slip::persist_complete ()
         ACE_TEXT ("(%P|%t) Notification Service Routing Slip: Unexpected transition in state %d\n"),
         static_cast<int> (this->state_)
         ));
+      guard.release ();
       break;
     }
   }
@@ -577,7 +583,6 @@ Routing_Slip::add_to_persist_queue(Routing_Slip_Guard & guard)
 {
   guard.release ();
   this->persistent_queue_.add (this->this_ptr_);
-  guard.acquire (); // necessary?
 }
 
 ////////////////////
@@ -603,6 +608,7 @@ Routing_Slip::continue_state_new (Routing_Slip_Guard & guard)
   {
     this->enter_state_complete_while_new (guard);
   }
+  guard.release ();
 }
 void
 Routing_Slip::enter_state_complete_while_new (Routing_Slip_Guard & guard)
@@ -626,19 +632,18 @@ void
 Routing_Slip::enter_state_reloaded (Routing_Slip_Guard & guard)
 {
   ++count_enter_reloaded_;
-  ACE_UNUSED_ARG (guard);
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
       ACE_TEXT ("(%P|%t) Routing Slip #&d: enter state RELOADED\n"),
       this->sequence_
       ));
   this->state_ = rssRELOADED;
+  guard.release();
 }
 
 void
 Routing_Slip::enter_state_transient (Routing_Slip_Guard & guard)
 {
   ++count_enter_transient_;
-  ACE_UNUSED_ARG (guard);
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
       ACE_TEXT ("(%P|%t) Routing Slip #%d: enter state TRANSIENT\n"),
       this->sequence_
@@ -653,6 +658,10 @@ Routing_Slip::enter_state_transient (Routing_Slip_Guard & guard)
   {
     enter_state_terminal (guard);
   }
+  else
+  {
+    guard.release ();
+  }
 }
 
 void
@@ -663,6 +672,10 @@ Routing_Slip::continue_state_transient (Routing_Slip_Guard & guard)
   {
     enter_state_terminal (guard);
   }
+  else
+  {
+    guard.release ();
+  }
 }
 void
 Routing_Slip::enter_state_saving (Routing_Slip_Guard & guard)
@@ -672,6 +685,7 @@ Routing_Slip::enter_state_saving (Routing_Slip_Guard & guard)
   {
     // Note This should actually be a throw (out of memory)
     // but we cheat and make this a transient event.
+    guard.release ();
     this->persistent_queue_.complete ();
     enter_state_transient (guard);
   }
@@ -693,8 +707,6 @@ Routing_Slip::enter_state_saving (Routing_Slip_Guard & guard)
 
     guard.release ();
     this->rspm_->store (*event_mb, *rs_mb);
-
-    guard.acquire (); // necessary?
   }
 }
 
@@ -702,12 +714,12 @@ void
 Routing_Slip::enter_state_saved (Routing_Slip_Guard & guard)
 {
   ++count_enter_saved_;
-  ACE_UNUSED_ARG (guard);
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
       ACE_TEXT ("(%P|%t) Routing Slip #%d: enter state SAVED\n"),
       this->sequence_
       ));
   this->state_ = rssSAVED;
+  guard.release ();
 }
 
 void
@@ -727,7 +739,6 @@ Routing_Slip::enter_state_updating (Routing_Slip_Guard & guard)
 
   ACE_ASSERT (this->rspm_ != 0);
   this->rspm_->update (*rs_mb);
-  guard.acquire (); // necessary?
 }
 
 
@@ -735,19 +746,19 @@ void
 Routing_Slip::enter_state_changed_while_saving (Routing_Slip_Guard & guard)
 {
   ++count_enter_changed_while_saving_;
-  ACE_UNUSED_ARG (guard);
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
       ACE_TEXT ("(%P|%t) Routing Slip #%d: enter state CHANGED_WHILE_SAVING\n"),
       this->sequence_
       ));
   this->state_ = rssCHANGED_WHILE_SAVING;
+  guard.release ();
 }
 
 void
 Routing_Slip::continue_state_changed_while_saving (Routing_Slip_Guard & guard)
 {
-  ACE_UNUSED_ARG (guard);
   // no action necessary
+  guard.release ();
 }
 
 void
@@ -776,18 +787,22 @@ Routing_Slip::continue_state_changed (Routing_Slip_Guard & guard)
   {
     enter_state_complete (guard);
   }
+  else
+  {
+    guard.release ();
+  }
 }
 
 void
 Routing_Slip::enter_state_complete (Routing_Slip_Guard & guard)
 {
   ++count_enter_complete_;
-  ACE_UNUSED_ARG (guard);
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
       ACE_TEXT ("(%P|%t) Routing Slip #%d: enter state COMPLETE\n"),
       this->sequence_
       ));
   this->state_ = rssCOMPLETE;
+  guard.release ();
 }
 
 void
@@ -801,14 +816,12 @@ Routing_Slip::enter_state_deleting (Routing_Slip_Guard & guard)
   this->state_ = rssDELETING;
   guard.release ();
   this->rspm_->remove ();
-  guard.acquire (); // necessary?
 }
 
 void
 Routing_Slip::enter_state_terminal (Routing_Slip_Guard & guard)
 {
   ++count_enter_terminal_;
-  ACE_UNUSED_ARG (guard);
   ACE_ASSERT( this->is_safe_);
   if (DEBUG_LEVEL > 8) ACE_DEBUG ((LM_DEBUG,
       ACE_TEXT ("(%P|%t) Routing Slip #%d: enter state TERMINAL\n"),
@@ -816,13 +829,15 @@ Routing_Slip::enter_state_terminal (Routing_Slip_Guard & guard)
       ));
   this->state_ = rssTERMINAL;
   this->this_ptr_.reset ();
+  guard.release ();
 }
 
 void
 Routing_Slip::marshal (TAO_OutputCDR & cdr)
 {
   size_t request_count = this->delivery_requests_.size();
-  cdr.write_ulong (request_count - this->complete_requests_);
+  cdr.write_ulong (
+    ACE_Utils::truncate_cast<CORBA::ULong> (request_count - this->complete_requests_));
   for (size_t nreq = 0; nreq < request_count; ++nreq)
   {
     Delivery_Request * request = this->delivery_requests_[nreq].get ();
@@ -843,8 +858,7 @@ Routing_Slip::unmarshal (TAO_Notify_EventChannelFactory &ecf, TAO_InputCDR & cdr
     ACE_CDR::Octet code = 0;
     while (cdr.read_octet(code))
     {
-      ACE_DECLARE_NEW_ENV;
-      ACE_TRY
+      try
       {
         if (code == TAO_Notify_Method_Request_Dispatch::persistence_code)
         {
@@ -853,15 +867,12 @@ Routing_Slip::unmarshal (TAO_Notify_EventChannelFactory &ecf, TAO_InputCDR & cdr
             prequest,
             Delivery_Request(this_ptr_, this->delivery_requests_.size ()),
             CORBA::NO_MEMORY ());
-          ACE_TRY_CHECK;
           Delivery_Request_Ptr request(prequest);
           TAO_Notify_Method_Request_Dispatch_Queueable * method =
             TAO_Notify_Method_Request_Dispatch::unmarshal (
               request,
               ecf,
-              cdr
-              ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK;
+              cdr);
           if (method != 0)
           {
             this->delivery_requests_.push_back (request);
@@ -875,9 +886,7 @@ Routing_Slip::unmarshal (TAO_Notify_EventChannelFactory &ecf, TAO_InputCDR & cdr
               TAO_Notify_Method_Request_Lookup::unmarshal (
                 request,
                 ecf,
-                cdr
-                ACE_ENV_ARG_PARAMETER);
-          ACE_TRY_CHECK
+                cdr);
           if (method != 0)
           {
             this->delivery_requests_.push_back (request);
@@ -885,28 +894,27 @@ Routing_Slip::unmarshal (TAO_Notify_EventChannelFactory &ecf, TAO_InputCDR & cdr
           }
         }
       }
-      ACE_CATCHANY;
+      catch (const CORBA::Exception&)
       {
         // @@todo should we log this?
         // just ignore failures
       }
-      ACE_ENDTRY;
     }
   }
   return this->delivery_requests_.size () > 0;
 }
 
 void
-Routing_Slip::reconnect (ACE_ENV_SINGLE_ARG_DECL)
+Routing_Slip::reconnect (void)
 {
   Routing_Slip_Guard guard (this->internals_);
   enter_state_saved (guard);
-  guard.release ();
+
   //@@todo is there a worker_task available to do this?
   size_t count = this->delivery_methods_.size ();
   for (size_t nmethod = 0; nmethod < count; ++nmethod)
   {
-    this->delivery_methods_[nmethod]->execute (ACE_ENV_SINGLE_ARG_PARAMETER);
+    this->delivery_methods_[nmethod]->execute ();
   }
   this->delivery_methods_.clear ();
 }
@@ -925,32 +933,6 @@ Routing_Slip::should_retry () const
   return this->state_ != rssTRANSIENT;
 }
 
-
-
 } // namespace
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-template class ACE_Auto_Basic_Ptr<TAO_Notify::Routing_Slip>;
-template class ACE_Strong_Bound_Ptr<TAO_Notify::Routing_Slip, TAO_SYNCH_MUTEX>;
-template class ACE_Auto_Basic_Ptr<TAO_Notify::Delivery_Request>;
-template class ACE_Strong_Bound_Ptr<TAO_Notify::Delivery_Request,TAO_SYNCH_MUTEX>;
-template class ACE_Vector <TAO_Notify::Delivery_Request_Ptr>;
-template class ACE_Array_Base<ACE_Strong_Bound_Ptr<TAO_Notify::Delivery_Request,TAO_SYNCH_MUTEX> >;
-template class ACE_Vector <TAO_Notify::Delivery_Request *>;
-template class ACE_Array_Base<TAO_Notify::Delivery_Request *>;
-template class ACE_Dynamic_Service <TAO_Notify::Event_Persistence_Strategy>;
-template class ACE_Array_Base<TAO_Notify_Method_Request_Dispatch_No_Copy*>;
-template class ACE_Vector<TAO_Notify_Method_Request_Dispatch_No_Copy*>;
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate ACE_Auto_Basic_Ptr<TAO_Notify::Routing_Slip>
-#pragma instantiate ACE_Strong_Bound_Ptr<TAO_Notify::Routing_Slip,TAO_SYNCH_MUTEX>
-#pragma instantiate ACE_Auto_Basic_Ptr<TAO_Notify::Delivery_Request>
-#pragma instantiate ACE_Strong_Bound_Ptr<TAO_Notify::Delivery_Request,TAO_SYNCH_MUTEX>
-#pragma instantiate ACE_Vector <TAO_Notify::Delivery_Request_Ptr>
-#pragma instantiate ACE_Array_Base<ACE_Strong_Bound_Ptr<TAO_Notify::Delivery_Request,TAO_SYNCH_MUTEX> >
-#pragma instantiate ACE_Vector <TAO_Notify::Delivery_Request *>
-#pragma instantiate ACE_Array_Base<TAO_Notify::Delivery_Request *>
-#pragma instantiate ACE_Dynamic_Service <TAO_Notify::Event_Persistence_Strategy>
-#pragma instantiate ACE_Array_Base<TAO_Notify_Method_Request_Dispatch_No_Copy*>
-#pragma instantiate ACE_Vector<TAO_Notify_Method_Request_Dispatch_No_Copy*>
-#endif /*ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
