@@ -1,8 +1,8 @@
-// $Id: SequencePushSupplier.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: SequencePushSupplier.cpp 84685 2009-03-02 22:49:17Z mesnier_p $
 
 #include "orbsvcs/Notify/Sequence/SequencePushSupplier.h"
 
-ACE_RCSID (Notify, TAO_Notify_SequencePushSupplier, "$Id: SequencePushSupplier.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+ACE_RCSID (Notify, TAO_Notify_SequencePushSupplier, "$Id: SequencePushSupplier.cpp 84685 2009-03-02 22:49:17Z mesnier_p $")
 
 #include "orbsvcs/Notify/Properties.h"
 
@@ -50,4 +50,10 @@ TAO_Notify_SequencePushSupplier::get_ior (void) const
   return result;
 }
 
+CORBA::Object_ptr
+TAO_Notify_SequencePushSupplier::get_supplier (void)
+{
+  return CosNotifyComm::SequencePushSupplier::_duplicate (this->push_supplier_.in ());
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
