@@ -2,7 +2,7 @@
 /**
  *  @file SequencePushSupplier.h
  *
- *  $Id: SequencePushSupplier.h 76589 2007-01-25 18:04:11Z elliott_c $
+ *  $Id: SequencePushSupplier.h 84685 2009-03-02 22:49:17Z mesnier_p $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -35,7 +35,7 @@ class TAO_Notify_ProxyConsumer;
 class TAO_Notify_Serv_Export TAO_Notify_SequencePushSupplier : public TAO_Notify_Supplier
 {
 public:
-  /// Constuctor
+  /// Constructor
   TAO_Notify_SequencePushSupplier (TAO_Notify_ProxyConsumer* proxy);
 
   /// Destructor
@@ -51,7 +51,10 @@ public:
   virtual ACE_CString get_ior (void) const;
 
 protected:
-  /// The Supplier
+
+  virtual CORBA::Object_ptr get_supplier (void);
+
+ /// The Supplier
   CosNotifyComm::SequencePushSupplier_var push_supplier_;
 };
 
