@@ -1,8 +1,8 @@
-// $Id: StructuredPushSupplier.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: StructuredPushSupplier.cpp 84685 2009-03-02 22:49:17Z mesnier_p $
 
 #include "orbsvcs/Notify/Structured/StructuredPushSupplier.h"
 
-ACE_RCSID(RT_Notify, TAO_Notify_StructuredPushSupplier, "$Id: StructuredPushSupplier.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+ACE_RCSID(RT_Notify, TAO_Notify_StructuredPushSupplier, "$Id: StructuredPushSupplier.cpp 84685 2009-03-02 22:49:17Z mesnier_p $")
 #include "orbsvcs/Notify/Properties.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -49,4 +49,10 @@ TAO_Notify_StructuredPushSupplier::get_ior (void) const
   return result;
 }
 
+CORBA::Object_ptr
+TAO_Notify_StructuredPushSupplier::get_supplier (void)
+{
+  return CosNotifyComm::StructuredPushSupplier::_duplicate (this->push_supplier_.in ());
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
