@@ -2,7 +2,7 @@
 /**
  *  @file StructuredPushSupplier.h
  *
- *  $Id: StructuredPushSupplier.h 76589 2007-01-25 18:04:11Z elliott_c $
+ *  $Id: StructuredPushSupplier.h 84685 2009-03-02 22:49:17Z mesnier_p $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -35,7 +35,7 @@ class TAO_Notify_ProxyConsumer;
 class TAO_Notify_Serv_Export TAO_Notify_StructuredPushSupplier : public TAO_Notify_Supplier
 {
 public:
-  /// Constuctor
+  /// Constructor
   TAO_Notify_StructuredPushSupplier (TAO_Notify_ProxyConsumer* proxy);
 
   /// Destructor
@@ -48,6 +48,9 @@ public:
   virtual ACE_CString get_ior (void) const;
 
 protected:
+  
+  virtual CORBA::Object_ptr get_supplier (void);
+
   /// The Supplier
   CosNotifyComm::StructuredPushSupplier_var push_supplier_;
 
