@@ -1,28 +1,32 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 /**
  *  @file Timer.h
  *
- *  Timer.h,v 1.7 2005/07/01 20:13:11 michel_j Exp
+ *  $Id: Timer.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
- *
- *
  */
 
 #ifndef TAO_Notify_TIMER_H
 #define TAO_Notify_TIMER_H
 #include /**/ "ace/pre.h"
 
-#include "notify_serv_export.h"
+#include "orbsvcs/Notify/notify_serv_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "ace/Time_Value.h"
-#include "Refcountable.h"
+#include "orbsvcs/Notify/Refcountable.h"
 
+#include "ace/Time_Value.h"
+
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 class ACE_Event_Handler;
+ACE_END_VERSIONED_NAMESPACE_DECL
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /**
  * @class TAO_Notify_Timer
@@ -46,5 +50,7 @@ public:
   virtual int cancel_timer (long timer_id) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_Notify_TIMER_H */
