@@ -3,7 +3,7 @@
 /**
  *  @file Timer_Queue.h
  *
- *  $Id: Timer_Queue.h 71526 2006-03-14 06:14:35Z jtc $
+ *  $Id: Timer_Queue.h 81422 2008-04-24 12:33:29Z johnnyw $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  */
@@ -37,12 +37,11 @@ class TAO_Notify_Serv_Export TAO_Notify_Timer_Queue : public TAO_Notify_Timer
 public:
   typedef TAO_Notify_Refcountable_Guard_T< TAO_Notify_Timer_Queue > Ptr;
 
-  /// Constuctor
+  /// Constructor
   TAO_Notify_Timer_Queue (void);
 
   /// Destructor
-  virtual ~TAO_Notify_Timer_Queue ();
-
+  virtual ~TAO_Notify_Timer_Queue (void);
 
   /// Schedule a timer
   virtual long schedule_timer (ACE_Event_Handler *handler,
