@@ -1,17 +1,18 @@
+// -*- C++ -*-
+
 /**
  *  @file Topology_Factory.h
  *
- *  Topology_Factory.h,v 1.2 2004/11/19 22:14:53 john_c Exp
+ *  $Id: Topology_Factory.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author Dale Wilson <wilson_d@ociweb.com>
- *
- *
  */
+
 #ifndef TAO_NOTIFY_TOPOLOGY_FACTORY_H
 #define TAO_NOTIFY_TOPOLOGY_FACTORY_H
 #include /**/ "ace/pre.h"
 
-#include "notify_serv_export.h"
+#include "orbsvcs/Notify/notify_serv_export.h"
 
 #include "ace/Service_Object.h"
 
@@ -19,6 +20,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO_Notify
 {
   class Topology_Saver;
@@ -39,8 +44,11 @@ namespace TAO_Notify
     /// \return a pointer to a Topology_Loader which must be deleted
     /// by the caller.
     virtual Topology_Loader* create_loader () = 0;
+    virtual ~Topology_Factory ();
   };
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif
