@@ -1,4 +1,4 @@
-// $Id: XML_Loader.cpp 78900 2007-07-15 13:05:48Z sowayaa $
+// $Id: XML_Loader.cpp 83324 2008-10-20 11:41:42Z vzykov $
 
 #include "orbsvcs/Notify/XML_Loader.h"
 #include "orbsvcs/Notify/Topology_Object.h"
@@ -32,14 +32,14 @@ namespace {
     CORBA::Long id = 0;
     for (size_t i = 0; i < attrs->getLength (); ++i)
     {
-      const char * name = attrs->getQName (i);
-      const char * value = attrs->getValue (i);
-      if (ACE_OS::strcmp (name,
-                         TAO_VERSIONED_NAMESPACE_NAME::TAO_Notify::TOPOLOGY_ID_NAME) == 0)
+      ACE_CString name = ACE_TEXT_ALWAYS_CHAR(attrs->getQName (i));
+      ACE_CString value = ACE_TEXT_ALWAYS_CHAR(attrs->getValue (i));
+      if (ACE_OS::strcmp (name.c_str (),
+                          TAO_VERSIONED_NAMESPACE_NAME::TAO_Notify::TOPOLOGY_ID_NAME) == 0)
       {
-        id = ACE_OS::atoi (value);
+        id = ACE_OS::atoi (value.c_str ());
       }
-      nvp.push_back (NVP (name, value));
+      nvp.push_back (NVP (name.c_str (), value.c_str ()));
     }
     return id;
   }
@@ -60,7 +60,7 @@ namespace TAO_Notify
   }
 
   bool
-  XML_Loader::open (const ACE_CString & base_name)
+  XML_Loader::open (const ACE_TString & base_name)
   {
     bool result = false;
 
@@ -71,7 +71,7 @@ namespace TAO_Notify
     // "impossible" happened (or its a new system with no saved state).
 
     this->file_name_ = base_name;
-    this->file_name_ += ".xml";
+    this->file_name_ += ACE_TEXT(".xml");
 
     // 4 is "read permission"
     result =  (0 == ACE_OS::access (this->file_name_.c_str (), 4));
@@ -115,7 +115,7 @@ namespace TAO_Notify
     if (! result)
     {
       this->file_name_ = base_name;
-      this->file_name_ += ".000";
+      this->file_name_ += ACE_TEXT(".000");
       result = (0 == ACE_OS::access (this->file_name_.c_str (), 4));
     }
     return result;
@@ -191,14 +191,14 @@ namespace TAO_Notify
             name
             ));
 
-          ACE_CString cname (name);
+          ACE_CString cname (ACE_TEXT_ALWAYS_CHAR(name));
           Topology_Object* next = cur->load_child (cname, id, attrs);
           ACE_ASSERT(next != 0);
           object_stack_.push (next);
         }
         catch (const CORBA::Exception& ex)
         {
-          throw ACEXML_SAXException (ex._info ().c_str ());
+          throw ACEXML_SAXException (ACE_TEXT_CHAR_TO_TCHAR(ex._info ().c_str ()));
         }
       }
     }
