@@ -4,7 +4,7 @@
 /**
  *  @file    XML_Loader.h
  *
- *  $Id: XML_Loader.h 78900 2007-07-15 13:05:48Z sowayaa $
+ *  $Id: XML_Loader.h 82940 2008-10-06 18:20:19Z johnnyw $
  *
  *  A topology saver class that outputs XML.
  *
@@ -44,7 +44,7 @@ public:
 
   /// Open a file and perform preliminary validation to determine whether
   /// the file is complete and valid.
-  bool open (const ACE_CString & file_name);
+  bool open (const ACE_TString & file_name);
 
   ///////////////////////////////////
   // Override Topology_Loader methods
@@ -66,7 +66,7 @@ public:
 
 private:
   /// The name of the file from which data is read.
-  ACE_CString file_name_;
+  ACE_TString file_name_;
   /// A stream representing our current output.
   FILE * input_;
 
