@@ -1,4 +1,4 @@
-// $Id: XML_Topology_Factory.cpp 71526 2006-03-14 06:14:35Z jtc $
+// $Id: XML_Topology_Factory.cpp 82954 2008-10-07 08:02:58Z johnnyw $
 
 #include "orbsvcs/Notify/XML_Topology_Factory.h"
 #include "orbsvcs/Notify/XML_Saver.h"
@@ -16,8 +16,8 @@ namespace TAO_Notify
   const char TOPOLOGY_ID_NAME[] = "TopologyID";
 
   XML_Topology_Factory::XML_Topology_Factory()
-    : save_base_path_ ("./Notification_Service_Topology")
-    , load_base_path_ ("./Notification_Service_Topology")
+    : save_base_path_ (ACE_TEXT("./Notification_Service_Topology"))
+    , load_base_path_ (ACE_TEXT("./Notification_Service_Topology"))
     , backup_count_ (2)
     , timestamp_ (true)
   {
@@ -68,14 +68,14 @@ namespace TAO_Notify
     for (int narg = 0; narg < argc; ++narg)
     {
       ACE_TCHAR * av = argv[narg];
-      if (ACE_OS::strcasecmp (av, "-v") == 0)
+      if (ACE_OS::strcasecmp (av, ACE_TEXT("-v")) == 0)
       {
         verbose = true;
         ACE_DEBUG ((LM_DEBUG,
           ACE_TEXT ("(%P|%t) Standard_Event_Persistence: -verbose\n")
           ));
       }
-      else if (ACE_OS::strcasecmp (av, "-base_path") == 0 && narg + 1 < argc)
+      else if (ACE_OS::strcasecmp (av, ACE_TEXT("-base_path")) == 0 && narg + 1 < argc)
       {
         this->save_base_path_ = argv[narg + 1];
         this->load_base_path_ = argv[narg + 1];
@@ -88,7 +88,7 @@ namespace TAO_Notify
         }
         narg += 1;
       }
-      else if (ACE_OS::strcasecmp (av, "-save_base_path") == 0 && narg + 1 < argc)
+      else if (ACE_OS::strcasecmp (av, ACE_TEXT("-save_base_path")) == 0 && narg + 1 < argc)
       {
         this->save_base_path_ = argv[narg + 1];
         if (TAO_debug_level > 0 || verbose)
@@ -100,7 +100,7 @@ namespace TAO_Notify
         }
         narg += 1;
       }
-      else if (ACE_OS::strcasecmp (av, "-load_base_path") == 0 && narg + 1 < argc)
+      else if (ACE_OS::strcasecmp (av, ACE_TEXT("-load_base_path")) == 0 && narg + 1 < argc)
       {
         this->load_base_path_ = argv[narg + 1];
         if (TAO_debug_level > 0 || verbose)
@@ -112,7 +112,7 @@ namespace TAO_Notify
         }
         narg += 1;
       }
-      else if (ACE_OS::strcasecmp (av, "-backup_count") == 0 && narg + 1 < argc)
+      else if (ACE_OS::strcasecmp (av, ACE_TEXT("-backup_count")) == 0 && narg + 1 < argc)
       {
         this->backup_count_ = ACE_OS::atoi(argv[narg + 1]);
         if (TAO_debug_level > 0 || verbose)
@@ -124,7 +124,7 @@ namespace TAO_Notify
         }
         narg += 1;
       }
-      else if (ACE_OS::strcasecmp (av, "-no_timestamp") == 0)
+      else if (ACE_OS::strcasecmp (av, ACE_TEXT("-no_timestamp")) == 0)
       {
         this->timestamp_ = false;
         if (TAO_debug_level > 0 || verbose)
