@@ -4,7 +4,7 @@
 /**
  *  @file    XML_Topology_Factory.h
  *
- *  $Id: XML_Topology_Factory.h 71526 2006-03-14 06:14:35Z jtc $
+ *  $Id: XML_Topology_Factory.h 82954 2008-10-07 08:02:58Z johnnyw $
  *
  *  @author Jonathan Pollack <pollack_j@ociweb.com>
  */
@@ -69,8 +69,8 @@ namespace TAO_Notify
     virtual int fini ();
 
    private:
-    ACE_CString save_base_path_;
-    ACE_CString load_base_path_;
+    ACE_TString save_base_path_;
+    ACE_TString load_base_path_;
     size_t backup_count_;
     bool timestamp_;
   };
