@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: PG_FactoryRegistry.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: PG_FactoryRegistry.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "orbsvcs/PortableGroup/PG_FactoryRegistry.h"
 
@@ -48,7 +48,7 @@ TAO::PG_FactoryRegistry::PG_FactoryRegistry (const char * name)
   , object_id_ (0)
   , this_obj_ (0)
   , ior_output_file_(0)
-  , ns_name_(0)
+  , ns_name_("")
   , naming_context_(0)
   , this_name_(1)
   , quit_on_idle_(0)
@@ -64,9 +64,9 @@ TAO::PG_FactoryRegistry::~PG_FactoryRegistry (void)
 //////////////////////////////////////////////////////
 // PG_FactoryRegistry public, non-CORBA methods
 
-int TAO::PG_FactoryRegistry::parse_args (int argc, char * argv[])
+int TAO::PG_FactoryRegistry::parse_args (int argc, ACE_TCHAR * argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:n:q");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:n:q"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -80,7 +80,7 @@ int TAO::PG_FactoryRegistry::parse_args (int argc, char * argv[])
       }
       case 'n':
       {
-        this->ns_name_ = get_opts.opt_arg();
+        this->ns_name_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg());
         break;
       }
       case 'q':
@@ -143,10 +143,10 @@ int TAO::PG_FactoryRegistry::fini (void)
     ACE_OS::unlink (this->ior_output_file_);
     this->ior_output_file_ = 0;
   }
-  if (this->ns_name_ != 0)
+  if (this->ns_name_.length () != 0)
   {
     this->naming_context_->unbind (this_name_);
-    this->ns_name_ = 0;
+    this->ns_name_ = "";
   }
   return 0;
 }
@@ -216,16 +216,15 @@ int TAO::PG_FactoryRegistry::init (CORBA::ORB_ptr orb)
   // and create a ior string
   this->ior_ = this->orb_->object_to_string (this->this_obj_.in ());
 
-
   if (this->ior_output_file_ != 0)
   {
     this->identity_ = "file:";
-    this->identity_ += this->ior_output_file_;
+    this->identity_ += ACE_TEXT_ALWAYS_CHAR(this->ior_output_file_);
     result = write_ior_file (this->ior_output_file_,
                              this->ior_.in ());
   }
 
-  if (this->ns_name_ != 0)
+  if (this->ns_name_.length () != 0)
   {
     this->identity_ = "name:";
     this->identity_ += this->ns_name_;
@@ -243,7 +242,7 @@ int TAO::PG_FactoryRegistry::init (CORBA::ORB_ptr orb)
       CosNaming::NamingContext::_narrow (naming_obj.in ());
 
     this->this_name_.length (1);
-    this->this_name_[0].id = CORBA::string_dup (this->ns_name_);
+    this->this_name_[0].id = CORBA::string_dup (this->ns_name_.c_str ());
 
     this->naming_context_->rebind (this->this_name_, this->this_obj_.in()  //CORBA::Object::_duplicate(this_obj)
                             );
@@ -339,7 +338,7 @@ void TAO::PG_FactoryRegistry::register_factory (
   }
 
   ACE_DEBUG(( LM_DEBUG,
-    "%s: Added factory: [%d] %s@%s \n",
+    "%s: Added factory: [%d] %s@%s\n",
       this->identity_.c_str(),
       static_cast<int> (length + 1),
       role,
@@ -669,7 +668,7 @@ void TAO::PG_FactoryRegistry::unregister_factory_by_location (
 //////////////////////////////
 // Implementation methods
 
-int TAO::PG_FactoryRegistry::write_ior_file(const char * outputFile, const char * ior)
+int TAO::PG_FactoryRegistry::write_ior_file(const ACE_TCHAR * outputFile, const char * ior)
 {
   int result = -1;
   FILE* out = ACE_OS::fopen (outputFile, "w");
