@@ -4,7 +4,7 @@
 /**
  * @file  PG_GenericFactory.h
  *
- * PG_GenericFactory.h,v 1.19 2004/08/16 23:53:14 jtc Exp
+ * $Id: PG_GenericFactory.h 77001 2007-02-12 07:54:49Z johnnyw $
  *
  * @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -22,12 +22,13 @@
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "PG_Factory_Map.h"
-#include "portablegroup_export.h"
+#include "orbsvcs/PortableGroup/PG_Factory_Map.h"
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
 #include "tao/PortableServer/PortableServerC.h"
 #include "orbsvcs/PortableGroupC.h"
 #include "ace/Null_Mutex.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 /// Forward declarations.
 class TAO_PG_ObjectGroupManager;
@@ -73,14 +74,7 @@ public:
       const char * type_id,
       const PortableGroup::Criteria & the_criteria,
       PortableGroup::GenericFactory::FactoryCreationId_out
-        factory_creation_id
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     PortableGroup::NoFactory,
-                     PortableGroup::ObjectNotCreated,
-                     PortableGroup::InvalidCriteria,
-                     PortableGroup::InvalidProperty,
-                     PortableGroup::CannotMeetCriteria));
+        factory_creation_id);
 
   /**
    * Delete the object corresponding to the provided
@@ -90,10 +84,7 @@ public:
    */
   virtual void delete_object (
       const PortableGroup::GenericFactory::FactoryCreationId &
-        factory_creation_id
-      ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     PortableGroup::ObjectNotFound));
+        factory_creation_id);
 
   //@}
 
@@ -109,8 +100,7 @@ public:
    * factories.
    */
   void delete_object_i (TAO_PG_Factory_Set & factory_set,
-                        CORBA::Boolean ignore_exceptions
-                        ACE_ENV_ARG_DECL);
+                        CORBA::Boolean ignore_exceptions);
 
   /// If the member corresponding to the given group ID and location
   /// was created by the infrastructure, call delete_object() on the
@@ -120,8 +110,7 @@ public:
    * when ObjectGroupManager::remove_member() is explicitly called.
    */
   void delete_member (CORBA::ULong group_id,
-                      const PortableGroup::Location & location
-                      ACE_ENV_ARG_DECL);
+                      const PortableGroup::Location & location);
 
   /// Verify that the MinimumNumberMembers criterion is satisfied.
   /**
@@ -134,8 +123,7 @@ public:
   void check_minimum_number_members (
     PortableGroup::ObjectGroup_ptr object_group,
     CORBA::ULong group_id,
-    const char * type_id
-    ACE_ENV_ARG_DECL);
+    const char * type_id);
 
   /// Create a new object group member using the supplied FactoryInfo
   /// and RepositoryId and add it to the given object group.
@@ -146,15 +134,7 @@ public:
       PortableGroup::ObjectGroup_ptr object_group,
       const PortableGroup::FactoryInfo & factory_info,
       const char * type_id,
-      const CORBA::Boolean propagate_member_already_present
-      ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     PortableGroup::NoFactory,
-                     PortableGroup::ObjectNotCreated,
-                     PortableGroup::InvalidCriteria,
-                     PortableGroup::InvalidProperty,
-                     PortableGroup::CannotMeetCriteria,
-		     PortableGroup::MemberAlreadyPresent));
+      const CORBA::Boolean propagate_member_already_present);
 
 private:
 
@@ -166,8 +146,7 @@ private:
          const char * type_id,
          const PortableGroup::FactoryInfos &factory_infos,
          PortableGroup::InitialNumberMembersValue initial_number_members,
-         TAO_PG_Factory_Set & factory_set
-         ACE_ENV_ARG_DECL);
+         TAO_PG_Factory_Set & factory_set);
 
   /// Get a new ObjectId to be used when creating a new ObjectGroup.
   /**
@@ -196,8 +175,7 @@ private:
     PortableGroup::MembershipStyleValue & membership_style,
     PortableGroup::FactoriesValue & factory_infos,
     PortableGroup::InitialNumberMembersValue & initial_number_members,
-    PortableGroup::MinimumNumberMembersValue & minimum_number_members
-    ACE_ENV_ARG_DECL);
+    PortableGroup::MinimumNumberMembersValue & minimum_number_members);
 
 private:
 
@@ -240,6 +218,7 @@ private:
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 
