@@ -4,7 +4,7 @@
 /**
  * @file  PG_Group_Guard.h
  *
- * $Id: PG_Group_Guard.h 71526 2006-03-14 06:14:35Z jtc $
+ * $Id: PG_Group_Guard.h 81416 2008-04-24 10:26:10Z johnnyw $
  *
  * @author Ossama Othman <ossama@uci.edu>
  */
@@ -82,7 +82,7 @@ private:
 
   /// Flag that dictates whether or not the destructor will perform
   /// cleanup.
-  int released_;
+  bool released_;
 
 };
 
