@@ -4,7 +4,7 @@
 /**
  *  @file     PG_Location_Map.h
  *
- *  PG_Location_Map.h,v 1.6 2004/08/16 23:53:14 jtc Exp
+ *  $Id: PG_Location_Map.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author  Ossama Othman <ossama@uci.edu>
  */
@@ -22,8 +22,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "PG_Location_Hash.h"
-#include "PG_Location_Equal_To.h"
+#include "orbsvcs/PortableGroup/PG_Location_Hash.h"
+#include "orbsvcs/PortableGroup/PG_Location_Equal_To.h"
 
 #include "orbsvcs/PortableGroupC.h"
 
@@ -31,6 +31,8 @@
 #include "ace/Hash_Map_Manager_T.h"
 #include "ace/Null_Mutex.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /// Forward declarations.
 struct TAO_PG_ObjectGroup_Map_Entry;
 
@@ -45,6 +47,8 @@ typedef ACE_Hash_Map_Manager_Ex<
   TAO_PG_Location_Equal_To,
   ACE_Null_Mutex> TAO_PG_Location_Map;
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_PG_LOCATION_MAP_H */
