@@ -3,12 +3,12 @@
 
 ACE_RCSID (PortableGroup,
            PG_MemberInfo,
-           "$Id: PG_MemberInfo.cpp 71526 2006-03-14 06:14:35Z jtc $")
+           "$Id: PG_MemberInfo.cpp 81628 2008-05-07 06:51:27Z wotte $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 bool
-TAO_PG_MemberInfo::operator== (const TAO_PG_MemberInfo & rhs)
+TAO_PG_MemberInfo::operator== (const TAO_PG_MemberInfo & rhs) const
 {
   // For the purposes of the member info set, only the location is
   // important.
