@@ -4,7 +4,7 @@
 /**
  *  @file    PG_MemberInfo.h
  *
- *  $Id: PG_MemberInfo.h 69353 2005-11-14 22:03:50Z ossama $
+ *  $Id: PG_MemberInfo.h 87872 2009-12-02 18:25:48Z dai_y $
  *
  *  @author  Ossama Othman <ossama@uci.edu>
  */
@@ -34,8 +34,10 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  *
  * Structure that contains all member-specific information.
  */
+
 struct TAO_PG_MemberInfo
 {
+  PortableGroup::ObjectGroup_var group;
 
   /// Reference to the member.
   CORBA::Object_var member;
@@ -43,13 +45,16 @@ struct TAO_PG_MemberInfo
   /// The location at which the member resides.
   PortableGroup::Location location;
 
+  /// Flag indicates that the member is alive.
+  bool is_alive;
+
   /// Equality operator.
   /**
    * For the purposes of the member info set, only the location is
    * important.  In particular, if a member already resides at the
    * given location, this equality operator will return true.
    */
-  bool operator== (const TAO_PG_MemberInfo & rhs);
+  bool operator== (const TAO_PG_MemberInfo & rhs) const;
 
 };
 
