@@ -11,7 +11,7 @@
 
 ACE_RCSID (PortableGroup,
            PG_ObjectGroupManager,
-           "$Id: PG_ObjectGroupManager.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: PG_ObjectGroupManager.cpp 87872 2009-12-02 18:25:48Z dai_y $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -160,8 +160,10 @@ TAO_PG_ObjectGroupManager::add_member_i (
     throw PortableGroup::MemberAlreadyPresent ();
 
   TAO_PG_MemberInfo member_info;
+  member_info.group    = PortableGroup::ObjectGroup::_duplicate (object_group);
   member_info.member   = CORBA::Object::_duplicate (member);
   member_info.location = the_location;
+  member_info.is_alive = true;
 
   if (groups == 0)
     {
@@ -215,12 +217,12 @@ TAO_PG_ObjectGroupManager::remove_member (
 
   // Multiple members from different object groups may reside at the
   // same location.  Iterate through the list to attempt to find a
-  // match for the exact object group.
-  size_t to_be_removed = 0;
-
-  // get the position of the object group in the object_group_array
-  to_be_removed = this->get_object_group_position (*groups, group_entry);
+  // match for the exact object group. If no match, -1 is returned.
+  int to_be_removed = this->get_object_group_position (*groups, group_entry);
 
+  if (to_be_removed == -1)
+    throw PortableGroup::ObjectGroupNotFound ();
+ 
   // remove the element from the array and resize the array.
   const size_t groups_len = groups->size ();
   size_t j;
@@ -248,7 +250,18 @@ TAO_PG_ObjectGroupManager::remove_member (
           // its membership is under infrastructure control.
           if (this->generic_factory_)
             {
-              this->generic_factory_->delete_member (group_entry->group_id,
+              CORBA::ULong group_id = group_entry->group_id;
+              // Release the lock during the factory delete_member()
+              // which may invoke delete_object()on registered factory.
+              // No need to block other threads during the invocation.
+              ACE_Reverse_Lock<TAO_SYNCH_MUTEX> reverse_lock (this->lock_);
+
+              ACE_GUARD_RETURN (ACE_Reverse_Lock<TAO_SYNCH_MUTEX>,
+                                reverse_guard,
+                                reverse_lock,
+                                PortableGroup::ObjectGroup::_nil ());
+
+              this->generic_factory_->delete_member (group_id,
                                                      the_location);
             }
 
@@ -272,6 +285,7 @@ TAO_PG_ObjectGroupManager::remove_member (
   throw PortableGroup::MemberNotFound ();
 }
 
+
 PortableGroup::Locations *
 TAO_PG_ObjectGroupManager::locations_of_members (
     PortableGroup::ObjectGroup_ptr object_group)
@@ -294,19 +308,27 @@ TAO_PG_ObjectGroupManager::locations_of_members (
 
   TAO_PG_MemberInfo_Set & member_infos = group_entry->member_infos;
 
-  locations->length (static_cast<CORBA::ULong> (member_infos.size ()));
-
   CORBA::ULong loc = 0;
   TAO_PG_MemberInfo_Set::iterator end = member_infos.end ();
 
   for (TAO_PG_MemberInfo_Set::iterator i = member_infos.begin ();
        i != end;
        ++i)
-    locations[loc++] = (*i).location;
-
+  {
+    // This flag is only set to false and used by TAO_LB_LoadManager
+    // which uses this flag to help avoid same member be returned by
+    // next member multiple times.
+    // The flag is always true for any other non-LB services.
+    if ((*i).is_alive)
+    {
+      locations->length (loc + 1);
+      locations[loc++] = (*i).location;
+    }
+  }
   return locations._retn ();
 }
 
+
 PortableGroup::ObjectGroups *
 TAO_PG_ObjectGroupManager::groups_at_location (
     const PortableGroup::Location & the_location)
@@ -666,7 +688,8 @@ TAO_PG_ObjectGroupManager::member_already_present (
   return 0;
 }
 
-size_t
+
+int
 TAO_PG_ObjectGroupManager::get_object_group_position (
   const TAO_PG_ObjectGroup_Array &groups,
   TAO_PG_ObjectGroup_Map_Entry * group_entry)
@@ -684,12 +707,12 @@ TAO_PG_ObjectGroupManager::get_object_group_position (
         {
           // Member with given type ID exists at the given
           // location.
-          return i;
+          return (int)i;
         }
     }
 
   // No member with given type ID present at the given location.
-  return 0;
+  return -1;
 }
 
 CORBA::Boolean
@@ -749,4 +772,228 @@ TAO_PG_ObjectGroupManager::generic_factory (
   this->generic_factory_ = generic_factory;
 }
 
+
+size_t
+TAO_PG_ObjectGroupManager::member_count (
+    const PortableServer::ObjectId & oid,
+    bool is_alive)
+{
+  ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, guard, this->lock_, 0);
+  
+  TAO_PG_ObjectGroup_Map_Entry * group_entry = 0;
+  if (this->object_group_map_.find (oid, group_entry) != 0)
+    throw PortableGroup::ObjectGroupNotFound ();
+
+  int count = 0;
+  TAO_PG_MemberInfo_Set & member_infos = group_entry->member_infos;
+
+  TAO_PG_MemberInfo_Set::iterator end = member_infos.end ();
+  
+  for (TAO_PG_MemberInfo_Set::iterator i = member_infos.begin ();
+       i != end;
+       ++i)
+  {
+    if ((*i).is_alive == is_alive)
+    { 
+      ++count;
+    }
+  }
+
+  return count;
+}
+
+
+bool
+TAO_PG_ObjectGroupManager::is_alive (
+    const PortableServer::ObjectId & oid,
+    CORBA::Object_ptr member)
+{
+  ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, guard, this->lock_, 0);
+  
+  TAO_PG_ObjectGroup_Map_Entry * group_entry = 0;
+  if (this->object_group_map_.find (oid, group_entry) != 0)
+    throw PortableGroup::ObjectGroupNotFound ();
+
+  TAO_PG_MemberInfo_Set & member_infos = group_entry->member_infos;
+
+  TAO_PG_MemberInfo_Set::iterator end = member_infos.end ();
+  
+  for (TAO_PG_MemberInfo_Set::iterator i = member_infos.begin ();
+       i != end;
+       ++i)
+  {
+    if ((*i).member->_is_equivalent (member))
+    { 
+      return (*i).is_alive;
+    }
+  }
+
+  throw PortableGroup::MemberNotFound (); 
+}
+
+
+void TAO_PG_ObjectGroupManager::remove_inactive_members ()
+{
+  TAO_PG_MemberInfo_Set inactive_members;
+  
+  {
+    ACE_GUARD (TAO_SYNCH_MUTEX, guard, this->lock_);
+    inactive_members = this->inactive_members_;
+    this->inactive_members_.reset ();
+  }
+
+  TAO_PG_MemberInfo_Set::iterator end = inactive_members.end ();
+  for (TAO_PG_MemberInfo_Set::iterator i = inactive_members.begin ();
+    i != end;
+    ++i)
+  {
+    this->remove_member ((*i).group.in (), (*i).location);
+  }
+}
+
+TAO_PG_MemberInfo_Set
+TAO_PG_ObjectGroupManager::get_members (bool is_alive)
+{
+  TAO_PG_MemberInfo_Set members;
+  {
+    ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, guard, this->lock_, TAO_PG_MemberInfo_Set());
+
+    for (TAO_PG_ObjectGroup_Map::iterator j = this->object_group_map_.begin ();
+      j != this->object_group_map_.end ();
+      ++j)
+    {
+      TAO_PG_MemberInfo_Set & member_infos = j->int_id_->member_infos;
+      TAO_PG_MemberInfo_Set::iterator end = member_infos.end ();
+
+      for (TAO_PG_MemberInfo_Set::iterator i = member_infos.begin ();
+        i != end;
+        ++i)
+      {
+        if ((*i).is_alive == is_alive)
+        {
+          if (members.insert_tail (*i) !=0)
+          {
+            throw CORBA::INTERNAL ();
+          }
+        }
+      }
+    }
+  }
+
+  return members;
+}
+
+void
+TAO_PG_ObjectGroupManager::validate_members (CORBA::ORB_ptr orb, 
+                                             const TimeBase::TimeT& timeout)
+{
+  if (TAO_debug_level > 0)
+    ACE_DEBUG ((LM_DEBUG, 
+      ACE_TEXT ("(%P|%t)TAO_PG_ObjectGroupManager::validate_members start\n")));
+    
+  /// Get list of active member info.
+  TAO_PG_MemberInfo_Set active_members = this->get_members (true);
+
+  /// Ping each member in the list and add ping failed member to
+  /// inactive member list.
+  TAO_PG_MemberInfo_Set inactive_members;
+  for (TAO_PG_MemberInfo_Set::iterator j = active_members.begin ();
+      j != active_members.end ();
+      ++j)
+  {
+    if (! this->ping (orb, (*j).member, timeout))
+    {
+      if (inactive_members.insert_tail (*j) !=0)
+      {
+        throw CORBA::INTERNAL ();
+      }
+    }
+  }
+  /// Mark the members as inactive in internal group maps.
+  {
+    ACE_GUARD (TAO_SYNCH_MUTEX, guard, this->lock_);
+    for (TAO_PG_MemberInfo_Set::iterator i = inactive_members.begin ();
+      i != inactive_members.end ();
+      ++i)
+    {
+      TAO_PG_ObjectGroup_Map_Entry * group_entry =
+        this->get_group_entry ((*i).group.in ());
+
+      TAO_PG_MemberInfo_Set & members = group_entry->member_infos;
+      for (TAO_PG_MemberInfo_Set::iterator j = members.begin ();
+        j != members.end ();
+        ++j)
+      {
+        if ((*j) == (*i))
+          (*j).is_alive = false;
+      }
+    }
+
+    /// keep a copy of inactive member for removing.
+    this->inactive_members_ = inactive_members;
+  }
+
+  if (TAO_debug_level > 0)
+    ACE_DEBUG ((LM_DEBUG, 
+      ACE_TEXT ("(%P|%t)TAO_PG_ObjectGroupManager::validate_members end\n")));
+}
+
+bool
+TAO_PG_ObjectGroupManager::ping (CORBA::ORB_ptr orb, 
+                                 CORBA::Object_var& obj, 
+                                 const TimeBase::TimeT& tt)
+{
+  bool status = true;
+  if (CORBA::is_nil (obj.in ()))
+    throw CORBA::OBJECT_NOT_EXIST ();
+  
+  // The ping() is used by LoadBalancer which may use RW strategy.
+  // The validate thread invokes the _non_existent call to members
+  // sequencially. We have to put a timeout on the call in case
+  // the client side is not processing ORB requests at this time.
+  // In the event that the timeout exception occurs, we will assume 
+  // that the peer is still around.  If we get any other exception
+  // we will say that the member is not available anymore.
+  TimeBase::TimeT timeout = tt;
+  CORBA::Any timeout_any;
+  timeout_any <<= timeout;
+
+  CORBA::PolicyList policy_list (1);
+  policy_list.length (1);
+  policy_list[0] = orb->
+                    create_policy (
+                          Messaging::RELATIVE_RT_TIMEOUT_POLICY_TYPE,
+                          timeout_any);
+  CORBA::Object_var rtt_obj =
+    obj->_set_policy_overrides (policy_list,
+                                CORBA::ADD_OVERRIDE);
+
+  // Clean up the policy that was allocated in the try/catch
+  for (CORBA::ULong i = 0; i < policy_list.length (); i++)
+    policy_list[i]->destroy ();
+
+  try {
+    status = ! rtt_obj->_non_existent ();
+  }
+  catch (CORBA::TIMEOUT& ex)
+  {
+    if (TAO_debug_level > 8)
+    {
+      ex._tao_print_exception ("TAO_PG_ObjectGroupManager::ping");
+    }
+  }
+  catch (CORBA::Exception& ex)
+  {
+    if (TAO_debug_level > 8)
+    {
+      ex._tao_print_exception ("TAO_PG_ObjectGroupManager::ping");
+    }
+
+    status = false;
+  }
+
+  return status;
+}
+
+
 TAO_END_VERSIONED_NAMESPACE_DECL
