@@ -4,7 +4,7 @@
 /**
  *  @file    PG_ObjectGroup_Map.h
  *
- *  PG_ObjectGroup_Map.h,v 1.6 2004/08/16 23:53:14 jtc Exp
+ *  $Id: PG_ObjectGroup_Map.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author  Ossama Othman <ossama@uci.edu>
  */
@@ -22,7 +22,7 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "PG_MemberInfo.h"
+#include "orbsvcs/PortableGroup/PG_MemberInfo.h"
 
 #include "orbsvcs/PortableGroupC.h"
 
@@ -32,6 +32,8 @@
 #include "ace/Hash_Map_Manager_T.h"
 #include "ace/Null_Mutex.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_PG_ObjectGroup_Map_Entry
  *
@@ -75,6 +77,7 @@ typedef ACE_Hash_Map_Manager_Ex<
   ACE_Equal_To<PortableServer::ObjectId>,
   ACE_Null_Mutex> TAO_PG_ObjectGroup_Map;
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 
