@@ -1,9 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file    PG_Object_Adapter_Factory.h
  *
- *  PG_Object_Adapter_Factory.h,v 1.2 2005/02/18 09:07:08 jwillemsen Exp
+ *  $Id: PG_Object_Adapter_Factory.h 71526 2006-03-14 06:14:35Z jtc $
  *
  *  @author  Johnny Willemsen
  */
@@ -13,7 +14,7 @@
 #define TAO_PG_OBJECT_ADAPTER_FACTORY_H
 #include /**/ "ace/pre.h"
 
-#include "portablegroup_export.h"
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
 
 #include "tao/PortableServer/Object_Adapter_Factory.h"
 #include "tao/orbconf.h"
@@ -24,6 +25,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_PortableGroup_Export TAO_PG_Object_Adapter_Factory : public TAO_Object_Adapter_Factory
 {
 public:
@@ -34,6 +37,8 @@ public:
   virtual TAO_Adapter *create (TAO_ORB_Core *orb_core);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 ACE_STATIC_SVC_DECLARE (TAO_PG_Object_Adapter_Factory)
 ACE_FACTORY_DECLARE (TAO_PortableGroup, TAO_PG_Object_Adapter_Factory)
 
