@@ -1,4 +1,4 @@
-// $Id: PG_Object_Group.cpp 77001 2007-02-12 07:54:49Z johnnyw $
+// $Id: PG_Object_Group.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "orbsvcs/PortableGroup/PG_Object_Group.h"
 #include "orbsvcs/PortableGroup/PG_conf.h"
@@ -12,18 +12,6 @@
 #include "ace/Vector_T.h"
 
 
-// Borland Developer Studio 2006 and earlier give a warning about comparing
-// signed and unsigned values in the minimum_polulate() and
-// initial_populate() warnings. The comparison uses a unsigned long and
-// unsigned short and it seems that the compiler promotes the unsigned
-// short of an int and this then gives the warning. Just for Borland
-// disabled the warning in this file.
-#if defined (__BORLANDC__) && (__BORLANDC__ <= 0x582)
-# pragma option push -w-csu
-# pragma nopushoptwarn
-# pragma nopackwarning
-#endif /* __BORLANDC__ && __BORLANDC__ <= 0x582 */
-
 #define TODO int todo;
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -240,7 +228,7 @@ TAO::PG_Object_Group::add_member (const PortableGroup::Location & the_location,
   if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT("PG (%P|%t) exit Object_Group add_member \n")));
+                  ACE_TEXT("PG (%P|%t) exit Object_Group add_member\n")));
     }
 }
 
@@ -809,9 +797,3 @@ TAO::PG_Object_Group::has_member_at (const PortableGroup::Location & location)
 
 TAO_END_VERSIONED_NAMESPACE_DECL
 
-// Restore original compiler flags.
-#if defined (__BORLANDC__) && (__BORLANDC__ <= 0x582)
-# pragma option pop
-# pragma nopushoptwarn
-# pragma nopackwarning
-#endif /* __BORLANDC__ && __BORLANDC__ <= 0x582 */
