@@ -4,21 +4,24 @@
 /**
  * @file PG_Object_Group_Manipulator.cpp
  *
- * PG_Object_Group_Manipulator.cpp,v 1.6 2005/01/27 19:44:47 jtc Exp
+ * $Id: PG_Object_Group_Manipulator.cpp 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Dale Wilson <wilson_d@ociweb.com>
  */
 //=============================================================================
 
-#include "PG_Object_Group_Manipulator.h"
-#include "PG_Utils.h"
+#include "orbsvcs/PortableGroup/PG_Object_Group_Manipulator.h"
+#include "orbsvcs/PortableGroup/PG_Utils.h"
 
 #include "tao/debug.h"
 #include <ace/OS_NS_stdio.h>
 
 ACE_RCSID (PortableGroup,
            PG_Object_Group_Manipulator,
-           "PG_Object_Group_Manipulator.cpp,v 1.6 2005/01/27 19:44:47 jtc Exp")
+           "$Id: PG_Object_Group_Manipulator.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO::PG_Object_Group_Manipulator::PG_Object_Group_Manipulator ()
   : orb_ (CORBA::ORB::_nil ())
@@ -60,18 +63,15 @@ PortableGroup::ObjectGroup_ptr
 TAO::PG_Object_Group_Manipulator::create_object_group (
   const char * type_id,
   const char * domain_id,
-  PortableGroup::ObjectGroupId & group_id
-  ACE_ENV_ARG_DECL)
+  PortableGroup::ObjectGroupId & group_id)
 {
    allocate_ogid(group_id);
    PortableServer::ObjectId_var oid = convert_ogid_to_oid (group_id);
 
   // Create a reference for the ObjectGroup
   CORBA::Object_var object_group =
-    this->poa_->create_reference_with_id (ACE_U64_TO_U32 (group_id),
-                                          type_id
-                                          ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CORBA::Object::_nil ());
+    this->poa_->create_reference_with_id (oid.in(),
+                                          type_id);
 
   PortableGroup::TagGroupTaggedComponent tag_component;
 
@@ -84,15 +84,13 @@ TAO::PG_Object_Group_Manipulator::create_object_group (
   // Set the property
   TAO::PG_Utils::set_tagged_component (object_group,
                                        tag_component);
-  ACE_CHECK_RETURN (CORBA::Object::_nil ());
 
   return object_group._retn ();
 }
 
 void
-TAO::PG_Object_Group_Manipulator::init (CORBA::ORB_ptr orb, 
-                                        PortableServer::POA_ptr poa 
-                                        ACE_ENV_ARG_DECL)
+TAO::PG_Object_Group_Manipulator::init (CORBA::ORB_ptr orb,
+                                        PortableServer::POA_ptr poa)
 {
   ACE_ASSERT (CORBA::is_nil (this->orb_.in ()) && !CORBA::is_nil (orb));
   this->orb_ = CORBA::ORB::_duplicate (orb);
@@ -102,43 +100,37 @@ TAO::PG_Object_Group_Manipulator::init (CORBA::ORB_ptr orb,
 
   // Get an object reference for the ORBs IORManipulation object!
   CORBA::Object_var IORM = this->orb_->resolve_initial_references (
-    TAO_OBJID_IORMANIPULATION, 0 ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    TAO_OBJID_IORMANIPULATION, 0);
 
   this->iorm_ = TAO_IOP::TAO_IOR_Manipulation::_narrow (
-    IORM.in () ACE_ENV_ARG_PARAMETER);
-//  ACE_CHECK;
+    IORM.in ());
 }
 
 int TAO::PG_Object_Group_Manipulator::set_primary (
       TAO_IOP::TAO_IOR_Property * prop,
       PortableGroup::ObjectGroup_ptr group,
-      CORBA::Object_ptr new_primary
-      ACE_ENV_ARG_DECL) const
+      CORBA::Object_ptr new_primary) const
 {
-  int sts = this->iorm_->is_primary_set (prop, group ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (0);
+  int sts = this->iorm_->is_primary_set (prop, group);
   if (sts)
   {
-    (void)this->iorm_->remove_primary_tag (prop, group ACE_ENV_ARG_PARAMETER);
-    ACE_CHECK_RETURN (0);
+    (void)this->iorm_->remove_primary_tag (prop, group);
   }
   /////note: iorm takes it's parameters in the "wrong" order for this call
-  return this->iorm_->set_primary (prop, new_primary, group ACE_ENV_ARG_PARAMETER);
+  return this->iorm_->set_primary (prop, new_primary, group);
 }
 
 PortableGroup::ObjectGroup_ptr TAO::PG_Object_Group_Manipulator::merge_iors(
-  TAO_IOP::TAO_IOR_Manipulation::IORList & list ACE_ENV_ARG_DECL) const
+  TAO_IOP::TAO_IOR_Manipulation::IORList & list) const
 {
-  return this->iorm_->merge_iors (list ACE_ENV_ARG_PARAMETER);
+  return this->iorm_->merge_iors (list);
 }
 
 PortableGroup::ObjectGroup_ptr TAO::PG_Object_Group_Manipulator::remove_profiles(
       PortableGroup::ObjectGroup_ptr group,
-      PortableGroup::ObjectGroup_ptr profile
-      ACE_ENV_ARG_DECL) const
+      PortableGroup::ObjectGroup_ptr profile) const
 {
-  return this->iorm_->remove_profiles(group, profile ACE_ENV_ARG_PARAMETER);
+  return this->iorm_->remove_profiles(group, profile);
 }
 
 void dump_membership (const char * label, PortableGroup::ObjectGroup_ptr member)
@@ -184,8 +176,4 @@ void dump_membership (const char * label, PortableGroup::ObjectGroup_ptr member)
 #endif
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
