@@ -4,7 +4,7 @@
 /**
  * @file PG_Object_Group_Manipulator.h
  *
- * PG_Object_Group_Manipulator.h,v 1.6 2004/08/16 23:53:14 jtc Exp
+ * $Id: PG_Object_Group_Manipulator.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Dale Wilson <wilson_d@ociweb.com>
  */
@@ -15,15 +15,19 @@
 #define TAO_PG_OBJECT_GROUP_MANIPULATOR_H
 
 #include /**/ "ace/pre.h"
-#include "orbsvcs/PortableGroupS.h"
+
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "portablegroup_export.h"
+#include "orbsvcs/PortableGroupS.h"
+
 #include "tao/IORManipulation/IORManip_Loader.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
 
@@ -49,8 +53,7 @@ namespace TAO
      * Initializes the group creator.
      */
     void init (CORBA::ORB_ptr orb,
-               PortableServer::POA_ptr poa
-               ACE_ENV_ARG_DECL);
+               PortableServer::POA_ptr poa);
 
     /**
      * Create an empty object group.
@@ -58,23 +61,19 @@ namespace TAO
     PortableGroup::ObjectGroup_ptr create_object_group (
       const char * type_id,
       const char * domain_id,
-      PortableGroup::ObjectGroupId & group_id
-      ACE_ENV_ARG_DECL);
+      PortableGroup::ObjectGroupId & group_id);
 
     PortableGroup::ObjectGroup_ptr remove_profiles (
       PortableGroup::ObjectGroup_ptr group,
-      PortableGroup::ObjectGroup_ptr profile
-      ACE_ENV_ARG_DECL) const;
+      PortableGroup::ObjectGroup_ptr profile) const;
 
     PortableGroup::ObjectGroup_ptr merge_iors (
-      TAO_IOP::TAO_IOR_Manipulation::IORList & iors
-      ACE_ENV_ARG_DECL) const;
+      TAO_IOP::TAO_IOR_Manipulation::IORList & iors) const;
 
     int set_primary (
       TAO_IOP::TAO_IOR_Property * prop,
       PortableGroup::ObjectGroup_ptr reference,
-      CORBA::Object_ptr new_primary
-      ACE_ENV_ARG_DECL) const;
+      CORBA::Object_ptr new_primary) const;
 
   void dump_membership (const char * label,
                         PortableGroup::ObjectGroup_ptr member) const;
@@ -112,6 +111,7 @@ namespace TAO
   };
 } //namespace TAO
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 
