@@ -1,9 +1,11 @@
-#include "PG_Operators.h"
+#include "orbsvcs/PortableGroup/PG_Operators.h"
 #include "ace/OS_NS_string.h"
 
 ACE_RCSID (PortableGroup,
            PG_Operators,
-           "PG_Operators.cpp,v 1.3 2004/04/23 06:19:12 ossama Exp")
+           "$Id: PG_Operators.cpp 71526 2006-03-14 06:14:35Z jtc $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 bool
 operator== (const CosNaming::Name & lhs, const CosNaming::Name & rhs)
@@ -27,3 +29,5 @@ operator!= (const CosNaming::Name & lhs, const CosNaming::Name & rhs)
 {
   return !(lhs == rhs);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
