@@ -5,7 +5,7 @@
 /**
  * @file PG_Operators.h
  *
- * PG_Operators.h,v 1.7 2004/08/16 23:53:14 jtc Exp
+ * $Id: PG_Operators.h 71526 2006-03-14 06:14:35Z jtc $
  *
  * @author Ossama Othman <ossama@uci.edu>
  */
@@ -17,7 +17,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "portablegroup_export.h"
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #pragma once
@@ -25,6 +25,8 @@
 
 #include "orbsvcs/CosNamingC.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /// Global CosNaming::Name equality operator.
 /**
  * Used for checking equality of PortableGroup::Location and
@@ -41,6 +43,7 @@ bool TAO_PortableGroup_Export operator== (const CosNaming::Name & lhs,
 bool TAO_PortableGroup_Export operator!= (const CosNaming::Name & lhs,
                                           const CosNaming::Name & rhs);
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 
