@@ -1,9 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file    PG_Properties_Support.cpp
  *
- *  PG_Properties_Support.cpp,v 1.5 2005/04/18 11:32:11 jwillemsen Exp
+ *  $Id: PG_Properties_Support.cpp 77001 2007-02-12 07:54:49Z johnnyw $
  *
  *  This file implements classes to help manage PortableGroup::Properties
  *
@@ -11,7 +12,9 @@
  */
 //=============================================================================
 
-#include "PG_Properties_Support.h"
+#include "orbsvcs/PortableGroup/PG_Properties_Support.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO::PG_Properties_Support::PG_Properties_Support ()
 {
@@ -23,39 +26,27 @@ TAO::PG_Properties_Support::~PG_Properties_Support ()
 }
 
 void TAO::PG_Properties_Support::set_default_property (const char * name,
-      const PortableGroup::Value & value
-      ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+      const PortableGroup::Value & value)
 {
-  this->default_properties_.set_property(name, value ACE_ENV_ARG_PARAMETER);
+  this->default_properties_.set_property(name, value);
 }
 
-void TAO::PG_Properties_Support::set_default_properties (const PortableGroup::Properties & props
-    ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+void TAO::PG_Properties_Support::set_default_properties (const PortableGroup::Properties & props)
 {
-  this->default_properties_.decode (props ACE_ENV_ARG_PARAMETER);
+  this->default_properties_.decode (props);
 }
 
 PortableGroup::Properties *
-TAO::PG_Properties_Support::get_default_properties (
-      ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((
-    CORBA::SystemException,
-    PortableGroup::InvalidProperty,
-    PortableGroup::UnsupportedProperty))
+TAO::PG_Properties_Support::get_default_properties ()
 {
   PortableGroup::Properties_var result;
   ACE_NEW_THROW_EX ( result, PortableGroup::Properties(), CORBA::NO_MEMORY());
-  ACE_CHECK_RETURN (0);
   this->default_properties_.export_properties (*result);
   return result._retn ();
 }
 
 void TAO::PG_Properties_Support::remove_default_properties (
-    const PortableGroup::Properties & props
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    const PortableGroup::Properties & props)
 {
   this->default_properties_.remove (props);
 }
@@ -63,11 +54,7 @@ void TAO::PG_Properties_Support::remove_default_properties (
 void
 TAO::PG_Properties_Support::set_type_properties (
     const char *type_id,
-    const PortableGroup::Properties & overrides
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ( (CORBA::SystemException,
-                   PortableGroup::InvalidProperty,
-                   PortableGroup::UnsupportedProperty))
+    const PortableGroup::Properties & overrides)
 {
   ACE_GUARD (TAO_SYNCH_MUTEX, guard, this->internals_);
 
@@ -81,14 +68,12 @@ TAO::PG_Properties_Support::set_type_properties (
     this->properties_map_.bind (type_id, typeid_properties);
   }
   typeid_properties->clear ();
-  typeid_properties->decode (overrides ACE_ENV_ARG_PARAMETER);
+  typeid_properties->decode (overrides);
 }
 
 PortableGroup::Properties *
 TAO::PG_Properties_Support::get_type_properties (
-    const char *type_id
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ( (CORBA::SystemException))
+    const char *type_id)
 {
   PortableGroup::Properties_var result;
   ACE_NEW_THROW_EX (result, PortableGroup::Properties(), CORBA::NO_MEMORY ());
@@ -106,9 +91,7 @@ TAO::PG_Properties_Support::get_type_properties (
 void
 TAO::PG_Properties_Support::remove_type_properties (
     const char *type_id,
-    const PortableGroup::Properties & props
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ( (CORBA::SystemException))
+    const PortableGroup::Properties & props)
 {
   // NOTE: do not actually delete the properties for this type.
   // There may be object groups depending on these.
@@ -127,9 +110,7 @@ TAO::PG_Properties_Support::remove_type_properties (
 
 TAO::PG_Property_Set *
 TAO::PG_Properties_Support::find_typeid_properties (
-    const char *type_id
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    const char *type_id)
 {
   ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, guard, this->internals_, 0);
 
@@ -145,29 +126,4 @@ TAO::PG_Properties_Support::find_typeid_properties (
   return typeid_properties;
 }
 
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-  template class ACE_Hash_Map_Manager<
-    ACE_CString,
-    ::TAO::PG_Property_Set *,
-    TAO_SYNCH_MUTEX>;
-
-  template class ACE_Hash_Map_Iterator<
-    ACE_CString,
-    ::TAO::PG_Property_Set *,
-    TAO_SYNCH_MUTEX>;
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-# pragma instantiate ACE_Hash_Map_Manager<
-    ACE_CString,
-    ::TAO::PG_Property_Set *,
-    TAO_SYNCH_MUTEX>
-
-# pragma instantiate ACE_Hash_Map_Iterator<
-    ACE_CString,
-    ::TAO::PG_Property_Set *,
-    TAO_SYNCH_MUTEX>
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
