@@ -1,4 +1,4 @@
-#include "PG_Utils.h"
+#include "orbsvcs/PortableGroup/PG_Utils.h"
 
 #include "tao/MProfile.h"
 #include "tao/Profile.h"
@@ -11,8 +11,9 @@
 
 ACE_RCSID (PortableGroup,
            PG_Utils,
-           "PG_Utils.cpp,v 1.6 2005/01/30 08:20:58 ossama Exp")
+           "$Id: PG_Utils.cpp 71526 2006-03-14 06:14:35Z jtc $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -171,3 +172,5 @@ namespace TAO
     return cdr.good_bit ();
   }
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
