@@ -4,7 +4,7 @@
 /**
  *  @file     PortableGroup_Loader.h
  *
- *  $Id: PortableGroup_Loader.h 77080 2007-02-12 19:43:29Z johnnyw $
+ *  $Id: PortableGroup_Loader.h 84304 2009-02-02 18:47:53Z johnnyw $
  *
  *  Loads and initializes the PortableGroup extensions to TAO.
  *
@@ -47,7 +47,7 @@ public:
   TAO_PortableGroup_Loader (void);
 
   /// Initialize the PortableGroup loader hooks.
-  virtual int init (int argc, char *[]);
+  virtual int init (int argc, ACE_TCHAR *[]);
 
   /// Used to force the initialization of the ORB code.
   static int Initializer (void);
