@@ -4,7 +4,7 @@
 /**
  *  @file PortableGroup_ORBInitializer.h
  *
- *  $Id: PortableGroup_ORBInitializer.h 77001 2007-02-12 07:54:49Z johnnyw $
+ *  $Id: PortableGroup_ORBInitializer.h 81490 2008-04-28 14:32:24Z johnnyw $
  *
  *  @author Frank Hunleth <fhunleth@cs.wustl.edu>
  */
@@ -37,7 +37,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// PortableGroup ORB initializer.
 class TAO_PortableGroup_Export TAO_PortableGroup_ORBInitializer :
   public virtual PortableInterceptor::ORBInitializer,
-  public virtual TAO_Local_RefCounted_Object
+  public virtual ::CORBA::LocalObject
 {
 public:
   virtual void pre_init (PortableInterceptor::ORBInitInfo_ptr info);
