@@ -1,4 +1,4 @@
-// $Id: PortableGroup_Request_Dispatcher.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: PortableGroup_Request_Dispatcher.cpp 84230 2009-01-23 23:07:35Z mitza $
 
 #include "orbsvcs/PortableGroup/UIPMC_Profile.h"
 #include "orbsvcs/PortableGroup/PortableGroup_Request_Dispatcher.h"
@@ -9,7 +9,7 @@
 
 ACE_RCSID (PortableGroup,
            PortableGroup_Request_Dispatcher,
-           "$Id: PortableGroup_Request_Dispatcher.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: PortableGroup_Request_Dispatcher.cpp 84230 2009-01-23 23:07:35Z mitza $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -48,9 +48,9 @@ PortableGroup_Request_Dispatcher::dispatch (TAO_ORB_Core *orb_core,
     }
 
   // Dispatch based on object key.
-  orb_core->adapter_registry ()->dispatch (request.object_key (),
-                                           request,
-                                           forward_to);
+  orb_core->adapter_registry ().dispatch (request.object_key (),
+                                          request,
+                                          forward_to);
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
