@@ -4,7 +4,7 @@
 /**
  *  @file   Portable_Group_Map.h
  *
- *  Portable_Group_Map.h,v 1.14 2005/07/16 15:38:42 schmidt Exp
+ *  $Id: Portable_Group_Map.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  *  @author Frank Hunleth <fhunleth@cs.wustl.edu>
  */
@@ -14,19 +14,22 @@
 #define TAO_PORTABLE_GROUP_MAP_H
 
 #include /**/ "ace/pre.h"
-#include "ace/Null_Mutex.h"
+
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "ace/Hash_Map_Manager_T.h"
-
-#include "portablegroup_export.h"
 #include "orbsvcs/PortableGroupC.h"
 
 #include "tao/Object_KeyC.h"
 
+#include "ace/Null_Mutex.h"
+#include "ace/Hash_Map_Manager_T.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_ServerRequest;
 
 /**
@@ -92,22 +95,19 @@ public:
   /// Add a GroupId->ObjectKey mapping to the map.
   /// This function takes ownership of the memory pointed to be group_id
   void add_groupid_objectkey_pair (PortableGroup::TagGroupTaggedComponent *group_id,
-                                   const TAO::ObjectKey &key
-                                   ACE_ENV_ARG_DECL);
+                                   const TAO::ObjectKey &key);
 
 
   /// Remove a GroupId->ObjectKey mapping from the map.
   void remove_groupid_objectkey_pair (const PortableGroup::TagGroupTaggedComponent* group_id,
-                                      const TAO::ObjectKey &key
-                                      ACE_ENV_ARG_DECL);
+                                      const TAO::ObjectKey &key);
 
   /// Dispatch a request to all of the ObjectIds that belong to
   /// the specified group.
   void dispatch (PortableGroup::TagGroupTaggedComponent* group_id,
                                     TAO_ORB_Core *orb_core,
                                     TAO_ServerRequest &request,
-                                    CORBA::Object_out forward_to
-                                    ACE_ENV_ARG_DECL);
+                                    CORBA::Object_out forward_to);
 
   /// Id hash map.
   typedef ACE_Hash_Map_Manager_Ex<
@@ -126,6 +126,8 @@ protected:
   GroupId_Table map_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 //#if defined (__ACE_INLINE__)
 //# include "Portable_Group_Map.i"
 //#endif /* __ACE_INLINE__ */
