@@ -4,7 +4,7 @@
 /**
  *  @file     UIPMC_Acceptor.h
  *
- *  UIPMC_Acceptor.h,v 1.9 2004/09/30 21:08:06 irfan Exp
+ *  $Id: UIPMC_Acceptor.h 79015 2007-07-24 15:03:04Z vridosh $
  *
  *  MIOP specific acceptor processing
  *
@@ -17,21 +17,22 @@
 
 #include /**/ "ace/pre.h"
 
-#include "tao/Transport_Acceptor.h"
+#include "orbsvcs/PortableGroup/UIPMC_Mcast_Connection_Handler.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "UIPMC_Connection_Handler.h"
-
+#include "tao/Transport_Acceptor.h"
 #include "tao/Acceptor_Impl.h"
 #include "tao/GIOP_Message_State.h"
 
 #include "ace/Acceptor.h"
 #include "ace/SOCK_Acceptor.h"
 
-#include "portablegroup_export.h"
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // TAO UIPMC_Acceptor concrete call defination
 
@@ -46,7 +47,7 @@ class TAO_PortableGroup_Export TAO_UIPMC_Acceptor : public TAO_Acceptor
 {
 public:
   /// Constructor.
-  TAO_UIPMC_Acceptor (CORBA::Boolean flag = 0);
+  TAO_UIPMC_Acceptor (void);
 
   /// Destructor.
   ~TAO_UIPMC_Acceptor (void);
@@ -146,11 +147,13 @@ protected:
 
 private:
 
-  TAO_UIPMC_Connection_Handler *connection_handler_;
+  TAO_UIPMC_Mcast_Connection_Handler *connection_handler_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(__ACE_INLINE__)
-#include "UIPMC_Acceptor.i"
+#include "orbsvcs/PortableGroup/UIPMC_Acceptor.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
