@@ -1,8 +1,7 @@
-// This may look like C, but it's really -*- C++ -*-
-//
-// UIPMC_Endpoint.cpp,v 1.10 2005/01/27 19:44:47 jtc Exp
+// $Id: UIPMC_Endpoint.cpp 79015 2007-07-24 15:03:04Z vridosh $
 
-#include "UIPMC_Endpoint.h"
+#include "orbsvcs/PortableGroup/UIPMC_Endpoint.h"
+#include "orbsvcs/PortableGroup/UIPMC_Profile.h"
 
 #include "tao/debug.h"
 #include "ace/Guard_T.h"
@@ -13,32 +12,38 @@
 
 ACE_RCSID (tao,
            UIPMC_Endpoint,
-           "UIPMC_Endpoint.cpp,v 1.10 2005/01/27 19:44:47 jtc Exp")
+           "$Id: UIPMC_Endpoint.cpp 79015 2007-07-24 15:03:04Z vridosh $")
 
 
 #if !defined (__ACE_INLINE__)
-# include "UIPMC_Endpoint.i"
+# include "orbsvcs/PortableGroup/UIPMC_Endpoint.inl"
 #endif /* __ACE_INLINE__ */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_UIPMC_Endpoint::TAO_UIPMC_Endpoint (void)
-  : TAO_Endpoint (TAO_TAG_UIPMC_PROFILE),
+  : TAO_Endpoint (IOP::TAG_UIPMC),
+    host_ (),
+    port_ (0),
     object_addr_ (),
     next_ (0)
 {
 }
 
-
 TAO_UIPMC_Endpoint::TAO_UIPMC_Endpoint (const ACE_INET_Addr &addr)
-  : TAO_Endpoint (TAO_TAG_UIPMC_PROFILE),
+  : TAO_Endpoint (IOP::TAG_UIPMC),
+    host_ (),
+    port_ (0),
     object_addr_ (addr),
     next_ (0)
 {
   this->object_addr (addr);
 }
 
+// Use of this ctr must be avoided
 TAO_UIPMC_Endpoint::TAO_UIPMC_Endpoint (const CORBA::Octet class_d_address[4],
                                         CORBA::UShort port)
-  : TAO_Endpoint (TAO_TAG_UIPMC_PROFILE),
+  : TAO_Endpoint (IOP::TAG_UIPMC),
     port_ (port),
     next_ (0)
 {
@@ -48,45 +53,51 @@ TAO_UIPMC_Endpoint::TAO_UIPMC_Endpoint (const CORBA::Octet class_d_address[4],
   this->update_object_addr ();
 }
 
-
 TAO_UIPMC_Endpoint::~TAO_UIPMC_Endpoint (void)
 {
-
 }
 
 void
 TAO_UIPMC_Endpoint::object_addr (const ACE_INET_Addr &addr)
 {
   this->port_ = addr.get_port_number();
-  this->uint_ip_addr (addr.get_ip_address ());
+  this->host_ = CORBA::string_dup (addr.get_host_addr ());
 
   this->object_addr_.set (addr);
 }
 
 const char *
-TAO_UIPMC_Endpoint::get_host_addr (void) const
+TAO_UIPMC_Endpoint::host (void) const
 {
-  return this->object_addr_.get_host_addr ();
+  return this->host_.in ();
 }
 
-
 int
 TAO_UIPMC_Endpoint::addr_to_string (char *buffer, size_t length)
 {
   size_t actual_len =
-    15                           // chars in dotted decimal addr
+    ACE_OS::strlen (this->object_addr_.get_host_addr ()) // chars in host name
     + sizeof (':')               // delimiter
     + 5                          // max port
     + sizeof ('\0');
 
+#if defined (ACE_HAS_IPV6)
+  if (this->object_addr_.get_type () == AF_INET6)
+    actual_len += 2; // '[' + ']'
+#endif /* ACE_HAS_IPV6 */
+
   if (length < actual_len)
     return -1;
 
-  ACE_OS::sprintf (buffer, "%d.%d.%d.%d:%d",
-                   this->class_d_address_[0],
-                   this->class_d_address_[1],
-                   this->class_d_address_[2],
-                   this->class_d_address_[3],
+#if defined (ACE_HAS_IPV6)
+  if (this->object_addr_.get_type () == AF_INET6)
+    ACE_OS::sprintf (buffer, "[%s]:%d",
+                     this->object_addr_.get_host_addr (),
+                     this->port_);
+  else
+#endif /* ACE_HAS_IPV6 */
+  ACE_OS::sprintf (buffer, "%s:%d",
+                   this->object_addr_.get_host_addr (),
                    this->port_);
 
   return 0;
@@ -113,15 +124,15 @@ TAO_UIPMC_Endpoint::duplicate (void)
 CORBA::Boolean
 TAO_UIPMC_Endpoint::is_equivalent (const TAO_Endpoint *other_endpoint)
 {
-  TAO_Endpoint *endpt = const_cast<TAO_Endpoint *> (other_endpoint);
+  const TAO_UIPMC_Endpoint *endpoint =
+    dynamic_cast<const TAO_UIPMC_Endpoint *> (other_endpoint);
 
-  TAO_UIPMC_Endpoint *endpoint = dynamic_cast<TAO_UIPMC_Endpoint *> (endpt);
   if (endpoint == 0)
     return 0;
 
   return
-    this->port_ == endpoint->port_
-    && ACE_OS::memcmp (this->class_d_address_, endpoint->class_d_address_, 4) == 0;
+    (this->port_ == endpoint->port_
+     && ACE_OS::strcmp (this->host (), endpoint->host ()) == 0);
 }
 
 CORBA::ULong
@@ -139,9 +150,10 @@ TAO_UIPMC_Endpoint::hash (void)
     if (this->hash_val_ != 0)
       return this->hash_val_;
 
-    this->hash_val_ =
-      this->uint_ip_addr () + this->port_;
+    this->hash_val_ = this->object_addr_.hash ();
   }
 
   return this->hash_val_;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
