@@ -4,7 +4,7 @@
 /**
  *  @file     UIPMC_Profile.h
  *
- *  UIPMC_Profile.h,v 1.15 2005/01/05 19:40:55 jwillemsen Exp
+ *  $Id: UIPMC_Profile.h 80273 2007-12-16 19:55:49Z johnnyw $
  *
  *  UIPMC profile specific processing
  *
@@ -17,22 +17,23 @@
 
 #include /**/ "ace/pre.h"
 
-#include "tao/Profile.h"
+#include "orbsvcs/PortableGroup/portablegroup_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/Object_KeyC.h"
-#include "tao/target_specification.h"
+#include "orbsvcs/PortableGroup/UIPMC_Endpoint.h"
 
 #include "orbsvcs/PortableGroupC.h"
 
-#include "UIPMC_Endpoint.h"
-#include "portablegroup_export.h"
+#include "tao/Object_KeyC.h"
+#include "tao/target_specification.h"
+#include "tao/Profile.h"
 
 #include "ace/SString.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // TAO UIPMC_Profile concrete Profile definitions
 /**
@@ -44,7 +45,7 @@
  * This class defines the UIPMC profile as specified in the CORBA
  * specification.
  *
- * @NOTE: This class inherits the ObjectKey from TAO_Profile which may
+ * @note This class inherits the ObjectKey from TAO_Profile which may
  *  not be needed at all! But lets punt on this for the timebeing.
  */
 class TAO_PortableGroup_Export TAO_UIPMC_Profile : public TAO_Profile
@@ -66,36 +67,36 @@ public:
   TAO_UIPMC_Profile (const ACE_INET_Addr &addr,
                      TAO_ORB_Core *orb_core);
 
-  ///  Profile constructor.
+  ///  Profile constructor.  @@ Vadym - deprecate this.
   TAO_UIPMC_Profile (const CORBA::Octet class_d_address[4],
                      CORBA::UShort port,
                      TAO_ORB_Core *orb_core);
 
   /// Create object using a string ior.
   TAO_UIPMC_Profile (const char *string,
-                     TAO_ORB_Core *orb_core
-                     ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+                     TAO_ORB_Core *orb_core);
 
   /// Destructor is to be called only through <_decr_refcnt>.
   ~TAO_UIPMC_Profile (void);
 
   /// Template methods. Please see tao/Profile.h for documentation.
-  virtual void parse_string (const char *string
-                             ACE_ENV_ARG_DECL);
-  virtual char * to_string (ACE_ENV_SINGLE_ARG_DECL);
+
+  /// N.B. We have to override the TAO_Profile default decode because
+  /// in UIPMC there is no object key marshalled and we do not implement
+  /// a useable ::decode_endpoints
+  virtual int decode (TAO_InputCDR& cdr);
+  virtual void parse_string (const char *string);
+  virtual char * to_string (void);
   virtual int encode_endpoints (void);
   virtual TAO_Endpoint *endpoint (void);
   virtual CORBA::ULong endpoint_count (void) const;
-  virtual CORBA::ULong hash (CORBA::ULong max
-                             ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+  virtual CORBA::ULong hash (CORBA::ULong max);
   virtual IOP::TaggedProfile &create_tagged_profile (void);
   virtual void request_target_specifier (
                       TAO_Target_Specification &target_spec,
-                      TAO_Target_Specification::TAO_Target_Address r
-                      ACE_ENV_ARG_DECL);
+                      TAO_Target_Specification::TAO_Target_Address r);
   virtual int supports_multicast (void) const;
-  virtual void addressing_mode (CORBA::Short addr_mode
-                                ACE_ENV_ARG_DECL);
+  virtual void addressing_mode (CORBA::Short addr_mode);
   static int extract_group_component (const IOP::TaggedProfile &profile,
                                       PortableGroup::TagGroupTaggedComponent &group);
 
@@ -109,8 +110,7 @@ protected:
   /// Template methods, please see documentation in tao/Profile.h
   virtual int decode_profile (TAO_InputCDR& cdr);
   virtual int decode_endpoints (void);
-  virtual void parse_string_i (const char *
-                               ACE_ENV_ARG_DECL);
+  virtual void parse_string_i (const char *);
   virtual void create_profile_body (TAO_OutputCDR &cdr) const;
   virtual CORBA::Boolean do_is_equivalent (const TAO_Profile *other_profile);
   virtual void update_cached_group_component (void);
@@ -134,9 +134,6 @@ protected:
    */
   TAO_UIPMC_Endpoint endpoint_;
 
-  /// Number of endpoints in the list headed by <endpoint_>.
-  CORBA::ULong count_;
-
 private:
 
   /// Cached version of our tagged profile.
@@ -151,7 +148,11 @@ private:
   /// The group reference's version.
   PortableGroup::ObjectGroupRefVersion ref_version_;
 
+  /// A sign whether ref_version is really present
+  bool has_ref_version_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif  /* TAO_UIPMC_PROFILE_H */
