@@ -1,4 +1,4 @@
-// $Id: UIPMC_Transport.cpp 80288 2007-12-17 20:05:04Z johnnyw $
+// $Id: UIPMC_Transport.cpp 86657 2009-09-08 10:46:19Z johnnyw $
 
 #ifndef TAO_UIPMC_TRANSPORT_CPP
 #define TAO_UIPMC_TRANSPORT_CPP
@@ -22,7 +22,7 @@
 
 ACE_RCSID (PortableGroup,
            UIPMC_Transport,
-           "$Id: UIPMC_Transport.cpp 80288 2007-12-17 20:05:04Z johnnyw $")
+           "$Id: UIPMC_Transport.cpp 86657 2009-09-08 10:46:19Z johnnyw $")
 
 // Local MIOP Definitions:
 
@@ -160,7 +160,7 @@ TAO_UIPMC_Transport<CONNECTION_HANDLER>::send (iovec *iov, int iovcnt,
      bytes_to_send += iov[i].iov_len;
 
   MIOP_Packet fragments[MIOP_MAX_FRAGMENTS];
-  MIOP_Packet *current_fragment;
+  MIOP_Packet *current_fragment = 0;
   int num_fragments = 1;
 
   UIPMC_Message_Block_Data_Iterator mb_iter (iov, iovcnt);
@@ -168,7 +168,7 @@ TAO_UIPMC_Transport<CONNECTION_HANDLER>::send (iovec *iov, int iovcnt,
   // Initialize the first fragment
   current_fragment = &fragments[0];
   current_fragment->iovcnt = 1;  // The MIOP Header
-  current_fragment->length = MIOP_HEADER_SIZE;
+  current_fragment->length = 0;
 
   // Go through all of the message blocks.
   while (mb_iter.next_block (MIOP_MAX_DGRAM_SIZE - current_fragment->length,
@@ -184,7 +184,7 @@ TAO_UIPMC_Transport<CONNECTION_HANDLER>::send (iovec *iov, int iovcnt,
           current_fragment->iovcnt == ACE_IOV_MAX)
         {
           // Make a new fragment.
-          num_fragments++;
+          ++num_fragments;
 
           // Check if too many fragments
           if (num_fragments > MIOP_MAX_FRAGMENTS)
@@ -213,9 +213,9 @@ TAO_UIPMC_Transport<CONNECTION_HANDLER>::send (iovec *iov, int iovcnt,
             }
 
           // Otherwise, initialize another fragment.
-          current_fragment++;
+          ++current_fragment;
           current_fragment->iovcnt = 1;  // The MIOP Header
-          current_fragment->length = MIOP_HEADER_SIZE;
+          current_fragment->length = 0;
         }
     }
 
@@ -403,7 +403,7 @@ TAO_UIPMC_Transport<CONNECTION_HANDLER>::recv (char *buf,
     }
 
   // Trim off the header for now.
-  ssize_t miop_header_size = (MIOP_ID_CONTENT_OFFSET + id_length + 7) & ~0x7;
+  ssize_t const miop_header_size = (MIOP_ID_CONTENT_OFFSET + id_length + 7) & ~0x7;
   if (miop_header_size > n)
     {
       if (TAO_debug_level > 0)
@@ -566,7 +566,7 @@ TAO_UIPMC_Transport<CONNECTION_HANDLER>::send_message (TAO_OutputCDR &stream,
                                                        ACE_Time_Value *max_wait_time)
 {
   // Format the message in the stream first
-  if (this->messaging_object_->format_message (stream) != 0)
+  if (this->messaging_object ()->format_message (stream, stub) != 0)
     return -1;
 
   // Strictly speaking, should not need to loop here because the
