@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file   RTCosScheduling_PCP_Manager.h
  *
- *  RTCosScheduling_PCP_Manager.h,v 1.6 2005/03/10 14:08:42 jwillemsen Exp
+ *  $Id: RTCosScheduling_PCP_Manager.h 80177 2007-12-03 18:07:04Z sowayaa $
  *
  *  @author Matt Murphy <murphym@cs.uri.edu>
  *  @author based upon work by Greg Cooper
@@ -32,11 +32,7 @@
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
-#if defined (__BORLANDC__)
-#pragma option push -w-rvl -w-rch -w-ccc -w-inl
-#endif /* __BORLANDC__ */
-
-
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO {
 
@@ -130,7 +126,7 @@ class CosSchedulingLockList
    */
   CosSchedulingLockList(CosSchedulingLockNode *lock_array,
                         const int size,
-                        ACE_SYNCH_MUTEX *mutex);
+                        TAO_SYNCH_MUTEX *mutex);
 
   /**
    * Calls ACE_Thread::remove() on all conditions in the list;
@@ -162,7 +158,7 @@ class CosSchedulingLockList
    * @param mutex The mutex that guards the locks.
    */
   int defer_lock(const CosSchedulingLockNode& L,
-    ACE_SYNCH_MUTEX &mutex);
+    TAO_SYNCH_MUTEX &mutex);
 
   /**
    * Removes a node from the granted lock list whose threadID_
@@ -228,7 +224,7 @@ public:
    * @param mutex The mutex to guard the locks.
    */
   PCP_Manager(CosSchedulingLockList *locks,
-              ACE_SYNCH_MUTEX *mutex,
+              TAO_SYNCH_MUTEX *mutex,
               const RTCORBA::Current_var current);
 
   /**
@@ -253,7 +249,7 @@ public:
   private:
   int                   threadID_;  /// ID of thread owning this object
   CosSchedulingLockList *locks_;     /// combined list of locks
-  ACE_SYNCH_MUTEX       *mutex_;     /// Mutex to guard lock list
+  TAO_SYNCH_MUTEX       *mutex_;     /// Mutex to guard lock list
   RTCORBA::Current_var  current_; /// reference to set local priority
 
 };
@@ -287,18 +283,19 @@ public:
 
   private:
   CosSchedulingLockList *locks_;      /// lists of granted and pending locks
-  ACE_SYNCH_MUTEX       mutex_;       /// The mutex for locking the lock list
+  TAO_SYNCH_MUTEX       mutex_;       /// The mutex for locking the lock list
   ACE_Shared_Memory_MM  mem_;         /// shared memory space
   char                  *shm_key_;    /// Key for shared memory
   CosSchedulingLockNode *lock_array_; /// The lock list
 
 };
 
-
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "RTCosScheduling_PCP_Manager.i"
+#include "orbsvcs/RTCosScheduling/RTCosScheduling_PCP_Manager.inl"
 #endif /* __ACE_INLINE__ */
 
 
@@ -306,9 +303,5 @@ public:
 #pragma warning(pop)
 #endif /* _MSC_VER */
 
-#if defined (__BORLANDC__)
-#pragma option pop
-#endif /* __BORLANDC__ */
-
 #include /**/ "ace/post.h"
 #endif /* PCP_MANAGER_H */
