@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    RTCosScheduling_ServerScheduler_i.h
  *
- *  RTCosScheduling_ServerScheduler_i.h,v 1.13 2005/06/14 10:22:55 jwillemsen Exp
+ *  $Id: RTCosScheduling_ServerScheduler_i.h 79589 2007-09-06 10:32:54Z johnnyw $
  *
  *  @author Matt Murphy <murphym@cs.uri.edu>
  */
@@ -23,7 +23,7 @@
 #include "ace/SString.h"
 #include <orbsvcs/RTCosSchedulingS.h>
 #include <orbsvcs/RTCosScheduling/RTCosScheduling_export.h>
-#include "RTCosScheduling_PCP_Manager.h"
+#include "orbsvcs/RTCosScheduling/RTCosScheduling_PCP_Manager.h"
 #include "tao/PortableInterceptorC.h"
 #include "tao/CodecFactory/CodecFactory.h"
 #include "tao/LocalObject.h"
@@ -35,10 +35,7 @@
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
-#if defined (__BORLANDC__)
-#pragma option push -w-rvl -w-rch -w-ccc -w-inl
-#endif /* __BORLANDC__ */
-
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 #ifndef RTCOSSCHEDULING_SERVER_CONTAINERS
 #define RTCOSSCHEDULING_SERVER_CONTAINERS
@@ -121,45 +118,24 @@ typedef ACE_Hash_Map_Manager_Ex_Adapter<
 
     virtual ~RTCosScheduling_ServerScheduler_Interceptor();
 
-    virtual char* name(ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC((
-      CORBA::SystemException));
+    virtual char* name(void);
 
-    virtual void destroy( ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-     ACE_THROW_SPEC((CORBA::SystemException));
+    virtual void destroy();
 
     virtual void receive_request(
-        PortableInterceptor::ServerRequestInfo_ptr ri
-        ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC((
-        CORBA::SystemException,
-        PortableInterceptor::ForwardRequest));
+        PortableInterceptor::ServerRequestInfo_ptr ri);
 
     virtual void receive_request_service_contexts(
-        PortableInterceptor::ServerRequestInfo_ptr ri
-        ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC((
-        CORBA::SystemException,
-        PortableInterceptor::ForwardRequest));
+        PortableInterceptor::ServerRequestInfo_ptr ri);
 
     virtual void send_reply(
-        PortableInterceptor::ServerRequestInfo_ptr ri
-        ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC((CORBA::SystemException));
+        PortableInterceptor::ServerRequestInfo_ptr ri);
 
     virtual void send_exception(
-        PortableInterceptor::ServerRequestInfo_ptr ri
-        ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC((
-        CORBA::SystemException,
-        PortableInterceptor::ForwardRequest));
+        PortableInterceptor::ServerRequestInfo_ptr ri);
 
     virtual void send_other(
-        PortableInterceptor::ServerRequestInfo_ptr ri
-        ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-      ACE_THROW_SPEC((
-        CORBA::SystemException,
-        PortableInterceptor::ForwardRequest));
+        PortableInterceptor::ServerRequestInfo_ptr ri);
 
     void finish_execution();
 
@@ -231,12 +207,7 @@ typedef ACE_Hash_Map_Manager_Ex_Adapter<
         PortableServer::POA_ptr parent,
         const char * adapter_name,
         PortableServer::POAManager_ptr a_POAManager,
-        const CORBA::PolicyList & policies
-        ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC ((
-        CORBA::SystemException
-        , PortableServer::POA::AdapterAlreadyExists
-        , PortableServer::POA::InvalidPolicy));
+        const CORBA::PolicyList & policies);
 
     /**
      * This maps a CORBA::Object_var with a name.  The names are
@@ -247,10 +218,7 @@ typedef ACE_Hash_Map_Manager_Ex_Adapter<
      * @param name name to associate with the CORBA object reference
      */
     virtual void schedule_object (CORBA::Object_ptr obj,
-        const char * name
-        ACE_ENV_ARG_DECL)
-      ACE_THROW_SPEC (( CORBA::SystemException
-        , RTCosScheduling::UnknownName));
+        const char * name);
 
   private:
 
@@ -295,8 +263,10 @@ typedef ACE_Hash_Map_Manager_Ex_Adapter<
   };
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-#include "RTCosScheduling_ServerScheduler_i.i"
+#include "orbsvcs/RTCosScheduling/RTCosScheduling_ServerScheduler_i.inl"
 #endif /* __ACE_INLINE__ */
 
 
@@ -304,10 +274,5 @@ typedef ACE_Hash_Map_Manager_Ex_Adapter<
 #pragma warning(pop)
 #endif /* _MSC_VER */
 
-#if defined (__BORLANDC__)
-#pragma option pop
-#endif /* __BORLANDC__ */
-
-
 #include /**/ "ace/post.h"
 #endif /* SERVER_SCHEDULERI_H  */
