@@ -4,7 +4,7 @@
 /**
  *  @file    IIOP_SSL_Acceptor.h
  *
- *  IIOP_SSL_Acceptor.h,v 1.10 2005/02/28 14:04:36 john_c Exp
+ *  $Id: IIOP_SSL_Acceptor.h 78931 2007-07-18 09:59:36Z johnnyw $
  *
  *  SSL-aware IIOP specific acceptor processing
  *
@@ -18,7 +18,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "IIOP_SSL_Connection_Handler.h"
+#include "orbsvcs/SSLIOP/IIOP_SSL_Connection_Handler.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -26,6 +26,8 @@
 
 #include "tao/IIOP_Acceptor.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
 
@@ -50,7 +52,7 @@ namespace TAO
     typedef TAO_Accept_Strategy<IIOP_SSL_Connection_Handler, ACE_SOCK_ACCEPTOR> TAO_IIOP_SSL_ACCEPT_STRATEGY;
 
     /// Constructor.
-    IIOP_SSL_Acceptor (CORBA::Boolean flag = 0);
+    IIOP_SSL_Acceptor (void);
 
     /// Destructor.
     ~IIOP_SSL_Acceptor (void);
@@ -77,6 +79,8 @@ namespace TAO
 
 } // End TAO namespace.
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_IIOP_SSL_ACCEPTOR_H */
