@@ -4,7 +4,7 @@
 /**
  *  @file   IIOP_SSL_Connection_Handler.h
  *
- *  IIOP_SSL_Connection_Handler.h,v 1.9 2004/09/30 21:08:06 irfan Exp
+ *  $Id: IIOP_SSL_Connection_Handler.h 78931 2007-07-18 09:59:36Z johnnyw $
  *
  *  @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -16,17 +16,18 @@
 
 #include /**/ "ace/pre.h"
 
-#include "SSLIOP_Export.h"
+#include "orbsvcs/SSLIOP/SSLIOP_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "SSLIOP_Current.h"
+#include "orbsvcs/SSLIOP/SSLIOP_Current.h"
 
 #include "orbsvcs/SSLIOPC.h"
 #include "tao/IIOP_Connection_Handler.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -51,8 +52,7 @@ namespace TAO
 
     /// Constructor.
     IIOP_SSL_Connection_Handler (ACE_Thread_Manager* t = 0);
-    IIOP_SSL_Connection_Handler (TAO_ORB_Core *orb_core,
-                                 CORBA::Boolean flag);
+    IIOP_SSL_Connection_Handler (TAO_ORB_Core *orb_core);
 
     /// Destructor.
     ~IIOP_SSL_Connection_Handler (void);
@@ -109,9 +109,10 @@ namespace TAO
 
 } // End TAO namespace.
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #if defined (__ACE_INLINE__)
-#include "IIOP_SSL_Connection_Handler.inl"
+#include "orbsvcs/SSLIOP/IIOP_SSL_Connection_Handler.inl"
 #endif /* __ACE_INLINE__ */
 
 
