@@ -15,14 +15,14 @@
 
 ACE_RCSID (SSLIOP,
            SSLIOP_Acceptor,
-           "$Id: SSLIOP_Acceptor.cpp 78931 2007-07-18 09:59:36Z johnnyw $")
+           "$Id: SSLIOP_Acceptor.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO::SSLIOP::Acceptor::Acceptor (::Security::QOP qop,
                                  const ACE_Time_Value & timeout)
   : TAO::IIOP_SSL_Acceptor (),
-    ssl_acceptor_ (),
+    ssl_acceptor_ (this),
     creation_strategy_ (0),
     concurrency_strategy_ (0),
     accept_strategy_ (0),
@@ -472,9 +472,9 @@ TAO::SSLIOP::Acceptor::ssliop_open_i (TAO_ORB_Core *orb_core,
                                     reactor,
                                     this->creation_strategy_,
                                     this->accept_strategy_,
-				    this->concurrency_strategy_,
-				    0, 0, 0, 1,
-				    this->reuse_addr_) == -1)
+                                    this->concurrency_strategy_,
+                                    0, 0, 0, 1,
+                                    this->reuse_addr_) == -1)
         {
           if (TAO_debug_level > 0)
             ACE_DEBUG ((LM_DEBUG,
@@ -508,9 +508,9 @@ TAO::SSLIOP::Acceptor::ssliop_open_i (TAO_ORB_Core *orb_core,
                                         reactor,
                                         this->creation_strategy_,
                                         this->accept_strategy_,
-					this->concurrency_strategy_,
-					0, 0, 0, 1,
-					this->reuse_addr_) != -1)
+                                        this->concurrency_strategy_,
+                                        0, 0, 0, 1,
+                                        this->reuse_addr_) != -1)
             {
               found_a_port = 1;
               break;
@@ -567,6 +567,13 @@ TAO::SSLIOP::Acceptor::ssliop_open_i (TAO_ORB_Core *orb_core,
         }
     }
 
+  // In the event that an accept() fails, we can examine the reason.  If
+  // the reason warrants it, we can try accepting again at a later time.
+  // The amount of time we wait to accept again is governed by this orb
+  // parameter.
+  this->set_error_retry_delay (
+    this->orb_core_->orb_params ()->accept_error_delay());
+
   return 0;
 }
 
@@ -593,7 +600,7 @@ TAO::SSLIOP::Acceptor::parse_options_i (int &argc, ACE_CString ** argv)
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              ACE_TEXT ("TAO (%P|%t) Invalid SSLIOP endpoint format: ")
-                             ACE_TEXT ("endpoint priorities no longer supported. \n"),
+                             ACE_TEXT ("endpoint priorities no longer supported.\n"),
                              value.c_str ()),
                             -1);
         }
