@@ -21,7 +21,7 @@
 
 ACE_RCSID (SSLIOP,
            SSLIOP_Connector,
-           "$Id: SSLIOP_Connector.cpp 80278 2007-12-17 08:36:08Z johnnyw $")
+           "$Id: SSLIOP_Connector.cpp 86593 2009-09-02 14:58:00Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -458,8 +458,8 @@ TAO::SSLIOP::Connector::ssliop_connect (
   if (!ssl_endpoint->credentials_set ())
     {
       if (TAO_debug_level > 2)
-        ACE_DEBUG ((LM_ERROR,
-                    ACE_TEXT ("TAO (%P|%t) Initializing SSLIOP_Endpoint \n")
+        ACE_DEBUG ((LM_DEBUG,
+                    ACE_TEXT ("TAO (%P|%t) Initializing SSLIOP_Endpoint\n")
                     ));
 
       if (this->base_connector_.creation_strategy ()->make_svc_handler (
@@ -479,30 +479,20 @@ TAO::SSLIOP::Connector::ssliop_connect (
         this->retrieve_credentials (resolver->stub (),
                                     svc_handler->peer ().ssl ());
 
-      safe_handler.release ();
-
       ssl_endpoint->set_sec_attrs (qop, trust, credentials.in());
+
+      safe_handler.release ();
     }
 
   // Check the Cache first for connections
+  size_t busy_count = 0; //not used but needed for the call
   if (this->orb_core ()->lane_resources ().transport_cache ().find_transport (
         desc,
-        transport) == 0)
+        transport,
+        busy_count)
+        == TAO::Transport_Cache_Manager::CACHE_FOUND_AVAILABLE)
     {
       // ...eliminate svc_handle memory leak...
-      // The make_svc_handler() method creates the service handler and
-      // bumps the #REFCOUNT# up one extra.  The extra reference count
-      // in TAO_Connect_Creation_Strategy::make_svc_handler() is
-      // needed in the case when connection completion is pending and
-      // we are going to wait on a variable in the handler to changes,
-      // signifying success or failure.  Note, that this increment
-      // cannot be done once the connect() returns since this might be
-      // too late if another thread pick up the completion and
-      // potentially deletes the handler before we get a chance to
-      // increment the reference count.
-      if (svc_handler)
-          svc_handler->remove_reference();
-
       ACE_Event_Handler_var
         safe_handler (svc_handler);
 
@@ -516,6 +506,7 @@ TAO::SSLIOP::Connector::ssliop_connect (
       if (!transport->is_connected())
         {
           if (!this->wait_for_connection_completion (resolver,
+                                                     *desc,
                                                      transport,
                                                      max_wait_time))
             {
@@ -525,13 +516,15 @@ TAO::SSLIOP::Connector::ssliop_connect (
 
             }
         }
+
+      safe_handler.release ();
     }
   else
     {
       if (TAO_debug_level > 4)
         ACE_DEBUG ((LM_DEBUG,
                     ACE_TEXT ("TAO (%P|%t) - SSLIOP_Connector::ssliop_connect, ")
-                    ACE_TEXT ("making a new connection \n")));
+                    ACE_TEXT ("making a new connection\n")));
 
       // Purge connections (if necessary)
       this->orb_core ()->lane_resources ().transport_cache ().purge ();
@@ -542,17 +535,6 @@ TAO::SSLIOP::Connector::ssliop_connect (
       // ACE_Strategy_Connector (the "base_connector_").  This is
       // thread-safe and reentrant, hence no synchronization is
       // necessary.
-      //
-      // The make_svc_handler() method creates the service handler and
-      // bumps the #REFCOUNT# up one extra.  The extra reference count
-      // in TAO_Connect_Creation_Strategy::make_svc_handler() is
-      // needed in the case when connection completion is pending and
-      // we are going to wait on a variable in the handler to changes,
-      // signifying success or failure.  Note, that this increment
-      // cannot be done once the connect() returns since this might be
-      // too late if another thread pick up the completion and
-      // potentially deletes the handler before we get a chance to
-      // increment the reference count.
       if (svc_handler == 0 &&
           this->base_connector_.creation_strategy ()->make_svc_handler (
                svc_handler) != 0)
@@ -630,20 +612,6 @@ TAO::SSLIOP::Connector::ssliop_connect (
                                               remote_address,
                                               synch_options);
 
-      // base_connector_.connect() will increment the handler's
-      // #REFCOUNT# once more. This is not required as we already hold
-      // a reference to the handler, so we discard this second
-      // reference.
-      svc_handler->remove_reference ();
-
-      // There are three possibilities from calling connect(): (a)
-      // connection succeeds immediately - in this case, the
-      // #REFCOUNT# on the handler is two; (b) connection completion
-      // is pending - in this case, the #REFCOUNT# on the handler is
-      // also two; (c) connection fails immediately - in this case,
-      // the #REFCOUNT# on the handler is one since close() gets
-      // called on the handler.
-
       // Make sure that we always do a remove_reference
       ACE_Event_Handler_var svc_handler_auto_ptr (svc_handler);
 
@@ -659,6 +627,7 @@ TAO::SSLIOP::Connector::ssliop_connect (
               // get a connected transport or not. In case of non block we get
               // a connected or not connected transport
               if (!this->wait_for_connection_completion (resolver,
+                                                         *desc,
                                                          transport,
                                                          max_wait_time))
                 {
@@ -723,7 +692,7 @@ TAO::SSLIOP::Connector::ssliop_connect (
                                                                 transport);
 
       // Failure in adding to cache.
-      if (retval != 0)
+      if (retval == -1)
         {
           // Close the handler.
           svc_handler->close ();
@@ -767,6 +736,8 @@ TAO::SSLIOP::Connector::ssliop_connect (
 
           return 0;
         }
+
+      svc_handler_auto_ptr.release ();
     }
 
   return transport;
