@@ -4,7 +4,7 @@
 /**
  * @file SSLIOP_CredentialsAcquirerFactory.h
  *
- * SSLIOP_CredentialsAcquirerFactory.h,v 1.3 2004/08/16 23:53:14 jtc Exp
+ * $Id: SSLIOP_CredentialsAcquirerFactory.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -27,6 +27,8 @@
 #include "orbsvcs/SecurityLevel3C.h"
 
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   namespace SSLIOP
@@ -48,14 +50,14 @@ namespace TAO
       /// Create a TAO::SSLIOP::CredentialsAcquirerFactory.
       virtual SecurityLevel3::CredentialsAcquirer_ptr make (
         TAO::SL3::CredentialsCurator_ptr curator,
-        const CORBA::Any & acquisition_arguments
-        ACE_ENV_ARG_DECL);
+        const CORBA::Any & acquisition_arguments);
 
     };
 
   } // End SSLIOP namespace
 }  // End TAO namespace
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 
