@@ -8,19 +8,20 @@
 
 #include "tao/debug.h"
 #include "tao/ORBInitializer_Registry.h"
+#include "tao/PI/DLL_Resident_ORB_Initializer.h"
 
 #include "ace/SSL/sslconf.h"
 #include "ace/SSL/SSL_Context.h"
 
 ACE_RCSID (SSLIOP,
            SSLIOP_Factory,
-           "$Id: SSLIOP_Factory.cpp 80431 2008-01-15 19:06:41Z johnnyw $")
+           "$Id: SSLIOP_Factory.cpp 85648 2009-06-15 18:41:37Z johnnyw $")
 
 
 // An SSL session id seed value. Needs not be too unique, just somewhat
 // different. See the OpenSSL manual
 static const unsigned char session_id_context_[] =
-  "$Id: SSLIOP_Factory.cpp 80431 2008-01-15 19:06:41Z johnnyw $";
+  "$Id: SSLIOP_Factory.cpp 85648 2009-06-15 18:41:37Z johnnyw $";
 
 // Protocol name prefix
 static const char * const the_prefix[] = {"iiop", "ssliop"};
@@ -116,14 +117,14 @@ TAO::SSLIOP::Protocol_Factory::parse_x509_file (char *arg, char **path)
 
 
 int
-TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
+TAO::SSLIOP::Protocol_Factory::init (int argc, ACE_TCHAR* argv[])
 {
   char *certificate_path = 0;
   char *private_key_path = 0;
   char *dhparams_path = 0;
   char *ca_file = 0;
-  char *ca_dir = 0;
-  char *rand_path = 0;
+  CORBA::String_var ca_dir;
+  ACE_TCHAR *rand_path = 0;
 
   int certificate_type = -1;
   int private_key_type = -1;
@@ -161,7 +162,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
     if (TAO_debug_level > 0)
       ACE_ERROR ((LM_ERROR,
                   ACE_TEXT ("TAO (%P|%t) Unable to set the session id ")
-                  ACE_TEXT ("context to \'%s\'\n"), session_id_context_));
+                  ACE_TEXT ("context to \'%C\'\n"), session_id_context_));
 
     return -1;
   }
@@ -169,9 +170,9 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
   for (int curarg = 0; curarg != argc; ++curarg)
     {
       if ((ACE_OS::strcasecmp (argv[curarg],
-                               "-verbose") == 0)
+                               ACE_TEXT("-verbose")) == 0)
           || (ACE_OS::strcasecmp (argv[curarg],
-                                  "-v") == 0))
+                                  ACE_TEXT("-v")) == 0))
         {
           if (TAO_debug_level == 0)
             {
@@ -181,7 +182,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLNoProtection") == 0)
+                                   ACE_TEXT("-SSLNoProtection")) == 0)
         {
           // Enable the eNULL cipher.  Note that enabling the "eNULL"
           // cipher only disables encryption.  However, certificate
@@ -189,11 +190,10 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
           if (::SSL_CTX_set_cipher_list (ssl_ctx->context (),
                                          "DEFAULT:eNULL") == 0)
             {
-              if (TAO_debug_level > 0)
-                ACE_DEBUG ((LM_ERROR,
-                            ACE_TEXT ("TAO (%P|%t) Unable to set eNULL ")
-                            ACE_TEXT ("SSL cipher in SSLIOP ")
-                            ACE_TEXT ("factory.\n")));
+              ACE_DEBUG ((LM_ERROR,
+                          ACE_TEXT ("TAO (%P|%t) Unable to set eNULL ")
+                          ACE_TEXT ("SSL cipher in SSLIOP ")
+                          ACE_TEXT ("factory.\n")));
 
               return -1;
             }
@@ -213,37 +213,37 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLCertificate") == 0)
+                                   ACE_TEXT("-SSLCertificate")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
-              certificate_type = parse_x509_file (argv[curarg], &certificate_path);
+              certificate_type = parse_x509_file (ACE_TEXT_ALWAYS_CHAR(argv[curarg]), &certificate_path);
             }
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLPrivateKey") == 0)
+                                   ACE_TEXT("-SSLPrivateKey")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
-              private_key_type = parse_x509_file (argv[curarg], &private_key_path);
+              private_key_type = parse_x509_file (ACE_TEXT_ALWAYS_CHAR(argv[curarg]), &private_key_path);
             }
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLAuthenticate") == 0)
+                                   ACE_TEXT("-SSLAuthenticate")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
               int mode = SSL_VERIFY_NONE;
-              if (ACE_OS::strcasecmp (argv[curarg], "NONE") == 0)
+              if (ACE_OS::strcasecmp (argv[curarg], ACE_TEXT("NONE")) == 0)
                 {
                   mode = SSL_VERIFY_NONE;
                 }
-              else if (ACE_OS::strcasecmp (argv[curarg], "SERVER") == 0)
+              else if (ACE_OS::strcasecmp (argv[curarg], ACE_TEXT("SERVER")) == 0)
                 {
                   mode = SSL_VERIFY_PEER;
 
@@ -251,9 +251,9 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
                                 CSIIOP::EstablishTrustInTarget
                                 | CSIIOP::EstablishTrustInClient);
                 }
-              else if (ACE_OS::strcasecmp (argv[curarg], "CLIENT") == 0
+              else if (ACE_OS::strcasecmp (argv[curarg], ACE_TEXT("CLIENT")) == 0
                        || ACE_OS::strcasecmp (argv[curarg],
-                                              "SERVER_AND_CLIENT") == 0)
+                                              ACE_TEXT("SERVER_AND_CLIENT")) == 0)
                 {
                   mode = SSL_VERIFY_PEER | SSL_VERIFY_FAIL_IF_NO_PEER_CERT;
 
@@ -270,14 +270,14 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLAcceptTimeout") == 0)
+                                   ACE_TEXT("-SSLAcceptTimeout")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
               float timeout = 0;
 
-              if (sscanf (argv[curarg], "%f", &timeout) != 1
+              if (sscanf (ACE_TEXT_ALWAYS_CHAR(argv[curarg]), "%f", &timeout) != 1
                   || timeout < 0)
                 ACE_ERROR_RETURN ((LM_ERROR,
                                    "ERROR: Invalid -SSLAcceptTimeout "
@@ -290,37 +290,37 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLDHparams") == 0)
+                                   ACE_TEXT("-SSLDHparams")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
-              dhparams_type = parse_x509_file (argv[curarg], &dhparams_path);
+              dhparams_type = parse_x509_file (ACE_TEXT_ALWAYS_CHAR(argv[curarg]), &dhparams_path);
             }
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLCAfile") == 0)
+                                   ACE_TEXT("-SSLCAfile")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
-              (void) parse_x509_file (argv[curarg], &ca_file);
+              (void) parse_x509_file (ACE_TEXT_ALWAYS_CHAR(argv[curarg]), &ca_file);
             }
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLCApath") == 0)
+                                   ACE_TEXT("-SSLCApath")) == 0)
         {
           curarg++;
           if (curarg < argc)
             {
-              ca_dir = argv[curarg];
+              ca_dir = CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR(argv[curarg]));
             }
         }
 
       else if (ACE_OS::strcasecmp (argv[curarg],
-                                   "-SSLrand") == 0)
+                                   ACE_TEXT("-SSLrand")) == 0)
         {
           curarg++;
           if (curarg < argc)
@@ -335,27 +335,25 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
   if (rand_path != 0)
   {
     short errors = 0;
-    char *file_name = 0;
-    const char *path = ACE_OS::strtok_r (rand_path,
-                                         TAO_PATH_SEPARATOR_STRING,
-                                         &file_name);
+    ACE_TCHAR *file_name = 0;
+    const ACE_TCHAR *path = ACE_OS::strtok_r (rand_path,
+                                              TAO_PATH_SEPARATOR_STRING,
+                                              &file_name);
     while ( path != 0)
     {
-      if( -1 == ssl_ctx->seed_file (path, -1))
+      if( -1 == ssl_ctx->seed_file (ACE_TEXT_ALWAYS_CHAR(path), -1))
       {
         ++errors;
-
-        if (TAO_debug_level > 0)
-          ACE_ERROR ((LM_ERROR,
-                      ACE_TEXT ("TAO (%P|%t) Failed to load ")
-                      ACE_TEXT ("more entropy from <%s>: %m\n"), path));
+        ACE_ERROR ((LM_ERROR,
+                    ACE_TEXT ("TAO (%P|%t) Failed to load ")
+                    ACE_TEXT ("more entropy from <%s>: %m\n"), path));
       }
       else
       {
-          if (TAO_debug_level > 0)
-            ACE_DEBUG ((LM_DEBUG,
-                        ACE_TEXT ("TAO (%P|%t) Loaded ")
-                        ACE_TEXT ("more entropy from <%s>\n"), path));
+        if (TAO_debug_level > 0)
+          ACE_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("TAO (%P|%t) Loaded ")
+                      ACE_TEXT ("more entropy from <%s>\n"), path));
       }
 
       path = ACE_OS::strtok_r (0, TAO_PATH_SEPARATOR_STRING, &file_name);
@@ -367,21 +365,21 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
 
   // Load any trusted certificates explicitely rather than relying on
   // previously set SSL_CERT_FILE and/or SSL_CERT_PATH environment variable
-  if (ca_file != 0 || ca_dir != 0)
+  if (ca_file != 0 || ca_dir.in () != 0)
     {
-      if (ssl_ctx->load_trusted_ca (ca_file, ca_dir) != 0)
+      if (ssl_ctx->load_trusted_ca (ca_file, ca_dir.in ()) != 0)
         {
-          if (TAO_debug_level > 0)
-            ACE_ERROR ((LM_ERROR,
-                        ACE_TEXT ("TAO (%P|%t) Unable to load ")
-                        ACE_TEXT ("CA certs from %s%s%s\n"),
-                        ((ca_file != 0) ? ca_file : ACE_TEXT ("a file pointed to by ")
-                                                    ACE_TEXT (ACE_SSL_CERT_FILE_ENV)
-                                                    ACE_TEXT (" env var (if any)")),
-                        ACE_TEXT (" and "),
-                        ((ca_dir != 0) ? ca_dir : ACE_TEXT ("a directory pointed to by ")
-                                                  ACE_TEXT (ACE_SSL_CERT_DIR_ENV)
-                                                  ACE_TEXT (" env var (if any)"))));
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) Unable to load ")
+                      ACE_TEXT ("CA certs from %C%C%C\n"),
+                      ((ca_file != 0) ? ca_file : "a file pointed to by "
+                                                  ACE_SSL_CERT_FILE_ENV
+                                                  " env var (if any)"),
+                      ACE_TEXT (" and "),
+                      ((ca_dir.in () != 0) ?
+                          ca_dir.in () : "a directory pointed to by "
+                                         ACE_SSL_CERT_DIR_ENV
+                                         " env var (if any)")));
 
           return -1;
         }
@@ -390,14 +388,15 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
           if (TAO_debug_level > 0)
             ACE_DEBUG ((LM_INFO,
                         ACE_TEXT ("TAO (%P|%t) SSLIOP loaded ")
-                        ACE_TEXT ("Trusted Certificates from %s%s%s\n"),
-                        ((ca_file != 0) ? ca_file : ACE_TEXT ("a file pointed to by ")
-                                                    ACE_TEXT (ACE_SSL_CERT_FILE_ENV)
-                                                    ACE_TEXT (" env var (if any)")),
+                        ACE_TEXT ("Trusted Certificates from %C%C%C\n"),
+                        ((ca_file != 0) ? ca_file : "a file pointed to by "
+                                                    ACE_SSL_CERT_FILE_ENV
+                                                    " env var (if any)"),
                         ACE_TEXT (" and "),
-                        ((ca_dir != 0) ? ca_dir : ACE_TEXT ("a directory pointed to by ")
-                                                  ACE_TEXT (ACE_SSL_CERT_DIR_ENV)
-                                                  ACE_TEXT (" env var (if any)"))));
+                        ((ca_dir.in () != 0) ?
+                            ca_dir.in () : "a directory pointed to by "
+                                           ACE_SSL_CERT_DIR_ENV
+                                           " env var (if any)")));
         }
     }
 
@@ -424,12 +423,11 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
               // We only want to fail catastrophically if the user specified
               // a dh parameter file and we were unable to actually find it
               // and load from it.
-              if (TAO_debug_level > 0)
-                ACE_ERROR ((LM_ERROR,
-                            ACE_TEXT ("(%P|%t) SSLIOP_Factory: ")
-                            ACE_TEXT ("unable to set ")
-                            ACE_TEXT ("DH parameters <%s>\n"),
-                            dhparams_path));
+              ACE_ERROR ((LM_ERROR,
+                          ACE_TEXT ("(%P|%t) SSLIOP_Factory: ")
+                          ACE_TEXT ("unable to set ")
+                          ACE_TEXT ("DH parameters <%C>\n"),
+                          dhparams_path));
               return -1;
             }
           else
@@ -438,7 +436,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
                 ACE_DEBUG ((LM_INFO,
                             ACE_TEXT ("(%P|%t) SSLIOP_Factory: ")
                             ACE_TEXT ("No DH parameters found in ")
-                            ACE_TEXT ("certificate <%s>; either none ")
+                            ACE_TEXT ("certificate <%C>; either none ")
                             ACE_TEXT ("are needed (RSA) or problems ")
                             ACE_TEXT ("will ensue later.\n"),
                             dhparams_path));
@@ -450,7 +448,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
             ACE_DEBUG ((LM_INFO,
                         ACE_TEXT ("(%P|%t) SSLIOP loaded ")
                         ACE_TEXT ("Diffie-Hellman params ")
-                        ACE_TEXT ("from %s\n"),
+                        ACE_TEXT ("from %C\n"),
                         dhparams_path));
         }
     }
@@ -464,12 +462,11 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
       if (ssl_ctx->certificate (certificate_path,
                                 certificate_type) != 0)
         {
-          if (TAO_debug_level > 0)
-            ACE_ERROR ((LM_ERROR,
-                        ACE_TEXT ("TAO (%P|%t) Unable to set ")
-                        ACE_TEXT ("SSL certificate <%s> ")
-                        ACE_TEXT ("in SSLIOP factory.\n"),
-                        certificate_path));
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) Unable to set ")
+                      ACE_TEXT ("SSL certificate <%C> ")
+                      ACE_TEXT ("in SSLIOP factory.\n"),
+                      certificate_path));
 
           return -1;
         }
@@ -479,7 +476,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
             ACE_DEBUG ((LM_INFO,
                         ACE_TEXT ("TAO (%P|%t) SSLIOP loaded ")
                         ACE_TEXT ("SSL certificate ")
-                        ACE_TEXT ("from %s\n"),
+                        ACE_TEXT ("from %C\n"),
                         certificate_path));
         }
     }
@@ -488,14 +485,12 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
     {
       if (ssl_ctx->private_key (private_key_path, private_key_type) != 0)
         {
-          if (TAO_debug_level > 0)
-            {
-              ACE_ERROR ((LM_ERROR,
-                          ACE_TEXT ("TAO (%P|%t) Unable to set ")
-                          ACE_TEXT ("SSL private key ")
-                          ACE_TEXT ("<%s> in SSLIOP factory.\n"),
-                          private_key_path));
-            }
+
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) Unable to set ")
+                      ACE_TEXT ("SSL private key ")
+                      ACE_TEXT ("<%C> in SSLIOP factory.\n"),
+                      private_key_path));
 
           return -1;
         }
@@ -505,7 +500,7 @@ TAO::SSLIOP::Protocol_Factory::init (int argc, char* argv[])
             ACE_DEBUG ((LM_INFO,
                         ACE_TEXT ("TAO (%P|%t) SSLIOP loaded ")
                         ACE_TEXT ("Private Key ")
-                        ACE_TEXT ("from %s\n"),
+                        ACE_TEXT ("from <%C>\n"),
                         private_key_path));
         }
     }
@@ -541,10 +536,26 @@ TAO::SSLIOP::Protocol_Factory::register_orb_initializer (
 
       PortableInterceptor::ORBInitializer_var initializer = tmp;
 
-      PortableInterceptor::register_orb_initializer (initializer.in ());
+  PortableInterceptor::ORBInitializer_ptr temp_dll_initializer =
+        PortableInterceptor::ORBInitializer::_nil ();
+
+  ACE_NEW_THROW_EX (temp_dll_initializer,
+        PortableInterceptor::DLL_Resident_ORB_Initializer(
+  initializer.in (),
+  ACE_TEXT ("TAO_Security")),
+  CORBA::NO_MEMORY (
+  CORBA::SystemException::_tao_minor_code (
+  TAO::VMCID,
+  ENOMEM),
+  CORBA::COMPLETED_NO));
+
+  PortableInterceptor::ORBInitializer_var dll_initializer
+  = temp_dll_initializer;
+
+  PortableInterceptor::register_orb_initializer (dll_initializer.in ());
+
 
       // Register the SSLIOP ORB initializer.
-      // PortableInterceptor::ORBInitializer_ptr tmp;
       ACE_NEW_THROW_EX (tmp,
                         TAO::SSLIOP::ORBInitializer (this->qop_,
                                                      csiv2_target_supports,
@@ -555,10 +566,24 @@ TAO::SSLIOP::Protocol_Factory::register_orb_initializer (
                             ENOMEM),
                           CORBA::COMPLETED_NO));
 
-      //PortableInterceptor::ORBInitializer_var initializer = tmp;
       initializer = tmp;
 
-      PortableInterceptor::register_orb_initializer (initializer.in ());
+  temp_dll_initializer = PortableInterceptor::ORBInitializer::_nil ();
+
+  ACE_NEW_THROW_EX (temp_dll_initializer,
+        PortableInterceptor::DLL_Resident_ORB_Initializer(
+  initializer.in (),
+  ACE_TEXT ("TAO_SSLIOP")),
+  CORBA::NO_MEMORY (
+  CORBA::SystemException::_tao_minor_code (
+  TAO::VMCID,
+  ENOMEM),
+  CORBA::COMPLETED_NO));
+
+  dll_initializer = temp_dll_initializer;
+
+  PortableInterceptor::register_orb_initializer (dll_initializer.in ());
+
     }
   catch (const CORBA::Exception& ex)
     {
