@@ -4,7 +4,7 @@
 /**
  *  @file   SSLIOP_Transport.h
  *
- *  $Id: SSLIOP_Transport.h 80288 2007-12-17 20:05:04Z johnnyw $
+ *  $Id: SSLIOP_Transport.h 84860 2009-03-17 10:17:38Z johnnyw $
  *
  *  SSLIOP Transport specific processing.
  *
@@ -108,13 +108,9 @@ namespace TAO
       virtual int send_message (TAO_OutputCDR &stream,
                                 TAO_Stub *stub = 0,
                                 TAO_Message_Semantics message_semantics =
-                                  TAO_Transport::TAO_TWOWAY_REQUEST,
+                                  TAO_TWOWAY_REQUEST,
                                 ACE_Time_Value *max_time_wait = 0);
 
-      virtual int generate_request_header (TAO_Operation_Details &opdetails,
-                                           TAO_Target_Specification &spec,
-                                           TAO_OutputCDR &msg);
-
       /// Open teh service context list and process it.
       virtual int tear_listen_point_list (TAO_InputCDR &cdr);
       //@}
