@@ -2,9 +2,9 @@
 /**
  *  @file    DynSched.cpp
  *
- *  $Id: DynSched.cpp 78858 2007-07-12 23:24:55Z sowayaa $
+ *  $Id: DynSched.cpp 84563 2009-02-23 08:13:54Z johnnyw $
  *
- *  $Id: DynSched.cpp 78858 2007-07-12 23:24:55Z sowayaa $
+ *  $Id: DynSched.cpp 84563 2009-02-23 08:13:54Z johnnyw $
  *
  *  @author Chris Gill
  */
@@ -21,7 +21,7 @@
 #include "orbsvcs/Sched/DynSched.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Sched, DynSched, "$Id: DynSched.cpp 78858 2007-07-12 23:24:55Z sowayaa $")
+ACE_RCSID(Sched, DynSched, "$Id: DynSched.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -444,16 +444,16 @@ int ACE_DynScheduler::add_dependency(RT_Info* rt_info,
     default:
 
       ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT("unrecognized dependency type %d for %s\n"),
-                  d.dependency_type, ACE_TEXT_CHAR_TO_TCHAR(rt_info->entry_point.in ())));
+                  ACE_TEXT("unrecognized dependency type %d for %C\n"),
+                  d.dependency_type, rt_info->entry_point.in ()));
       return -1;
   }
 
   ACE_DEBUG ((LM_DEBUG,
-              ACE_TEXT("Sched (%t) adding %s dependency to caller: %s\n"),
+              ACE_TEXT("Sched (%t) adding %s dependency to caller: %C\n"),
               (const ACE_TCHAR *) ((d.dependency_type == RtecBase::TWO_WAY_CALL)
                               ? ACE_TEXT("TWO_WAY") : ACE_TEXT("ONE_WAY")),
-              ACE_TEXT_CHAR_TO_TCHAR(temp_info->entry_point.in ())));
+              temp_info->entry_point.in ()));
 
   RtecScheduler::Dependency_Set& set = temp_info->dependencies;
   int l = set.length();
@@ -1549,8 +1549,8 @@ ACE_DynScheduler::identify_threads (ACE_CString & unresolved_locals,
           ACE_DEBUG (
              (LM_DEBUG,
               ACE_TEXT("Warning: an operation identified by ")
-              ACE_TEXT("\"%s\" has unresolved remote dependencies.\n"),
-              ACE_TEXT_CHAR_TO_TCHAR((const char*)task_entries_ [i].rt_info ()->entry_point)));
+              ACE_TEXT("\"%C\" has unresolved remote dependencies.\n"),
+              (const char*)task_entries_ [i].rt_info ()->entry_point));
 
           // Record entry point in list of unresolved remote dependencies
           ACE_OS::sprintf (string_buffer, "// %s\n",
@@ -1564,10 +1564,10 @@ ACE_DynScheduler::identify_threads (ACE_CString & unresolved_locals,
           // Local node that no one calls and has neither rate nor threads is suspect
           ACE_DEBUG (
              (LM_DEBUG,
-              ACE_TEXT("Error: operation \"%s\" does not specify a period or\n")
+              ACE_TEXT("Error: operation \"%C\" does not specify a period or\n")
               ACE_TEXT("visible threads, and is not called by any other operation.\n")
               ACE_TEXT("Are there backwards dependencies.\n"),
-              ACE_TEXT_CHAR_TO_TCHAR((const char*)task_entries_ [i].rt_info ()->entry_point)));
+              (const char*)task_entries_ [i].rt_info ()->entry_point));
 
           result = ST_UNRESOLVED_LOCAL_DEPENDENCIES;
 
@@ -1651,9 +1651,9 @@ ACE_DynScheduler::check_dependency_cycles_recurse (Task_Entry &entry)
     {
       // indicate the two tasks are in (the same) dependency cycle
       ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT("Tasks \"%s\" and \"%s\" are part of a call cycle.\n"),
-                  ACE_TEXT_CHAR_TO_TCHAR((*calling_entry_link)->caller ().rt_info ()->entry_point.in ()),
-                  ACE_TEXT_CHAR_TO_TCHAR(entry.rt_info ()->entry_point.in ())));
+                  ACE_TEXT("Tasks \"%C\" and \"%C\" are part of a call cycle.\n"),
+                  (*calling_entry_link)->caller ().rt_info ()->entry_point.in (),
+                  entry.rt_info ()->entry_point.in ()));
 
       // set return status, ignore status returned by recursive call:
       // we already know there are cycles in the dependencies
@@ -1936,8 +1936,8 @@ ACE_DynScheduler::output_dispatch_priorities (const char *filename)
   {
     ACE_ERROR ((LM_ERROR,
                 ACE_TEXT("ACE_DynScheduler::output_dispatch_priorities: ")
-                ACE_TEXT("Could not open schedule file (\"%s\")"),
-                ACE_TEXT_CHAR_TO_TCHAR(filename)));
+                ACE_TEXT("Could not open schedule file (\"%C\")"),
+                filename));
   }
 
   return status;
@@ -1972,9 +1972,9 @@ ACE_DynScheduler::output_dispatch_priorities (FILE *file)
             "Minimum Critical Priority:         %3d\n\n\n"
 
             "DISPATCH PRIORITIES:\n\n"
-            "                                  (critical              \n"
-            "                                   instant)              \n"
-            "             dispatch              dynamic      static   \n"
+            "                                  (critical             \n"
+            "                                   instant)             \n"
+            "             dispatch              dynamic      static  \n"
             "operation          ID  priority  subpriority  subpriority\n"
             "---------    --------  --------  -----------  -----------\n",
       dispatch_count, threads_, tasks_, status_,
@@ -2158,8 +2158,8 @@ ACE_DynScheduler::output_preemption_timeline (const char *filename)
   {
     ACE_ERROR ((LM_ERROR,
                 ACE_TEXT("ACE_DynScheduler::output_preemption_timeline: ")
-                ACE_TEXT("Cannot open timeline file (\"%s\")\n"),
-                ACE_TEXT_CHAR_TO_TCHAR(filename)));
+                ACE_TEXT("Cannot open timeline file (\"%C\")\n"),
+                filename));
   }
 
   return status;
@@ -2170,7 +2170,7 @@ ACE_DynScheduler::output_preemption_timeline (FILE *file)
 {
   if (ACE_OS::fprintf (
         file, "\n\nPREEMPTION TIMELINE:\n\n"
-        "              dispatch     start      stop  \n"
+        "              dispatch     start      stop \n"
         "operation           ID    (nsec)    (nsec)\n"
         "---------  -----------    ------    ------\n") < 0)
   {
@@ -2254,7 +2254,7 @@ ACE_DynScheduler::output_viewer_timeline (FILE *file)
   //FUZZ: disable check_for_lack_ACE_OS
   if (ACE_OS::fprintf (
       file, "\n\nVIEWER TIMELINE:\n\n"
-            "                                    arrival  deadline   completion    execution  \n"
+            "                                    arrival  deadline   completion    execution \n"
             "operation  utilization   overhead    (nsec)    (nsec)  time (nsec)  time (nsec)\n"
             "---------  -----------   --------   -------  --------  -----------  -----------\n") < 0)
   {
