@@ -1,30 +1,26 @@
-// SchedEntry.cpp,v 1.21 2004/04/24 04:30:46 ossama Exp
 
-// ============================================================================
-//
-// = LIBRARY
-//    sched
-//
-// = FILENAME
-//    SchedEntry.cpp
-//
-// = CREATION DATE
-//    7 February 1998
-//
-// = AUTHOR
-//    Chris Gill
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    SchedEntry.cpp
+ *
+ *  $Id: SchedEntry.cpp 77054 2007-02-12 19:01:18Z johnnyw $
+ *
+ *  @author Chris Gill
+ */
+//=============================================================================
 
-#include "SchedEntry.h"
+
+#include "orbsvcs/Sched/SchedEntry.h"
 #include "ace/SString.h"
 #include "ace/OS_NS_stdio.h"
 
 #if ! defined (__ACE_INLINE__)
-#include "SchedEntry.i"
+#include "orbsvcs/Sched/SchedEntry.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Sched, SchedEntry, "SchedEntry.cpp,v 1.21 2004/04/24 04:30:46 ossama Exp")
+ACE_RCSID(Sched, SchedEntry, "$Id: SchedEntry.cpp 77054 2007-02-12 19:01:18Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 Task_Entry::Task_Entry (void)
   : rt_info_ (0),
@@ -932,3 +928,5 @@ TimeLine_Entry::TimeLine_Entry (Dispatch_Entry &dispatch_entry,
     prev_ (prev)
 {
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
