@@ -1,27 +1,20 @@
-// Strategy_Scheduler.cpp,v 1.29 2005/04/30 07:52:10 ossama Exp
-//
-// ============================================================================
-//
-// = LIBRARY
-//    sched
-//
-// = FILENAME
-//    Strategy_Scheduler.cpp
-//
-// = CREATION DATE
-//    22 December 1997
-//
-// = AUTHOR
-//    Chris Gill
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    Strategy_Scheduler.cpp
+ *
+ *  $Id: Strategy_Scheduler.cpp 77054 2007-02-12 19:01:18Z johnnyw $
+ *
+ *  @author Chris Gill
+ */
+//=============================================================================
 
-#include "Strategy_Scheduler.h"
+
+#include "orbsvcs/Sched/Strategy_Scheduler.h"
 #include "ace/Sched_Params.h"
 
 ACE_RCSID (Sched,
            Strategy_Scheduler,
-           "Strategy_Scheduler.cpp,v 1.29 2005/04/30 07:52:10 ossama Exp")
+           "$Id: Strategy_Scheduler.cpp 77054 2007-02-12 19:01:18Z johnnyw $")
 
 //////////////////////////////////////////////
 // Helper function type definition for sort //
@@ -43,6 +36,8 @@ typedef int (*COMP_FUNC) (const void*, const void*);
 
 // = Constructor.
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 ACE_Strategy_Scheduler::ACE_Strategy_Scheduler (ACE_Scheduler_Strategy &strategy)
   : ACE_DynScheduler (),
     strategy_ (strategy)
@@ -860,9 +855,8 @@ ACE_MUF_Scheduler_Strategy::minimum_critical_priority ()
 // = Provides the dispatching queue type for the given dispatch entry.
 
 ACE_DynScheduler::Dispatching_Type
-ACE_MUF_Scheduler_Strategy::dispatch_type (const Dispatch_Entry &entry)
+ACE_MUF_Scheduler_Strategy::dispatch_type (const Dispatch_Entry & /* entry */)
 {
-  ACE_UNUSED_ARG (entry);
   return RtecScheduler::LAXITY_DISPATCHING;
 }
 
@@ -951,12 +945,10 @@ ACE_RMS_Scheduler_Strategy::~ACE_RMS_Scheduler_Strategy ()
 // = All entries have the same dynamic subpriority value.
 
 long
-ACE_RMS_Scheduler_Strategy::dynamic_subpriority (Dispatch_Entry &entry,
-                                                 RtecScheduler::Time current_time)
+ACE_RMS_Scheduler_Strategy::dynamic_subpriority (
+  Dispatch_Entry & /* entry */,
+  RtecScheduler::Time /* current_time */)
 {
-  ACE_UNUSED_ARG (entry);
-  ACE_UNUSED_ARG (current_time);
-
   return 0;
 }
 
@@ -996,9 +988,8 @@ ACE_RMS_Scheduler_Strategy::minimum_critical_priority ()
 // = Provide the dispatching queue type for the given dispatch entry.
 
 ACE_DynScheduler::Dispatching_Type
-ACE_RMS_Scheduler_Strategy::dispatch_type (const Dispatch_Entry &entry)
+ACE_RMS_Scheduler_Strategy::dispatch_type (const Dispatch_Entry & /* entry */)
 {
-  ACE_UNUSED_ARG (entry);
   return RtecScheduler::STATIC_DISPATCHING;
 }
 
@@ -1131,9 +1122,8 @@ ACE_MLF_Scheduler_Strategy::sort_function (void *arg1, void *arg2)
 // = Provides the dispatching queue type for the given dispatch entry.
 
 ACE_DynScheduler::Dispatching_Type
-ACE_MLF_Scheduler_Strategy::dispatch_type (const Dispatch_Entry &entry)
+ACE_MLF_Scheduler_Strategy::dispatch_type (const Dispatch_Entry & /* entry */)
 {
-  ACE_UNUSED_ARG (entry);
   return RtecScheduler::LAXITY_DISPATCHING;
 }
 
@@ -1257,9 +1247,8 @@ ACE_EDF_Scheduler_Strategy::sort_function (void *arg1, void *arg2)
 // = Provides the dispatching queue type for the given dispatch entry.
 
 ACE_DynScheduler::Dispatching_Type
-ACE_EDF_Scheduler_Strategy::dispatch_type (const Dispatch_Entry &entry)
+ACE_EDF_Scheduler_Strategy::dispatch_type (const Dispatch_Entry & /* entry */)
 {
-  ACE_UNUSED_ARG (entry);
   return RtecScheduler::DEADLINE_DISPATCHING;
 }
 
@@ -1347,12 +1336,10 @@ ACE_Criticality_Scheduler_Strategy::~ACE_Criticality_Scheduler_Strategy ()
 // = All entries have the same dynamic subpriority value.
 
 long
-ACE_Criticality_Scheduler_Strategy::dynamic_subpriority (Dispatch_Entry &entry,
-                                                 RtecScheduler::Time current_time)
+ACE_Criticality_Scheduler_Strategy::dynamic_subpriority (
+  Dispatch_Entry & /* entry */,
+  RtecScheduler::Time /* current_time */)
 {
-  ACE_UNUSED_ARG (entry);
-  ACE_UNUSED_ARG (current_time);
-
   return 0;
 }
 
@@ -1388,38 +1375,13 @@ ACE_Criticality_Scheduler_Strategy::minimum_critical_priority ()
   return minimum_critical_priority_;
 }
 
-
 // = Provides the dispatching queue type for the given dispatch entry.
 
 ACE_DynScheduler::Dispatching_Type
-ACE_Criticality_Scheduler_Strategy::dispatch_type (const Dispatch_Entry &entry)
+ACE_Criticality_Scheduler_Strategy::dispatch_type (
+  const Dispatch_Entry & /* entry */)
 {
-  ACE_UNUSED_ARG (entry);
   return RtecScheduler::STATIC_DISPATCHING;
 }
 
-
-
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-template class ACE_Node<Dispatch_Entry *>;
-template class ACE_Unbounded_Set<Dispatch_Entry *>;
-template class ACE_Unbounded_Set_Iterator<Dispatch_Entry *>;
-template class ACE_Strategy_Scheduler_Factory<ACE_MUF_Scheduler_Strategy>;
-template class ACE_Strategy_Scheduler_Factory<ACE_RMS_Scheduler_Strategy>;
-template class ACE_Strategy_Scheduler_Factory<ACE_MLF_Scheduler_Strategy>;
-template class ACE_Strategy_Scheduler_Factory<ACE_EDF_Scheduler_Strategy>;
-template class ACE_Strategy_Scheduler_Factory<ACE_Criticality_Scheduler_Strategy>;
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate ACE_Node<Dispatch_Entry *>
-#pragma instantiate ACE_Unbounded_Set<Dispatch_Entry *>
-#pragma instantiate ACE_Unbounded_Set_Iterator<Dispatch_Entry *>
-#pragma instantiate ACE_Strategy_Scheduler_Factory<ACE_MUF_Scheduler_Strategy>
-#pragma instantiate ACE_Strategy_Scheduler_Factory<ACE_RMS_Scheduler_Strategy>
-#pragma instantiate ACE_Strategy_Scheduler_Factory<ACE_MLF_Scheduler_Strategy>
-#pragma instantiate ACE_Strategy_Scheduler_Factory<ACE_EDF_Scheduler_Strategy>
-#pragma instantiate ACE_Strategy_Scheduler_Factory<ACE_Criticality_Scheduler_Strategy>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
-
-
-// EOF
+TAO_END_VERSIONED_NAMESPACE_DECL
