@@ -1,4 +1,4 @@
-// $Id: Scheduler_Factory.cpp 80166 2007-12-03 13:53:49Z sowayaa $
+// $Id: Scheduler_Factory.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "ace/OS.h"
 #include "ace/Singleton.h"
@@ -15,7 +15,7 @@
 
 ACE_RCSID(orbsvcs,
           Scheduler_Factory,
-          "$Id: Scheduler_Factory.cpp 80166 2007-12-03 13:53:49Z sowayaa $")
+          "$Id: Scheduler_Factory.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -251,7 +251,7 @@ static char header[] =
 static char footer[] =
 "\n"
 "// This sets up Scheduler_Factory to use the runtime version.\n"
-"int scheduler_factory_setup = \n"
+"int scheduler_factory_setup =\n"
 "  ACE_Scheduler_Factory::use_runtime (configs_size, configs, infos_size, infos);\n"
 "\n"
 "// EOF\n";
@@ -300,7 +300,7 @@ int ACE_Scheduler_Factory::dump_schedule
     const RtecScheduler::Dependency_Set& dependencies,
     const RtecScheduler::Config_Info_Set& configs,
     const RtecScheduler::Scheduling_Anomaly_Set& anomalies,
-    const char* file_name,
+    const ACE_TCHAR* file_name,
     const char* rt_info_format,
     const char* dependency_format,
     const char* config_info_format,
@@ -343,7 +343,7 @@ int ACE_Scheduler_Factory::dump_schedule
   FILE* file = stdout;
   if (file_name != 0)
     {
-      file = ACE_OS::fopen (ACE_TEXT_CHAR_TO_TCHAR(file_name), ACE_TEXT("w"));
+      file = ACE_OS::fopen (file_name, ACE_TEXT("w"));
       if (file == 0)
           return -1;
     }
