@@ -1,6 +1,6 @@
-// CSI_Utils.cpp,v 1.4 2004/08/16 23:53:14 jtc Exp
+// $Id: CSI_Utils.cpp 71526 2006-03-14 06:14:35Z jtc $
 
-#include "CSI_Utils.h"
+#include "orbsvcs/Security/CSI_Utils.h"
 #include "orbsvcs/CSIC.h"
 
 #include "tao/CDR.h"
@@ -10,8 +10,9 @@
 
 ACE_RCSID (Security,
            CSI_Utils,
-           "CSI_Utils.cpp,v 1.4 2004/08/16 23:53:14 jtc Exp")
+           "$Id: CSI_Utils.cpp 71526 2006-03-14 06:14:35Z jtc $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 void
 TAO::CSI_Utils::create_sas_service_context (
@@ -64,3 +65,5 @@ TAO::CSI_Utils::extract_sas_service_context (
 
   return (cdr >> sas_context);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
