@@ -4,7 +4,7 @@
 /**
  * @file CSI_Utils.h
  *
- * CSI_Utils.h,v 1.3 2004/07/27 06:09:59 jwillemsen Exp
+ * $Id: CSI_Utils.h 69380 2005-11-16 07:53:25Z ossama $
  *
  * @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -18,6 +18,11 @@
 // the declared types/variables are not meant to be used outside TAO's
 // CSIv2 implementation.
 
+#include "tao/orbconf.h"
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 // Forward declarations
 namespace IOP
 {
@@ -46,4 +51,6 @@ namespace TAO
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif  /* TAO_CSI_UTILS_H */
