@@ -5,7 +5,7 @@
 
 ACE_RCSID (Security,
            Security_Current,
-           "$Id: Security_Current.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
+           "$Id: Security_Current.cpp 82864 2008-09-29 07:44:18Z johnnyw $")
 
 #if !defined (__ACE_INLINE__)
 # include "orbsvcs/Security/Security_Current.inl"
@@ -62,7 +62,7 @@ TAO_Security_Current::init (void)
   try
     {
       int argc = 0;
-      char **argv = 0;
+      ACE_TCHAR **argv = 0;
       CORBA::ORB_var orb = CORBA::ORB_init (argc,
                                             argv,
                                             this->orb_id_.in ());
