@@ -1,16 +1,18 @@
 // -*- C++ -*-
-// TAO_UTO.cpp,v 1.29 2005/01/28 15:56:34 jtc Exp
+// $Id: TAO_UTO.cpp 77001 2007-02-12 07:54:49Z johnnyw $
 
-#include "TAO_UTO.h"
-#include "TAO_TIO.h"
+#include "orbsvcs/Time/TAO_UTO.h"
+#include "orbsvcs/Time/TAO_TIO.h"
 #include "ace/OS.h"
 
 
 ACE_RCSID (Time,
            TAO_UTO,
-           "TAO_UTO.cpp,v 1.29 2005/01/28 15:56:34 jtc Exp")
+           "$Id: TAO_UTO.cpp 77001 2007-02-12 07:54:49Z johnnyw $")
 
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_UTO::TAO_UTO (TimeBase::TimeT time,
                   TimeBase::InaccuracyT inaccuracy,
                   TimeBase::TdfT tdf)
@@ -45,8 +47,7 @@ TAO_UTO::~TAO_UTO (void)
 // Get Method for the readonly attribute time.
 
 TimeBase::TimeT
-TAO_UTO::time (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::time (void)
 {
   return attr_utc_time_.time;
 }
@@ -54,8 +55,7 @@ TAO_UTO::time (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 // Get method for the readonly attribute inaccuracy.
 
 TimeBase::InaccuracyT
-TAO_UTO::inaccuracy (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::inaccuracy (void)
 {
   // Construct the Inaccuracy from the
   // inacchi and inacclo.
@@ -69,8 +69,7 @@ TAO_UTO::inaccuracy (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 // Get method for the readonly attribute tdf.
 
 TimeBase::TdfT
-TAO_UTO::tdf (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::tdf (void)
 {
   return attr_utc_time_.tdf;
 }
@@ -78,8 +77,7 @@ TAO_UTO::tdf (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 // Get method for the readonly attribute utc_time.
 
 TimeBase::UtcT
-TAO_UTO::utc_time (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::utc_time (void)
 {
   return attr_utc_time_;
 }
@@ -88,8 +86,7 @@ TAO_UTO::utc_time (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 // the Base Time, UTC and Distributed Time Sync. Algos. [3].
 
 CosTime::UTO_ptr
-TAO_UTO::absolute_time (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::absolute_time (void)
 {
   return CosTime::UTO::_nil ();
 }
@@ -99,20 +96,15 @@ TAO_UTO::absolute_time (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 
 CosTime::TimeComparison
 TAO_UTO::compare_time (CosTime::ComparisonType comparison_type,
-                       CosTime::UTO_ptr uto
-                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+                       CosTime::UTO_ptr uto)
 {
-  TimeBase::TimeT uto_time = uto->time (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CosTime::TCIndeterminate);
+  TimeBase::TimeT uto_time = uto->time ();
 
   TimeBase::InaccuracyT this_inaccuracy =
-    this->inaccuracy (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CosTime::TCIndeterminate);
+    this->inaccuracy ();
 
   TimeBase::InaccuracyT uto_inaccuracy =
-    uto->inaccuracy (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK_RETURN (CosTime::TCIndeterminate);
+    uto->inaccuracy ();
 
   if (comparison_type == CosTime::MidC)
     {
@@ -162,16 +154,13 @@ TAO_UTO::compare_time (CosTime::ComparisonType comparison_type,
 // is meaningless if the base times of UTOs are different.
 
 CosTime::TIO_ptr
-TAO_UTO::time_to_interval (CosTime::UTO_ptr uto
-                           ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::time_to_interval (CosTime::UTO_ptr uto)
 {
   TAO_TIO *tio = 0;
 
-  ACE_TRY
+  try
     {
-      TimeBase::TimeT uto_time = uto->time (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      TimeBase::TimeT uto_time = uto->time ();
 
       if (this->time () > uto_time)
         {
@@ -180,7 +169,6 @@ TAO_UTO::time_to_interval (CosTime::UTO_ptr uto
                                      this->time ()),
                             CORBA::NO_MEMORY ());
 
-          ACE_TRY_CHECK;
         }
       else
         {
@@ -189,34 +177,29 @@ TAO_UTO::time_to_interval (CosTime::UTO_ptr uto
                                      uto_time),
                             CORBA::NO_MEMORY ());
 
-          ACE_TRY_CHECK;
         }
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Exception:");
+      ex._tao_print_exception ("Exception:");
       return CosTime::TIO::_nil ();
     }
-  ACE_ENDTRY;
-  ACE_CHECK_RETURN (CosTime::TIO::_nil ());
 
-  return tio->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return tio->_this ();
 }
 
 // Returns a TIO object representing the error interval around the
 // time value in the UTO.
 
 CosTime::TIO_ptr
-TAO_UTO::interval (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_UTO::interval (void)
 {
   TAO_TIO *tio = 0;
 
-  ACE_TRY
+  try
     {
       TimeBase::TimeT this_inaccuracy =
-          this->inaccuracy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+          this->inaccuracy ();
 
       TimeBase::TimeT lower =
         this->time () - this_inaccuracy;
@@ -228,15 +211,14 @@ TAO_UTO::interval (ACE_ENV_SINGLE_ARG_DECL)
                         TAO_TIO (lower,
                                  upper),
                         CORBA::NO_MEMORY ());
-      ACE_TRY_CHECK;
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Exception:");
+      ex._tao_print_exception ("Exception:");
       return CosTime::TIO::_nil ();
     }
-  ACE_ENDTRY;
-  ACE_CHECK_RETURN (CosTime::TIO::_nil ());
 
-  return tio->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return tio->_this ();
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
