@@ -1,4 +1,4 @@
-// $Id: Time_Utilities.cpp 73791 2006-07-27 20:54:56Z wotte $
+// $Id: Time_Utilities.cpp 82313 2008-07-15 00:39:02Z jtc $
 
 #include "orbsvcs/Time_Utilities.h"
 
@@ -6,17 +6,17 @@
 # include "orbsvcs/Time_Utilities.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(orbsvcs, Time_Utilities, "$Id: Time_Utilities.cpp 73791 2006-07-27 20:54:56Z wotte $")
+ACE_RCSID(orbsvcs, Time_Utilities, "$Id: Time_Utilities.cpp 82313 2008-07-15 00:39:02Z jtc $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // Number of nanoseconds between CORBA and POSIX epochs.
 #ifdef ACE_LACKS_LONGLONG_T
 const ACE_UINT64
-ORBSVCS_Time::Time_Base_Offset(0x82B60000, 0x0A990E2D6);
+ORBSVCS_Time::Time_Base_Offset(0x9e7d0000, 0x0A993A60F);
 #else
 const ACE_UINT64
-ORBSVCS_Time::Time_Base_Offset(ACE_UINT64_LITERAL(12218515200000000000));
+ORBSVCS_Time::Time_Base_Offset(ACE_UINT64_LITERAL(12219292800000000000));
 #endif
 
 TAO_END_VERSIONED_NAMESPACE_DECL
