@@ -1,17 +1,18 @@
-// Service_Type_Repository.cpp,v 1.53 2005/01/28 15:56:34 jtc Exp
+// $Id: Service_Type_Repository.cpp 77079 2007-02-12 19:41:31Z johnnyw $
 
-#include "Service_Type_Repository.h"
+#include "orbsvcs/Trader/Service_Type_Repository.h"
 
 #include "ace/Lock_Adapter_T.h"
 
 
 ACE_RCSID (Trader,
            Service_Type_Repository,
-           "Service_Type_Repository.cpp,v 1.53 2005/01/28 15:56:34 jtc Exp")
+           "$Id: Service_Type_Repository.cpp 77079 2007-02-12 19:41:31Z johnnyw $")
 
 
-TAO_Service_Type_Repository::
-TAO_Service_Type_Repository (ACE_Lock* lock)
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+TAO_Service_Type_Repository::TAO_Service_Type_Repository (ACE_Lock* lock)
   : lock_ (lock)
 {
   this->incarnation_.low = 0;
@@ -43,8 +44,7 @@ TAO_Service_Type_Repository::~TAO_Service_Type_Repository (void)
 }
 
 CosTradingRepos::ServiceTypeRepository::IncarnationNumber
-TAO_Service_Type_Repository::incarnation (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_Service_Type_Repository::incarnation (void)
 {
   CosTradingRepos::ServiceTypeRepository::IncarnationNumber inc_num;
 
@@ -68,75 +68,47 @@ TAO_Service_Type_Repository::
 add_type (const char *name,
           const char *if_name,
           const CosTradingRepos::ServiceTypeRepository::PropStructSeq &props,
-          const CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq &super_types
-          ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosTrading::IllegalServiceType,
-                   CosTradingRepos::ServiceTypeRepository::ServiceTypeExists,
-                   CosTradingRepos::ServiceTypeRepository::InterfaceTypeMismatch,
-                   CosTrading::IllegalPropertyName,
-                   CosTrading::DuplicatePropertyName,
-                   CosTradingRepos::ServiceTypeRepository::ValueTypeRedefinition,
-                   CosTrading::UnknownServiceType,
-                   CosTradingRepos::ServiceTypeRepository::DuplicateServiceTypeName))
+          const CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq &super_types)
 {
   Prop_Map prop_map;
   Service_Type_Map super_map;
-  CosTradingRepos::ServiceTypeRepository::IncarnationNumber inc_num;
-
-  inc_num.low = 0;
-  inc_num.high = 0;
-
-  // With exceptions enabled, inc_num isn't used.
-  ACE_UNUSED_ARG (inc_num);
 
   ACE_WRITE_GUARD_THROW_EX (ACE_Lock, ace_mon, *this->lock_, CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (inc_num);
 
   // Make sure Type name is valid.
   if (TAO_Trader_Base::is_valid_identifier_name (name) == 0)
-    ACE_THROW_RETURN (CosTrading::IllegalServiceType (name),
-                      this->incarnation_);
+    throw CosTrading::IllegalServiceType (name);
 
   // Check if the service type already exists.
-  TAO_String_Hash_Key type_name (name);
+  CORBA::String_var type_name (name);
   if (this->type_map_.find (type_name) == 0)
-    ACE_THROW_RETURN (CosTradingRepos::ServiceTypeRepository::ServiceTypeExists (),
-                      this->incarnation_);
+    throw CosTradingRepos::ServiceTypeRepository::ServiceTypeExists ();
 
   // Make sure all property names are valid and appear only once.
   this->validate_properties (prop_map,
-                             props
-                             ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (this->incarnation_);
+                             props);
 
   // Check that all super_types exist, and none are duplicated.
   this->validate_supertypes (super_map,
-                             super_types
-                             ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (this->incarnation_);
+                             super_types);
 
   // NOTE: I don't really know a way to do this without an Interface
   // Repository, since the Interface Repository IDs don't contain
   // information about supertypes.
   //
   // make sure interface name is legal.
-  //  this->validate_interface (if_name, super_types ACE_ENV_ARG_PARAMETER);
-  //  ACE_CHECK_RETURN (this->incarnation);
+  //  this->validate_interface (if_name, super_types);
   //
   // Instead, we do this:
   //
   if (if_name == 0)
-    ACE_THROW_RETURN (CosTradingRepos::ServiceTypeRepository::InterfaceTypeMismatch (),
-                      this->incarnation_);
+    throw CosTradingRepos::ServiceTypeRepository::InterfaceTypeMismatch ();
 
   // Collect and make sure that properties of all supertypes and this
   // type are compatible.  We can use prop_map and super_types_map for
   // the job.
   this->validate_inheritance (prop_map,
-                              super_types
-                              ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (this->incarnation_);
+                              super_types);
 
   // We can now use prop_map to construct a sequence of all properties
   // the this type.
@@ -161,29 +133,23 @@ add_type (const char *name,
 }
 
 void
-TAO_Service_Type_Repository::remove_type (const char *name
-                                          ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosTrading::IllegalServiceType,
-                   CosTrading::UnknownServiceType,
-                   CosTradingRepos::ServiceTypeRepository::HasSubTypes))
+TAO_Service_Type_Repository::remove_type (const char *name)
 {
   if (TAO_Trader_Base::is_valid_identifier_name (name) == 0)
-    ACE_THROW (CosTrading::IllegalServiceType (name));
+    throw CosTrading::IllegalServiceType (name);
 
   ACE_WRITE_GUARD_THROW_EX (ACE_Lock, ace_mon, *this->lock_, CORBA::INTERNAL ());
-  ACE_CHECK;
 
   // Check if the type exists.
   Service_Type_Map::ENTRY* type_entry = 0; ;
   if (this->type_map_.find (name,
                             type_entry) == -1)
-    ACE_THROW (CosTrading::UnknownServiceType (name));
+    throw CosTrading::UnknownServiceType (name);
 
   // Check if it has any subtypes.
   Type_Info *type_info = type_entry->int_id_;
   if (type_info->has_subtypes_)
-    ACE_THROW (CosTradingRepos::ServiceTypeRepository::HasSubTypes (name, ""));
+    throw CosTradingRepos::ServiceTypeRepository::HasSubTypes (name, "");
 
   // Remove the type from the map.
   this->type_map_.unbind (type_entry);
@@ -192,12 +158,9 @@ TAO_Service_Type_Repository::remove_type (const char *name
 
 CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq *
 TAO_Service_Type_Repository::
-list_types (const CosTradingRepos::ServiceTypeRepository::SpecifiedServiceTypes &which_types
-            ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+list_types (const CosTradingRepos::ServiceTypeRepository::SpecifiedServiceTypes &which_types)
 {
   ACE_READ_GUARD_THROW_EX (ACE_Lock, ace_mon, *this->lock_, CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (0);
 
   CORBA::ULong i = 0;
   CORBA::ULong length = static_cast<CORBA::ULong> (this->type_map_.current_size ());
@@ -238,31 +201,25 @@ list_types (const CosTradingRepos::ServiceTypeRepository::SpecifiedServiceTypes
 
 CosTradingRepos::ServiceTypeRepository::TypeStruct *
 TAO_Service_Type_Repository::
-describe_type (const char * name
-               ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosTrading::IllegalServiceType,
-                   CosTrading::UnknownServiceType))
+describe_type (const char * name)
 {
   if (TAO_Trader_Base::is_valid_identifier_name (name) == 0)
-    ACE_THROW_RETURN
-      (CosTrading::IllegalServiceType (name),
-       (CosTradingRepos::ServiceTypeRepository::TypeStruct *) 0);
+    {
+      throw CosTrading::IllegalServiceType (name);
+    }
 
   ACE_READ_GUARD_THROW_EX
     (ACE_Lock,
      ace_mon,
      *this->lock_,
      CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (0);
 
   // Make sure the type exists.
-  TAO_String_Hash_Key type_name (name);
+  CORBA::String_var type_name (name);
   Service_Type_Map::ENTRY *type_entry = 0;
   if (this->type_map_.find (type_name,
                             type_entry) == -1)
-    ACE_THROW_RETURN (CosTrading::UnknownServiceType (name),
-                      (CosTradingRepos::ServiceTypeRepository::TypeStruct *) 0);
+    throw CosTrading::UnknownServiceType (name);
 
   // Return appropriate information about the type.
   CosTradingRepos::ServiceTypeRepository::TypeStruct *descr = 0;
@@ -288,26 +245,19 @@ describe_type (const char * name
 
 CosTradingRepos::ServiceTypeRepository::TypeStruct *
 TAO_Service_Type_Repository::
-fully_describe_type (const char *name
-                     ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosTrading::IllegalServiceType,
-                   CosTrading::UnknownServiceType))
+fully_describe_type (const char *name)
 {
   if (TAO_Trader_Base::is_valid_identifier_name (name) == 0)
-    ACE_THROW_RETURN (CosTrading::IllegalServiceType (name),
-                      0);
+    throw CosTrading::IllegalServiceType (name);
 
   ACE_READ_GUARD_THROW_EX (ACE_Lock, ace_mon, *this->lock_, CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (0);
 
   // Make sure the type exists.
-  TAO_String_Hash_Key type_name (name);
+  CORBA::String_var type_name (name);
   Service_Type_Map::ENTRY *type_entry = 0;
   if (this->type_map_.find (type_name,
                             type_entry) == -1)
-    ACE_THROW_RETURN (CosTrading::UnknownServiceType (name),
-                      0);
+    throw CosTrading::UnknownServiceType (name);
 
   // Return appropriate information about the type.
   CosTradingRepos::ServiceTypeRepository::TypeStruct *descr = 0;
@@ -334,61 +284,50 @@ fully_describe_type (const char *name
 
 void
 TAO_Service_Type_Repository::
-mask_type (const char *name
-           ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CosTrading::IllegalServiceType,
-                   CosTrading::UnknownServiceType,
-                   CosTradingRepos::ServiceTypeRepository::AlreadyMasked))
+mask_type (const char *name)
 {
   if (TAO_Trader_Base::is_valid_identifier_name (name) == 0)
-    ACE_THROW (CosTrading::IllegalServiceType (name));
+    throw CosTrading::IllegalServiceType (name);
 
   ACE_WRITE_GUARD_THROW_EX (ACE_Lock, ace_mon, *this->lock_, CORBA::INTERNAL ());
 
   // Make sure the type exists.
-  TAO_String_Hash_Key type_name (name);
+  CORBA::String_var type_name (name);
   Service_Type_Map::ENTRY *type_entry = 0;
   if (this->type_map_.find (type_name,
                             type_entry) != -1)
-    ACE_THROW (CosTrading::UnknownServiceType (name));
+    throw CosTrading::UnknownServiceType (name);
 
   // Make sure the type is unmasked.
   CORBA::Boolean &mask =
     type_entry->int_id_->type_struct_.masked;
 
   if (mask == 1)
-    ACE_THROW (CosTradingRepos::ServiceTypeRepository::AlreadyMasked (name));
+    throw CosTradingRepos::ServiceTypeRepository::AlreadyMasked (name);
   else
     mask = 1;
 }
 
 void
-TAO_Service_Type_Repository::
-unmask_type (const char *name
-             ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                  CosTrading::IllegalServiceType,
-                  CosTrading::UnknownServiceType,
-                  CosTradingRepos::ServiceTypeRepository::NotMasked))
+TAO_Service_Type_Repository::unmask_type (const char *name)
 {
   if (TAO_Trader_Base::is_valid_identifier_name (name) == 0)
-    ACE_THROW (CosTrading::IllegalServiceType (name));
+    throw CosTrading::IllegalServiceType (name);
 
   ACE_WRITE_GUARD_THROW_EX (ACE_Lock, ace_mon, *this->lock_, CORBA::INTERNAL ());
 
   // Make sure the type exists.
-  TAO_String_Hash_Key type_name (name);
+  CORBA::String_var type_name (name);
   Service_Type_Map::ENTRY *type_entry = 0;
   if (this->type_map_.find (type_name,
                             type_entry) != -1)
-    ACE_THROW (CosTrading::UnknownServiceType (name));
+    throw CosTrading::UnknownServiceType (name);
 
   // Make sure the type is masked.
   CORBA::Boolean &mask = type_entry->int_id_->type_struct_.masked;
 
   if (mask == 0)
-    ACE_THROW (CosTradingRepos::ServiceTypeRepository::NotMasked (name));
+    throw CosTradingRepos::ServiceTypeRepository::NotMasked (name);
   else
     mask = 0;
 }
@@ -417,7 +356,7 @@ fully_describe_type_i (const CosTradingRepos::ServiceTypeRepository::TypeStruct
       Service_Type_Map::ENTRY *type_entry = 0;
 
       iterator.next (next_type_name);
-      TAO_String_Hash_Key hash_key (const_cast<const char *> (*next_type_name));
+      CORBA::String_var hash_key (const_cast<const char *> (*next_type_name));
       this->type_map_.find (hash_key,
                             type_entry);
 
@@ -448,7 +387,7 @@ fully_describe_type_i (const CosTradingRepos::ServiceTypeRepository::TypeStruct
       Service_Type_Map::ENTRY *type_entry = 0;
 
       iterator.next (next_type_name);
-      TAO_String_Hash_Key hash_key (const_cast<const char *> (*next_type_name));
+      CORBA::String_var hash_key (const_cast<const char *> (*next_type_name));
       this->type_map_.find (hash_key,
                             type_entry);
 
@@ -479,7 +418,7 @@ collect_inheritance_hierarchy (const CosTradingRepos::ServiceTypeRepository::Typ
        i--)
     {
       Service_Type_Map::ENTRY *next_type_entry = 0;
-      TAO_String_Hash_Key next_type_name (type_struct.super_types[i]);
+      CORBA::String_var next_type_name (type_struct.super_types[i]);
 
       if (this->type_map_.find (next_type_name, next_type_entry) != -1)
         {
@@ -499,10 +438,7 @@ collect_inheritance_hierarchy (const CosTradingRepos::ServiceTypeRepository::Typ
 void
 TAO_Service_Type_Repository::
 validate_properties (Prop_Map &prop_map,
-                     const CosTradingRepos::ServiceTypeRepository::PropStructSeq &props
-                     ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CosTrading::IllegalPropertyName,
-                   CosTrading::DuplicatePropertyName))
+                     const CosTradingRepos::ServiceTypeRepository::PropStructSeq &props)
 {
   for (CORBA::ULong i = 0;
        i < props.length ();
@@ -510,16 +446,16 @@ validate_properties (Prop_Map &prop_map,
     {
       const char *n = props[i].name;
       if (TAO_Trader_Base::is_valid_property_name (n) == 0)
-        ACE_THROW (CosTrading::IllegalPropertyName (n));
+        throw CosTrading::IllegalPropertyName (n);
       else
         {
-          TAO_String_Hash_Key prop_name (n);
+          CORBA::String_var prop_name (n);
           CosTradingRepos::ServiceTypeRepository::PropStruct *prop_val =
             const_cast<CosTradingRepos::ServiceTypeRepository::PropStruct *> (&props[i]);
 
           if (prop_map.bind (prop_name,
                              prop_val) == 1)
-            ACE_THROW (CosTrading::DuplicatePropertyName (n));
+            throw CosTrading::DuplicatePropertyName (n);
         }
     }
 }
@@ -527,11 +463,7 @@ validate_properties (Prop_Map &prop_map,
 void
 TAO_Service_Type_Repository::
 validate_supertypes (Service_Type_Map &super_map,
-                     const CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq &super_types
-                     ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CosTrading::IllegalServiceType,
-                   CosTrading::UnknownServiceType,
-                   CosTradingRepos::ServiceTypeRepository::DuplicateServiceTypeName))
+                     const CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq &super_types)
 {
   for (CORBA::ULong i = 0;
        i < super_types.length ();
@@ -541,20 +473,21 @@ validate_supertypes (Service_Type_Map &super_map,
         super_types[i];
 
       if (TAO_Trader_Base::is_valid_identifier_name (type) == 0)
-        ACE_THROW (CosTrading::IllegalServiceType (type));
+        throw CosTrading::IllegalServiceType (type);
       else
         {
-          TAO_String_Hash_Key hash_type (type);
+          CORBA::String_var hash_type (type);
           Service_Type_Map::ENTRY *type_entry = 0;
 
           if (this->type_map_.find (hash_type,
                                     type_entry) == -1)
-            ACE_THROW (CosTrading::UnknownServiceType (type));
+            throw CosTrading::UnknownServiceType (type);
           else
             {
               if (super_map.bind (hash_type,
                                   type_entry->int_id_) == 1)
-                ACE_THROW (CosTradingRepos::ServiceTypeRepository::DuplicateServiceTypeName (type));
+                throw CosTradingRepos::ServiceTypeRepository::DuplicateServiceTypeName (
+                  type);
             }
         }
     }
@@ -563,9 +496,7 @@ validate_supertypes (Service_Type_Map &super_map,
 void
 TAO_Service_Type_Repository::
 validate_inheritance (Prop_Map &prop_map,
-                      const CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq &super_types
-                      ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CosTradingRepos::ServiceTypeRepository::ValueTypeRedefinition))
+                      const CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq &super_types)
 {
   CORBA::ULong num_super_types = super_types.length ();
 
@@ -574,7 +505,7 @@ validate_inheritance (Prop_Map &prop_map,
        i++)
     {
       Service_Type_Map::ENTRY *super_type_entry = 0;
-      TAO_String_Hash_Key super_type (super_types[i]);
+      CORBA::String_var super_type (super_types[i]);
       CosTradingRepos::ServiceTypeRepository::ServiceTypeNameSeq place_holder;
       CosTradingRepos::ServiceTypeRepository::PropStructSeq super_props;
 
@@ -595,7 +526,7 @@ validate_inheritance (Prop_Map &prop_map,
            j++)
         {
           Prop_Map::ENTRY *existing_prop = 0;
-          TAO_String_Hash_Key prop_name (super_props[j].name);
+          CORBA::String_var prop_name (super_props[j].name);
 
           if (prop_map.bind (prop_name,
                              &super_props[j],
@@ -609,31 +540,27 @@ validate_inheritance (Prop_Map &prop_map,
 
               CORBA::TypeCode_ptr prop_type = property_in_map.value_type.in ();
               int compare = 0;
-              ACE_TRY
+              try
                 {
                   compare =
-                    super_props[j].value_type->equal (prop_type
-                                                      ACE_ENV_ARG_PARAMETER);
-                  ACE_TRY_CHECK;
+                    super_props[j].value_type->equal (prop_type);
                 }
-              ACE_CATCHANY
+              catch (const CORBA::Exception&)
                 {
-                ACE_TRY_THROW (CosTradingRepos::ServiceTypeRepository::ValueTypeRedefinition
-                               (super_props[j].name,
-                                super_props[j],
-                                property_in_map.name,
-                                property_in_map));
+                throw CosTradingRepos::ServiceTypeRepository::ValueTypeRedefinition(
+                  super_props[j].name,
+                  super_props[j],
+                  property_in_map.name,
+                  property_in_map);
                 }
-              ACE_ENDTRY;
-              ACE_CHECK;
 
               if (compare == 0
                   || super_props[j].mode > property_in_map.mode)
-                ACE_THROW (CosTradingRepos::ServiceTypeRepository::ValueTypeRedefinition
-                           (super_props[j].name,
-                            super_props[j],
-                            property_in_map.name,
-                            property_in_map));
+                throw CosTradingRepos::ServiceTypeRepository::ValueTypeRedefinition(
+                  super_props[j].name,
+                  super_props[j],
+                  property_in_map.name,
+                  property_in_map);
             }
         }
     }
@@ -686,30 +613,8 @@ update_type_map (const char *name,
                                     psbuf,
                                     1);
   */
-  TAO_String_Hash_Key type_name (name);
+  CORBA::String_var type_name (name);
   this->type_map_.bind (type_name, type);
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-template class ACE_Hash_Map_Entry<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*>;
-template class ACE_Hash_Map_Manager_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Base_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Reverse_Iterator_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Entry<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*>;
-template class ACE_Hash_Map_Manager_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Base_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Reverse_Iterator_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>;
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate ACE_Hash_Map_Entry<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*>
-#pragma instantiate ACE_Hash_Map_Manager_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<TAO_String_Hash_Key, CosTradingRepos::ServiceTypeRepository::PropStruct*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Entry<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*>
-#pragma instantiate ACE_Hash_Map_Manager_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<TAO_String_Hash_Key, TAO_Service_Type_Repository::Type_Info*, ACE_Hash<TAO_String_Hash_Key>, ACE_Equal_To<TAO_String_Hash_Key>, ACE_Null_Mutex>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
