@@ -1,6 +1,8 @@
-// Trading_Loader.h,v 1.12 2005/02/18 09:07:08 jwillemsen Exp
+// -*- C++ -*-
 
-// ===========================================================================================
+// $Id: Trading_Loader.h 77001 2007-02-12 07:54:49Z johnnyw $
+
+// ===========================================================================
 // FILENAME
 //   Trading_Loader.h
 //
@@ -11,23 +13,24 @@
 // AUTHORS
 //   Priyanka Gontla <pgontla@ece.uci.edu>
 //
-// ==========================================================================================
+// ==========================================================================
 
 #ifndef TAO_TRADING_LOADER_H
 #define TAO_TRADING_LOADER_H
 
-#include "tao/Object_Loader.h"
-#include "tao/Utils/ORB_Manager.h"
-#include "ace/Auto_Ptr.h"
+#include "orbsvcs/Trader/Trader.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #include "orbsvcs/IOR_Multicast.h"
-#include "orbsvcs/Trader/Trader.h"
 #include "orbsvcs/Trader/Service_Type_Repository.h"
 
+#include "tao/Object_Loader.h"
+#include "tao/Utils/ORB_Manager.h"
+#include "ace/Auto_Ptr.h"
+
 class TAO_Trading_Serv_Export TAO_Trading_Loader : public TAO_Object_Loader
 {
 public:
@@ -46,24 +49,22 @@ public:
   // Called by the Service Configurator framework to remove the
   // Event Service. Defined in <ace/Service_Config.h>
 
-  int run (ACE_ENV_SINGLE_ARG_DECL);
+  int run (void);
   // Run the Trading Service
 
   CORBA::Object_ptr create_object (CORBA::ORB_ptr orb,
                                    int argc,
-                                   ACE_TCHAR *argv[]
-                                   ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                                   ACE_TCHAR *argv[]);
   // This function call initializes the Trading Service given a reference to the
   // ORB and the command line parameters.
 
- protected:
+protected:
 
   int init_multicast_server (void);
   // Enable the Trading Service to answer multicast requests for its
   // IOR.
 
-  int bootstrap_to_federation (ACE_ENV_SINGLE_ARG_DECL);
+  int bootstrap_to_federation (void);
   // Bootstrap to another trader, and attach to its trader network.
 
   int parse_args (int &argc, ACE_TCHAR *argv []);
@@ -100,9 +101,11 @@ public:
   CORBA::Boolean dumpior_;
   // Flag indication whether to dump the ior to standard output
 
- private:
-   ACE_UNIMPLEMENTED_FUNC (TAO_Trading_Loader (const TAO_Trading_Loader &))
-   ACE_UNIMPLEMENTED_FUNC (TAO_Trading_Loader &operator= (const TAO_Trading_Loader &))
+private:
+
+  // Disallow copying and assignment.
+  TAO_Trading_Loader (const TAO_Trading_Loader &);
+  TAO_Trading_Loader &operator= (const TAO_Trading_Loader &);
 
 };
 
