@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// Roundtrip.h,v 1.3 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Roundtrip.h 81861 2008-06-08 21:10:48Z sowayaa $
 
 #ifndef ROUNDTRIP_H
 #define ROUNDTRIP_H
@@ -23,12 +23,9 @@ public:
 
   // = The skeleton methods
   virtual Test::Timestamp test_method (Test::Timestamp send_time,
-		                       Test::number cl_number
-                                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                                       Test::number cl_number);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
 private:
   /// Use an ORB reference to conver strings to objects and shutdown
