@@ -1,4 +1,4 @@
-// $Id: client.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: client.cpp 85152 2009-04-23 08:32:53Z johnnyw $
 
 #include "RT_Class.h"
 #include "ORB_Holder.h"
@@ -28,9 +28,9 @@
 #include "ace/Sched_Params.h"
 #include "ace/Barrier.h"
 
-ACE_RCSID(TAO_RTEC_PERF_Roundtrip, client, "$Id: client.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
+ACE_RCSID(TAO_RTEC_PERF_Roundtrip, client, "$Id: client.cpp 85152 2009-04-23 08:32:53Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT ("file://test.ior");
 int nthreads   = 0;
 int high_priority_period = 0;
 int high_priority_workload = 0;
@@ -63,9 +63,9 @@ private:
 };
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:n:l:h:w:v:zr");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:n:l:h:w:v:zr"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -124,7 +124,7 @@ parse_args (int argc, char *argv[])
   return 0;
 }
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   TAO_EC_Default_Factory::init_svcs();
   RT_Class rt_class;
