@@ -1,12 +1,12 @@
 //
-// Roundtrip.cpp,v 1.4 2004/09/24 18:00:42 parsons Exp
+// $Id: Roundtrip.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 //
 #include "Roundtrip.h"
 #include "ace/High_Res_Timer.h"
 
-ACE_RCSID (TAO_RTEC_Perf_RTCORBA_Baseline, 
-           Roundtrip, 
-           "Roundtrip.cpp,v 1.4 2004/09/24 18:00:42 parsons Exp")
+ACE_RCSID (TAO_RTEC_Perf_RTCORBA_Baseline,
+           Roundtrip,
+           "$Id: Roundtrip.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 Roundtrip::Roundtrip (CORBA::ORB_ptr orb)
   : orb_ (CORBA::ORB::_duplicate (orb))
@@ -16,13 +16,11 @@ Roundtrip::Roundtrip (CORBA::ORB_ptr orb)
 
 Test::Timestamp
 Roundtrip::test_method (Test::Timestamp send_time,
-                        CORBA::Long workload_in_usecs
-                        ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                        CORBA::Long workload_in_usecs)
 {
   ACE_hrtime_t start = ACE_OS::gethrtime ();
   CORBA::Long elapsed = 0;
-  
+
   while (elapsed < workload_in_usecs)
     {
       elapsed =
@@ -30,13 +28,12 @@ Roundtrip::test_method (Test::Timestamp send_time,
             (ACE_OS::gethrtime () - start) / this->gsf_
           );
     }
-    
+
   return send_time;
 }
 
 void
-Roundtrip::shutdown (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Roundtrip::shutdown (void)
 {
-  this->orb_->shutdown (0 ACE_ENV_ARG_PARAMETER);
+  this->orb_->shutdown (0);
 }
