@@ -1,4 +1,4 @@
-// $Id: server.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: server.cpp 82735 2008-09-16 12:12:29Z johnnyw $
 
 #include "RT_Class.h"
 #include "ORB_Holder.h"
@@ -16,16 +16,16 @@
 
 ACE_RCSID (TAO_PERF_RTEC_RTCORBA_Baseline,
            server,
-           "$Id: server.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: server.cpp 82735 2008-09-16 12:12:29Z johnnyw $")
 
-const char *ior_output_file = "test.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT ("test.ior");
 int use_rt_corba = 0;
 int nthreads = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:n:r");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:n:r"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -58,7 +58,7 @@ parse_args (int argc, char *argv[])
   return 0;
 }
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   /// Move the test to the real-time class if it is possible.
   RT_Class rt_class;
