@@ -1,7 +1,7 @@
 /**
  * @file Callback.h
  *
- * Callback.h,v 1.3 2005/07/04 08:55:12 jwillemsen Exp
+ * $Id: Callback.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  */
 
@@ -36,12 +36,9 @@ public:
   //@{
   /** @name The RtecEventComm::PushCallback methods
    */
-  virtual void sample (Test::Timestamp the_timestamp
-                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void sample (Test::Timestamp the_timestamp);
 
-  PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  PortableServer::POA_ptr _default_POA (void);
   //@}
 
 private:
