@@ -1,5 +1,5 @@
 //
-// Session.h,v 1.3 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Session.h 77020 2007-02-12 13:56:49Z johnnyw $
 //
 
 #ifndef SESSION_H
@@ -18,15 +18,11 @@ public:
            PortableServer::POA_ptr poa);
 
   // = The skeleton methods
-  virtual void sample (Test::Timestamp the_timestamp
-                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void sample (Test::Timestamp the_timestamp);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
-  virtual PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual PortableServer::POA_ptr _default_POA (void);
 
 private:
   Test::Callback_var cb_;
