@@ -1,5 +1,5 @@
 //
-// Session_Factory.h,v 1.3 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Session_Factory.h 77020 2007-02-12 13:56:49Z johnnyw $
 //
 
 #ifndef SESSION_FACTORY_H
@@ -18,15 +18,11 @@ public:
                    PortableServer::POA_ptr poa);
 
   // = The skeleton methods
-  virtual Test::Session_ptr create_new_session (Test::Callback_ptr cb
-                                                ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual Test::Session_ptr create_new_session (Test::Callback_ptr cb);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
-  PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  PortableServer::POA_ptr _default_POA (void);
 
 private:
   /// Use an ORB reference to shutdown the application.
