@@ -1,4 +1,4 @@
-// $Id: client.cpp 76641 2007-01-26 18:25:17Z elliott_c $
+// $Id: client.cpp 82914 2008-10-02 19:24:42Z johnnyw $
 
 #include "Callback.h"
 
@@ -28,7 +28,7 @@
 
 ACE_RCSID (TAO_PERF_RTEC_RTCORBA_Baseline,
            client,
-           "$Id: client.cpp 76641 2007-01-26 18:25:17Z elliott_c $")
+           "$Id: client.cpp 82914 2008-10-02 19:24:42Z johnnyw $")
 
 class Roundtrip_Task : public ACE_Task_Base
 {
@@ -180,7 +180,7 @@ private:
   int period_in_usecs_;
 };
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   /// Move the test to the real-time class if it is possible.
   RT_Class rt_class;
@@ -281,12 +281,12 @@ int main (int argc, char *argv[])
         high_priority.callback->sample_history ();
       if (options.dump_history)
         {
-          history.dump_samples ("HISTORY", gsf);
+          history.dump_samples (ACE_TEXT("HISTORY"), gsf);
         }
 
       ACE_Basic_Stats high_priority_stats;
       history.collect_basic_stats (high_priority_stats);
-      high_priority_stats.dump_results ("High Priority", gsf);
+      high_priority_stats.dump_results (ACE_TEXT("High Priority"), gsf);
 
       low_priority.wait ();
 
