@@ -1,4 +1,4 @@
-// $Id: client.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: client.cpp 82914 2008-10-02 19:24:42Z johnnyw $
 
 #include "RT_Class.h"
 #include "ORB_Holder.h"
@@ -27,9 +27,9 @@
 #include "ace/Sched_Params.h"
 #include "ace/Barrier.h"
 
-ACE_RCSID(TAO_RTEC_PERF_Roundtrip, client, "$Id: client.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+ACE_RCSID(TAO_RTEC_PERF_Roundtrip, client, "$Id: client.cpp 82914 2008-10-02 19:24:42Z johnnyw $")
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   const CORBA::Long experiment_id = 1;
 
@@ -189,16 +189,16 @@ int main (int argc, char *argv[])
         high_priority_group.consumer ()->sample_history ();
       if (options.dump_history)
         {
-          history.dump_samples ("HISTORY", gsf);
+          history.dump_samples (ACE_TEXT("HISTORY"), gsf);
         }
 
       ACE_Basic_Stats high_priority_stats;
       history.collect_basic_stats (high_priority_stats);
-      high_priority_stats.dump_results ("High Priority", gsf);
+      high_priority_stats.dump_results (ACE_TEXT("High Priority"), gsf);
 
       ACE_Basic_Stats low_priority_stats;
       low_priority_setup.collect_basic_stats (low_priority_stats);
-      low_priority_stats.dump_results ("Low Priority", gsf);
+      low_priority_stats.dump_results (ACE_TEXT("Low Priority"), gsf);
 
       ACE_DEBUG ((LM_DEBUG, "(%P|%t) client - starting cleanup\n"));
     }
