@@ -1,7 +1,7 @@
 /**
  * @file Client_Options.cpp
  *
- * $Id: Client_Options.cpp 73075 2006-06-09 18:31:05Z jwillemsen $
+ * $Id: Client_Options.cpp 82976 2008-10-08 11:32:47Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -13,10 +13,10 @@
 
 ACE_RCSID (TAO_PERF_RTEC,
            Client_Options,
-           "$Id: Client_Options.cpp 73075 2006-06-09 18:31:05Z jwillemsen $")
+           "$Id: Client_Options.cpp 82976 2008-10-08 11:32:47Z johnnyw $")
 
-Client_Options::Client_Options (int &argc, char *argv[])
-  : ior ("file://test.ior")
+Client_Options::Client_Options (int &argc, ACE_TCHAR *argv[])
+  : ior (ACE_TEXT("file://test.ior"))
   , iterations (1000)
   , nthreads (0)
   , high_priority_period (0)
@@ -35,9 +35,9 @@ Client_Options::Client_Options (int &argc, char *argv[])
 
   while (arg_shifter.is_anything_left ())
     {
-      const char *arg = arg_shifter.get_current ();
+      const ACE_TCHAR *arg = arg_shifter.get_current ();
 
-      if (ACE_OS::strcmp (arg, "-k") == 0)
+      if (ACE_OS::strcmp (arg, ACE_TEXT("-k")) == 0)
         {
           arg_shifter.consume_arg ();
 
@@ -48,20 +48,20 @@ Client_Options::Client_Options (int &argc, char *argv[])
             }
         }
 
-      else if (option (arg_shifter, "-i", iterations)) {}
-      else if (option (arg_shifter, "-n", nthreads)) {}
-      else if (option (arg_shifter, "-h", high_priority_period)) {}
-      else if (option (arg_shifter, "-l", low_priority_period)) {}
-      else if (option (arg_shifter, "-w", low_priority_workload)) {}
-      else if (option (arg_shifter, "-v", high_priority_workload)) {}
-      else if (option (arg_shifter, "-c", low_priority_consumers)) {}
+      else if (option (arg_shifter, ACE_TEXT("-i"), iterations)) {}
+      else if (option (arg_shifter, ACE_TEXT("-n"), nthreads)) {}
+      else if (option (arg_shifter, ACE_TEXT("-h"), high_priority_period)) {}
+      else if (option (arg_shifter, ACE_TEXT("-l"), low_priority_period)) {}
+      else if (option (arg_shifter, ACE_TEXT("-w"), low_priority_workload)) {}
+      else if (option (arg_shifter, ACE_TEXT("-v"), high_priority_workload)) {}
+      else if (option (arg_shifter, ACE_TEXT("-c"), low_priority_consumers)) {}
 
-      else if (boolean_option (arg_shifter, "-d", dump_history)) {}
-      else if (boolean_option (arg_shifter, "-r", use_rt_corba)) {}
-      else if (boolean_option (arg_shifter, "-g", global_low_priority_rate)) {}
-      else if (boolean_option (arg_shifter, "-u", unique_low_priority_event)) {}
-      else if (boolean_option (arg_shifter, "-f", funky_supplier_publication)) {}
-      else if (boolean_option (arg_shifter, "-x", high_priority_is_last)) {}
+      else if (boolean_option (arg_shifter, ACE_TEXT("-d"), dump_history)) {}
+      else if (boolean_option (arg_shifter, ACE_TEXT("-r"), use_rt_corba)) {}
+      else if (boolean_option (arg_shifter, ACE_TEXT("-g"), global_low_priority_rate)) {}
+      else if (boolean_option (arg_shifter, ACE_TEXT("-u"), unique_low_priority_event)) {}
+      else if (boolean_option (arg_shifter, ACE_TEXT("-f"), funky_supplier_publication)) {}
+      else if (boolean_option (arg_shifter, ACE_TEXT("-x"), high_priority_is_last)) {}
 
       else
         {
@@ -72,8 +72,8 @@ Client_Options::Client_Options (int &argc, char *argv[])
 
 int
 Client_Options::option (ACE_Arg_Shifter &arg_shifter,
-                 const char *option_name,
-                 int &option_value)
+                        const ACE_TCHAR *option_name,
+                        int &option_value)
 {
   if (ACE_OS::strcmp (arg_shifter.get_current (), option_name) != 0)
     return 0;
@@ -93,8 +93,8 @@ Client_Options::option (ACE_Arg_Shifter &arg_shifter,
 
 int
 Client_Options::boolean_option (ACE_Arg_Shifter &arg_shifter,
-                         const char *option_name,
-                         int &option_value)
+                                const ACE_TCHAR *option_name,
+                                int &option_value)
 {
   if (ACE_OS::strcmp (arg_shifter.get_current (), option_name) != 0)
     return 0;
