@@ -1,7 +1,7 @@
 /**
  * @file Client_Options.h
  *
- * $Id: Client_Options.h 73075 2006-06-09 18:31:05Z jwillemsen $
+ * $Id: Client_Options.h 82976 2008-10-08 11:32:47Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  *
@@ -28,9 +28,9 @@ class TAO_RTEC_Perf_Export Client_Options
 {
 public:
   /// Constructor
-  Client_Options (int &argc, char *argv[]);
+  Client_Options (int &argc, ACE_TCHAR *argv[]);
 
-  const char *ior;
+  const ACE_TCHAR *ior;
   int iterations;
   int nthreads;
   int high_priority_period;
@@ -48,11 +48,11 @@ public:
 
 private:
   int option (ACE_Arg_Shifter &arg_shifter,
-              const char *option_name,
+              const ACE_TCHAR *option_name,
               int &option_value);
 
   int boolean_option (ACE_Arg_Shifter &arg_shifter,
-                      const char *option_name,
+                      const ACE_TCHAR *option_name,
                       int &option_value);
 };
 
