@@ -1,7 +1,7 @@
 /**
  * @file Consumer.cpp
  *
- * Consumer.cpp,v 1.6 2004/08/16 23:53:14 jtc Exp
+ * $Id: Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -11,9 +11,9 @@
 #include "orbsvcs/Event_Service_Constants.h"
 #include "ace/OS_NS_unistd.h"
 
-ACE_RCSID (TAO_PERF_RTEC, 
-           Consumer, 
-           "Consumer.cpp,v 1.6 2004/08/16 23:53:14 jtc Exp")
+ACE_RCSID (TAO_PERF_RTEC,
+           Consumer,
+           "$Id: Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 Consumer::Consumer (CORBA::Long experiment_id,
                     CORBA::Long event_type,
@@ -31,12 +31,10 @@ Consumer::Consumer (CORBA::Long experiment_id,
 }
 
 void
-Consumer::connect (RtecEventChannelAdmin::EventChannel_ptr ec
-                   ACE_ENV_ARG_DECL)
+Consumer::connect (RtecEventChannelAdmin::EventChannel_ptr ec)
 {
   RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin =
-    ec->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    ec->for_consumers ();
 
   {
     ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->mutex_);
@@ -44,13 +42,11 @@ Consumer::connect (RtecEventChannelAdmin::EventChannel_ptr ec
       return;
 
     this->proxy_supplier_ =
-      consumer_admin->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-    ACE_CHECK;
+      consumer_admin->obtain_push_supplier ();
   }
 
   RtecEventComm::PushConsumer_var consumer =
-    this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->_this ();
 
   RtecEventChannelAdmin::ConsumerQOS consumer_qos;
   consumer_qos.is_gateway = 0;
@@ -66,13 +62,11 @@ Consumer::connect (RtecEventChannelAdmin::EventChannel_ptr ec
   h1.source = this->experiment_id_;
 
   this->proxy_supplier_->connect_push_consumer (consumer.in (),
-                                                consumer_qos
-                                                ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                                consumer_qos);
 }
 
 void
-Consumer::disconnect (ACE_ENV_SINGLE_ARG_DECL)
+Consumer::disconnect (void)
 {
   RtecEventChannelAdmin::ProxyPushSupplier_var proxy;
   {
@@ -82,15 +76,12 @@ Consumer::disconnect (ACE_ENV_SINGLE_ARG_DECL)
     proxy = this->proxy_supplier_._retn ();
   }
 
-  Implicit_Deactivator deactivator (this
-                                    ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  Implicit_Deactivator deactivator (this);
 
-  ACE_TRY {
-    proxy->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-    ACE_TRY_CHECK;
-  } ACE_CATCHANY {
-  } ACE_ENDTRY;
+  try{
+    proxy->disconnect_push_supplier ();
+  } catch (const CORBA::Exception&) {
+  }
 }
 
 ACE_Sample_History &
@@ -100,9 +91,7 @@ Consumer::sample_history (void)
 }
 
 void
-Consumer::push (const RtecEventComm::EventSet &events
-                ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Consumer::push (const RtecEventComm::EventSet &events)
 {
   ACE_hrtime_t now = ACE_OS::gethrtime ();
 
@@ -125,8 +114,7 @@ Consumer::push (const RtecEventComm::EventSet &events
 }
 
 void
-Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Consumer::disconnect_push_consumer (void)
 {
   ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->mutex_);
   this->proxy_supplier_ =
@@ -134,8 +122,7 @@ Consumer::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 }
 
 PortableServer::POA_ptr
-Consumer::_default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Consumer::_default_POA (void)
 {
   return PortableServer::POA::_duplicate (this->default_POA_.in ());
 }
