@@ -1,7 +1,7 @@
 /**
  * @file Implicit_Deactivator.h
  *
- * Implicit_Deactivator.h,v 1.2 2005/02/14 10:57:14 jwillemsen Exp
+ * $Id: Implicit_Deactivator.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -23,8 +23,7 @@ public:
   /**
    * @param client The client
    */
-  explicit Implicit_Deactivator (PortableServer::Servant servant = 0
-                                 ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+  explicit Implicit_Deactivator (PortableServer::Servant servant = 0);
   Implicit_Deactivator (Implicit_Deactivator& rhs);
   Implicit_Deactivator& operator= (Implicit_Deactivator& rhs);
 
