@@ -1,7 +1,7 @@
 /**
  * @file Loopback.cpp
  *
- * Loopback.cpp,v 1.2 2004/02/04 20:20:23 parsons Exp
+ * $Id: Loopback.cpp 77020 2007-02-12 13:56:49Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -10,37 +10,28 @@
 #include "Auto_Disconnect.h"
 #include "Implicit_Deactivator.h"
 
-ACE_RCSID (TAO_RTEC_Perf, 
-           Loopback, 
-           "Loopback.cpp,v 1.2 2004/02/04 20:20:23 parsons Exp")
+ACE_RCSID (TAO_RTEC_Perf,
+           Loopback,
+           "$Id: Loopback.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 Loopback::Loopback (CORBA::Long experiment_id,
                     CORBA::Long base_event_type,
                     PortableServer::POA_ptr supplier_poa,
                     PortableServer::POA_ptr consumer_poa,
-                    RtecEventChannelAdmin::EventChannel_ptr ec
-                    ACE_ENV_ARG_DECL)
+                    RtecEventChannelAdmin::EventChannel_ptr ec)
 {
   this->loopback_pair_.init (experiment_id,
                              base_event_type,
                              supplier_poa,
                              consumer_poa);
 
-  this->loopback_pair_.connect (ec ACE_ENV_ARG_PARAMETER);
+  this->loopback_pair_.connect (ec);
 }
 
 void
-Loopback::disconnect (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+Loopback::disconnect (void)
 {
   Auto_Disconnect<Loopback_Pair> disconnect (&this->loopback_pair_);
 
-  Implicit_Deactivator deactivator (this ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  Implicit_Deactivator deactivator (this);
 }
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
