@@ -1,7 +1,7 @@
 /**
  * @file Loopback.h
  *
- * Loopback.h,v 1.3 2005/07/04 08:55:12 jwillemsen Exp
+ * $Id: Loopback.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  */
 
@@ -30,14 +30,12 @@ public:
             CORBA::Long base_event_type,
             PortableServer::POA_ptr supplier_poa,
             PortableServer::POA_ptr consumer_poa,
-            RtecEventChannelAdmin::EventChannel_ptr ec
-            ACE_ENV_ARG_DECL);
+            RtecEventChannelAdmin::EventChannel_ptr ec);
 
   //@{
   /** @name The Federated_Test::Loopback methods
    */
-  virtual void disconnect (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect (void);
   //@}
 
 private:
