@@ -1,7 +1,7 @@
 /**
  * @file Loopback_Supplier.h
  *
- * Loopback_Supplier.h,v 1.7 2005/07/04 08:55:12 jwillemsen Exp
+ * $Id: Loopback_Supplier.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -37,23 +37,18 @@ public:
                      PortableServer::POA_ptr poa);
 
   /// Connect to the event channel
-  void connect (RtecEventChannelAdmin::EventChannel_ptr ec
-                ACE_ENV_ARG_DECL);
+  void connect (RtecEventChannelAdmin::EventChannel_ptr ec);
 
   /// Disconnect from the event channel
-  void disconnect (ACE_ENV_SINGLE_ARG_DECL);
+  void disconnect (void);
 
-  void push (const RtecEventComm::EventSet &events
-             ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void push (const RtecEventComm::EventSet &events);
 
   //@{
   /** @name The RtecEventComm::PushSupplier methods
    */
-  virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-  virtual PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_push_supplier (void);
+  virtual PortableServer::POA_ptr _default_POA (void);
   //@}
 
 private:
