@@ -1,7 +1,7 @@
 /**
  * @file ORB_Holder.cpp
  *
- * $Id: ORB_Holder.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+ * $Id: ORB_Holder.cpp 82869 2008-09-29 08:02:27Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -14,9 +14,9 @@
 
 ACE_RCSID (TAO_PERF_RTEC,
            ORB_Holder,
-           "$Id: ORB_Holder.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: ORB_Holder.cpp 82869 2008-09-29 08:02:27Z johnnyw $")
 
-ORB_Holder::ORB_Holder (int &argc, char *argv[],
+ORB_Holder::ORB_Holder (int &argc, ACE_TCHAR *argv[],
                         const char *orb_id)
   :  orb_ (CORBA::ORB_init (argc, argv, orb_id))
 {
