@@ -1,7 +1,7 @@
 /**
  * @file Peer_Base.h
  *
- * Peer_Base.h,v 1.5 2005/07/04 08:55:12 jwillemsen Exp
+ * $Id: Peer_Base.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  *
@@ -32,8 +32,7 @@ class TAO_RTEC_Perf_Export Peer_Base
 public:
   /// Constructor
   Peer_Base (CORBA::ORB_ptr orb,
-             RTServer_Setup &rtserver_setup
-             ACE_ENV_ARG_DECL);
+             RTServer_Setup &rtserver_setup);
 
   /// Destructor
   virtual ~Peer_Base (void);
@@ -41,24 +40,17 @@ public:
   //@{
   /** @name The Federated_Test::Peer methods
    */
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
   virtual CORBA::Object_ptr
-      channel (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-        ACE_THROW_SPEC ((CORBA::SystemException));
+      channel (void);
 
-  virtual void connect (Federated_Test::Peer_ptr remote_peer
-                        ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void connect (Federated_Test::Peer_ptr remote_peer);
 
   Federated_Test::Loopback_ptr setup_loopback (CORBA::Long experiment_id,
-                                               CORBA::Long base_event_type
-                                               ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                                               CORBA::Long base_event_type);
 
-  PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  PortableServer::POA_ptr _default_POA (void);
   //@}
 
 protected:
