@@ -1,7 +1,7 @@
 /**
  * @file RTClient_Setup.cpp
  *
- * RTClient_Setup.cpp,v 1.5 2004/02/04 20:20:23 parsons Exp
+ * $Id: RTClient_Setup.cpp 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -16,40 +16,34 @@
 #include "RTClient_Setup.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (TAO_PERF_RTEC, 
-           RTClient_Setup, 
-           "RTClient_Setup.cpp,v 1.5 2004/02/04 20:20:23 parsons Exp")
+ACE_RCSID (TAO_PERF_RTEC,
+           RTClient_Setup,
+           "$Id: RTClient_Setup.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
 
 RTClient_Setup::RTClient_Setup (int use_rt_corba,
                                 CORBA::ORB_ptr orb,
                                 const RT_Class &rt_class,
-                                int nthreads
-                                ACE_ENV_ARG_DECL)
+                                int nthreads)
   : use_rt_corba_ (use_rt_corba)
-  , syncscope_setup_ (orb ACE_ENV_ARG_PARAMETER)
+  , syncscope_setup_ (orb)
 {
-  ACE_CHECK;
 
   if (use_rt_corba)
     {
       ACE_AUTO_PTR_RESET (this->rtcorba_setup_,
                           new RTCORBA_Setup (orb,
                                              rt_class,
-                                             nthreads
-                                             ACE_ENV_ARG_PARAMETER),
+                                             nthreads),
                           RTCORBA_Setup
                          );
-      ACE_CHECK;
 
 #if 0
       ACE_AUTO_PTR_RESET (this->priorityband_setup_,
                           new PriorityBand_Setup (orb,
-                                                  *this->rtcorba_setup_
-                                                  ACE_ENV_ARG_PARAMETER),
+                                                  *this->rtcorba_setup_),
                           PriorityBand_Setup
                          );
-      ACE_CHECK;
-        
+
 #endif /* 0 */
     }
 }
