@@ -1,7 +1,7 @@
 /**
  * @file RTClient_Setup.h
  *
- * RTClient_Setup.h,v 1.2 2003/07/21 23:51:33 dhinton Exp
+ * $Id: RTClient_Setup.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -34,8 +34,7 @@ public:
   RTClient_Setup (int use_rt_corba,
                   CORBA::ORB_ptr orb,
                   const RT_Class &rt_class,
-                  int nthreads
-                  ACE_ENV_ARG_DECL);
+                  int nthreads);
 
   /// Return non-zero if RTCORBA is enabled
   int use_rt_corba (void) const;
