@@ -1,7 +1,7 @@
 /**
  * @file RTEC_Initializer.cpp
  *
- * RTEC_Initializer.cpp,v 1.7 2004/08/16 23:53:14 jtc Exp
+ * $Id: RTEC_Initializer.cpp 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -15,15 +15,14 @@
 
 #include "ace/Dynamic_Service.h"
 
-ACE_RCSID (TAO_PERF_RTEC, 
-           RTEC_Initializer, 
-           "RTEC_Initializer.cpp,v 1.7 2004/08/16 23:53:14 jtc Exp")
+ACE_RCSID (TAO_PERF_RTEC,
+           RTEC_Initializer,
+           "$Id: RTEC_Initializer.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
 
 TAO_EC_Event_Channel *
 RTEC_Initializer::create (PortableServer::POA_ptr consumer_poa,
                           PortableServer::POA_ptr supplier_poa,
-                          RTCORBA_Setup * rtcorba_setup
-                          ACE_ENV_ARG_DECL_NOT_USED)
+                          RTCORBA_Setup * rtcorba_setup)
 {
   TAO_EC_Event_Channel_Attributes attr (consumer_poa,
                                         supplier_poa);
