@@ -1,7 +1,7 @@
 /**
  * @file RTServer_Setup.cpp
  *
- * RTServer_Setup.cpp,v 1.10 2004/02/04 20:20:23 parsons Exp
+ * $Id: RTServer_Setup.cpp 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -16,32 +16,27 @@
 #include "RTServer_Setup.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (TAO_PERF_RTEC, 
-           RTServer_Setup, 
-           "RTServer_Setup.cpp,v 1.10 2004/02/04 20:20:23 parsons Exp")
+ACE_RCSID (TAO_PERF_RTEC,
+           RTServer_Setup,
+           "$Id: RTServer_Setup.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
 
 RTServer_Setup::RTServer_Setup (int use_rt_corba,
                                 CORBA::ORB_ptr orb,
                                 const RT_Class &rt_class,
-                                int nthreads
-                                ACE_ENV_ARG_DECL)
+                                int nthreads)
   : RTClient_Setup (use_rt_corba,
                     orb,
                     rt_class,
-                    nthreads
-                    ACE_ENV_ARG_PARAMETER)
+                    nthreads)
 {
-  ACE_CHECK;
 
   if (use_rt_corba)
     {
       ACE_AUTO_PTR_RESET (this->rtpoa_setup_,
                           new RTPOA_Setup (orb,
-                                           *this->rtcorba_setup ()
-                                           ACE_ENV_ARG_PARAMETER),
+                                           *this->rtcorba_setup ()),
                           RTPOA_Setup
                          );
-      ACE_CHECK;
 
       this->poa_ =
         this->rtpoa_setup_->poa ();
@@ -50,8 +45,6 @@ RTServer_Setup::RTServer_Setup (int use_rt_corba,
     {
       this->poa_ =
         RIR_Narrow<RTPortableServer::POA>::resolve (orb,
-                                                    "RootPOA"
-                                                    ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                                    "RootPOA");
     }
 }
