@@ -1,7 +1,7 @@
 /**
  * @file SyncScope_Setup.h
  *
- * SyncScope_Setup.h,v 1.3 2002/03/04 16:56:37 coryan Exp
+ * $Id: SyncScope_Setup.h 76589 2007-01-25 18:04:11Z elliott_c $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -26,12 +26,10 @@ class TAO_RTEC_Perf_Export SyncScope_Setup
 {
 public:
   /// Constructor
-  SyncScope_Setup (CORBA::ORB_ptr orb
-                   ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+  SyncScope_Setup (CORBA::ORB_ptr orb);
 
   SyncScope_Setup (CORBA::ORB_ptr orb,
-                   Messaging::SyncScope value
-                   ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+                   Messaging::SyncScope value);
 
   /// Destructor
   /**
@@ -42,8 +40,7 @@ public:
 private:
   /// Implement the shared code between both constructors
   void init (CORBA::ORB_ptr orb,
-             Messaging::SyncScope value
-             ACE_ENV_ARG_DECL);
+             Messaging::SyncScope value);
 };
 
 #if defined(__ACE_INLINE__)
