@@ -1,4 +1,4 @@
-// $Id: sender.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: sender.cpp 83504 2008-10-30 12:52:14Z johnnyw $
 
 #include "sender.h"
 #include "tao/debug.h"
@@ -169,10 +169,10 @@ Sender::shut_down (void)
 
 int
 Sender::parse_args (int argc,
-                    char **argv)
+                    ACE_TCHAR *argv[])
 {
   /// Parse command line arguments
-  ACE_Get_Opt opts (argc, argv, "s:f:r:d");
+  ACE_Get_Opt opts (argc, argv, ACE_TEXT("s:f:r:d"));
 
   int c;
   while ((c= opts ()) != -1)
@@ -180,13 +180,13 @@ Sender::parse_args (int argc,
       switch (c)
         {
         case 'f':
-          this->filename_ = opts.opt_arg ();
+          this->filename_ = ACE_TEXT_ALWAYS_CHAR (opts.opt_arg ());
           break;
         case 'r':
           this->frame_rate_ = ACE_OS::atoi (opts.opt_arg ());
           break;
         case 's':
-          this->sender_name_ = opts.opt_arg ();
+          this->sender_name_ = ACE_TEXT_ALWAYS_CHAR (opts.opt_arg ());
           break;
         case 'd':
           TAO_debug_level++;
@@ -201,7 +201,7 @@ Sender::parse_args (int argc,
 
 int
 Sender::init (int argc,
-              char **argv)
+              ACE_TCHAR *argv[])
 {
   /// Initialize the endpoint strategy with the orb and poa.
   int result =
@@ -243,7 +243,7 @@ Sender::init (int argc,
 
   if (this->input_file_ == 0)
     ACE_ERROR_RETURN ((LM_DEBUG,
-                       "Cannot open input file %s\n",
+                       "Cannot open input file %C\n",
                        this->filename_.c_str ()),
                       -1);
   else
@@ -436,14 +436,12 @@ Sender::connection_manager (void)
 //  }
 
 int
-main (int argc,
-      char **argv)
+ACE_TMAIN (int argc,
+      ACE_TCHAR *argv[])
 {
   try
     {
-      CORBA::ORB_var orb = CORBA::ORB_init (argc,
-                                            argv,
-                                            0);
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var obj
         = orb->resolve_initial_references ("RootPOA");
