@@ -1,4 +1,4 @@
-// $Id: receiver.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: receiver.cpp 82226 2008-06-30 15:07:33Z sma $
 
 #include "receiver.h"
 #include "ace/Get_Opt.h"
@@ -6,7 +6,7 @@
 static FILE *output_file = 0;
 // File handle of the file into which received data is written.
 
-static const char *output_file_name = "output";
+static const ACE_TCHAR *output_file_name = ACE_TEXT ("output");
 // File name of the file into which received data is written.
 
 int
@@ -89,7 +89,7 @@ Receiver::~Receiver (void)
 
 int
 Receiver::init (int,
-                char **)
+                ACE_TCHAR *[])
 {
   // Initialize the endpoint strategy with the orb and poa.
   int result =
@@ -132,7 +132,7 @@ Receiver::init (int,
 
 int
 parse_args (int argc,
-            char **argv)
+            ACE_TCHAR *argv[])
 {
   // Parse the command line arguments
   ACE_Get_Opt opts (argc,
@@ -158,16 +158,14 @@ parse_args (int argc,
 }
 
 int
-main (int argc,
-      char **argv)
+ACE_TMAIN (int argc,
+      ACE_TCHAR *argv[])
 {
   try
     {
       // Initialize the ORB first.
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         0);
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var obj
         = orb->resolve_initial_references ("RootPOA");
