@@ -1,4 +1,4 @@
-// $Id: receiver.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: receiver.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "receiver.h"
 #include "ace/Get_Opt.h"
@@ -7,10 +7,10 @@
 static FILE *output_file = 0;
 // File handle of the file into which received data is written.
 
-static const char *output_file_name = "output";
+static const ACE_TCHAR *output_file_name = ACE_TEXT ("output");
 // File name of the file into which received data is written.
 
-static const char* stats_file_name = "Stats.dat";
+static const ACE_TCHAR *stats_file_name = ACE_TEXT ("Stats.dat");
 
 int stats [1000010];
 long stats_index = 0;
@@ -43,8 +43,8 @@ Receiver_Callback::receive_frame (ACE_Message_Block *frame,
   // the sender.
   //
   ACE_DEBUG ((LM_DEBUG,
-	      "Receiver_Callback::receive_frame for frame %d\n",
-	      this->frame_count_++));
+              "Receiver_Callback::receive_frame for frame %d\n",
+              this->frame_count_++));
 
   if (start)
     {
@@ -77,8 +77,6 @@ Receiver_Callback::receive_frame (ACE_Message_Block *frame,
       frame = frame->cont ();
     }
 
-
-
   return 0;
 }
 
@@ -86,14 +84,14 @@ void
 Receiver_Callback::dump_samples (const char* file)
 {
   ACE_DEBUG ((LM_DEBUG,
-	      "Dumping Stats.....\n"));
+              "Dumping Stats.....\n"));
 
   FILE* stats_file = ACE_OS::fopen (file, "w");
 
   if (stats_file == 0)
     {
       ACE_ERROR ((LM_ERROR,
-		  "Stats.dat cannot be opened \n"));
+                  "Stats.dat cannot be opened\n"));
     }
 
   int i;
@@ -102,9 +100,9 @@ Receiver_Callback::dump_samples (const char* file)
       stats_.sample ((ACE_UINT64)stats [i]);
     }
 
-  stats_.dump_results ("Inter Frame Arrival Time Statistics ",
-		       stats_file,
-		       1);
+  stats_.dump_results (ACE_TEXT("Inter Frame Arrival Time Statistics "),
+                       stats_file,
+                       1);
   //  ACE_High_Res_Timer::global_scale_factor ());
 
   for (i = 0; i < stats_index; i++)
@@ -115,7 +113,7 @@ Receiver_Callback::dump_samples (const char* file)
   ACE_OS::fclose (stats_file);
 
   ACE_DEBUG ((LM_DEBUG,
-	      "Done\n"));
+              "Done\n"));
 }
 
 int
@@ -125,7 +123,7 @@ Receiver_Callback::handle_destroy (void)
   ACE_DEBUG ((LM_DEBUG,
               "Receiver_Callback::end_stream\n"));
 
-  dump_samples (stats_file_name);
+  dump_samples (ACE_TEXT_ALWAYS_CHAR (stats_file_name));
 
   try
     {
@@ -152,7 +150,7 @@ Receiver::~Receiver (void)
 
 int
 Receiver::init (int,
-                char **)
+                ACE_TCHAR *[])
 {
   // Initialize the endpoint strategy with the orb and poa.
   int result =
@@ -196,7 +194,7 @@ Receiver::init (int,
 
 int
 parse_args (int argc,
-            char **argv)
+            ACE_TCHAR *argv[])
 {
   // Parse the command line arguments
   ACE_Get_Opt opts (argc,
@@ -211,9 +209,9 @@ parse_args (int argc,
         case 'f':
           output_file_name = opts.opt_arg ();
           break;
-	case 's':
-	  stats_file_name = opts.opt_arg ();
-	  break;
+        case 's':
+          stats_file_name = opts.opt_arg ();
+          break;
         default:
           ACE_ERROR_RETURN ((LM_ERROR,
                              "Usage: receiver -f filename"),
@@ -225,16 +223,13 @@ parse_args (int argc,
 }
 
 int
-main (int argc,
-      char **argv)
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
       // Initialize the ORB first.
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         0);
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var obj
         = orb->resolve_initial_references ("RootPOA");
