@@ -1,11 +1,11 @@
-// $Id: client.cpp 76872 2007-02-02 13:41:21Z johnnyw $
+// $Id: client.cpp 83504 2008-10-30 12:52:14Z johnnyw $
 
 #include "tao/IFR_Client/IFR_BasicC.h"
 #include "tao/ORB.h"
 #include "ace/OS_NS_string.h"
 #include "ace/Log_Msg.h"
 
-int main(int argc, char** argv)
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -39,7 +39,7 @@ int main(int argc, char** argv)
 
       if (ACE_OS::strcmp (name.in(), "int"))
       {
-        ACE_DEBUG ((LM_DEBUG, "CLIENT (%P): Interface name has been munged - it is now %s\n",
+        ACE_DEBUG ((LM_DEBUG, "CLIENT (%P): Interface name has been munged - it is now %C\n",
                       name.in()));
         return -1;
       }
