@@ -1,15 +1,35 @@
-// $Id: server.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: server.cpp 83253 2008-10-15 12:17:30Z vzykov $
 
 #include "ace/Get_Opt.h"
 #include "Test_i.h"
 #include "ace/OS_NS_stdio.h"
+#include "orbsvcs/Shutdown_Utilities.h"
 
-const char *ior_output_file = 0;
+const ACE_TCHAR *ior_output_file = 0;
+
+class Service_Shutdown_Functor : public Shutdown_Functor
+{
+public:
+  Service_Shutdown_Functor (CORBA::ORB_ptr orb)
+    : orb_(CORBA::ORB::_duplicate (orb))
+  {
+  }
+
+  void operator() (int which_signal)
+  {
+    ACE_DEBUG ((LM_DEBUG,
+                "shutting down on signal %d\n", which_signal));
+    (void) this->orb_->shutdown ();
+  }
+
+private:
+  CORBA::ORB_var orb_;
+};
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -40,6 +60,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv);
 
+      Service_Shutdown_Functor killer (orb.in ());
+      Service_Shutdown kill_contractor (killer);
+
       CORBA::Object_var poa_object =
         orb->resolve_initial_references ("RootPOA");
 
@@ -59,7 +82,8 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       Test_i server_impl (orb.in ());
 
-      root_poa->activate_object (&server_impl);
+      PortableServer::ObjectId_var tmp =
+        root_poa->activate_object (&server_impl);
 
 
       CORBA::Object_var server = server_impl._this();
