@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: client.cpp 82735 2008-09-16 12:12:29Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "tao/corba.h"
@@ -10,9 +10,9 @@
 CORBA::ORB_var orb = CORBA::ORB::_nil ();
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT(""));
   int c;
 
   while ((c = get_opts ()) != -1)
