@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Manager.h 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: Manager.h 82869 2008-09-29 08:02:27Z johnnyw $
 
 #ifndef BUG_2247_REGRESSION_MANAGER_H
 #define BUG_2247_REGRESSION_MANAGER_H
@@ -20,7 +20,7 @@ public:
   // Ctor
 
   void init (int argc,
-             char *argv[]);
+             ACE_TCHAR *argv[]);
 
   // Initialize the ORB, POA etc.
 
