@@ -1,4 +1,4 @@
-// $Id: client.h 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: client.h 82963 2008-10-07 15:21:02Z johnnyw $
 
 #ifndef BUG_2248_REGRESSION_CLIENT_H
 #define BUG_2248_REGRESSION_CLIENT_H
@@ -19,7 +19,7 @@ public:
   // Ctor
 
   void init (int& argc,
-             char**& argv);
+             ACE_TCHAR *argv[]);
 
   // Initialize the ORB, POA etc.
 
@@ -38,12 +38,12 @@ public:
 private:
 
   /// Write the merged IOGRs to a file
-  int write_to_file (CORBA::Object_ptr ior, const char* ior_output_file);
+  int write_to_file (CORBA::Object_ptr ior, const ACE_TCHAR* ior_output_file);
 
   /// Sets the properties for the profiles
   int set_properties (TAO_IOP::TAO_IOR_Manipulation_ptr iorm,
-		      CORBA::Object_ptr merged_set,
-		      CORBA::Object_ptr primary, CORBA::ULong version);
+                      CORBA::Object_ptr merged_set,
+                      CORBA::Object_ptr primary, CORBA::ULong version);
 
   /// Our ORB
   CORBA::ORB_var orb_;
