@@ -1,4 +1,4 @@
-// $Id: Server_Task.h 75834 2006-12-05 15:37:18Z vridosh $
+// $Id: Server_Task.h 82886 2008-09-30 18:03:46Z johnnyw $
 
 #include "ace/Task.h"
 #include "ace/Manual_Event.h"
@@ -11,7 +11,7 @@ class Server_Task : public ACE_Task_Base
 {
 public:
   /// Constructor
-  Server_Task (const char *output,
+  Server_Task (const ACE_TCHAR *output,
     CORBA::ORB_ptr sorb,
     ACE_Manual_Event &me,
     ACE_Thread_Manager *thr_mgr);
@@ -21,7 +21,7 @@ public:
 
 private:
   /// Output file for IOR
-  const char *output_;
+  const ACE_TCHAR *output_;
 
   /// Manual event to wake up the main thread to create a client
   /// thread.
