@@ -1,4 +1,4 @@
-// $Id: NamingTask.h 77384 2007-02-26 09:27:16Z johnnyw $
+// $Id: NamingTask.h 82211 2008-06-27 11:00:06Z sma $
 
 #ifndef NAMINGTASK_H
 #define NAMINGTASK_H
@@ -11,7 +11,7 @@
 class NamingTask : public ACE_Task_Base
 {
 public:
-  NamingTask (const char* orbname, int argc, char** argv, unsigned short port);
+  NamingTask (const char* orbname, int argc, ACE_TCHAR **argv, unsigned short port);
   virtual int svc();
   void waitInit ();
   void end();
