@@ -2,7 +2,7 @@
 
 //=============================================================================
 /**
- *  $Id: ServerORBInitializer2.h 80560 2008-02-04 13:42:31Z smcqueen $
+ *  $Id: ServerORBInitializer2.h 83307 2008-10-17 12:42:16Z smcqueen $
  */
 //=============================================================================
 #ifndef TAO249_SERVER_ORBINITIALIZER2_H
@@ -20,19 +20,25 @@
 
 #include "tao/LocalObject.h"
 
+class TAO249_ServerRequest_Interceptor2;
+
 /// RTCORBA ORB initializer.
 class Server_ORBInitializer2 :
   public virtual PortableInterceptor::ORBInitializer,
-  public virtual TAO_Local_RefCounted_Object
+  public virtual ::CORBA::LocalObject
 {
 public:
 
+  Server_ORBInitializer2 (void);
+
   virtual void pre_init (PortableInterceptor::ORBInitInfo_ptr info
                          );
 
   virtual void post_init (PortableInterceptor::ORBInitInfo_ptr info
                           );
 
+  void set_server_iogr (CORBA::Object_ptr obj);
+
 private:
 
   /// Register the necessary interceptors.
@@ -40,9 +46,10 @@ private:
          PortableInterceptor::ORBInitInfo_ptr info
          );
 
+  // Private temprorary pointer
+  TAO249_ServerRequest_Interceptor2 *sri_;
 };
 
 #include /**/ "ace/post.h"
 
 #endif /* TAO249_SERVER_ORBINITIALIZER2_H */
-
