@@ -2,7 +2,7 @@
 
 //=============================================================================
 /**
- *  $Id: ServerORBInitializer.h 80573 2008-02-05 22:02:41Z smcqueen $
+ *  $Id: ServerORBInitializer.h 81490 2008-04-28 14:32:24Z johnnyw $
  */
 //=============================================================================
 #ifndef TAO249_SERVER_ORBINITIALIZER_H
@@ -23,7 +23,7 @@
 /// RTCORBA ORB initializer.
 class Server_ORBInitializer :
   public virtual PortableInterceptor::ORBInitializer,
-  public virtual TAO_Local_RefCounted_Object
+  public virtual ::CORBA::LocalObject
 {
 public:
 
