@@ -1,4 +1,4 @@
-// CC_test_utils.cpp,v 1.8 2005/01/28 15:56:34 jtc Exp
+// $Id: CC_test_utils.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
 // ============================================================================
 //
@@ -22,7 +22,7 @@
 #include "ace/OS.h"
 #include "ace/Log_Msg.h"
 
-ACE_RCSID(Concurrency, CC_test_utils, "CC_test_utils.cpp,v 1.8 2005/01/28 15:56:34 jtc Exp")
+ACE_RCSID(Concurrency, CC_test_utils, "$Id: CC_test_utils.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
 
 char *CC_TestUtils::get_lock_mode_name (CosConcurrencyControl::lock_mode mode)
 {
@@ -50,24 +50,20 @@ CC_TestUtils::create_lock_set (void)
   // Create the lock set and return an obj ref corresponding to the
   // key.
   CosConcurrencyControl::LockSet_ptr lock_set(0);
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       lock_set =
-        CC_naming_service::Instance()->get_lock_set_factory ()->create (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CC_naming_service::Instance()->get_lock_set_factory ()->create ();
 
       if (CORBA::is_nil (lock_set))
         ACE_ERROR_RETURN ((LM_ERROR,
                            "null lock set objref returned by factory\n"),
                           0);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                           "CC_Client::create_lock_set");
+      ex._tao_print_exception ("CC_Client::create_lock_set");
       return 0;
     }
-  ACE_ENDTRY;
   return lock_set;
 }
