@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// MT_Disconnect.h,v 1.6 2004/10/04 17:53:27 elliott_c Exp
+// $Id: MT_Disconnect.h 76555 2007-01-24 15:39:09Z johnnyw $
 //
 // ============================================================================
 //
@@ -34,7 +34,7 @@ public:
   // = Check the ACE_Task_Base documentation.
   int svc (void);
 
-  void run_iteration (ACE_ENV_SINGLE_ARG_DECL);
+  void run_iteration (void);
   // Run a single iteration of the test
 
 private:
