@@ -1,4 +1,4 @@
-// Push_Event.cpp,v 1.7 2004/08/16 23:53:15 jtc Exp
+// $Id: Push_Event.cpp 78770 2007-07-04 05:19:15Z sowayaa $
 
 #include "Counting_Consumer.h"
 #include "Counting_Supplier.h"
@@ -8,32 +8,26 @@
 
 ACE_RCSID (CEC_Tests_Basic,
            Push_Event,
-           "Push_Event.cpp,v 1.7 2004/08/16 23:53:15 jtc Exp")
+           "$Id: Push_Event.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   TAO_CEC_Default_Factory::init_svcs ();
 
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       // ORB initialization boiler plate...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var object =
-        orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        orb->resolve_initial_references ("RootPOA");
       PortableServer::POA_var poa =
-        PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        PortableServer::POA::_narrow (object.in ());
       PortableServer::POAManager_var poa_manager =
-        poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        poa->the_POAManager ();
+      poa_manager->activate ();
 
       // ****************************************************************
 
@@ -41,24 +35,20 @@ main (int argc, char* argv[])
                                                   poa.in ());
 
       TAO_CEC_EventChannel ec_impl (attributes);
-      ec_impl.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      ec_impl.activate ();
 
       CosEventChannelAdmin::EventChannel_var event_channel =
-        ec_impl._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        ec_impl._this ();
 
       // ****************************************************************
 
       // Obtain the consumer admin..
       CosEventChannelAdmin::ConsumerAdmin_var consumer_admin =
-        event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel->for_consumers ();
 
       // Obtain the supplier admin..
       CosEventChannelAdmin::SupplierAdmin_var supplier_admin =
-        event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel->for_suppliers ();
 
       // ****************************************************************
 
@@ -66,49 +56,37 @@ main (int argc, char* argv[])
 
       CEC_Counting_Supplier supplier_00;
 
-      supplier_00.connect (supplier_admin.in ()
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_00.connect (supplier_admin.in ());
 
       // ****************************************************************
 
       CEC_Counting_Supplier supplier_01;
 
-      supplier_01.connect (supplier_admin.in ()
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_01.connect (supplier_admin.in ());
 
       // ****************************************************************
 
       CEC_Counting_Supplier supplier_10;
 
-      supplier_10.connect (supplier_admin.in ()
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_10.connect (supplier_admin.in ());
 
       // ****************************************************************
 
       CEC_Counting_Supplier supplier_11;
 
-      supplier_11.connect (supplier_admin.in ()
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_11.connect (supplier_admin.in ());
 
       // ****************************************************************
 
       // Create a consumer, intialize its RT_Info structures, and
       // connnect to the event channel....
       CEC_Counting_Consumer consumer_00 ("Consumer/00");
-      consumer_00.connect (consumer_admin.in ()
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer_00.connect (consumer_admin.in ());
 
       // ****************************************************************
 
       CEC_Counting_Consumer consumer_01 ("Consumer/01");
-      consumer_01.connect (consumer_admin.in ()
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer_01.connect (consumer_admin.in ());
 
       // ****************************************************************
 
@@ -147,33 +125,24 @@ main (int argc, char* argv[])
 
       // ****************************************************************
 
-      consumer_01.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer_01.disconnect ();
 
-      consumer_00.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer_00.disconnect ();
 
-      supplier_11.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      supplier_10.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      supplier_01.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      supplier_00.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_11.disconnect ();
+      supplier_10.disconnect ();
+      supplier_01.disconnect ();
+      supplier_00.disconnect ();
 
       // ****************************************************************
 
-      event_channel->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      event_channel->destroy ();
 
       // ****************************************************************
 
-      poa->destroy (1, 1 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      poa->destroy (1, 1);
 
-      orb->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      orb->destroy ();
 
       // ****************************************************************
 
@@ -186,11 +155,10 @@ main (int argc, char* argv[])
       consumer_00.dump_results (expected, 5);
       consumer_01.dump_results (expected, 5);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Service");
+      ex._tao_print_exception ("Service");
       return 1;
     }
-  ACE_ENDTRY;
   return 0;
 }
