@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Counting_Consumer.h,v 1.7 2004/08/16 23:53:15 jtc Exp
+// $Id: Counting_Consumer.h 77020 2007-02-12 13:56:49Z johnnyw $
 //
 // ============================================================================
 //
@@ -39,9 +39,8 @@ public:
   CEC_Counting_Consumer (const char* name);
   // Constructor
 
-  void connect (CosEventChannelAdmin::ConsumerAdmin_ptr consumer_admin
-                ACE_ENV_ARG_DECL);
-  void disconnect (ACE_ENV_SINGLE_ARG_DECL);
+  void connect (CosEventChannelAdmin::ConsumerAdmin_ptr consumer_admin);
+  void disconnect (void);
   // Simple connect/disconnect methods..
 
   void dump_results (int expected_count, int tolerance);
@@ -50,11 +49,8 @@ public:
 
   // = The CosEventComm::PushConsumer methods
 
-  virtual void push (const CORBA::Any& events
-                     ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-  virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void push (const CORBA::Any& events);
+  virtual void disconnect_push_consumer (void);
   // The skeleton methods.
 
   CORBA::ULong event_count;
@@ -85,22 +81,19 @@ public:
   CEC_Pull_Counting_Consumer (const char* name);
   // Constructor
 
-  void connect (CosEventChannelAdmin::ConsumerAdmin_ptr consumer_admin
-                ACE_ENV_ARG_DECL);
-  void disconnect (ACE_ENV_SINGLE_ARG_DECL);
+  void connect (CosEventChannelAdmin::ConsumerAdmin_ptr consumer_admin);
+  void disconnect (void);
   // Simple connect/disconnect methods..
 
   void dump_results (int expected_count, int tolerance);
   // Print out an error message if the event count is too far from the
   // expected count.
 
-  CORBA::Any *pull (ACE_ENV_SINGLE_ARG_DECL);
-  CORBA::Any *try_pull (CORBA::Boolean_out has_event
-                        ACE_ENV_ARG_DECL);
+  CORBA::Any *pull (void);
+  CORBA::Any *try_pull (CORBA::Boolean_out has_event);
 
   // = The CosEventComm::PullConsumer methods
-  virtual void disconnect_pull_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_pull_consumer (void);
   // The skeleton methods.
 
   CORBA::ULong event_count;
@@ -132,7 +125,7 @@ public:
   void stop (void);
   CORBA::ULong pull_count (void);
 
-  void run (ACE_ENV_SINGLE_ARG_DECL);
+  void run (void);
   // Run a single iteration of the test
 
 private:
