@@ -1,4 +1,5 @@
-// AddrServer.h,v 1.4 2004/08/16 23:53:15 jtc Exp
+// -*- C++ -*-
+// $Id: AddrServer.h 78534 2007-05-31 19:15:55Z mesnier_p $
 // Reused from: $TAO_ROOT/orbsvcs/examples/RtEC/MCast
 
 #ifndef ADDRSERVER_H
@@ -7,6 +8,10 @@
 
 #include "orbsvcs/RtecUDPAdminS.h"
 
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
+class ACE_INET_Addr;
+ACE_END_VERSIONED_NAMESPACE_DECL
+
 class AddrServer : public POA_RtecUDPAdmin::AddrServer
 {
   // = TITLE
@@ -22,17 +27,18 @@ class AddrServer : public POA_RtecUDPAdmin::AddrServer
   //   provided at initialization time.
   //
 public:
-  AddrServer (const RtecUDPAdmin::UDP_Addr& addr);
+  AddrServer (const ACE_INET_Addr &addr);
   // Constructor
 
   // = The RtecUDPAdmin::AddrServer methods
   virtual void get_addr (const RtecEventComm::EventHeader& header,
-                         RtecUDPAdmin::UDP_Addr_out addr
-                         ACE_ENV_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+                         RtecUDPAdmin::UDP_Addr_out addr);
+
+  virtual void get_address (const RtecEventComm::EventHeader& header,
+                            RtecUDPAdmin::UDP_Address_out addr);
 
 private:
-  RtecUDPAdmin::UDP_Addr addr_;
+  RtecUDPAdmin::UDP_Address addr_;
   // The address
 };
 
