@@ -1,4 +1,4 @@
-// Consumer.h,v 1.3 2004/08/16 23:53:15 jtc Exp
+// $Id: Consumer.h 77020 2007-02-12 13:56:49Z johnnyw $
 // Reused from: $TAO_ROOT/orbsvcs/examples/RtEC/MCast
 
 #ifndef CONSUMER_H
@@ -24,20 +24,16 @@ public:
   Consumer (void);
   // Constructor
 
-  void connect (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin
-                ACE_ENV_ARG_DECL);
+  void connect (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin);
   // Connect to the Event Channel
 
-  void disconnect (ACE_ENV_SINGLE_ARG_DECL);
+  void disconnect (void);
   // Disconnect from the event channel
 
   // = The RtecEventComm::PushConsumer methods
 
-  virtual void push (const RtecEventComm::EventSet& events
-                     ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-  virtual void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void push (const RtecEventComm::EventSet& events);
+  virtual void disconnect_push_consumer (void);
   // The skeleton methods.
 
 private:
