@@ -1,4 +1,4 @@
-// Supplier.h,v 1.3 2004/08/16 23:53:15 jtc Exp
+// $Id: Supplier.h 77020 2007-02-12 13:56:49Z johnnyw $
 // Reused from: $TAO_ROOT/orbsvcs/examples/RtEC/MCast
 
 #ifndef SUPPLIER_H
@@ -25,20 +25,18 @@ public:
   Supplier (void);
   // Constructor
 
-  void connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin
-                ACE_ENV_ARG_DECL);
+  void connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin);
   // Connect to the event channel
 
-  void disconnect (ACE_ENV_SINGLE_ARG_DECL);
+  void disconnect (void);
   // Disconnect from the event channel
 
-  void perform_push (ACE_ENV_SINGLE_ARG_DECL);
+  void perform_push (void);
   // Push a single event
 
   // = The RtecEventComm::PushSupplier methods
 
-  virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_push_supplier (void);
   // The skeleton methods.
 
 private:
