@@ -1,4 +1,4 @@
-// $Id: EC_Mcast.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: EC_Mcast.cpp 85653 2009-06-16 07:22:00Z olli $
 
 #include "EC_Mcast.h"
 
@@ -25,7 +25,7 @@
 
 ACE_RCSID (EC_Mcast,
            EC_Mcast,
-           "$Id: EC_Mcast.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+           "$Id: EC_Mcast.cpp 85653 2009-06-16 07:22:00Z olli $")
 
 ECM_Driver::ECM_Driver (void)
   : event_period_ (250000),
@@ -38,7 +38,7 @@ ECM_Driver::ECM_Driver (void)
 }
 
 int
-ECM_Driver::run (int argc, char* argv[])
+ECM_Driver::run (int argc, ACE_TCHAR* argv[])
 {
   try
     {
@@ -75,8 +75,8 @@ ECM_Driver::run (int argc, char* argv[])
                   this->event_period_,
                   this->event_count_,
 
-                  this->config_filename_?this->config_filename_:"nil",
-                  this->pid_filename_?this->pid_filename_:"nil") );
+                  this->config_filename_?this->config_filename_:ACE_TEXT("nil"),
+                  this->pid_filename_?this->pid_filename_:ACE_TEXT("nil")) );
 
       int i;
       for (i = 0; i < this->local_federations_count_; ++i)
@@ -309,9 +309,9 @@ ECM_Driver::dump_results (void)
 // ****************************************************************
 
 int
-ECM_Driver::parse_args (int argc, char *argv [])
+ECM_Driver::parse_args (int argc, ACE_TCHAR *argv [])
 {
-  ACE_Get_Opt get_opt (argc, argv, "l:p:c:n:t:f:");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("l:p:c:n:t:f:"));
   int opt;
 
   while ((opt = get_opt ()) != EOF)
@@ -338,7 +338,7 @@ ECM_Driver::parse_args (int argc, char *argv [])
           {
             char* aux;
             int i = 0;
-            for (char* arg = ACE_OS::strtok_r (get_opt.opt_arg (), ",", &aux);
+            for (char* arg = ACE_OS::strtok_r (ACE_TEXT_ALWAYS_CHAR(get_opt.opt_arg ()), ",", &aux);
                  arg != 0 && i < ECM_Driver::MAX_LOCAL_FEDERATIONS;
                  arg = ACE_OS::strtok_r (0, ",", &aux), ++i)
               {
@@ -416,7 +416,13 @@ ECM_Driver::parse_config_file (void)
       int port;
       if (this->skip_blanks (cfg, "reading federation port number"))
         return -1;
-      fscanf (cfg, "%d", &port);
+      s = fscanf (cfg, "%d", &port);
+      if (s == 0 || s == EOF)
+        {
+          ACE_ERROR_RETURN ((LM_ERROR,
+                             "problem reading federation port number\n"), -1);
+        }
+
       CORBA::UShort mcast_port = static_cast<CORBA::UShort> (port);
 
       int ns, nc;
@@ -521,7 +527,11 @@ ECM_Driver::skip_blanks (FILE* file,
 {
   int c;
   // Consume all the blanks.
-  while (ACE_OS::ace_isspace (c = ACE_OS::fgetc (file)));
+  while (ACE_OS::ace_isspace (c = ACE_OS::fgetc (file)))
+    {
+      // No action.
+    }
+
   if (c == EOF)
     {
       ACE_ERROR_RETURN ((LM_ERROR,
@@ -529,6 +539,7 @@ ECM_Driver::skip_blanks (FILE* file,
                          error_msg),
                         -1);
     }
+
   ACE_OS::ungetc (c, file);
   return 0;
 }
