@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// ECT_Driver.h,v 1.9 2005/01/05 14:18:46 jwillemsen Exp
+// $Id: ECT_Driver.h 78693 2007-06-30 06:13:27Z johnnyw $
 //
 // ============================================================================
 //
@@ -12,13 +12,18 @@
 #ifndef ECT_DRIVER_H
 #define ECT_DRIVER_H
 
+#include "tao/orbconf.h"
 #include "ace/Stats.h"
 #include "ace/CORBA_macros.h"
+#include "ace/Throughput_Stats.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 namespace CORBA
 {
   class Environment;
 }
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 class ECT_Driver
 {
   //
@@ -29,8 +34,7 @@ class ECT_Driver
 public:
   virtual ~ECT_Driver (void);
 
-  virtual void shutdown_consumer (void* consumer_cookie
-                                  ACE_ENV_ARG_DECL_NOT_USED) = 0;
+  virtual void shutdown_consumer (void* consumer_cookie) = 0;
   // Callback method for consumers, each consumer will call this
   // method once it receives all the shutdown events from the
   // suppliers.
