@@ -1,4 +1,4 @@
-// $Id: ECT_Throughput.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: ECT_Throughput.cpp 82977 2008-10-08 12:56:33Z johnnyw $
 
 #include "ECT_Throughput.h"
 
@@ -23,7 +23,7 @@
 
 ACE_RCSID (EC_Throughput,
            ECT_Throughput,
-           "$Id: ECT_Throughput.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+           "$Id: ECT_Throughput.cpp 82977 2008-10-08 12:56:33Z johnnyw $")
 
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
@@ -61,7 +61,7 @@ ECT_Throughput::~ECT_Throughput (void)
 }
 
 int
-ECT_Throughput::run (int argc, char* argv[])
+ECT_Throughput::run (int argc, ACE_TCHAR* argv[])
 {
   try
     {
@@ -123,7 +123,7 @@ ECT_Throughput::run (int argc, char* argv[])
                       this->supplier_type_count_,
                       this->supplier_type_shift_,
 
-                      this->pid_file_name_?this->pid_file_name_:"nil",
+                      this->pid_file_name_?this->pid_file_name_:ACE_TEXT("nil"),
                       this->ec_concurrency_hwm_
                       ) );
         }
@@ -416,30 +416,30 @@ ECT_Throughput::dump_results (void)
   ACE_Throughput_Stats consumers;
   for (int j = 0; j < this->n_consumers_; ++j)
     {
-      char buf[BUFSIZ];
-      ACE_OS::sprintf (buf, "consumer_%02d", j);
+      ACE_TCHAR buf[BUFSIZ];
+      ACE_OS::sprintf (buf, ACE_TEXT("consumer_%02d"), j);
 
       this->consumers_[j]->dump_results (buf, gsf);
       this->consumers_[j]->accumulate (consumers);
     }
-  consumers.dump_results ("ECT_Consumer/totals", gsf);
+  consumers.dump_results (ACE_TEXT("ECT_Consumer/totals"), gsf);
 
   ACE_Throughput_Stats suppliers;
   for (int i = 0; i < this->n_suppliers_; ++i)
     {
-      char buf[BUFSIZ];
-      ACE_OS::sprintf (buf, "supplier_%02d", i);
+      ACE_TCHAR buf[BUFSIZ];
+      ACE_OS::sprintf (buf, ACE_TEXT("supplier_%02d"), i);
 
       this->suppliers_[i]->dump_results (buf, gsf);
       this->suppliers_[i]->accumulate (suppliers);
     }
-  suppliers.dump_results ("ECT_Supplier/totals", gsf);
+  suppliers.dump_results (ACE_TEXT("ECT_Supplier/totals"), gsf);
 }
 
 int
-ECT_Throughput::parse_args (int argc, char *argv [])
+ECT_Throughput::parse_args (int argc, ACE_TCHAR *argv [])
 {
-  ACE_Get_Opt get_opt (argc, argv, "dc:s:u:n:t:b:h:l:p:w:");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("dc:s:u:n:t:b:h:l:p:w:"));
   int opt;
 
   while ((opt = get_opt ()) != EOF)
@@ -473,7 +473,7 @@ ECT_Throughput::parse_args (int argc, char *argv [])
         case 'h':
           {
             char* aux;
-                char* arg = ACE_OS::strtok_r (get_opt.opt_arg (), ",", &aux);
+                char* arg = ACE_OS::strtok_r (ACE_TEXT_ALWAYS_CHAR(get_opt.opt_arg ()), ",", &aux);
 
             this->consumer_type_start_ = ACE_ES_EVENT_UNDEFINED + ACE_OS::atoi (arg);
                 arg = ACE_OS::strtok_r (0, ",", &aux);
@@ -486,7 +486,7 @@ ECT_Throughput::parse_args (int argc, char *argv [])
         case 'l':
           {
             char* aux;
-                char* arg = ACE_OS::strtok_r (get_opt.opt_arg (), ",", &aux);
+                char* arg = ACE_OS::strtok_r (ACE_TEXT_ALWAYS_CHAR(get_opt.opt_arg ()), ",", &aux);
 
             this->supplier_type_start_ = ACE_ES_EVENT_UNDEFINED + ACE_OS::atoi (arg);
                 arg = ACE_OS::strtok_r (0, ",", &aux);
