@@ -3,7 +3,7 @@
 /**
  *  @file   BCast.h
  *
- *  $Id: BCast.h 78519 2007-05-29 14:54:16Z mesnier_p $
+ *  $Id: BCast.h 83342 2008-10-21 12:53:19Z vzykov $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  */
@@ -33,7 +33,7 @@ public:
 
   // = The EC_Driver methods
   /// add some command line args to enable/disable bcastions
-  virtual int parse_args (int& argc, char* argv[]);
+  virtual int parse_args (int& argc, ACE_TCHAR* argv[]);
   virtual void print_args (void) const;
   virtual void print_usage (void);
 
@@ -48,7 +48,7 @@ public:
 
 private:
   /// The IP address used to broadcast
-  const char* bcast_address_;
+  const ACE_TCHAR *bcast_address_;
 
   /// The port used to send and receive bcast messages...
   u_short bcast_port_;
