@@ -1,4 +1,4 @@
-// Disconnect.cpp,v 1.6 2004/08/16 23:53:15 jtc Exp
+// $Id: Disconnect.cpp 78770 2007-07-04 05:19:15Z sowayaa $
 
 #include "Counting_Supplier.h"
 #include "Counting_Consumer.h"
@@ -8,108 +8,87 @@
 #include "orbsvcs/Event/EC_Event_Channel.h"
 #include "orbsvcs/Event/EC_Default_Factory.h"
 
-ACE_RCSID (EC_Tests, 
-           Disconnect, 
-           "Disconnect.cpp,v 1.6 2004/08/16 23:53:15 jtc Exp")
+ACE_RCSID (EC_Tests,
+           Disconnect,
+           "$Id: Disconnect.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
 
 static void run_test (PortableServer::POA_ptr poa,
-                      int use_callbacks
-                      ACE_ENV_ARG_DECL);
+                      int use_callbacks);
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   TAO_EC_Default_Factory::init_svcs ();
 
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       // ORB initialization boiler plate...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var object =
-        orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        orb->resolve_initial_references ("RootPOA");
       PortableServer::POA_var poa =
-        PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        PortableServer::POA::_narrow (object.in ());
       PortableServer::POAManager_var poa_manager =
-        poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        poa->the_POAManager ();
+      poa_manager->activate ();
 
       // ****************************************************************
 
-      run_test (poa.in (), 0 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      run_test (poa.in (), 0);
 
-      run_test (poa.in (), 1 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      run_test (poa.in (), 1);
 
       // ****************************************************************
 
-      poa->destroy (1, 1 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      poa->destroy (1, 1);
 
-      orb->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      orb->destroy ();
 
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Service");
+      ex._tao_print_exception ("Service");
       return 1;
     }
-  ACE_ENDTRY;
   return 0;
 }
 
 // ****************************************************************
 
 void
-deactivate_servant (PortableServer::Servant servant
-                    ACE_ENV_ARG_DECL)
+deactivate_servant (PortableServer::Servant servant)
 {
   PortableServer::POA_var poa =
-    servant->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    servant->_default_POA ();
   PortableServer::ObjectId_var id =
-    poa->servant_to_id (servant ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
-  poa->deactivate_object (id.in () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    poa->servant_to_id (servant);
+  poa->deactivate_object (id.in ());
 }
 
 void
 run_test (PortableServer::POA_ptr poa,
-          int use_callbacks
-          ACE_ENV_ARG_DECL)
+          int use_callbacks)
 {
   TAO_EC_Event_Channel_Attributes attributes (poa, poa);
   attributes.disconnect_callbacks = use_callbacks;
 
   TAO_EC_Event_Channel ec_impl (attributes);
-  ec_impl.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  ec_impl.activate ();
 
   RtecEventChannelAdmin::EventChannel_var event_channel =
-    ec_impl._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    ec_impl._this ();
 
   // ****************************************************************
 
   // Obtain the consumer admin..
   RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin =
-    event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    event_channel->for_consumers ();
 
   // and the supplier admin..
   RtecEventChannelAdmin::SupplierAdmin_var supplier_admin =
-    event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    event_channel->for_suppliers ();
 
   // ****************************************************************
 
@@ -135,57 +114,37 @@ run_test (PortableServer::POA_ptr poa,
   for (int i = 0; i != iterations; ++i)
     {
       supplier_0.connect (supplier_admin.in (),
-                          supplier_qos.get_SupplierQOS ()
-                          ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                          supplier_qos.get_SupplierQOS ());
       consumer_0.connect (consumer_admin.in (),
-                          consumer_qos.get_ConsumerQOS ()
-                          ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                          consumer_qos.get_ConsumerQOS ());
       if (i % 2 == 1)
         {
           supplier_1.connect (supplier_admin.in (),
-                              supplier_qos.get_SupplierQOS ()
-                              ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+                              supplier_qos.get_SupplierQOS ());
           consumer_1.connect (consumer_admin.in (),
-                              consumer_qos.get_ConsumerQOS ()
-                              ACE_ENV_ARG_PARAMETER);
-          ACE_CHECK;
+                              consumer_qos.get_ConsumerQOS ());
         }
-      supplier_0.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
-      consumer_0.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
+      supplier_0.disconnect ();
+      consumer_0.disconnect ();
       if (i % 2 == 1)
         {
-          consumer_1.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_CHECK;
-          supplier_1.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_CHECK;
+          consumer_1.disconnect ();
+          supplier_1.disconnect ();
         }
     }
 
   supplier_0.connect (supplier_admin.in (),
-                      supplier_qos.get_SupplierQOS ()
-                      ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                      supplier_qos.get_SupplierQOS ());
   consumer_0.connect (consumer_admin.in (),
-                      consumer_qos.get_ConsumerQOS ()
-                      ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                      consumer_qos.get_ConsumerQOS ());
 
-  event_channel->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  event_channel->destroy ();
 
-  deactivate_servant (&supplier_0 ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  deactivate_servant (&supplier_0);
 
-  deactivate_servant (&consumer_0 ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  deactivate_servant (&consumer_0);
 
-  deactivate_servant (&ec_impl ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  deactivate_servant (&ec_impl);
 
   CORBA::ULong count_0 = 1;
   CORBA::ULong count_1 = 0;
@@ -221,11 +180,3 @@ run_test (PortableServer::POA_ptr poa,
                 supplier_1.disconnect_count, count_1,
                 use_callbacks));
 }
-
-// ****************************************************************
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
