@@ -1,4 +1,4 @@
-// Gateway.cpp,v 1.10 2004/08/16 23:53:15 jtc Exp
+// $Id: Gateway.cpp 78770 2007-07-04 05:19:15Z sowayaa $
 
 #include "Counting_Consumer.h"
 #include "Counting_Supplier.h"
@@ -8,34 +8,28 @@
 #include "orbsvcs/Event/EC_Default_Factory.h"
 #include "orbsvcs/Event/EC_Gateway_IIOP.h"
 
-ACE_RCSID (EC_Tests, 
-           Gateway, 
-           "Gateway.cpp,v 1.10 2004/08/16 23:53:15 jtc Exp")
+ACE_RCSID (EC_Tests,
+           Gateway,
+           "$Id: Gateway.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   TAO_EC_Default_Factory::init_svcs ();
 
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       // ORB initialization boiler plate...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var object =
-        orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        orb->resolve_initial_references ("RootPOA");
       PortableServer::POA_var poa =
-        PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        PortableServer::POA::_narrow (object.in ());
       PortableServer::POAManager_var poa_manager =
-        poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        poa->the_POAManager ();
+      poa_manager->activate ();
 
       // ****************************************************************
 
@@ -45,61 +39,50 @@ main (int argc, char* argv[])
       attributes.supplier_reconnect = 1;
 
       TAO_EC_Event_Channel ec_impl_1 (attributes);
-      ec_impl_1.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      ec_impl_1.activate ();
 
       RtecEventChannelAdmin::EventChannel_var event_channel_1 =
-        ec_impl_1._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        ec_impl_1._this ();
 
       // ****************************************************************
 
       TAO_EC_Event_Channel ec_impl_2 (attributes);
-      ec_impl_2.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      ec_impl_2.activate ();
 
       RtecEventChannelAdmin::EventChannel_var event_channel_2 =
-        ec_impl_2._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        ec_impl_2._this ();
 
       // ****************************************************************
 
       // Obtain the consumer admin..
       RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin_1 =
-        event_channel_1->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel_1->for_consumers ();
 
       // Obtain the supplier admin..
       RtecEventChannelAdmin::SupplierAdmin_var supplier_admin_1 =
-        event_channel_1->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel_1->for_suppliers ();
 
       // ****************************************************************
 
       // Obtain the consumer admin..
       RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin_2 =
-        event_channel_2->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel_2->for_consumers ();
 
       // Obtain the supplier admin..
       RtecEventChannelAdmin::SupplierAdmin_var supplier_admin_2 =
-        event_channel_2->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel_2->for_suppliers ();
 
       // ****************************************************************
 
       TAO_EC_Gateway_IIOP gateway;
       gateway.init (event_channel_1.in (),
-                    event_channel_2.in ()
-                    ACE_ENV_ARG_PARAMETER);
+                    event_channel_2.in ());
 
       RtecEventChannelAdmin::Observer_var obs =
-        gateway._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        gateway._this ();
 
       RtecEventChannelAdmin::Observer_Handle h =
-        event_channel_2->append_observer (obs.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel_2->append_observer (obs.in ());
 
       gateway.observer_handle (h);
 
@@ -112,30 +95,22 @@ main (int argc, char* argv[])
       EC_Counting_Supplier supplier_00;
 
       supplier_00.activate (consumer_admin_1.in (),
-                            milliseconds
-                            ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                            milliseconds);
       supplier_00.connect (supplier_admin_1.in (),
                            event_source,
                            event_type,
                            event_source,
-                           event_type
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                           event_type);
 
       EC_Counting_Supplier supplier_01;
 
       supplier_01.activate (consumer_admin_1.in (),
-                            milliseconds
-                            ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                            milliseconds);
       supplier_01.connect (supplier_admin_1.in (),
                            event_source,
                            event_type + 1,
                            event_source,
-                           event_type + 1
-                           ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                           event_type + 1);
 
       // ****************************************************************
 
@@ -150,9 +125,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (event_source, event_type, 0);
 
         consumer_00.connect (consumer_admin_2.in (),
-                             consumer_qos.get_ConsumerQOS ()
-                             ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                             consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -181,9 +154,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (event_source, event_type + 1, 0);
 
         consumer_00.connect (consumer_admin_2.in (),
-                             consumer_qos.get_ConsumerQOS ()
-                             ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                             consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -208,9 +179,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (event_source, event_type, 0);
 
         consumer_00.connect (consumer_admin_2.in (),
-                             consumer_qos.get_ConsumerQOS ()
-                             ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                             consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -228,8 +197,7 @@ main (int argc, char* argv[])
 
       // ****************************************************************
 
-      consumer_00.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer_00.disconnect ();
 
       // ****************************************************************
 
@@ -239,9 +207,7 @@ main (int argc, char* argv[])
         consumer_qos.insert_type (event_type, 0);
 
         consumer_00.connect (consumer_admin_2.in (),
-                             consumer_qos.get_ConsumerQOS ()
-                             ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                             consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -270,9 +236,7 @@ main (int argc, char* argv[])
         consumer_qos.insert_type (event_type + 1, 0);
 
         consumer_00.connect (consumer_admin_2.in (),
-                             consumer_qos.get_ConsumerQOS ()
-                             ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                             consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -297,9 +261,7 @@ main (int argc, char* argv[])
         consumer_qos.insert_type (event_type, 0);
 
         consumer_00.connect (consumer_admin_2.in (),
-                             consumer_qos.get_ConsumerQOS ()
-                             ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                             consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -317,43 +279,32 @@ main (int argc, char* argv[])
 
       // ****************************************************************
 
-      consumer_00.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      consumer_00.disconnect ();
 
-      supplier_01.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      supplier_00.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_01.deactivate ();
+      supplier_00.deactivate ();
 
-      supplier_01.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      supplier_00.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier_01.disconnect ();
+      supplier_00.disconnect ();
 
-      gateway.shutdown (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      gateway.shutdown ();
 
       // ****************************************************************
 
-      event_channel_1->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      event_channel_1->destroy ();
 
-      event_channel_2->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      event_channel_2->destroy ();
 
       // ****************************************************************
 
-      poa->destroy (1, 1 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      poa->destroy (1, 1);
 
-      orb->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      orb->destroy ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Service");
+      ex._tao_print_exception ("Service");
       return 1;
     }
-  ACE_ENDTRY;
   return 0;
 }
