@@ -1,4 +1,4 @@
-// $Id: Schedule.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: Schedule.cpp 82735 2008-09-16 12:12:29Z johnnyw $
 
 #include "Schedule.h"
 #include "Consumer.h"
@@ -11,7 +11,7 @@
 #include "ace/Get_Opt.h"
 #include "ace/Sched_Params.h"
 
-ACE_RCSID(EC_Tests_Basic, Schedule, "$Id: Schedule.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(EC_Tests_Basic, Schedule, "$Id: Schedule.cpp 82735 2008-09-16 12:12:29Z johnnyw $")
 
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
@@ -28,7 +28,7 @@ EC_Schedule::EC_Schedule (void)
 }
 
 int
-EC_Schedule::parse_args (int& argc, char* argv[])
+EC_Schedule::parse_args (int& argc, ACE_TCHAR* argv[])
 {
   if (this->EC_Driver::parse_args (argc, argv) != 0)
     return -1;
