@@ -3,7 +3,7 @@
 /**
  *  @file   Schedule.h
  *
- *  $Id: Schedule.h 76589 2007-01-25 18:04:11Z elliott_c $
+ *  $Id: Schedule.h 82735 2008-09-16 12:12:29Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  */
@@ -47,7 +47,7 @@ public:
   // = The EC_Driver methods
   /// add some command line args to change the scheduling service to
   /// use.
-  virtual int parse_args (int& argc, char* argv[]);
+  virtual int parse_args (int& argc, ACE_TCHAR* argv[]);
   virtual void print_args (void) const;
   virtual void print_usage (void);
 
