@@ -1,4 +1,4 @@
-// Wildcard.cpp,v 1.8 2004/08/16 23:53:15 jtc Exp
+// $Id: Wildcard.cpp 78770 2007-07-04 05:19:15Z sowayaa $
 
 #include "Counting_Consumer.h"
 #include "Counting_Supplier.h"
@@ -7,34 +7,28 @@
 #include "orbsvcs/Event/EC_Event_Channel.h"
 #include "orbsvcs/Event/EC_Default_Factory.h"
 
-ACE_RCSID (EC_Tests, 
-           Wildcard, 
-           "Wildcard.cpp,v 1.8 2004/08/16 23:53:15 jtc Exp")
+ACE_RCSID (EC_Tests,
+           Wildcard,
+           "$Id: Wildcard.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
 
 int
-main (int argc, char* argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   TAO_EC_Default_Factory::init_svcs ();
 
-  ACE_DECLARE_NEW_CORBA_ENV;
-  ACE_TRY
+  try
     {
       // ORB initialization boiler plate...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc, argv, "" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var object =
-        orb->resolve_initial_references ("RootPOA" ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        orb->resolve_initial_references ("RootPOA");
       PortableServer::POA_var poa =
-        PortableServer::POA::_narrow (object.in () ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        PortableServer::POA::_narrow (object.in ());
       PortableServer::POAManager_var poa_manager =
-        poa->the_POAManager (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      poa_manager->activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        poa->the_POAManager ();
+      poa_manager->activate ();
 
       // ****************************************************************
 
@@ -42,25 +36,21 @@ main (int argc, char* argv[])
                                                   poa.in ());
 
       TAO_EC_Event_Channel ec_impl (attributes);
-      ec_impl.activate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      ec_impl.activate ();
 
       RtecEventChannelAdmin::EventChannel_var event_channel =
-        ec_impl._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        ec_impl._this ();
 
 
       // ****************************************************************
 
       // Obtain the consumer admin..
       RtecEventChannelAdmin::ConsumerAdmin_var consumer_admin =
-        event_channel->for_consumers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel->for_consumers ();
 
       // Obtain the supplier admin..
       RtecEventChannelAdmin::SupplierAdmin_var supplier_admin =
-        event_channel->for_suppliers (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+        event_channel->for_suppliers ();
 
       // ****************************************************************
 
@@ -71,80 +61,60 @@ main (int argc, char* argv[])
       EC_Counting_Supplier supplier;
 
       supplier.activate (consumer_admin.in (),
-                         milliseconds
-                         ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                         milliseconds);
       supplier.connect (supplier_admin.in (),
                         event_source,
                         event_type,
                         event_source,
-                        event_type
-                        ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                        event_type);
 
       // ****************************************************************
 
       EC_Counting_Supplier other_supplier;
 
       other_supplier.activate (consumer_admin.in (),
-                               milliseconds
-                               ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                               milliseconds);
       other_supplier.connect (supplier_admin.in (),
                               event_source + 1,
                               event_type + 1,
                               event_source + 1,
-                              event_type + 1
-                              ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                              event_type + 1);
 
       // ****************************************************************
 
       EC_Counting_Supplier any_source_supplier;
 
       any_source_supplier.activate (consumer_admin.in (),
-                                    milliseconds
-                                    ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                    milliseconds);
       any_source_supplier.connect (supplier_admin.in (),
                                    0,
                                    event_type,
                                    event_source,
-                                   event_type
-                                   ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                   event_type);
 
       // ****************************************************************
 
       EC_Counting_Supplier any_type_supplier;
 
       any_type_supplier.activate (consumer_admin.in (),
-                                  milliseconds
-                                  ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                  milliseconds);
       any_type_supplier.connect (supplier_admin.in (),
                                  event_source,
                                  0,
                                  event_source,
-                                 event_type
-                                 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                 event_type);
 
       // ****************************************************************
 
       EC_Counting_Supplier wildcard_supplier;
 
       wildcard_supplier.activate (consumer_admin.in (),
-                                  milliseconds
-                                  ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                  milliseconds);
       wildcard_supplier.connect (supplier_admin.in (),
                                  0,
                                  0,
                                  event_source,
-                                 event_type
-                                 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                 event_type);
 
       // ****************************************************************
 
@@ -159,9 +129,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (event_source, event_type, 0);
 
         regular_consumer.connect (consumer_admin.in (),
-                                  consumer_qos.get_ConsumerQOS ()
-                                  ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                                  consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -177,9 +145,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (event_source, 0, 0);
 
         any_type_consumer.connect (consumer_admin.in (),
-                                   consumer_qos.get_ConsumerQOS ()
-                                   ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                                   consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -195,9 +161,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (0, event_type, 0);
 
         any_source_consumer.connect (consumer_admin.in (),
-                                     consumer_qos.get_ConsumerQOS ()
-                                     ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                                     consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -213,9 +177,7 @@ main (int argc, char* argv[])
         consumer_qos.insert (0, 0, 0);
 
         wildcard_consumer.connect (consumer_admin.in (),
-                                   consumer_qos.get_ConsumerQOS ()
-                                   ACE_ENV_ARG_PARAMETER);
-        ACE_TRY_CHECK;
+                                   consumer_qos.get_ConsumerQOS ());
       }
 
       // ****************************************************************
@@ -227,53 +189,37 @@ main (int argc, char* argv[])
 
       // ****************************************************************
 
-      wildcard_consumer.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      wildcard_consumer.disconnect ();
 
-      any_source_consumer.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      any_source_consumer.disconnect ();
 
-      any_type_consumer.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      any_type_consumer.disconnect ();
 
-      regular_consumer.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      regular_consumer.disconnect ();
 
-      wildcard_supplier.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      wildcard_supplier.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      wildcard_supplier.deactivate ();
+      wildcard_supplier.disconnect ();
 
-      any_type_supplier.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      any_type_supplier.deactivate ();
 
-      any_source_supplier.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      any_source_supplier.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      any_source_supplier.deactivate ();
+      any_source_supplier.disconnect ();
 
-      other_supplier.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      other_supplier.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      other_supplier.deactivate ();
+      other_supplier.disconnect ();
 
-      supplier.deactivate (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
-      supplier.disconnect (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      supplier.deactivate ();
+      supplier.disconnect ();
 
       // ****************************************************************
 
-      event_channel->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      event_channel->destroy ();
 
       // ****************************************************************
 
-      poa->destroy (1, 1 ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      poa->destroy (1, 1);
 
-      orb->destroy (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      orb->destroy ();
 
       // ****************************************************************
 
@@ -309,11 +255,10 @@ main (int argc, char* argv[])
         + supplier.event_count;
       regular_consumer.dump_results (expected, 5);
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION, "Service");
+      ex._tao_print_exception ("Service");
       return 1;
     }
-  ACE_ENDTRY;
   return 0;
 }
