@@ -1,4 +1,4 @@
-// $Id: consumer.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: consumer.cpp 82979 2008-10-08 13:20:08Z johnnyw $
 
 #include "Constants.h"
 #include "orbsvcs/Event/EC_Lifetime_Utils_T.h"
@@ -91,7 +91,7 @@ check_for_nil (CORBA::Object_ptr obj, const char *message)
 }
 
 int
-parse_args (int /* argc */, char ** /* argv */)
+parse_args (int /* argc */, ACE_TCHAR ** /* argv */)
 {
   return 0;
 }
