@@ -1,9 +1,9 @@
-// gateway-ec.cpp,v 1.1 2003/06/18 05:43:54 jwillemsen Exp
+// $Id: gateway-ec.cpp 78770 2007-07-04 05:19:15Z sowayaa $
 
 #include "Gateway_EC.h"
 
 int
-main (int argc, char ** argv)
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   Gateway_EC test;
 
