@@ -1,4 +1,4 @@
-// $Id: application.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: application.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Constants.h"
 
@@ -431,7 +431,7 @@ Heartbeat_Application::push (const RtecEventComm::EventSet &events)
             {
               ACE_ERROR ((LM_ERROR,
                           "Unable to add new entry "
-                          "to heartbeat database \n"));
+                          "to heartbeat database\n"));
               break;
             }
 
@@ -540,9 +540,9 @@ check_for_nil (CORBA::Object_ptr obj, const char *message)
 }
 
 int
-parse_args (int argc, char ** argv)
+parse_args (int argc, ACE_TCHAR ** argv)
 {
-  ACE_Get_Opt get_opt (argc, argv, "d");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("d"));
   int opt;
 
   while ((opt = get_opt ()) != EOF)
