@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: Connect.h 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: Connect.h 82977 2008-10-08 12:56:33Z johnnyw $
 //
 // ============================================================================
 //
@@ -47,7 +47,7 @@ public:
   // Constructor
 
   // = The EC_Driver methods
-  virtual int parse_args (int& argc, char* argv[]);
+  virtual int parse_args (int& argc, ACE_TCHAR* argv[]);
   virtual void print_usage (void);
   virtual void print_args (void) const;
 
@@ -96,7 +96,7 @@ public:
   virtual void connect (
       const RtecEventChannelAdmin::ConsumerQOS& qos,
       int shutdown_event_type);
-  virtual void dump_results (const char* name,
+  virtual void dump_results (const ACE_TCHAR* name,
                              ACE_UINT32 global_scale_factor);
 
 private:
@@ -117,7 +117,7 @@ public:
   virtual void connect (
       const RtecEventChannelAdmin::SupplierQOS& qos,
       int shutdown_event_type);
-  virtual void dump_results (const char* name,
+  virtual void dump_results (const ACE_TCHAR* name,
                              ACE_UINT32 global_scale_factor);
 
 private:
