@@ -1,4 +1,4 @@
-// $Id: Throughput.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: Throughput.cpp 82735 2008-09-16 12:12:29Z johnnyw $
 
 #include "Throughput.h"
 #include "Consumer.h"
@@ -8,7 +8,7 @@
 
 ACE_RCSID (EC_Tests_Performance,
            Throughput,
-           "$Id: Throughput.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+           "$Id: Throughput.cpp 82735 2008-09-16 12:12:29Z johnnyw $")
 
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
@@ -24,7 +24,7 @@ EC_Throughput::EC_Throughput (void)
 }
 
 int
-EC_Throughput::parse_args (int& argc, char* argv[])
+EC_Throughput::parse_args (int& argc, ACE_TCHAR* argv[])
 {
   if (this->EC_Driver::parse_args (argc, argv) != 0)
     return -1;
