@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: Throughput.h 76555 2007-01-24 15:39:09Z johnnyw $
+// $Id: Throughput.h 82735 2008-09-16 12:12:29Z johnnyw $
 //
 // ============================================================================
 //
@@ -36,7 +36,7 @@ public:
   // Constructor
 
   // = The EC_Driver methods
-  virtual int parse_args (int& argc, char* argv[]);
+  virtual int parse_args (int& argc, ACE_TCHAR* argv[]);
   virtual void print_args (void) const;
   virtual void print_usage (void);
   // add some command line args to enable/disable throughputions
