@@ -1,8 +1,8 @@
-// $Id: Counting_Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: Counting_Consumer.cpp 81675 2008-05-11 06:29:39Z johnnyw $
 
 #include "Counting_Consumer.h"
 
-ACE_RCSID(EC_Tests, EC_Count_Consumer, "$Id: Counting_Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
+ACE_RCSID(EC_Tests, EC_Count_Consumer, "$Id: Counting_Consumer.cpp 81675 2008-05-11 06:29:39Z johnnyw $")
 
 EC_Counting_Consumer::EC_Counting_Consumer (const char* name)
   : event_count (0),
@@ -60,16 +60,18 @@ EC_Counting_Consumer::dump_results (int expected_count, int tolerance)
   if (diff > tolerance || diff < -tolerance)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "ERROR - %s unexpected number of events  <%d>\n",
+                  "ERROR - %s unexpected number of events <%d> instead of <%d>\n",
                   this->name_,
-                  this->event_count));
+                  this->event_count,
+                  expected_count));
     }
   else
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "%s - number of events <%d> within margins\n",
+                  "%s - number of events <%d> within margins expected <%d>\n",
                   this->name_,
-                  this->event_count));
+                  this->event_count,
+                  expected_count));
     }
 }
 
