@@ -1,12 +1,12 @@
-// Counting_Supplier.cpp,v 1.12 2004/08/16 23:53:15 jtc Exp
+// $Id: Counting_Supplier.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #include "Counting_Supplier.h"
 #include "orbsvcs/Event_Utilities.h"
 #include "ace/OS_NS_unistd.h"
 
-ACE_RCSID (EC_Tests, 
-           EC_Count_Supplier, 
-           "Counting_Supplier.cpp,v 1.12 2004/08/16 23:53:15 jtc Exp")
+ACE_RCSID (EC_Tests,
+           EC_Count_Supplier,
+           "$Id: Counting_Supplier.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 EC_Counting_Supplier::EC_Counting_Supplier (void)
   :  event_count (0),
@@ -19,16 +19,13 @@ EC_Counting_Supplier::EC_Counting_Supplier (void)
 
 void
 EC_Counting_Supplier::activate (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin,
-                    int milliseconds
-                    ACE_ENV_ARG_DECL)
+                    int milliseconds)
 {
   RtecEventComm::PushConsumer_var consumer =
-    this->consumer_adapter_._this (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->consumer_adapter_._this ();
 
   this->supplier_proxy_ =
-    consumer_admin->obtain_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    consumer_admin->obtain_push_supplier ();
 
   // Let's say that the execution time for event 2 is 1
   // milliseconds...
@@ -43,25 +40,19 @@ EC_Counting_Supplier::activate (RtecEventChannelAdmin::ConsumerAdmin_ptr consume
                             0);
 
   this->supplier_proxy_->connect_push_consumer (consumer.in (),
-                                                consumer_qos.get_ConsumerQOS ()
-                                                ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                                consumer_qos.get_ConsumerQOS ());
 }
 
 void
-EC_Counting_Supplier::deactivate (ACE_ENV_SINGLE_ARG_DECL)
+EC_Counting_Supplier::deactivate (void)
 {
-  this->supplier_proxy_->disconnect_push_supplier (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->supplier_proxy_->disconnect_push_supplier ();
 
   PortableServer::POA_var consumer_poa =
-    this->consumer_adapter_._default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->consumer_adapter_._default_POA ();
   PortableServer::ObjectId_var consumer_id =
-    consumer_poa->servant_to_id (&this->consumer_adapter_ ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
-  consumer_poa->deactivate_object (consumer_id.in () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    consumer_poa->servant_to_id (&this->consumer_adapter_);
+  consumer_poa->deactivate_object (consumer_id.in ());
 }
 
 void
@@ -70,8 +61,7 @@ EC_Counting_Supplier::connect (
     int published_source,
     int published_type,
     int event_source,
-    int event_type
-    ACE_ENV_ARG_DECL)
+    int event_type)
 {
   this->event_source_ = event_source;
   this->event_type_ = event_type;
@@ -81,59 +71,47 @@ EC_Counting_Supplier::connect (
                        published_type,
                        0, 1);
   this->connect (supplier_admin,
-                 supplier_qos.get_SupplierQOS ()
-                 ACE_ENV_ARG_PARAMETER);
+                 supplier_qos.get_SupplierQOS ());
 }
 
 void
 EC_Counting_Supplier::connect (
     RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin,
-    const RtecEventChannelAdmin::SupplierQOS &qos
-    ACE_ENV_ARG_DECL)
+    const RtecEventChannelAdmin::SupplierQOS &qos)
 {
   RtecEventComm::PushSupplier_var supplier =
-    this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->_this ();
 
   if (CORBA::is_nil (this->consumer_proxy_.in ()))
     {
       this->consumer_proxy_ =
-        supplier_admin->obtain_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
+        supplier_admin->obtain_push_consumer ();
     }
 
   this->consumer_proxy_->connect_push_supplier (supplier.in (),
-                                                qos
-                                                ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                                qos);
 }
 
 void
-EC_Counting_Supplier::disconnect (ACE_ENV_SINGLE_ARG_DECL)
+EC_Counting_Supplier::disconnect (void)
 {
   if (!CORBA::is_nil (this->consumer_proxy_.in ()))
     {
-      this->consumer_proxy_->disconnect_push_consumer (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
+      this->consumer_proxy_->disconnect_push_consumer ();
     }
 
   PortableServer::POA_var supplier_poa =
-    this->_default_POA (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->_default_POA ();
   PortableServer::ObjectId_var supplier_id =
-    supplier_poa->servant_to_id (this ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
-  supplier_poa->deactivate_object (supplier_id.in () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    supplier_poa->servant_to_id (this);
+  supplier_poa->deactivate_object (supplier_id.in ());
 
   this->consumer_proxy_ =
     RtecEventChannelAdmin::ProxyPushConsumer::_nil ();
 }
 
 void
-EC_Counting_Supplier::push (const RtecEventComm::EventSet&
-                ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+EC_Counting_Supplier::push (const RtecEventComm::EventSet&)
 {
   if (CORBA::is_nil (this->consumer_proxy_.in ()))
     return;
@@ -144,20 +122,17 @@ EC_Counting_Supplier::push (const RtecEventComm::EventSet&
   event[0].header.type = this->event_type_;
   event[0].header.ttl = 1;
 
-  this->consumer_proxy_->push (event ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->consumer_proxy_->push (event);
   this->event_count++;
 }
 
 void
-EC_Counting_Supplier::disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+EC_Counting_Supplier::disconnect_push_consumer (void)
 {
 }
 
 void
-EC_Counting_Supplier::disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+EC_Counting_Supplier::disconnect_push_supplier (void)
 {
   this->disconnect_count++;
   this->consumer_proxy_ =
@@ -177,16 +152,14 @@ EC_Counting_Supplier_Task::
 int
 EC_Counting_Supplier_Task::svc ()
 {
-  ACE_TRY_NEW_ENV
+  try
     {
-      this->run (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      this->run ();
     }
-  ACE_CATCHANY
+  catch (const CORBA::Exception&)
     {
       return -1;
     }
-  ACE_ENDTRY;
   return 0;
 }
 
@@ -204,14 +177,13 @@ EC_Counting_Supplier_Task::push_count (void)
 }
 
 void
-EC_Counting_Supplier_Task::run (ACE_ENV_SINGLE_ARG_DECL)
+EC_Counting_Supplier_Task::run (void)
 {
   this->event_.length (1);
 
   int stop = 0;
   do {
-    this->supplier_->push (this->event_ ACE_ENV_ARG_PARAMETER);
-    ACE_CHECK;
+    this->supplier_->push (this->event_);
 
     // Sleep for a short time to avoid spinning...
     ACE_OS::sleep (0);
@@ -223,13 +195,3 @@ EC_Counting_Supplier_Task::run (ACE_ENV_SINGLE_ARG_DECL)
     stop = this->stop_flag_;
   } while (stop == 0);
 }
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_PushConsumer_Adapter<EC_Counting_Supplier>;
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_PushConsumer_Adapter<EC_Counting_Supplier>
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
