@@ -3,7 +3,7 @@
 /**
  *  @file   Counting_Supplier.h
  *
- *  Counting_Supplier.h,v 1.9 2005/05/16 14:50:18 jwillemsen Exp
+ *  $Id: Counting_Supplier.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  */
@@ -45,32 +45,25 @@ public:
    * receives the timeout.
    */
   void activate (RtecEventChannelAdmin::ConsumerAdmin_ptr consumer_admin,
-                 int period
-                 ACE_ENV_ARG_DECL);
-  void deactivate (ACE_ENV_SINGLE_ARG_DECL);
+                 int period);
+  void deactivate (void);
 
   /// Simple connect/disconnect methods..
   void connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin,
                 int published_source,
                 int published_type,
                 int event_source,
-                int event_type
-                ACE_ENV_ARG_DECL);
+                int event_type);
   void connect (RtecEventChannelAdmin::SupplierAdmin_ptr supplier_admin,
-                const RtecEventChannelAdmin::SupplierQOS &qos
-                ACE_ENV_ARG_DECL);
-  void disconnect (ACE_ENV_SINGLE_ARG_DECL);
+                const RtecEventChannelAdmin::SupplierQOS &qos);
+  void disconnect (void);
 
   /// The Consumer side methods.
-  void push (const RtecEventComm::EventSet& events
-             ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-  void disconnect_push_consumer (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void push (const RtecEventComm::EventSet& events);
+  void disconnect_push_consumer (void);
 
   /// The skeleton methods.
-  virtual void disconnect_push_supplier (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void disconnect_push_supplier (void);
 
   /// Count the number of events sent
   CORBA::ULong event_count;
@@ -108,7 +101,7 @@ public:
   CORBA::ULong push_count (void);
 
   /// Run a single iteration of the test
-  void run (ACE_ENV_SINGLE_ARG_DECL);
+  void run (void);
 
 private:
   /// The supplier we are turning into an active object
