@@ -3,7 +3,7 @@
 /**
  *  @file    FTAPP_FactoryRegistry_Main.cpp
  *
- *  FTAPP_FactoryRegistry_Main.cpp,v 1.5 2004/08/16 23:53:16 jtc Exp
+ *  $Id: FTAPP_FactoryRegistry_Main.cpp 68471 2005-10-04 11:38:20Z jwillemsen $
  *
  *  This file is part of Fault Tolerant CORBA.
  *  This file provides the main routine for a stub FactoryRegistry
@@ -20,14 +20,3 @@ int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
   TAO::Utils::Server_Main<TAO::PG_FactoryRegistry> server_main("FactoryRegistry");
   return server_main.run(argc, argv);
 }
-
-///////////////////////////////////
-// Template instantiation for
-// inept compilers.
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-  template class TAO::Utils::Server_Main<TAO::PG_FactoryRegistry>;
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-# pragma instantiate TAO::Utils::Server_Main<TAO::PG_FactoryRegistry>
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
-
