@@ -3,7 +3,7 @@
 /**
  *  @file    FT_ReplicaFactory_i.cpp
  *
- *  $Id: FT_ReplicaFactory_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+ *  $Id: FT_ReplicaFactory_i.cpp 87882 2009-12-03 09:26:50Z dbudko $
  *
  *  This file is part of Fault Tolerant CORBA.
  *
@@ -62,7 +62,7 @@ FT_ReplicaFactory_i::FT_ReplicaFactory_i ()
   , factory_registry_ (0)
   , registered_(0)
   , test_output_file_(0)
-  , ns_name_(0)
+  , ns_name_("")
   , naming_context_ (CosNaming::NamingContext::_nil ())
   , this_name_ ()
   , roles_ ()
@@ -72,6 +72,7 @@ FT_ReplicaFactory_i::FT_ReplicaFactory_i ()
   , replicas_ ()
   , empty_slots_(0)
   , quit_requested_(0)
+  , name_persistent_file_(ACE_TEXT(""))
 {
   char const * repo_id =
     FT_TEST::_tc_TestReplica->id ();
@@ -136,7 +137,7 @@ void FT_ReplicaFactory_i::shutdown_i()
   }
 }
 
-int FT_ReplicaFactory_i::write_ior(const char * outputFile, const char * ior)
+int FT_ReplicaFactory_i::write_ior(const ACE_TCHAR * outputFile, const char * ior)
 {
   int result = -1;
   FILE* out = ACE_OS::fopen (outputFile, "w");
@@ -158,9 +159,9 @@ int FT_ReplicaFactory_i::write_ior(const char * outputFile, const char * ior)
 //////////////////////////////////////////////////////
 // FT_ReplicaFactory_i public, non-CORBA methods
 
-int FT_ReplicaFactory_i::parse_args (int argc, char * argv[])
+int FT_ReplicaFactory_i::parse_args (int argc, ACE_TCHAR * argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:n:f:i:l:t:qu");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:n:f:i:l:t:p:qu"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -174,7 +175,7 @@ int FT_ReplicaFactory_i::parse_args (int argc, char * argv[])
       }
       case 'n':
       {
-        this->ns_name_ = get_opts.opt_arg ();
+        this->ns_name_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
         break;
       }
       case 'f':
@@ -184,12 +185,12 @@ int FT_ReplicaFactory_i::parse_args (int argc, char * argv[])
       }
       case 'i':
       {
-        this->roles_.push_back(get_opts.opt_arg ());
+        this->roles_.push_back(ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ()));
         break;
       }
       case 'l':
       {
-        this->location_ = get_opts.opt_arg ();
+        this->location_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
         break;
       }
       case 'q':
@@ -208,18 +209,24 @@ int FT_ReplicaFactory_i::parse_args (int argc, char * argv[])
         this->test_output_file_ = get_opts.opt_arg ();
         break;
       }
+      case 'p':
+      {
+       this->name_persistent_file_ = get_opts.opt_arg ();
+       break;
+      }
 
       case '?':
         // fall thru
       default:
         ACE_ERROR_RETURN ((LM_ERROR,
-                           "usage:  %s \n"
+                           "usage:  %s\n"
                            " -o <factory ior file>\n"
                            " -n <naming service registration name>\n"
                            " -f <factory registry ior file>\n"
                            " -i <registration: role>\n"
                            " -l <registration: location>\n"
                            " -t <test replica ior file>\n"
+                           " -p <name presistent file>\n"
                            " -u{nregister by location}\n"
                            " -q{uit on idle}\n",
                            argv [0]),
@@ -233,10 +240,10 @@ int FT_ReplicaFactory_i::parse_args (int argc, char * argv[])
 
 const char * FT_ReplicaFactory_i::location () const
 {
-  return this->location_;
+  return this->location_.c_str ();
 }
 
-const char * FT_ReplicaFactory_i::identity () const
+const ACE_TCHAR * FT_ReplicaFactory_i::identity () const
 {
   return this->identity_.c_str();
 }
@@ -328,7 +335,7 @@ int FT_ReplicaFactory_i::init (CORBA::ORB_ptr orb)
 
   if (this->factory_registry_ior_ != 0)
   {
-    if (ACE_OS::strcmp (this->factory_registry_ior_, "none") != 0)
+    if (ACE_OS::strcmp (this->factory_registry_ior_, ACE_TEXT("none")) != 0)
     {
       CORBA::Object_var reg_obj = this->orb_->string_to_object(factory_registry_ior_);
       this->factory_registry_ = ::PortableGroup::FactoryRegistry::_narrow(reg_obj.in ());
@@ -395,16 +402,16 @@ int FT_ReplicaFactory_i::init (CORBA::ORB_ptr orb)
       PortableGroup::FactoryInfo info;
       info.the_factory = ::PortableGroup::GenericFactory::_narrow(this_obj.in ());
       info.the_location.length(1);
-      info.the_location[0].id = CORBA::string_dup(this->location_);
+      info.the_location[0].id = CORBA::string_dup(this->location_.c_str ());
       info.the_criteria.length(1);
       info.the_criteria[0].nam.length(1);
       info.the_criteria[0].nam[0].id = CORBA::string_dup(PortableGroup::role_criterion);
       info.the_criteria[0].val <<= CORBA::string_dup(roleName);
 
       ACE_ERROR (( LM_INFO,
-         "Factory: %s@%s registering with factory registry\n",
+         "Factory: %s@%C registering with factory registry\n",
          roleName,
-         location_
+         location_.c_str ()
          ));
 
       char const * replica_repository_id =
@@ -422,11 +429,11 @@ int FT_ReplicaFactory_i::init (CORBA::ORB_ptr orb)
 
   if (this->roles_.size() > 0)
   {
-    this->identity_ = "Factory";
-    if (this->location_ != 0)
+    this->identity_ = ACE_TEXT("Factory");
+    if (this->location_.length () != 0)
     {
-      this->identity_ += "@";
-      this->identity_ += this->location_;
+      this->identity_ += ACE_TEXT("@");
+      this->identity_ += ACE_TEXT_CHAR_TO_TCHAR(this->location_.c_str ());
     }
     identified = 1;
   }
@@ -435,7 +442,7 @@ int FT_ReplicaFactory_i::init (CORBA::ORB_ptr orb)
   {
     if (!identified)
     {
-      this->identity_ = "file:";
+      this->identity_ = ACE_TEXT("file:");
       this->identity_ += this->ior_output_file_;
       // note: don't set identified--ns identity overrides file identitiy
     }
@@ -452,12 +459,12 @@ int FT_ReplicaFactory_i::init (CORBA::ORB_ptr orb)
     }
   }
 
-  if (this->ns_name_ != 0)
+  if (this->ns_name_.length () != 0)
   {
     if (!identified)
     {
-      this->identity_ = "name:";
-      this->identity_ += this->ns_name_;
+      this->identity_ = ACE_TEXT("name:");
+      this->identity_ += ACE_TEXT_CHAR_TO_TCHAR(this->ns_name_.c_str ());
     }
 
     CORBA::Object_var naming_obj =
@@ -473,7 +480,7 @@ int FT_ReplicaFactory_i::init (CORBA::ORB_ptr orb)
       CosNaming::NamingContext::_narrow (naming_obj.in ());
 
     this->this_name_.length (1);
-    this->this_name_[0].id = CORBA::string_dup (this->ns_name_);
+    this->this_name_[0].id = CORBA::string_dup (this->ns_name_.c_str ());
 
     this->naming_context_->rebind (this->this_name_, this_obj.in()  // CORBA::Object::_duplicate(this_obj)
                             );
@@ -502,10 +509,10 @@ int FT_ReplicaFactory_i::fini (void)
     ACE_OS::unlink (this->ior_output_file_);
     this->ior_output_file_ = 0;
   }
-  if (this->ns_name_ != 0)
+  if (this->ns_name_.length () != 0)
   {
     this->naming_context_->unbind (this_name_);
-    this->ns_name_ = 0;
+    this->ns_name_.clear ();
   }
 
   if (registered_)
@@ -515,14 +522,14 @@ int FT_ReplicaFactory_i::fini (void)
     if (this->unregister_by_location_)
     {
       ACE_ERROR (( LM_INFO,
-         "%s: unregistering all factories at %s\n",
+         "%s: unregistering all factories at %C\n",
          identity(),
-         location_
+         location_.c_str ()
          ));
 
       PortableGroup::Location location(1);
       location.length(1);
-      location[0].id = CORBA::string_dup(location_);
+      location[0].id = CORBA::string_dup(location_.c_str ());
       this->factory_registry_->unregister_factory_by_location (
               location);
     }
@@ -533,14 +540,14 @@ int FT_ReplicaFactory_i::fini (void)
       {
         const char * roleName = this->roles_[nRole].c_str();
         ACE_ERROR (( LM_INFO,
-           "Factory for: %s@%s unregistering from factory registry\n",
+           "Factory for: %s@%C unregistering from factory registry\n",
            roleName,
-           location_
+           location_.c_str ()
            ));
 
         PortableGroup::Location location(1);
         location.length(1);
-        location[0].id = CORBA::string_dup(location_);
+        location[0].id = CORBA::string_dup(location_.c_str ());
         this->factory_registry_->unregister_factory (
                 roleName,
                 location);
@@ -645,7 +652,7 @@ CORBA::Object_ptr FT_ReplicaFactory_i::create_object (
   (*factory_creation_id) <<= factory_id;
 
   ACE_ERROR ((LM_INFO,
-    "Created %s@%s#%d.\n", role, this->location_, static_cast<int> (factory_id)
+    "Created %s@%C#%d.\n", role, this->location_.c_str (), static_cast<int> (factory_id)
     ));
 
 
@@ -670,7 +677,7 @@ FT_TestReplica_i * FT_ReplicaFactory_i::create_replica(const char * name)
   this->replicas_[factoryId] = pFTReplica;
   this->empty_slots_ -= 1;
 
-  pFTReplica->init (this->orb_);
+  pFTReplica->init (this->orb_, this->name_persistent_file_);
   return pFTReplica;
 }
 
