@@ -5,7 +5,7 @@
 
 ACE_RCSID (ForwardRequest,
            Server_ORBInitializer,
-           "Server_ORBInitializer.cpp,v 1.3 2005/02/18 09:07:08 jwillemsen Exp")
+           "$Id: Server_ORBInitializer.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 #if TAO_HAS_INTERCEPTORS == 1
 
@@ -18,17 +18,13 @@ Server_ORBInitializer::Server_ORBInitializer (void)
 
 void
 Server_ORBInitializer::pre_init (
-    PortableInterceptor::ORBInitInfo_ptr
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ORBInitInfo_ptr)
 {
 }
 
 void
 Server_ORBInitializer::post_init (
-    PortableInterceptor::ORBInitInfo_ptr info
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+    PortableInterceptor::ORBInitInfo_ptr info)
 {
   PortableInterceptor::ServerRequestInterceptor_ptr interceptor;
   // Install the server request interceptor.
@@ -39,13 +35,10 @@ Server_ORBInitializer::post_init (
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK;
 
   this->server_interceptor_ = interceptor;
 
-  info->add_server_request_interceptor (interceptor
-                                        ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  info->add_server_request_interceptor (interceptor);
 }
 
 PortableInterceptor::ServerRequestInterceptor_ptr
