@@ -4,7 +4,7 @@
 
 ACE_RCSID (ForwardRequest,
            test_i,
-           "test_i.cpp,v 1.1 2003/07/30 18:05:43 bala Exp")
+           "$Id: test_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 test_i::test_i (CORBA::Short num,
                 CORBA::ORB_ptr orb)
@@ -18,18 +18,16 @@ test_i::~test_i (void)
 }
 
 CORBA::Short
-test_i::number (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+test_i::number (void)
 {
   return this->number_;
 }
 
 void
-test_i::shutdown (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+test_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
               "Server is shutting down via object %d.\n",
               this->number_));
-  this->orb_->shutdown (0 ACE_ENV_ARG_PARAMETER);
+  this->orb_->shutdown (0);
 }
