@@ -1,6 +1,6 @@
-//$Id: Manager.h 77948 2007-04-06 18:00:25Z elliott_c $
+//$Id: Manager.h 82869 2008-09-29 08:02:27Z johnnyw $
 // -*- C++ -*-
-// $Id: Manager.h 77948 2007-04-06 18:00:25Z elliott_c $
+// $Id: Manager.h 82869 2008-09-29 08:02:27Z johnnyw $
 
 // ============================================================================
 //
@@ -32,7 +32,7 @@ class Manager
 {
 public:
   void init (int argc,
-             char *argv[]);
+             ACE_TCHAR *argv[]);
 
   // Initialize the ORB, POA etc.
 
