@@ -1,4 +1,4 @@
-// $Id: client.cpp 79344 2007-08-14 21:54:46Z mesnier_p $
+// $Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 // ============================================================================
 //
@@ -23,18 +23,18 @@
 #include "ami_testC.h"
 #include "ami_testS.h"
 
-ACE_RCSID(AMI, client, "$Id: client.cpp 79344 2007-08-14 21:54:46Z mesnier_p $")
+ACE_RCSID(AMI, client, "$Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int nthreads = 5;
 int niterations = 5;
 int debug = 0;
 int number_of_replies = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "dk:n:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dk:n:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -117,7 +117,7 @@ public:
     {
 
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <foo_excep> called: \n"));
+                  "Callback method <foo_excep> called:\n"));
       try
         {
           excep_holder->raise_exception ();
@@ -138,19 +138,19 @@ public:
   void get_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <get_yadda_excep> called: \n"));
+                  "Callback method <get_yadda_excep> called:\n"));
     };
 
   void set_yadda (void)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda> called: \n"));
+                  "Callback method <set_yadda> called:\n"));
     };
 
   void set_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda_excep> called: \n"));
+                  "Callback method <set_yadda_excep> called:\n"));
     };
   ~Handler (void) {};
 };
