@@ -1,4 +1,4 @@
-// $Id: simple_client.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: simple_client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 // ============================================================================
 //
@@ -26,17 +26,17 @@
 #include "ami_testC.h"
 #include "ami_testS.h"
 
-ACE_RCSID(AMI, simple_client, "$Id: simple_client.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(AMI, simple_client, "$Id: simple_client.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 5;
 int shutdown_flag = 0;
 int debug = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "dk:i:x");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dk:i:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -94,7 +94,7 @@ public:
     {
 
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <foo_excep> called: \n"
+                  "Callback method <foo_excep> called:\n"
                                   "Testing proper exception handling ...\n"));
       try
         {
@@ -123,19 +123,19 @@ public:
   void get_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <get_yadda_excep> called: \n"));
+                  "Callback method <get_yadda_excep> called:\n"));
     };
 
   void set_yadda (void)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda> called: \n"));
+                  "Callback method <set_yadda> called:\n"));
     };
 
   void set_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda_excep> called: \n"));
+                  "Callback method <set_yadda_excep> called:\n"));
     };
 
 };
