@@ -1,22 +1,22 @@
-// $Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: client.cpp 82847 2008-09-28 11:26:15Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "test_i.h"
 #include "tao/BiDir_GIOP/BiDirGIOP.h"
 #include "tao/AnyTypeCode/Any.h"
 
-ACE_RCSID(BiDirectional, client, "$Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(BiDirectional, client, "$Id: client.cpp 82847 2008-09-28 11:26:15Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 
 void do_nothing (void)
 {
 }
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
