@@ -1,5 +1,5 @@
 //
-// Hello.h,v 1.4 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Hello.h 77020 2007-02-12 13:56:49Z johnnyw $
 //
 
 #ifndef HELLO_H
@@ -22,11 +22,9 @@ public:
   Hello (CORBA::ORB_ptr orb);
 
   // = The skeleton methods
-  virtual char * get_string (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual char * get_string (void);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
 private:
   /// Use an ORB reference to conver strings to objects and shutdown
