@@ -1,14 +1,11 @@
-// $Id: client.cpp 76641 2007-01-26 18:25:17Z elliott_c $
+// $Id: client.cpp 82211 2008-06-27 11:00:06Z sma $
 
 #include "ior_mcast_client_i.h"
 
-int main (int argc, char *argv [])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
-
-
   try
     {
-
       ior_mcast_Client_i client;
 
       int init_result;
@@ -18,7 +15,7 @@ int main (int argc, char *argv [])
     }
   catch (const CORBA::SystemException&)
     {
-      //
+      // Ignore
     }
   catch (const CORBA::Exception& ex)
     {
