@@ -1,4 +1,4 @@
-// $Id: ior_mcast_client_i.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: ior_mcast_client_i.cpp 82211 2008-06-27 11:00:06Z sma $
 
 #include "ior_mcast_client_i.h"
 #include "ace/Get_Opt.h"
@@ -15,17 +15,13 @@ ior_mcast_Client_i::~ior_mcast_Client_i (void)
 
 int
 ior_mcast_Client_i::init (int& argc,
-                          char *argv[])
+                          ACE_TCHAR *argv[])
 {
-
   try
     {
       // First initialize the ORB, that will remove some arguments...
       CORBA::ORB_var orb =
-        CORBA::ORB_init (argc,
-                         argv,
-                         "" /* the ORB name, it can be anything! */
-                         );
+        CORBA::ORB_init (argc, argv);
 
       CORBA::Object_var mcast_server_object =
         orb->resolve_initial_references ("MCASTServer");
