@@ -1,8 +1,8 @@
-// $Id: server.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: server.cpp 82211 2008-06-27 11:00:06Z sma $
 
 #include "server_i.h"
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
