@@ -1,4 +1,4 @@
-// $Id: server_i.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: server_i.cpp 82735 2008-09-16 12:12:29Z johnnyw $
 
 #include "MCastC.h"
 #include "MCastS.h"
@@ -29,7 +29,7 @@ Server_i::~Server_i (void)
 
 int
 Server_i::init (int &argc,
-                char **&argv)
+                ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
@@ -38,10 +38,7 @@ Server_i::init (int &argc,
     {
       // First initialize the ORB, that will remove some arguments...
       this->orb_ =
-        CORBA::ORB_init (this->argc_,
-                         this->argv_,
-                         "" /* the ORB name, it can be anything! */
-                         );
+        CORBA::ORB_init (this->argc_, this->argv_);
 
       // Get a reference to the RootPOA.
       CORBA::Object_var poa_object =
@@ -146,16 +143,16 @@ Server_i::enable_multicast (const char *ior)
 }
 
 int
-Server_i::parse_args (int argc, char *argv [])
+Server_i::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "a:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("a:"));
   int c;
 
   while ((c = get_opts ()) != -1)
     switch (c)
       {
       case 'a':
-        this->mcast_address_ = get_opts.opt_arg ();
+        this->mcast_address_ = ACE_TEXT_ALWAYS_CHAR (get_opts.opt_arg ());
         break;
 
       case '?':
