@@ -1,12 +1,12 @@
 //
-// $Id: test.cpp 76869 2007-02-02 13:22:45Z johnnyw $
+// $Id: test.cpp 82203 2008-06-26 15:10:39Z sma $
 //
 
 #include "orbsvcs/CosNamingC.h"
 
 #include "ace/Log_Msg.h"
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
