@@ -1,4 +1,4 @@
-// $Id: server_i.cpp 77086 2007-02-13 07:36:47Z johnnyw $
+// $Id: server_i.cpp 82981 2008-10-08 14:49:02Z johnnyw $
 
 #include "server_i.h"
 
@@ -51,9 +51,9 @@ Server_i::~Server_i()
 }
 
 int
-Server_i::parse_args (int argc, char* argv[])
+Server_i::parse_args (int argc, ACE_TCHAR* argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "p:c:h");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("p:c:h"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -61,7 +61,7 @@ Server_i::parse_args (int argc, char* argv[])
     switch (c)
     {
     case 'p':  // prefix for all created objects
-      this->server_name_ = get_opts.opt_arg ();
+      this->server_name_ = ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ());
       break;
     case 'c':  // Number of imr-ified objects to create.
       this->count_ = ACE_OS::atoi(get_opts.opt_arg());
@@ -92,7 +92,7 @@ namespace
 }
 
 int
-Server_i::init (int argc, char** argv)
+Server_i::init (int argc, ACE_TCHAR** argv)
 {
   try
   {
