@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: test_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: test_i.cpp 84599 2009-02-25 16:25:48Z vzykov $
 
 #include "test_i.h"
 
@@ -8,7 +8,7 @@
 
 ACE_RCSID (Application_Test,
            test_i,
-           "$Id: test_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
+           "$Id: test_i.cpp 84599 2009-02-25 16:25:48Z vzykov $")
 
 
 CORBA::Boolean
@@ -20,6 +20,8 @@ inventory_i::getCDinfo (const char * artist,
   price = 0.0f;
   ACE_CString name_key ("Beatles");
   ACE_CString name (artist);
+  CORBA::String_var tmp = title;
+  ACE_UNUSED_ARG (tmp);
 
   if (name.strstr (name_key) != ACE_CString::npos)
     {
