@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: idl3_client.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: idl3_client.cpp 83504 2008-10-30 12:52:14Z johnnyw $
 
 #include "idl3_client.h"
 #include "tao/ORB.h"
@@ -8,7 +8,7 @@
 
 ACE_RCSID (Application_Test,
            ifr_dii_client,
-           "$Id: idl3_client.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: idl3_client.cpp 83504 2008-10-30 12:52:14Z johnnyw $")
 
 // All the magic quantities are here at the top.
 
@@ -258,11 +258,9 @@ IDL3_Client::~IDL3_Client (void)
 
 int
 IDL3_Client::init (int argc,
-                   char *argv[])
+                   ACE_TCHAR *argv[])
 {
-  this->orb_ = CORBA::ORB_init (argc,
-                                argv,
-                                0);
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
   CORBA::Object_var obj =
     this->orb_->resolve_initial_references ("InterfaceRepository");
@@ -330,9 +328,9 @@ IDL3_Client::run (void)
 
 int
 IDL3_Client::parse_args (int argc,
-                         char *argv[])
+                         ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt opts (argc, argv, "d");
+  ACE_Get_Opt opts (argc, argv, ACE_TEXT("d"));
   int c;
 
   while ((c = opts ()) != -1)
@@ -344,9 +342,7 @@ IDL3_Client::parse_args (int argc,
       case '?':
       default:
         ACE_ERROR_RETURN ((LM_ERROR,
-                           "usage: %s"
-                           " [-d]"
-                           "\n",
+                           "usage: %s [-d]\n",
                            argv [0]),
                           -1);
       }
@@ -607,7 +603,7 @@ IDL3_Client::valuetype_test (const char *repo_id,
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_test: lookup by id failed\n",
+                      "%Ctype_test: lookup by id failed\n",
                       prefix));
         }
 
@@ -622,7 +618,8 @@ IDL3_Client::valuetype_test (const char *repo_id,
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_test: narrow to ExtValueDef failed\n"));
+                      "%Ctype_test: narrow to ExtValueDef failed\n",
+                      prefix));
         }
 
       return -1;
@@ -1037,7 +1034,7 @@ IDL3_Client::event_port_test (CORBA::ComponentIR::EventPortDescriptionSeq &eds,
         {
           ACE_DEBUG ((LM_DEBUG,
                       "event_port_test: "
-                      "wrong number of event %s ports\n",
+                      "wrong number of event %C ports\n",
                       port_type));
         }
 
@@ -1056,7 +1053,7 @@ IDL3_Client::event_port_test (CORBA::ComponentIR::EventPortDescriptionSeq &eds,
             {
               ACE_DEBUG ((LM_DEBUG,
                           "event_port_test: "
-                          "wrong local name for %s port #%d\n",
+                          "wrong local name for %C port #%d\n",
                           port_type,
                           i + 1));
             }
@@ -1072,7 +1069,7 @@ IDL3_Client::event_port_test (CORBA::ComponentIR::EventPortDescriptionSeq &eds,
             {
               ACE_DEBUG ((LM_DEBUG,
                           "event_port_test: "
-                          "wrong base event type id for %s port #%d\n",
+                          "wrong base event type id for %C port #%d\n",
                           port_type,
                           i + 1));
             }
@@ -1095,7 +1092,7 @@ IDL3_Client::valuetype_inheritance_test (CORBA::ExtValueDef_var &vd,
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_inheritance_test: "
+                      "%Ctype_inheritance_test: "
                       "base valuetype is null\n",
                       prefix));
         }
@@ -1110,7 +1107,7 @@ IDL3_Client::valuetype_inheritance_test (CORBA::ExtValueDef_var &vd,
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_inheritance_test: "
+                      "%Ctype_inheritance_test: "
                       "wrong repo id for base valuetype\n",
                       prefix));
         }
@@ -1128,7 +1125,7 @@ IDL3_Client::valuetype_inheritance_test (CORBA::ExtValueDef_var &vd,
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_inheritance_test: "
+                      "%Ctype_inheritance_test: "
                       "wrong number of supported interfaces\n",
                       prefix));
         }
@@ -1146,7 +1143,7 @@ IDL3_Client::valuetype_inheritance_test (CORBA::ExtValueDef_var &vd,
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_inheritance_test: "
+                          "%Ctype_inheritance_test: "
                           "bad id on supported interface #%d\n",
                           prefix,
                           i + 1));
@@ -1170,7 +1167,7 @@ IDL3_Client::valuetype_attribute_test (
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_attribute_test: wrong number of attrs\n",
+                      "%Ctype_attribute_test: wrong number of attrs\n",
                       prefix));
         }
 
@@ -1188,7 +1185,7 @@ IDL3_Client::valuetype_attribute_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_attribute_test: "
+                          "%Ctype_attribute_test: "
                           "wrong local name for attribute #%d\n",
                           prefix,
                           i + 1));
@@ -1205,7 +1202,7 @@ IDL3_Client::valuetype_attribute_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_attribute_test: "
+                          "%Ctype_attribute_test: "
                           "wrong TCKind for attribute #%d\n",
                           prefix,
                           i + 1));
@@ -1219,7 +1216,7 @@ IDL3_Client::valuetype_attribute_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_attribute_test: "
+                          "%Ctype_attribute_test: "
                           "wrong number of get-exceptions"
                           " for attribute #%d\n",
                           prefix,
@@ -1234,7 +1231,7 @@ IDL3_Client::valuetype_attribute_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_attribute_test: "
+                          "%Ctype_attribute_test: "
                           "wrong number of put-exceptions"
                           " for attribute #%d\n",
                           prefix,
@@ -1261,7 +1258,7 @@ IDL3_Client::valuetype_operation_test (
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_operation_test: "
+                      "%Ctype_operation_test: "
                       "wrong number of operations\n",
                       prefix));
         }
@@ -1282,7 +1279,7 @@ IDL3_Client::valuetype_operation_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_operation_test: "
+                          "%Ctype_operation_test: "
                           "wrong name for operation #%d\n",
                           prefix,
                           i + 1));
@@ -1299,7 +1296,7 @@ IDL3_Client::valuetype_operation_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_operation_test: "
+                          "%Ctype_operation_test: "
                           "wrong return type\n",
                           prefix));
             }
@@ -1314,7 +1311,7 @@ IDL3_Client::valuetype_operation_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_operation_test: "
+                          "%Ctype_operation_test: "
                           "wrong number of parameters in operation #%d\n",
                           prefix,
                           i + 1));
@@ -1332,7 +1329,7 @@ IDL3_Client::valuetype_operation_test (
               if (this->debug_)
                 {
                   ACE_DEBUG ((LM_DEBUG,
-                              "%stype_operation_test: "
+                              "%Ctype_operation_test: "
                               "wrong name for operation #%d,"
                               "parameter #%d\n",
                               prefix,
@@ -1351,7 +1348,7 @@ IDL3_Client::valuetype_operation_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_operation_test: "
+                          "%Ctype_operation_test: "
                           "wrong number of exceptions in operation #%d\n",
                           prefix,
                           i + 1));
@@ -1377,7 +1374,7 @@ IDL3_Client::valuetype_member_test (
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_member_test: "
+                      "%Ctype_member_test: "
                       "wrong number of members\n",
                       prefix));
         }
@@ -1394,7 +1391,7 @@ IDL3_Client::valuetype_member_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_member_test: "
+                          "%Ctype_member_test: "
                           "wrong access value in member #%d\n",
                           prefix,
                           i + 1));
@@ -1410,7 +1407,7 @@ IDL3_Client::valuetype_member_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_member_test: "
+                          "%Ctype_member_test: "
                           "wrong repo id for member #%d\n",
                           prefix,
                           i + 1));
@@ -1436,7 +1433,7 @@ IDL3_Client::valuetype_factory_test (
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "%stype_factory_test: "
+                      "%Ctype_factory_test: "
                       "wrong number of factories\n",
                       prefix));
         }
@@ -1456,7 +1453,7 @@ IDL3_Client::valuetype_factory_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_factory_test: "
+                          "%Ctype_factory_test: "
                           "wrong number of params in factory #%d\n",
                           prefix,
                           i + 1));
@@ -1477,7 +1474,7 @@ IDL3_Client::valuetype_factory_test (
               if (this->debug_)
                 {
                   ACE_DEBUG ((LM_DEBUG,
-                              "%stype_factory_test: "
+                              "%Ctype_factory_test: "
                               "wrong name for arg #%d in factory #%d\n",
                               prefix,
                               j + 1,
@@ -1495,7 +1492,7 @@ IDL3_Client::valuetype_factory_test (
           if (this->debug_)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "%stype_factory_test: "
+                          "%Ctype_factory_test: "
                           "wrong number of exceptions in factory #%d\n",
                           prefix,
                           i + 1));
@@ -1514,7 +1511,7 @@ IDL3_Client::valuetype_factory_test (
               if (this->debug_)
                 {
                   ACE_DEBUG ((LM_DEBUG,
-                              "%stype_factory_test: "
+                              "%Ctype_factory_test: "
                               "wrong name for exception #%d in factory #%d\n",
                               prefix,
                               j + 1,
