@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: idl3_client.h 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: idl3_client.h 82869 2008-09-29 08:02:27Z johnnyw $
 
 // ============================================================================
 //
@@ -38,7 +38,7 @@ public:
   // Destructor
 
   int init (int argc,
-            char *argv[]);
+            ACE_TCHAR *argv[]);
   // Initialize the ORB and get the IFR object reference.
 
   int run (void);
@@ -46,7 +46,7 @@ public:
 
 private:
   int parse_args (int argc,
-                  char *argv[]);
+                  ACE_TCHAR *argv[]);
   // Process the command line arguments.
 
   int component_test (void);
