@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Admin_Client.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: Admin_Client.cpp 83512 2008-10-31 07:05:50Z johnnyw $
 
 #include "Admin_Client.h"
 
@@ -11,7 +11,7 @@
 
 ACE_RCSID (IFR_Test,
            Admin_Client,
-           "$Id: Admin_Client.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: Admin_Client.cpp 83512 2008-10-31 07:05:50Z johnnyw $")
 
 Admin_Client::Admin_Client (void)
   : debug_ (0),
@@ -55,17 +55,13 @@ const char *Admin_Client::test_names_[] =
 };
 
 int
-Admin_Client::init (int argc,
-                    char *argv[])
+Admin_Client::init (int argc, ACE_TCHAR *argv[])
 {
   try
     {
-      this->orb_ = CORBA::ORB_init (argc,
-                                    argv,
-                                    0);
+      this->orb_ = CORBA::ORB_init (argc, argv);
 
-      int retval = this->parse_args (argc,
-                                     argv);
+      int retval = this->parse_args (argc, argv);
 
       if (retval != 0)
         return retval;
@@ -139,14 +135,13 @@ Admin_Client::run (void)
 }
 
 int
-Admin_Client::parse_args (int argc,
-                          char *argv[])
+Admin_Client::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt opts (argc, argv, "di:t:");
+  ACE_Get_Opt opts (argc, argv, ACE_TEXT("di:t:"));
   int c;
   int result = 0;
   CORBA::ULong i = 0;
-  char *name = 0;
+  ACE_TCHAR *name = 0;
 
   while ((c = opts ()) != -1)
     switch (c)
@@ -165,7 +160,7 @@ Admin_Client::parse_args (int argc,
 
         for (i = 0; i < NUMBER_OF_TESTS; ++i)
           {
-            if (ACE_OS::strcmp (name, this->test_names_[i]) == 0)
+            if (ACE_OS::strcmp (ACE_TEXT_ALWAYS_CHAR (name), this->test_names_[i]) == 0)
               {
                 this->which_test_ = i;
                 break;
@@ -349,7 +344,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::id: %s\n"),
+                  ACE_TEXT ("EnumDef::id: %C\n"),
                   str.in ()));
     }
 
@@ -360,7 +355,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::name: %s\n"),
+                  ACE_TEXT ("EnumDef::name: %C\n"),
                   str.in ()));
     }
 
@@ -371,7 +366,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::absolute_name: %s\n"),
+                  ACE_TEXT ("EnumDef::absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -382,7 +377,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::version: %s\n"),
+                  ACE_TEXT ("EnumDef::version: %C\n"),
                   str.in ()));
     }
 
@@ -420,7 +415,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::describe::value::name: %s\n"),
+                  ACE_TEXT ("EnumDef::describe::value::name: %C\n"),
                   td->name.in ()));
     }
 
@@ -429,7 +424,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::describe::value::id: %s\n"),
+                  ACE_TEXT ("EnumDef::describe::value::id: %C\n"),
                   td->id.in ()));
     }
 
@@ -438,7 +433,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::describe::value::defined_in: %s\n"),
+                  ACE_TEXT ("EnumDef::describe::value::defined_in: %C\n"),
                   td->defined_in.in ()));
     }
 
@@ -447,7 +442,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::describe::value::version: %s\n"),
+                  ACE_TEXT ("EnumDef::describe::value::version: %C\n"),
                   td->version.in ()));
     }
 
@@ -469,7 +464,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::describe::value::type::id: %s\n"),
+                  ACE_TEXT ("EnumDef::describe::value::type::id: %C\n"),
                   str.in ()));
     }
 
@@ -480,7 +475,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::describe::value::type::name: %s\n"),
+                  ACE_TEXT ("EnumDef::describe::value::type::name: %C\n"),
                   str.in ()));
     }
 
@@ -510,7 +505,7 @@ Admin_Client::enum_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("EnumDef::describe::value::type::")
-                      ACE_TEXT ("member_name[%d]: %s\n"),
+                      ACE_TEXT ("member_name[%d]: %C\n"),
                       i,
                       str.in ()));
         }
@@ -547,7 +542,7 @@ Admin_Client::enum_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("EnumDef::")
-                      ACE_TEXT ("members[%d]: %s\n"),
+                      ACE_TEXT ("members[%d]: %C\n"),
                       i,
                       tmp));
         }
@@ -567,7 +562,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::name: %s\n"),
+                  ACE_TEXT ("EnumDef::name: %C\n"),
                   str.in ()));
     }
 
@@ -578,7 +573,7 @@ Admin_Client::enum_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("EnumDef::absolute_name: %s\n"),
+                  ACE_TEXT ("EnumDef::absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -618,7 +613,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::id: %s\n"),
+                  ACE_TEXT ("AliasDef::id: %C\n"),
                   str.in ()));
     }
 
@@ -629,7 +624,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::name: %s\n"),
+                  ACE_TEXT ("AliasDef::name: %C\n"),
                   str.in ()));
     }
 
@@ -640,7 +635,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::absolute_name: %s\n"),
+                  ACE_TEXT ("AliasDef::absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -651,7 +646,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::version: %s\n"),
+                  ACE_TEXT ("AliasDef::version: %C\n"),
                   str.in ()));
     }
 
@@ -670,7 +665,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::version: %s\n"),
+                  ACE_TEXT ("AliasDef::version: %C\n"),
                   str.in ()));
     }
 
@@ -683,7 +678,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("\nAliasDef::type::name: %s\n"),
+                  ACE_TEXT ("\nAliasDef::type::name: %C\n"),
                   str.in ()));
     }
 
@@ -761,7 +756,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("\nAliasDef::describe::value::name: %s\n"),
+                  ACE_TEXT ("\nAliasDef::describe::value::name: %C\n"),
                   td->name.in ()));
     }
 
@@ -770,7 +765,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::describe::value::version: %s\n"),
+                  ACE_TEXT ("AliasDef::describe::value::version: %C\n"),
                   td->version.in ()));
     }
 
@@ -792,7 +787,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::describe::value::type::id: %s\n"),
+                  ACE_TEXT ("AliasDef::describe::value::type::id: %C\n"),
                   str.in ()));
     }
 
@@ -803,7 +798,7 @@ Admin_Client::alias_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("AliasDef::describe::value::type::name: %s\n"),
+                  ACE_TEXT ("AliasDef::describe::value::type::name: %C\n"),
                   str.in ()));
     }
 
@@ -850,7 +845,7 @@ Admin_Client::native_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("NativeDef::id: %s\n"),
+                  ACE_TEXT ("NativeDef::id: %C\n"),
                   str.in ()));
     }
 
@@ -861,7 +856,7 @@ Admin_Client::native_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("NativeDef::name: %s\n"),
+                  ACE_TEXT ("NativeDef::name: %C\n"),
                   str.in ()));
     }
 
@@ -872,7 +867,7 @@ Admin_Client::native_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("NativeDef::version: %s\n"),
+                  ACE_TEXT ("NativeDef::version: %C\n"),
                   str.in ()));
     }
 
@@ -883,7 +878,7 @@ Admin_Client::native_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("NativeDef::absolute_name: %s\n"),
+                  ACE_TEXT ("NativeDef::absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -972,7 +967,7 @@ Admin_Client::struct_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("StructDef::type::member_name[%d]: %s\n"),
+                      ACE_TEXT ("StructDef::type::member_name[%d]: %C\n"),
                       i,
                       str.in ()));
         }
@@ -989,7 +984,7 @@ Admin_Client::struct_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("\nStructDef::describe::value::name: %s\n"),
+                  ACE_TEXT ("\nStructDef::describe::value::name: %C\n"),
                   td->name.in ()));
     }
 
@@ -998,7 +993,7 @@ Admin_Client::struct_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("StructDef::describe::value::id: %s\n"),
+                  ACE_TEXT ("StructDef::describe::value::id: %C\n"),
                   td->id.in ()));
     }
 
@@ -1007,7 +1002,7 @@ Admin_Client::struct_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("StructDef::describe::value::version: %s\n"),
+                  ACE_TEXT ("StructDef::describe::value::version: %C\n"),
                   td->version.in ()));
     }
 
@@ -1054,7 +1049,7 @@ Admin_Client::struct_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("StructDef::members[%d]::name: %s\n"),
+                      ACE_TEXT ("StructDef::members[%d]::name: %C\n"),
                       i,
                       out_members[i].name.in ()));
         }
@@ -1080,7 +1075,7 @@ Admin_Client::struct_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("Repository::lookup::absolute_name: %s\n"),
+                  ACE_TEXT ("Repository::lookup::absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -1093,7 +1088,7 @@ Admin_Client::struct_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("StructDef::lookup::absolute_name: %s\n"),
+                  ACE_TEXT ("StructDef::lookup::absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -1109,7 +1104,7 @@ Admin_Client::struct_test (void)
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("StructDef::lookup::defined_in::")
-                  ACE_TEXT ("absolute_name: %s\n"),
+                  ACE_TEXT ("absolute_name: %C\n"),
                   str.in ()));
     }
 
@@ -1152,7 +1147,7 @@ Admin_Client::struct_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("StructDef::contents[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("StructDef::contents[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -1192,7 +1187,7 @@ Admin_Client::struct_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -1229,7 +1224,7 @@ Admin_Client::struct_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("Repository::describe_contents[%d]::id: %s\n"),
+              ACE_TEXT ("Repository::describe_contents[%d]::id: %C\n"),
               i,
               str.in ()
             ));
@@ -1277,7 +1272,7 @@ Admin_Client::struct_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("StructDef::contents[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("StructDef::contents[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -1450,7 +1445,7 @@ Admin_Client::union_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("UnionDef::type::member_name[%d]: %s\n"),
+                      ACE_TEXT ("UnionDef::type::member_name[%d]: %C\n"),
                       i,
                       str.in ()));
         }
@@ -1479,7 +1474,7 @@ Admin_Client::union_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("UnionDef::type::member_label[%d]: %s\n"),
+                      ACE_TEXT ("UnionDef::type::member_label[%d]: %C\n"),
                       i,
                       i == (CORBA::ULong) slot ? "default" : tmp));
         }
@@ -1573,7 +1568,7 @@ Admin_Client::exception_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("ExceptionDef::type::member_name[%d]: %s\n"),
+                      ACE_TEXT ("ExceptionDef::type::member_name[%d]: %C\n"),
                       i,
                       str.in ()));
         }
@@ -1590,7 +1585,7 @@ Admin_Client::exception_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("\nExceptionDef::describe::value::name: %s\n"),
+                  ACE_TEXT ("\nExceptionDef::describe::value::name: %C\n"),
                   ed->name.in ()));
     }
 
@@ -1599,7 +1594,7 @@ Admin_Client::exception_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("ExceptionDef::describe::value::id: %s\n"),
+                  ACE_TEXT ("ExceptionDef::describe::value::id: %C\n"),
                   ed->id.in ()));
     }
 
@@ -1608,7 +1603,7 @@ Admin_Client::exception_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("ExceptionDef::describe::value::defined_in: %s\n"),
+                  ACE_TEXT ("ExceptionDef::describe::value::defined_in: %C\n"),
                   ed->defined_in.in ()));
     }
 
@@ -1617,7 +1612,7 @@ Admin_Client::exception_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("ExceptionDef::describe::value::version: %s\n"),
+                  ACE_TEXT ("ExceptionDef::describe::value::version: %C\n"),
                   ed->version.in ()));
     }
 
@@ -1666,7 +1661,7 @@ Admin_Client::exception_test (void)
     {
       if (this->debug_)
         ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("ExceptionDef::members[%d]::name: %s\n"),
+                    ACE_TEXT ("ExceptionDef::members[%d]::name: %C\n"),
                     i,
                     out_members[i].name.in ()));
 
@@ -1700,7 +1695,7 @@ Admin_Client::exception_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("ExceptionDef::members[%d]::name: %s\n"),
+                      ACE_TEXT ("ExceptionDef::members[%d]::name: %C\n"),
                       i,
                       out_members[i].name.in ()));
         }
@@ -1782,7 +1777,7 @@ Admin_Client::exception_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("ExceptionDef::contents[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("ExceptionDef::contents[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -1816,7 +1811,7 @@ Admin_Client::exception_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("Repository::lookup_name%d]::absolute_name: %s\n"),
+              ACE_TEXT ("Repository::lookup_name%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -1869,7 +1864,7 @@ Admin_Client::exception_test (void)
             {
               ACE_DEBUG ((LM_DEBUG,
                           ACE_TEXT ("Repository::describe_contents[%d]")
-                          ACE_TEXT ("::value::name: %s\n"),
+                          ACE_TEXT ("::value::name: %C\n"),
                           i,
                           ed->name.in ()));
             }
@@ -1898,7 +1893,7 @@ Admin_Client::exception_test (void)
             {
               ACE_DEBUG ((LM_DEBUG,
                           ACE_TEXT ("Repository::describe_contents[%d]")
-                          ACE_TEXT ("::value::name: %s\n"),
+                          ACE_TEXT ("::value::name: %C\n"),
                           i,
                           td->name.in ()));
             }
@@ -1929,7 +1924,7 @@ Admin_Client::exception_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("ExceptionDef::contents[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("ExceptionDef::contents[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -2007,7 +2002,7 @@ Admin_Client::constant_test (void)
   if (this->debug_)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("ConstantDef::value (string): %s\n"),
+                  ACE_TEXT ("ConstantDef::value (string): %C\n"),
                   out_s));
     }
 
@@ -2121,7 +2116,7 @@ Admin_Client::constant_test (void)
 #if defined (ACE_LACKS_LONGLONG_T)
       char buffer[32];
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("ConstantDef::value (ulonglong): %s\n"),
+                  ACE_TEXT ("ConstantDef::value (ulonglong): %C\n"),
                   out_ull_val.as_string (buffer)));
 #else
       ACE_DEBUG ((LM_DEBUG,
@@ -2282,7 +2277,7 @@ Admin_Client::interface_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("OperationDef::describe::parameters[%d]::")
-                      ACE_TEXT ("name: %s\n"),
+                      ACE_TEXT ("name: %C\n"),
                       i,
                       tmp));
         }
@@ -2343,7 +2338,7 @@ Admin_Client::interface_test (void)
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("\nInterfaceDef::describe_interface::")
-                  ACE_TEXT ("type::id: %s\n"),
+                  ACE_TEXT ("type::id: %C\n"),
                   str.in ()));
     }
 
@@ -2381,7 +2376,7 @@ Admin_Client::interface_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("InterfaceDef::describe_interface::")
-                      ACE_TEXT ("operations[0]::contexts[%d]: %s\n"),
+                      ACE_TEXT ("operations[0]::contexts[%d]: %C\n"),
                       i,
                       tmp));
         }
@@ -2409,7 +2404,7 @@ Admin_Client::interface_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("InterfaceDef::describe::operations[3]::")
-                      ACE_TEXT ("contexts[%d]: %s\n"),
+                      ACE_TEXT ("contexts[%d]: %C\n"),
                       i,
                       tmp));
         }
@@ -2423,7 +2418,7 @@ Admin_Client::interface_test (void)
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("\nInterfaceDef::describe_interface::")
-                  ACE_TEXT ("attributes::defined_in: %s\n"),
+                  ACE_TEXT ("attributes::defined_in: %C\n"),
                   tmp));
     }
 
@@ -2464,7 +2459,7 @@ Admin_Client::interface_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("InterfaceDef::describe::")
-                      ACE_TEXT ("base_interfaces[%d]: %s\n"),
+                      ACE_TEXT ("base_interfaces[%d]: %C\n"),
                       i,
                       base_iface_id));
         }
@@ -2492,7 +2487,7 @@ Admin_Client::interface_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("InterfaceDef::base_interfaces[%d]::name: %s\n"),
+              ACE_TEXT ("InterfaceDef::base_interfaces[%d]::name: %C\n"),
               i,
               str.in ()
             ));
@@ -2520,7 +2515,7 @@ Admin_Client::interface_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("InterfaceDef::contents[%d]::name: %s\n"),
+                      ACE_TEXT ("InterfaceDef::contents[%d]::name: %C\n"),
                       i,
                       str.in ()));
         }
@@ -2537,7 +2532,7 @@ Admin_Client::interface_test (void)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("InterfaceDef::contents[%d]::")
-                      ACE_TEXT ("defined_in::name: %s\n"),
+                      ACE_TEXT ("defined_in::name: %C\n"),
                       i,
                       str.in ()));
         }
@@ -2660,7 +2655,7 @@ Admin_Client::move_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("UnionDef::members[%d]::name: %s\n"),
+                      ACE_TEXT ("UnionDef::members[%d]::name: %C\n"),
                       i,
                       tmp));
         }
@@ -2713,7 +2708,7 @@ Admin_Client::move_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("UnionDef::members[%d]::name: %s\n"),
+                      ACE_TEXT ("UnionDef::members[%d]::name: %C\n"),
                       i,
                       tmp));
         }
@@ -2752,7 +2747,7 @@ Admin_Client::move_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("UnionDef::contents[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("UnionDef::contents[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -2813,7 +2808,7 @@ Admin_Client::move_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("UnionDef::members[%d]::name: %s\n"),
+                      ACE_TEXT ("UnionDef::members[%d]::name: %C\n"),
                       i,
                       tmp));
         }
@@ -2846,7 +2841,7 @@ Admin_Client::move_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("UnionDef::contents[%d]::absolute_name: %s\n"),
+                      ACE_TEXT ("UnionDef::contents[%d]::absolute_name: %C\n"),
                       i,
                       str.in ()));
         }
@@ -2885,7 +2880,7 @@ Admin_Client::move_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("StructDef::contents[%d]::absolute_name: %s\n"),
+                      ACE_TEXT ("StructDef::contents[%d]::absolute_name: %C\n"),
                       i,
                       str.in ()));
         }
@@ -2922,7 +2917,7 @@ Admin_Client::move_test (void)
       if (this->debug_)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("StructDef::members[%d]::name: %s\n"),
+                      ACE_TEXT ("StructDef::members[%d]::name: %C\n"),
                       i,
                       tmp));
         }
@@ -3045,7 +3040,7 @@ Admin_Client::module_test (void)
     {
       ACE_DEBUG ((
           LM_DEBUG,
-          ACE_TEXT ("ModuleDef::lookup (absolute)::absolute_name: %s\n"),
+          ACE_TEXT ("ModuleDef::lookup (absolute)::absolute_name: %C\n"),
           str.in ()
         ));
     }
@@ -3063,7 +3058,7 @@ Admin_Client::module_test (void)
     {
       ACE_DEBUG ((
           LM_DEBUG,
-          ACE_TEXT ("ModuleDef::lookup (relative)::absolute_name: %s\n"),
+          ACE_TEXT ("ModuleDef::lookup (relative)::absolute_name: %C\n"),
           str.in ()
         ));
     }
@@ -3098,7 +3093,7 @@ Admin_Client::module_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -3134,7 +3129,7 @@ Admin_Client::module_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
@@ -3177,7 +3172,7 @@ Admin_Client::module_test (void)
         {
           ACE_DEBUG ((
               LM_DEBUG,
-              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %s\n"),
+              ACE_TEXT ("Repository::lookup_name[%d]::absolute_name: %C\n"),
               i,
               str.in ()
             ));
