@@ -1,5 +1,5 @@
 // -*- C++ -*-
-// $Id: Ptest.h 76555 2007-01-24 15:39:09Z johnnyw $
+// $Id: Ptest.h 83252 2008-10-15 11:09:34Z vzykov $
 
 // ============================================================================
 //
@@ -43,7 +43,7 @@ public:
   // Destructor
 
   int init (int argc,
-            char *argv[]);
+            ACE_TCHAR *argv[]);
   // Initialize the ORB and get the IFR object reference.
 
   int run (void);
@@ -51,11 +51,11 @@ public:
 
 private:
   void populate (void);
-  void query (void);
+  int query (void);
   // The two IFR tests.
 
   int parse_args (int argc,
-                  char *argv[]);
+                  ACE_TCHAR *argv[]);
   // Process the command line arguments.
 
   CORBA::Boolean debug_;
