@@ -1,4 +1,4 @@
-// $Id: client.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: client.cpp 82203 2008-06-26 15:10:39Z sma $
 
 // ============================================================================
 //
@@ -20,7 +20,7 @@
 
 #include "ncontextext_client_i.h"
 
-int main (int argc, char *argv [])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   int result = 0;
 
