@@ -3,14 +3,14 @@
 
 ACE_RCSID (Application_Controlled,
            client,
-           "$Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+           "$Id: client.cpp 82847 2008-09-28 11:26:15Z johnnyw $")
 
-const char *ior = "file://obj.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://obj.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -56,7 +56,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                              "Nil Test::Basic reference <%s>\n",
                              ior),
                             1);
-	}
+        }
 
       for (int i = 0; i < 5; i++)
         {
@@ -65,7 +65,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
           ACE_DEBUG ((LM_DEBUG, "(%P|%t) - Client request handled by object at <%s>\n",
                       the_string.in ()));
-	}
+        }
 
       basic->remove_member ();
 
