@@ -7,11 +7,12 @@
 
 ACE_RCSID (Infrastructure_Controlled,
            LB_server,
-           "$Id: LB_server.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+           "$Id: LB_server.cpp 87782 2009-11-26 10:45:22Z dbudko $")
 
-LB_server::LB_server (int argc, char **argv)
+LB_server::LB_server (int argc, ACE_TCHAR **argv)
   : argc_ (argc)
   , argv_ (argv)
+  , ior_output_file_(ACE_TEXT("obj.ior"))
 {
 }
 
@@ -28,7 +29,7 @@ LB_server::run (void)
     {
       ACE_Time_Value period (0, 10);
       while (1)
-	{
+        {
           this->orb_->perform_work (&period);
         }
     }
@@ -67,7 +68,7 @@ int
 LB_server::write_ior_to_file (const char *ior)
 {
   FILE *output_file =
-    ACE_OS::fopen ("obj.ior", "w");
+    ACE_OS::fopen (this->ior_output_file_, "w");
 
   if (output_file == 0)
     {
@@ -81,15 +82,39 @@ LB_server::write_ior_to_file (const char *ior)
   return 0;
 }
 
+int
+LB_server::parse_args (int argc, ACE_TCHAR *argv[])
+{
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
+  int c;
+
+  while ((c = get_opts ()) != -1)
+    switch (c)
+      {
+      case 'o':
+        this->ior_output_file_ = get_opts.opt_arg ();
+        break;
+      case '?':
+      default:
+        ACE_ERROR_RETURN ((LM_ERROR,
+                           "usage:  %s "
+                           "-o <iorfile>"
+                           "\n",
+                           argv [0]),
+                          -1);
+      }
+  // Indicates sucessful parsing of the command line
+  return 0;
+}
+
+
 int
 LB_server::start_orb_and_poa (void)
 {
   try
     {
       // Initialise the ORB.
-      this->orb_ = CORBA::ORB_init (this->argc_,
-                                    this->argv_,
-                                    "");
+      this->orb_ = CORBA::ORB_init (this->argc_, this->argv_);
 
       CORBA::Object_var poa_object =
         this->orb_->resolve_initial_references("RootPOA");
@@ -138,6 +163,9 @@ LB_server::create_object_group (const char *loc_1, const char *loc_2)
       Factory factory_object1;
       Factory factory_object2;
 
+      if (this->parse_args (argc_, argv_) != 0)
+              return -1;
+
       PortableGroup::GenericFactory_var factory_obj1 =
         factory_object1._this ();
 
