@@ -4,10 +4,10 @@
 
 ACE_RCSID (Infrastructure_Controlled,
            server,
-           "server.cpp,v 1.4 2004/04/29 13:31:00 jwillemsen Exp")
+           "$Id: server.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
 
 int
-main (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   const char *location1 = "MyLocation 1";
   const char *location2 = "MyLocation 2";
