@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// Basic.h,v 1.4 2005/07/04 08:55:12 jwillemsen Exp
+// $Id: Basic.h 77020 2007-02-12 13:56:49Z johnnyw $
 
 #ifndef BASIC_H
 #define BASIC_H
@@ -26,17 +26,13 @@ public:
          CORBA::Short num,
          const char *loc);
 
-  virtual char * get_string (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual char * get_string (void);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
-  virtual void remove_member (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void remove_member (void);
 
-  virtual CORBA::Short number (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual CORBA::Short number (void);
 
 private:
   /// Use an ORB reference to convert strings to objects and shutdown
