@@ -7,9 +7,9 @@
 
 ACE_RCSID (Application_Controlled,
            LB_server,
-           "$Id: LB_server.cpp 78706 2007-06-30 21:51:17Z sowayaa $")
+           "$Id: LB_server.cpp 82864 2008-09-29 07:44:18Z johnnyw $")
 
-LB_server::LB_server (int argc, char **argv)
+LB_server::LB_server (int argc, ACE_TCHAR **argv)
   : argc_ (argc)
   , argv_ (argv)
 {
@@ -68,9 +68,7 @@ LB_server::start_orb_and_poa (void)
   try
     {
       // Initialise the ORB.
-      this->orb_ = CORBA::ORB_init (this->argc_,
-                                    this->argv_,
-                                    "");
+      this->orb_ = CORBA::ORB_init (this->argc_, this->argv_);
 
       CORBA::Object_var poa_object =
         this->orb_->resolve_initial_references("RootPOA");
