@@ -10,7 +10,7 @@
 
 ACE_RCSID (Basic_Log_Test,
            Basic_Log_Test,
-           "$Id: Basic_Log_Test.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+           "$Id: Basic_Log_Test.cpp 82869 2008-09-29 08:02:27Z johnnyw $")
 
 
 const char* BasicLog_Test::basic_log_factory_name_= "BasicLogFactory";
@@ -28,7 +28,7 @@ BasicLog_Test::~BasicLog_Test (void)
 }
 
 int
-BasicLog_Test::init (int argc, char *argv[])
+BasicLog_Test::init (int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -509,9 +509,9 @@ BasicLog_Test::test_query(CORBA::ULong numberOfRecordsToWrite)
 
 
 int
-BasicLog_Test::parse_args (int argc, char *argv[])
+BasicLog_Test::parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "di");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("di"));
   int c;
 
   while ((c = get_opts ()) != -1)
