@@ -1,20 +1,20 @@
-// $Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: client.cpp 82847 2008-09-28 11:26:15Z johnnyw $
 
 #include "TestC.h"
 #include "ace/Get_Opt.h"
 #include "tao/Object_T.h"
 #include "orbsvcs/PortableGroup/MIOP.h"
 
-ACE_RCSID(Hello, client, "$Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(Hello, client, "$Id: client.cpp 82847 2008-09-28 11:26:15Z johnnyw $")
 
 #define MAX_MIOP_OCTET_SEQUENCE  (ACE_MAX_DGRAM_SIZE - 272 /* MIOP_MAX_HEADER_SIZE */)
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
