@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: AdminProperties.h 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: AdminProperties.h 82735 2008-09-16 12:12:29Z johnnyw $
 // ==========================================================================
 //
 // = FILENAME
@@ -92,7 +92,7 @@ public:
   AdminProperties (void);
   ~AdminProperties (void);
 
-  int parse_args (int argc, char *argv[]) ;
+  int parse_args (int argc, ACE_TCHAR *argv[]) ;
 
   // Initialization.
 
