@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: LifeCycle.h 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: LifeCycle.h 82869 2008-09-29 08:02:27Z johnnyw $
 // ==========================================================================
 //
 // = FILENAME
@@ -23,10 +23,10 @@ public:
   ~LifeCycle (void);
 
   void init (int argc,
-             char *argv[]);
+             ACE_TCHAR *argv[]);
   void run_test (void);
   int parse_args (int argc,
-                  char *argv[]);
+                  ACE_TCHAR *argv[]);
 
 private:
    void create_ec (void);
