@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: MultiTypes.h 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: MultiTypes.h 82903 2008-10-01 19:22:10Z johnnyw $
 // ==========================================================================
 //
 // = FILENAME
@@ -90,10 +90,10 @@ public:
   void on_received_event (MultiTypes_SequencePushConsumer* consumer);
 
   int parse_args (int argc,
-                  char *argv[]);
+                  ACE_TCHAR *argv[]);
 
   int init (int argc,
-            char *argv []);
+            ACE_TCHAR *argv []);
   // initialization.
 
   void run_test (void);
