@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Notify_Structured_Push_Consumer.h,v 1.8 2005/07/01 20:13:11 michel_j Exp
+// $Id: Notify_Structured_Push_Consumer.h 77020 2007-02-12 13:56:49Z johnnyw $
 // ==========================================================================
 //
 // = LIBRARY
@@ -32,14 +32,10 @@ public:
                         unsigned int expected,
                         Notify_Test_Client& client);
 
-  void _connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin
-                ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void _connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin);
 
 protected:
-  void push_structured_event (const CosNotification::StructuredEvent&
-                              ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void push_structured_event (const CosNotification::StructuredEvent&);
 
   ACE_CString name_;
   TimeBase::TimeT blocking_timeout_;
