@@ -1,10 +1,10 @@
-//$Id: main.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+//$Id: main.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "../lib/Driver.h"
 #include "ace/OS_main.h"
 
 int
-ACE_TMAIN (int argc, char *argv[])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
   TAO_Notify_Tests_Driver driver;
 
@@ -21,7 +21,7 @@ ACE_TMAIN (int argc, char *argv[])
     }
   catch (const CORBA::Exception& ex)
     {
-      ex._tao_print_exception (ACE_TEXT("Error: \n"));
+      ex._tao_print_exception (ACE_TEXT("Error:\n"));
       return 1;
     }
 
