@@ -3,7 +3,7 @@
 /**
  *  @file   Notify_Structured_Push_Consumer.h
  *
- *  $Id: Notify_Structured_Push_Consumer.h 79328 2007-08-13 14:14:56Z elliott_c $
+ *  $Id: Notify_Structured_Push_Consumer.h 87253 2009-10-28 23:29:32Z dai_y $
  *
  *  A structured push consumer implementation.
  *
@@ -28,6 +28,7 @@ public:
                                    Notify_Test_Client& client);
 
   void _connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin);
+  void set_delay_parameters (unsigned int delayCount_, unsigned long delayPeriod_);
 
 protected:
   void push_structured_event (const CosNotification::StructuredEvent&);
@@ -35,6 +36,8 @@ protected:
   ACE_CString name_;
   unsigned int expected_;
   unsigned int count_;
+  unsigned int delay_count_;
+  unsigned long delay_period_;
   Notify_Test_Client& client_;
 };
 
