@@ -1,7 +1,8 @@
-// $Id: Notify_Structured_Push_Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: Notify_Structured_Push_Consumer.cpp 87253 2009-10-28 23:29:32Z dai_y $
 
 #include "Notify_Structured_Push_Consumer.h"
 #include "Notify_Test_Client.h"
+#include "ace/OS.h"
 
 Notify_Structured_Push_Consumer::Notify_Structured_Push_Consumer (
   const char* name,
@@ -10,11 +11,19 @@ Notify_Structured_Push_Consumer::Notify_Structured_Push_Consumer (
   : name_ (name),
   expected_ (expected),
   count_ (0),
+  delay_count_ (0),
+  delay_period_ (5),
   client_ (client)
 {
   this->client_.consumer_start (this);
 }
 
+void
+Notify_Structured_Push_Consumer::set_delay_parameters (unsigned int delay_count, unsigned long delay_period)
+{
+  this->delay_count_ = delay_count;
+  this->delay_period_ = delay_period;
+}
 
 void
 Notify_Structured_Push_Consumer::push_structured_event (
@@ -24,6 +33,11 @@ Notify_Structured_Push_Consumer::push_structured_event (
 
   ++count_;
 
+  if (this->delay_count_ != 0 && this->count_ % this->delay_count_ == 0)
+    {
+      ACE_OS::sleep (this->delay_period_);
+    }
+
   if (this->count_ > this->expected_)
   {
     ACE_ERROR ((LM_ERROR, ACE_TEXT ("ERROR: too many events received.\n")));
