@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Notify_Sequence_Push_Consumer.h,v 1.7 2005/07/13 16:20:12 michel_j Exp
+// $Id: Notify_Sequence_Push_Consumer.h 77020 2007-02-12 13:56:49Z johnnyw $
 // ==========================================================================
 //
 // = LIBRARY
@@ -31,14 +31,10 @@ public:
                                  int expected_count,
                                  Notify_Test_Client& client);
 
-  void _connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin
-                ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void _connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin);
 
 protected:
-  void push_structured_events (const CosNotification::EventBatch&
-                               ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void push_structured_events (const CosNotification::EventBatch&);
 
   ACE_CString name_;
   CORBA::Short order_policy_;
