@@ -1,4 +1,4 @@
-// Test_Saver.cpp,v 1.4 2004/11/28 11:01:31 jwillemsen Exp
+// $Id: Test_Saver.cpp 76589 2007-01-25 18:04:11Z elliott_c $
 
 #include "Test_Saver.h"
 
@@ -13,8 +13,7 @@ bool
 Test_Saver::begin_object(CORBA::Long id,
       const ACE_CString &type,
       const TAO_Notify::NVPList& attrs,
-      bool changed
-      ACE_ENV_ARG_DECL_NOT_USED)
+      bool changed)
 {
   ACE_OS::fprintf (stdout, "Test_Saver::begin_object type=\"%s\""
                    "  id=%d changed=\"%d\"", type.c_str(), id, changed);
@@ -29,7 +28,7 @@ Test_Saver::begin_object(CORBA::Long id,
 
 void
 Test_Saver::end_object (CORBA::Long id,
-      const ACE_CString &type ACE_ENV_ARG_DECL_NOT_USED)
+      const ACE_CString &type)
 {
   ACE_OS::fprintf (stdout, "Test_Saver::end_object type=\"%s\" id=%d\n",
                    type.c_str(), id);
