@@ -1,6 +1,6 @@
 /* -*- C++ -*- */
 /**
- *  Test_Saver.h,v 1.2 2004/11/19 22:14:54 john_c Exp
+ *  $Id: Test_Saver.h 76589 2007-01-25 18:04:11Z elliott_c $
  */
 
 #ifndef TEST_SAVER_H
@@ -26,12 +26,10 @@ public:
    virtual bool begin_object (CORBA::Long id,
       const ACE_CString &type,
       const TAO_Notify::NVPList& attrs,
-      bool changed
-      ACE_ENV_ARG_DECL);
+      bool changed);
 
     virtual void end_object (CORBA::Long id,
-      const ACE_CString &type
-      ACE_ENV_ARG_DECL);
+      const ACE_CString &type);
 };
 
 
