@@ -1,8 +1,8 @@
-// $Id: RT_POA_Command.cpp 78501 2007-05-27 15:36:13Z sowayaa $
+// $Id: RT_POA_Command.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "RT_POA_Command.h"
 
-ACE_RCSID(lib, TAO_RT_POA_Command, "$Id: RT_POA_Command.cpp 78501 2007-05-27 15:36:13Z sowayaa $")
+ACE_RCSID(lib, TAO_RT_POA_Command, "$Id: RT_POA_Command.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 #include "tao/debug.h"
 #include "../lib/LookupManager.h"
@@ -39,21 +39,21 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
 
   if (arg_shifter.is_anything_left ())
     {
-      if (arg_shifter.cur_arg_strncasecmp ("-Create") == 0)
+      if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Create")) == 0)
         {
           this->command_ = CREATE;
 
           arg_shifter.consume_arg ();
 
-          this->POA_name_ = arg_shifter.get_current ();
+          this->POA_name_ = ACE_TEXT_ALWAYS_CHAR(arg_shifter.get_current ());
 
           arg_shifter.consume_arg ();
 
           while (arg_shifter.is_anything_left ())
             {
-              if (0 != (current_arg = arg_shifter.get_the_parameter ("-PriorityModel")))
+              if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-PriorityModel"))))
                 {
-                  if (arg_shifter.cur_arg_strncasecmp ("CLIENT") == 0)
+                  if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("CLIENT")) == 0)
                     priority_model_ = RTCORBA::CLIENT_PROPAGATED;
                   else
                     priority_model_ = RTCORBA::SERVER_DECLARED;
@@ -65,7 +65,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                   continue;
                 }
               // -Lanes lane-count -Lane prio statc_thr dyn_thr
-              if (0 != (current_arg = arg_shifter.get_the_parameter ("-Lanes")))
+              if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Lanes"))))
                 {
                   int lanecount = ACE_OS::atoi (current_arg);
                   lanes_.length (lanecount);
@@ -75,7 +75,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                   //parse lane values ...
                   while (arg_shifter.is_anything_left ())
                     {
-                      if (arg_shifter.cur_arg_strncasecmp ("-Lane") == 0)
+                      if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Lane")) == 0)
                         {
                           arg_shifter.consume_arg ();
 
@@ -103,7 +103,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                   continue;
                 } /* if -Lanes */
 
-              if (0 != (current_arg = arg_shifter.get_the_parameter ("-Bands")))
+              if (0 != (current_arg = arg_shifter.get_the_parameter (ACE_TEXT("-Bands"))))
                 {
                   int bandcount = ACE_OS::atoi (current_arg);
                   bands_.length (bandcount);
@@ -113,7 +113,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                   //parse band values ...
                   while (arg_shifter.is_anything_left ())
                     {
-                      if (arg_shifter.cur_arg_strncasecmp ("-Band") == 0)
+                      if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Band")) == 0)
                         {
                           arg_shifter.consume_arg ();
 
@@ -126,7 +126,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                           arg_shifter.consume_arg ();
 
                           if (TAO_debug_level > 0)
-                            ACE_DEBUG ((LM_DEBUG, "POA Create: band parsed - %d, %d \n",
+                            ACE_DEBUG ((LM_DEBUG, "POA Create: band parsed - %d, %d\n",
                                         bands_[b_index].low, bands_[b_index].high));
                           b_index++;
                         }
@@ -138,7 +138,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                 } /* if -Bands */
 
               // -ThreadPool thread_pool_count thread_pool_default_priority
-              if (arg_shifter.cur_arg_strncasecmp ("-ThreadPool") == 0)
+              if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-ThreadPool")) == 0)
                 {
                   arg_shifter.consume_arg ();
 
@@ -153,7 +153,7 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
                   arg_shifter.consume_arg ();
 
                   if (TAO_debug_level > 0)
-                    ACE_DEBUG ((LM_DEBUG, "ThreadPool parsed - static threads = %d, prio = %d \n",
+                    ACE_DEBUG ((LM_DEBUG, "ThreadPool parsed - static threads = %d, prio = %d\n",
                                 this->thread_pool_static_threads_, this->thread_pool_default_priority_));
 
                   continue;
@@ -163,13 +163,13 @@ TAO_Notify_Tests_RT_POA_Command::init (ACE_Arg_Shifter& arg_shifter)
               break;
             } /* while */
         }
-      else if (arg_shifter.cur_arg_strncasecmp ("-Destroy") == 0)
+      else if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT("-Destroy")) == 0)
         {
           this->command_ = DESTROY;
 
           arg_shifter.consume_arg ();
 
-          this->POA_name_ = arg_shifter.get_current ();
+          this->POA_name_ = ACE_TEXT_ALWAYS_CHAR(arg_shifter.get_current ());
 
           arg_shifter.consume_arg ();
         }
@@ -355,7 +355,7 @@ TAO_Notify_Tests_RT_POA_Command::create (RTCORBA::RTORB_ptr rt_orb, PortableServ
   poa_policy_list[act_index] = activation_policy;
 
   if (TAO_debug_level > 0)
-    ACE_DEBUG ((LM_DEBUG, "creating POA %s\n", POA_name_.c_str ()));
+    ACE_DEBUG ((LM_DEBUG, "creating POA %C\n", POA_name_.c_str ()));
 
   // Get the POA Manager.
   PortableServer::POAManager_var poa_manager =
