@@ -1,4 +1,4 @@
-//$Id: Consumer.cpp 79324 2007-08-13 11:20:01Z elliott_c $
+//$Id: Consumer.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Consumer.h"
 #include "tao/debug.h"
@@ -8,7 +8,7 @@
 #include "ace/OS_NS_stdio.h"
 #include "tao/AnyTypeCode/Any.h"
 
-ACE_RCSID (Notify_Tests, Consumer_Main, "$Id: Consumer.cpp 79324 2007-08-13 11:20:01Z elliott_c $")
+ACE_RCSID (Notify_Tests, Consumer_Main, "$Id: Consumer.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 static const char NOTIFY_FACTORY_NAME[] = "NotifyEventChannelFactory";
 static const char NAMING_SERVICE_NAME[] = "NameService";
@@ -73,7 +73,7 @@ StructuredPushConsumer_i::offer_change (
   ACE_UNUSED_ARG (added);
   ACE_UNUSED_ARG (removed);
   ACE_DEBUG ((LM_DEBUG,
-    ACE_TEXT ("(%P,%t) StructuredPushConsumer offered change \n")
+    ACE_TEXT ("(%P,%t) StructuredPushConsumer offered change\n")
     ));
 }
 
@@ -213,7 +213,7 @@ StructuredPushConsumer_i::push_structured_event (
   {
     this->problem_ = true;
     ACE_DEBUG ((LM_ERROR,
-      ACE_TEXT ("(%P|%t) Structured Consumer: no filterable data. \n")
+      ACE_TEXT ("(%P|%t) Structured Consumer: no filterable data.\n")
       ));
   }
   this->may_discard_ = 0;
@@ -621,7 +621,7 @@ AnyPushConsumer_i::push (
       {
         this->problem_ = true;
         ACE_DEBUG ((LM_ERROR,
-          ACE_TEXT ("(%P|%t) Any Consumer: no filterable data in structured event. \n")
+          ACE_TEXT ("(%P|%t) Any Consumer: no filterable data in structured event.\n")
           ));
       }
     }
@@ -761,7 +761,7 @@ Consumer_Main::~Consumer_Main ()
 }
 
 int
-Consumer_Main::parse_args (int argc, char *argv[])
+Consumer_Main::parse_args (int argc, ACE_TCHAR *argv[])
 {
   int result = 0;
   int narg = 1;
@@ -774,7 +774,7 @@ Consumer_Main::parse_args (int argc, char *argv[])
       narg += consumed;
       corba_arg = false;
     }
-    else if (ACE_OS::strncmp (argv[narg], "-ORB", 4) == 0)
+    else if (ACE_OS::strncmp (argv[narg], ACE_TEXT("-ORB"), 4) == 0)
     {
       corba_arg = true;
     }
@@ -798,55 +798,55 @@ Consumer_Main::parse_args (int argc, char *argv[])
 }
 
 int
-Consumer_Main::parse_single_arg (int argc, char *argv[])
+Consumer_Main::parse_single_arg (int argc, ACE_TCHAR *argv[])
 {
   int consumed = 0;
-  if (ACE_OS::strcasecmp (argv[0], "-any") == 0)
+  if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-any")) == 0)
   {
     this->mode_ = MODE_ANY;
     consumed = 1;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-structured") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-structured")) == 0)
   {
     this->mode_ = MODE_STRUCTURED;
     consumed = 1;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-sequence") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-sequence")) == 0)
   {
     this->mode_ = MODE_SEQUENCE;
     consumed = 1;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-v") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-v")) == 0)
   {
     this->verbose_ = true;
     consumed = 1;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-channel") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-channel")) == 0)
   {
     this->channel_file_= argv[1];
     consumed = 2;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-expect") == 0 && argc > 1)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-expect")) == 0 && argc > 1)
   {
     this->expect_ = ACE_OS::atoi (argv[1]);
     consumed = 2;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-fail") == 0 && argc > 1)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-fail")) == 0 && argc > 1)
   {
     this->fail_ = ACE_OS::atoi (argv[1]);
     consumed = 2;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-serial_number") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-serial_number")) == 0)
   {
     this->serial_number_= ACE_OS::atoi (argv[1]);
     consumed = 2;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-nonamesvc") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-nonamesvc")) == 0)
   {
     this->use_naming_service_ = false;
     consumed = 1;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-disconnect") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-disconnect")) == 0)
   {
     this->disconnect_on_exit_ = true;
     consumed = 1;
@@ -864,20 +864,20 @@ void Consumer_Main::usage(FILE * out)const
     ACE_TEXT ("                    What type of event to send (pick one, default is -any)\n")
     ACE_TEXT ("  -expect n         How many events of each type are expected.\n")
     ACE_TEXT ("  -fail n           Throw an exception every n events.\n")
-    ACE_TEXT ("  -serial_number n  What serial number to start with \n")
+    ACE_TEXT ("  -serial_number n  What serial number to start with\n")
     ACE_TEXT ("                    or -1 to disable serial number checking.\n")
     ACE_TEXT ("  -v                Verbose output.\n")
-    ACE_TEXT ("  -disconnect       Disconnect from channel on exit (prevents reconnect.) \n")
+    ACE_TEXT ("  -disconnect       Disconnect from channel on exit (prevents reconnect.)\n")
     ACE_TEXT ("  -nonamesvc        Don't use the name service to find EventChannelFactory\n")
     , out);
   //FUZZ: enable check_for_lack_ACE_OS
 }
 
-int Consumer_Main::init (int argc, char *argv[])
+int Consumer_Main::init (int argc, ACE_TCHAR *argv[])
 {
-  this->orb_ = CORBA::ORB_init(argc, argv, "");
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
-  if (0 != this->parse_args(argc, argv))
+  if (0 != this->parse_args (argc, argv))
   {
     return -1;
   }
@@ -1210,7 +1210,7 @@ Consumer_Main::init_event_channel (void)
               ));
           }
           // kill the channel filename so we don't overwrite the file
-          this->channel_file_ = "";
+          this->channel_file_ = ACE_TEXT("");
         }
       }
       catch (...)
