@@ -1,4 +1,4 @@
-//$Id: Supplier.cpp 79324 2007-08-13 11:20:01Z elliott_c $
+//$Id: Supplier.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Supplier.h"
 #include "orbsvcs/CosNotifyChannelAdminC.h"
@@ -8,7 +8,7 @@
 #include "ace/OS_NS_stdio.h"
 #include "ace/OS_NS_strings.h"
 
-ACE_RCSID (Notify_Tests, Supplier_Main, "$Id: Supplier.cpp 79324 2007-08-13 11:20:01Z elliott_c $")
+ACE_RCSID (Notify_Tests, Supplier_Main, "$Id: Supplier.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 static const char NOTIFY_FACTORY_NAME[] = "NotifyEventChannelFactory";
 static const char NAMING_SERVICE_NAME[] = "NameService";
@@ -205,7 +205,7 @@ Supplier_Main::~Supplier_Main ()
 }
 
 int
-Supplier_Main::parse_args (int argc, char *argv[])
+Supplier_Main::parse_args (int argc, ACE_TCHAR *argv[])
 {
   int result = 0;
   int narg = 1;
@@ -218,7 +218,7 @@ Supplier_Main::parse_args (int argc, char *argv[])
       narg += consumed;
       corba_arg = false;
     }
-    else if (ACE_OS::strncmp (argv[narg], "-ORB", 4) == 0)
+    else if (ACE_OS::strncmp (argv[narg], ACE_TEXT("-ORB"), 4) == 0)
     {
       corba_arg = true;
     }
@@ -241,7 +241,7 @@ Supplier_Main::parse_args (int argc, char *argv[])
 }
 
 int
-Supplier_Main::parse_single_arg (int argc, char *argv[])
+Supplier_Main::parse_single_arg (int argc, ACE_TCHAR *argv[])
 {
   int consumed = 0;
   if (ACE_OS::strcasecmp (argv[0], ACE_TEXT ("-v")) == 0)
@@ -289,7 +289,7 @@ Supplier_Main::parse_single_arg (int argc, char *argv[])
     this->use_naming_service_ = false;
     consumed = 1;
   }
-  else if (ACE_OS::strcasecmp (argv[0], "-disconnect") == 0)
+  else if (ACE_OS::strcasecmp (argv[0], ACE_TEXT("-disconnect")) == 0)
   {
     this->disconnect_on_exit_ = true;
     consumed = 1;
@@ -310,17 +310,17 @@ void Supplier_Main::usage(FILE * log)const
       ACE_TEXT ("  -pause n          Pause after sending n events. Write to file \"Supplier.paused\"\n")
       ACE_TEXT ("  -serial_number n  What serial number to start with.\n")
       ACE_TEXT ("  -v                Verbose output.\n")
-      ACE_TEXT ("  -disconnect       Disconnect from channel on exit (prevents reconnect.) \n")
+      ACE_TEXT ("  -disconnect       Disconnect from channel on exit (prevents reconnect.)\n")
       ACE_TEXT ("  -nonamesvc        Don't use the name service to find EventChannelFactory\n")
       , log);
   //FUZZ: enable check_for_lack_ACE_OS
 }
 
-int Supplier_Main::init (int argc, char *argv[])
+int Supplier_Main::init (int argc, ACE_TCHAR *argv[])
 {
-  this->orb_ = CORBA::ORB_init(argc, argv, "");
+  this->orb_ = CORBA::ORB_init (argc, argv);
 
-  if (0 != this->parse_args(argc, argv))
+  if (0 != this->parse_args (argc, argv))
   {
     return -1;
   }
@@ -612,7 +612,7 @@ Supplier_Main::init_event_channel (void)
               ));
           }
           // kill the channel filename so we don't overwrite the file
-          this->channel_file_ = "";
+          this->channel_file_ = ACE_TEXT("");
         }
       }
       catch (...)
