@@ -1,4 +1,4 @@
-// $Id: Notify_Push_Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: Notify_Push_Consumer.cpp 86192 2009-07-23 17:51:06Z johnnyw $
 #include "Notify_Push_Consumer.h"
 #include "Notify_Test_Client.h"
 #include "tao/debug.h"
@@ -30,9 +30,8 @@ Notify_Push_Consumer::Notify_Push_Consumer (const char* name,
 
 void
 Notify_Push_Consumer::_connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin,
-                                CosNotifyChannelAdmin::EventChannel_ptr notify_channel)
+                                CosNotifyChannelAdmin::EventChannel_ptr)
 {
-  ACE_UNUSED_ARG(notify_channel);
   CosNotifyComm::StructuredPushConsumer_var objref =
     this->_this ();
 
@@ -55,7 +54,7 @@ static void validate_expression(bool expr, const char* msg)
 {
   if (! expr)
   {
-    ACE_ERROR((LM_ERROR, "Error: %s\n", msg));
+    ACE_ERROR((LM_ERROR, ACE_TEXT("Error: %C\n"), msg));
   }
 }
 
@@ -66,7 +65,7 @@ Notify_Push_Consumer::push_structured_event (
   const CosNotification::StructuredEvent& event)
 {
   ACE_DEBUG((LM_DEBUG, "-"));
-  received_++;
+  ++received_;
 
   CORBA::ULong id = 0;
   CORBA::ULong group = 0;
