@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// Notify_Push_Consumer.h,v 1.4 2005/07/01 20:27:00 michel_j Exp
+// $Id: Notify_Push_Consumer.h 77020 2007-02-12 13:56:49Z johnnyw $
 // ==========================================================================
 //
 // = LIBRARY
@@ -28,12 +28,10 @@ public:
   Notify_Push_Consumer (const char* name, int sent, bool useFilter, Notify_Test_Client& client);
 
   void _connect (CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin,
-                CosNotifyChannelAdmin::EventChannel_ptr ec ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                CosNotifyChannelAdmin::EventChannel_ptr ec);
 
 private:
-  void push_structured_event (const CosNotification::StructuredEvent& ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void push_structured_event (const CosNotification::StructuredEvent&);
 private:
   ACE_CString name_;
   CORBA::Long sent_;
