@@ -1,8 +1,8 @@
-// $Id: RT_Test_FilterFactory.cpp 77020 2007-02-12 13:56:49Z johnnyw $
+// $Id: RT_Test_FilterFactory.cpp 84826 2009-03-15 19:51:46Z olli $
 
 #include "RT_Test_FilterFactory.h"
 
-ACE_RCSID(Notify, TAO_RT_Test_FilterFactory, "$Id: RT_Test_FilterFactory.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
+ACE_RCSID(Notify, TAO_RT_Test_FilterFactory, "$Id: RT_Test_FilterFactory.cpp 84826 2009-03-15 19:51:46Z olli $")
 
 #include "RT_Test_Filter.h"
 #include "tao/debug.h"
@@ -17,13 +17,35 @@ TAO_Notify_Tests_RT_Test_FilterFactory::~TAO_Notify_Tests_RT_Test_FilterFactory
 }
 
 CosNotifyFilter::FilterFactory_ptr
-TAO_Notify_Tests_RT_Test_FilterFactory::create (PortableServer::POA_var& filter_poa)
+TAO_Notify_Tests_RT_Test_FilterFactory::create (PortableServer::POA_ptr filter_poa)
 {
-  this->filter_poa_ = filter_poa; // save the filter poa.
+  this->filter_poa_ = PortableServer::POA::_duplicate(filter_poa); // save the filter poa.
 
-  PortableServer::ServantBase_var servant_var (this);
+  PortableServer::ObjectId_var id = filter_poa->activate_object (this);
+
+  CORBA::Object_var object = filter_poa->id_to_reference (id.in ());
+
+  CosNotifyFilter::FilterFactory_var filter = CosNotifyFilter::FilterFactory::_narrow (object.in ());
+
+  return filter._retn();
+}
+
+void
+TAO_Notify_Tests_RT_Test_FilterFactory::destroy (void)
+{
+  if (CORBA::is_nil(this->filter_poa_.in ()))
+    return;
+  PortableServer::ServantBase_var guard(this);
+  try
+    {
+      PortableServer::ObjectId_var id =
+        this->filter_poa_->servant_to_id (this);
+      this->filter_poa_->deactivate_object (id.in());
+    }
+  catch (CORBA::Exception&)
+    {
+    }
 
-  return _this ();
 }
 
 CosNotifyFilter::Filter_ptr
@@ -38,7 +60,6 @@ TAO_Notify_Tests_RT_Test_FilterFactory::create_filter (const char *constraint_gr
       ACE_OS::strcmp (constraint_grammar, "EXTENDED_TCL") != 0)
     throw CosNotifyFilter::InvalidGrammar ();
 
-
   // Create the RefCounted servant.
   TAO_Notify_Tests_RT_Test_Filter* filter = 0;
 
@@ -65,4 +86,29 @@ TAO_Notify_Tests_RT_Test_FilterFactory::create_mapping_filter (const char * /*co
   throw CORBA::NO_IMPLEMENT ();
 }
 
+TAO_Notify_Object::ID 
+TAO_Notify_Tests_RT_Test_FilterFactory::get_filter_id (CosNotifyFilter::Filter_ptr /*filter*/)
+{
+  throw CORBA::NO_IMPLEMENT ();
+}
+
+CosNotifyFilter::Filter_ptr 
+TAO_Notify_Tests_RT_Test_FilterFactory::get_filter (const TAO_Notify_Object::ID& /*id*/)
+{
+  throw CORBA::NO_IMPLEMENT ();
+}
+
+void
+TAO_Notify_Tests_RT_Test_FilterFactory::release (void)
+{
+  delete this;
+  //@@ inform factory
+}
+
+void 
+TAO_Notify_Tests_RT_Test_FilterFactory::save_persistent (TAO_Notify::Topology_Saver& /*saver*/)
+{
+  throw CORBA::NO_IMPLEMENT ();
+}
+
 ACE_FACTORY_DEFINE (TAO_RT_Test_Filter, TAO_Notify_Tests_RT_Test_FilterFactory)
