@@ -1,5 +1,5 @@
 /**
- *  $Id: main.cpp 78900 2007-07-15 13:05:48Z sowayaa $
+ *  $Id: main.cpp 83067 2008-10-10 13:19:02Z johnnyw $
  */
 
 #include "orbsvcs/CosNotificationC.h"
@@ -51,7 +51,7 @@ class TestConsumer
   }
 };
 
-int main(int ac, char **av)
+int ACE_TMAIN (int ac, ACE_TCHAR *av[])
 {
   int retval = 1;
 
@@ -62,10 +62,10 @@ int main(int ac, char **av)
     CORBA::ORB_var orb;
     PortableServer::POA_var poa;
 
-    orb = CORBA::ORB_init(ac, av, "");
+    orb = CORBA::ORB_init (ac, av);
     ACE_ASSERT(! CORBA::is_nil (orb.in ()));
 
-    if (ac > 2 && ACE_OS::strcmp (av[1], "-pass") == 0)
+    if (ac > 2 && ACE_OS::strcmp (av[1], ACE_TEXT ("-pass")) == 0)
     {
       int pn = av[2][0] - '0';
       switch (pn)
