@@ -1,4 +1,4 @@
-// $Id: Activation_Manager.cpp 79230 2007-08-06 18:18:07Z elliott_c $
+// $Id: Activation_Manager.cpp 83042 2008-10-10 11:40:26Z johnnyw $
 
 #include "Activation_Manager.h"
 #include "ace/OS_NS_unistd.h"
@@ -6,7 +6,7 @@
 
 ACE_RCSID (lib,
            TAO_Activation_Manager,
-           "$Id: Activation_Manager.cpp 79230 2007-08-06 18:18:07Z elliott_c $")
+           "$Id: Activation_Manager.cpp 83042 2008-10-10 11:40:26Z johnnyw $")
 
 #include "LookupManager.h"
 #include "Command_Builder.h"
@@ -188,8 +188,8 @@ TAO_Notify_Tests_Activation_Manager::dump_stats (int dump_samples)
   ACE_OS::hostname (hostname, MAXHOSTNAMELEN);
 
   /// dump suppliers:
-  char msg[BUFSIZ];
-  ACE_OS::sprintf (msg, "# Stats generated on %s\n", hostname);
+  ACE_TCHAR msg[BUFSIZ];
+  ACE_OS::sprintf (msg, ACE_TEXT("# Stats generated on %s\n"), hostname);
 
   TAO_Notify_Tests_PeriodicSupplier_Iterator sup_iter(this->supplier_map_);
 
