@@ -2,7 +2,7 @@
 /**
  *  @file Activation_Manager.h
  *
- *  $Id: Activation_Manager.h 77020 2007-02-12 13:56:49Z johnnyw $
+ *  $Id: Activation_Manager.h 83042 2008-10-10 11:40:26Z johnnyw $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -48,7 +48,7 @@ class TAO_NOTIFY_TEST_Export TAO_Notify_Tests_Activation_Manager : public TAO_No
   typedef ACE_Hash_Map_Entry<ACE_CString, TAO_Notify_Tests_Periodic_Consumer*> TAO_Notify_Tests_PeriodicConsumer_Entry;
 
 public:
-  /// Constuctor
+  /// Constructor
   TAO_Notify_Tests_Activation_Manager (void);
 
   /// Destructor
@@ -123,7 +123,7 @@ protected:
   FILE *ior_output_file_;
 
   /// The file for input
-  ACE_CString ior_input_file_;
+  ACE_TString ior_input_file_;
 
   /// Set when the start method is called.
   CORBA::Boolean started_;
