@@ -2,7 +2,7 @@
 /**
  *  @file Name.h
  *
- *  $Id: Name.h 51175 2003-07-21 23:51:40Z dhinton $
+ *  $Id: Name.h 83042 2008-10-10 11:40:26Z johnnyw $
  *
  *  @author Pradeep Gore <pradeep@oomworks.com>
  *
@@ -32,31 +32,31 @@ public:
   static const char* const event_channel_factory;
   static const char* const naming_service;
 
-  static const char* const command_builder;
+  static const ACE_TCHAR* const command_builder;
 
-  static const char* const application_command_factory;
+  static const ACE_TCHAR* const application_command_factory;
   static const char* const application_command;
 
-  static const char* const event_channel_command_factory;
+  static const ACE_TCHAR* const event_channel_command_factory;
   static const char* const event_channel_command;
 
-  static const char* const supplier_admin_command_factory;
+  static const ACE_TCHAR* const supplier_admin_command_factory;
   static const char* const supplier_admin_command;
 
-  static const char* const consumer_admin_command_factory;
+  static const ACE_TCHAR* const consumer_admin_command_factory;
   static const char* const consumer_admin_command;
 
   static const char* const periodic_supplier_command;
-  static const char* const periodic_supplier_command_factory;
+  static const ACE_TCHAR* const periodic_supplier_command_factory;
 
   static const char* const periodic_consumer_command;
-  static const char* const periodic_consumer_command_factory;
+  static const ACE_TCHAR* const periodic_consumer_command_factory;
 
   static const char* const poa_command;
-  static const char* const poa_command_factory;
+  static const ACE_TCHAR* const poa_command_factory;
 
   static const char* const filter_command;
-  static const char* const filter_command_factory;
+  static const ACE_TCHAR* const filter_command_factory;
 };
 
 #include /**/ "ace/post.h"
