@@ -1,8 +1,8 @@
-// Priority_Mapping.cpp,v 1.5 2003/08/24 13:50:14 jwillemsen Exp
+// $Id: Priority_Mapping.cpp 51873 2003-08-24 13:53:30Z jwillemsen $
 
 #include "Priority_Mapping.h"
 
-ACE_RCSID(lib, Priority_Mapping, "Priority_Mapping.cpp,v 1.5 2003/08/24 13:50:14 jwillemsen Exp")
+ACE_RCSID(lib, Priority_Mapping, "$Id: Priority_Mapping.cpp 51873 2003-08-24 13:53:30Z jwillemsen $")
 
 TAO_Notify_Tests_Priority_Mapping::~TAO_Notify_Tests_Priority_Mapping (void)
 {
