@@ -1,4 +1,4 @@
-//Task_Stats.cpp,v 1.5 2005/07/01 20:27:01 michel_j Exp
+//$Id: Task_Stats.cpp 68471 2005-10-04 11:38:20Z jwillemsen $
 
 #include "Task_Stats.h"
 #include "ace/OS.h"
@@ -147,13 +147,3 @@ Task_Stats::dump_samples (const ACE_TCHAR *file_name, const ACE_TCHAR *msg, int
 
   ACE_OS::fclose (output_file);
 }
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_Singleton<Base_Time, TAO_SYNCH_MUTEX>;
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_Singleton<Base_Time, TAO_SYNCH_MUTEX>
-
-#endif /*ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
