@@ -1,4 +1,4 @@
-// Notify_Sequence_Push_Consumer.cpp,v 1.8 2005/07/05 12:42:48 michel_j Exp
+// $Id: Notify_Sequence_Push_Consumer.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #include "Notify_Sequence_Push_Consumer.h"
 #include "Notify_Test_Client.h"
@@ -25,25 +25,19 @@ Notify_Sequence_Push_Consumer::~Notify_Sequence_Push_Consumer ()
 
 void
 Notify_Sequence_Push_Consumer::_connect (
-  CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin
-  ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+  CosNotifyChannelAdmin::ConsumerAdmin_ptr consumer_admin)
 {
   CosNotifyComm::SequencePushConsumer_var objref =
-    this->_this (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+    this->_this ();
 
   CosNotifyChannelAdmin::ProxySupplier_var proxysupplier =
     consumer_admin->obtain_notification_push_supplier (
     CosNotifyChannelAdmin::SEQUENCE_EVENT,
-    proxy_id_
-    ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    proxy_id_);
 
   this->proxy_ =
     CosNotifyChannelAdmin::SequenceProxyPushSupplier::_narrow (
-    proxysupplier.in () ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+    proxysupplier.in ());
 
   CosNotification::QoSProperties properties(1);
   properties.length(1);
@@ -51,21 +45,16 @@ Notify_Sequence_Push_Consumer::_connect (
   properties[0].value <<= (CORBA::Long)10;
 
   proxy_->set_qos(properties);
-  proxy_->connect_sequence_push_consumer (objref.in ()
-    ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  proxy_->connect_sequence_push_consumer (objref.in ());
 
   // give ownership to POA
-  this->_remove_ref (ACE_ENV_SINGLE_ARG_PARAMETER);
-  ACE_CHECK;
+  this->_remove_ref ();
 }
 
 
 void
 Notify_Sequence_Push_Consumer::push_structured_events(
-  const CosNotification::EventBatch& events
-  ACE_ENV_ARG_DECL_NOT_USED /*ACE_ENV_SINGLE_ARG_PARAMETER*/)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+  const CosNotification::EventBatch& events)
 {
   if ( this->count_ == 0 )
   {
