@@ -2,11 +2,10 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# run_all.pl,v 1.2 2005/07/01 20:27:01 michel_j Exp
+# $Id: run_all.pl 88108 2009-12-11 09:26:37Z dbudko $
 # -*- perl -*-
 
-use lib "../../../../../../../bin";
-use PerlACE::Run_Test;
+use lib "$ENV{ACE_ROOT}/bin";
 use File::Copy;
 use Getopt::Long;
 
@@ -16,16 +15,13 @@ GetOptions ("rt" => \$rt,
 
 @list=("Load_0", "Load_5", "Load_10","Load_15","Load_20","Load_25","Load_30","Load_35","Load_40","Load_45","Load_50");
 
-for $file (@list)
-{
+for $file (@list) {
     # default to rt
-    if (!$all && !$rt && !$cos)
-    {
+    if (!$all && !$rt && !$cos) {
         $rt = 1;
     }
 
-    if (-d $file)
-    {
+    if (-d $file) {
         if ($all || $rt)
         {
             print STDERR "Running $file test with RT Notification\n";
@@ -34,23 +30,20 @@ for $file (@list)
 
             $status = system ("perl $cmd");
 
-            if ($status != 0)
-            {
+            if ($status != 0) {
                 print STDERR "ERROR: $file test returned $status\n";
             }
         }
 
 
-        if ($all || $cos)
-        {
+        if ($all || $cos) {
             print STDERR "Running $file test with COS Notification\n";
 
             $cmd = "run_test.pl -n cos_notify.conf -s $file/supplier.conf -c consumer.conf -o $file/cos_output";
 
             $status = system ("perl $cmd");
 
-            if ($status != 0)
-            {
+            if ($status != 0) {
                 print STDERR "ERROR: $file test returned $status\n";
             }
         }
