@@ -2,20 +2,17 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# $Id: run_all.pl 73797 2006-07-28 14:35:40Z wotte $
+# $Id: run_all.pl 88108 2009-12-11 09:26:37Z dbudko $
 # -*- perl -*-
 
 use lib "$ENV{ACE_ROOT}/bin";
-use PerlACE::Run_Test;
 use File::Copy;
 use Getopt::Std;
 
 @list= ("2_Hops","2_Hops_RTCORBA","3_Hops","3_Hops_RTCORBA","Colocated","Colocated_RTCORBA","Notify","Notify_RTCORBA");
 
-for $file (@list)
-{
-    if (-d $file)
-    {
+for $file (@list) {
+    if (-d $file) {
         print STDERR "Running $file test\n";
 
         $cmd = "run_test.pl";
@@ -24,8 +21,7 @@ for $file (@list)
 
         $status = system ("perl $cmd");
 
-        if ($status != 0)
-        {
+        if ($status != 0) {
             print STDERR "ERROR: $file test returned $status\n";
         }
 
