@@ -2,11 +2,11 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# $Id: run_all.pl 73797 2006-07-28 14:35:40Z wotte $
+# $Id: run_all.pl 87817 2009-11-30 10:03:58Z dbudko $
 # -*- perl -*-
 
 use lib "$ENV{ACE_ROOT}/bin";
-use PerlACE::Run_Test;
+use PerlACE::TestTarget;
 use File::Copy;
 use Getopt::Long;
 
@@ -16,41 +16,34 @@ GetOptions ("rt" => \$rt,
 
 @list=("Paths_1", "Paths_3","Paths_5","Paths_10","Paths_20");
 
-for $file (@list)
-{
+for $file (@list) {
     # default to rt
-    if (!$all && !$rt && !$cos)
-    {
+    if (!$all && !$rt && !$cos) {
         $rt = 1;
     }
 
-    if (-d $file)
-    {
-        if ($all || $rt)
-        {
+    if (-d $file) {
+        if ($all || $rt) {
             print STDERR "Running $file test with RT Notification\n";
 
             $cmd = "run_test.pl -n rt_notify.conf -s high_path.conf -c $file/other_paths.conf -o $file/rt_output";
 
             $status = system ("perl $cmd");
 
-            if ($status != 0)
-            {
+            if ($status != 0) {
                 print STDERR "ERROR: $file test returned $status\n";
             }
         }
 
 
-        if ($all || $cos)
-        {
+        if ($all || $cos) {
             print STDERR "Running $file test with COS Notification\n";
 
             $cmd = "run_test.pl -n cos_notify.conf -s high_path.conf -c $file/other_paths.conf -o $file/cos_output";
 
             $status = system ("perl $cmd");
 
-            if ($status != 0)
-            {
+            if ($status != 0) {
                 print STDERR "ERROR: $file test returned $status\n";
             }
         }
