@@ -1,4 +1,4 @@
-// $Id: client.cpp 79413 2007-08-20 14:02:40Z johnnyw $
+// $Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 // ============================================================================
 //
@@ -19,7 +19,7 @@
 #include "client.h"
 #include "tao/debug.h"
 
-ACE_RCSID(CosPropertyService, client, "$Id: client.cpp 79413 2007-08-20 14:02:40Z johnnyw $")
+ACE_RCSID(CosPropertyService, client, "$Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
   Client::Client (void)
 {
@@ -27,7 +27,7 @@ ACE_RCSID(CosPropertyService, client, "$Id: client.cpp 79413 2007-08-20 14:02:40
 
 int
 Client::init (int argc,
-              char *argv[])
+              ACE_TCHAR *argv[])
 {
   // Init the ORB.
   manager_.init (argc, argv);
@@ -36,7 +36,7 @@ Client::init (int argc,
   if (my_name_client_.init (manager_.orb()) != 0)
     ACE_ERROR_RETURN ((LM_ERROR,
                        " (%P|%t) Unable to initialize "
-                       "the TAO_Naming_Client. \n"),
+                       "the TAO_Naming_Client.\n"),
                       -1);
 
   // Bind PropertySetDef Object.
