@@ -4,7 +4,7 @@
 /**
  *  @file    Object1_i.cpp
  *
- *  Object1_i.cpp,v 1.8 2004/11/28 18:14:16 jwillemsen Exp
+ *  $Id: Object1_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
  *
  *  @author Matt Murphy <murphym@cs.uri.edu>
  */
@@ -40,9 +40,7 @@ Object1_impl::~Object1_impl()
 
 void Object1_impl::method1(const char* activity,
     CORBA::Long seconds,
-    char* &output
-    ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException, testSched::testSchedException))
+    char* &output)
 {
   const int scale_factor = 2000;
   int work;
