@@ -4,7 +4,7 @@
 /**
  *  @file    Object1_i.h
  *
- *  Object1_i.h,v 1.5 2005/07/04 08:55:12 jwillemsen Exp
+ *  $Id: Object1_i.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  *  @author Matt Murphy <murphym@cs.uri.edu>
  */
@@ -35,9 +35,7 @@ class Object1_impl : public POA_testSched::Object1
     virtual void method1(const char *activity,
                          CORBA::Long seconds,
                          char *&output
-                         ACE_ENV_ARG_DECL_WITH_DEFAULTS
-                         )
-      ACE_THROW_SPEC ((CORBA::SystemException, testSched::testSchedException));
+                         );
 };
 
 #endif /* Object1_I_H  */
