@@ -1,4 +1,4 @@
-// $Id: Sched_Conf.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: Sched_Conf.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 // This program performa a simple scheduler configuration run,
 // and dumps the results of one scheduling into a C++ header file.
@@ -13,9 +13,9 @@
 
 ACE_RCSID (Sched_Conf,
            Sched_Conf,
-           "$Id: Sched_Conf.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+           "$Id: Sched_Conf.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
-const char* service_name = "ScheduleService";
+const ACE_TCHAR *service_name = ACE_TEXT("ScheduleService");
 
 const char* format_string = " {%-12s, %d, %d, %d, %d, %8d, "
   " static_cast<RtecScheduler::Criticality_t> (%d), "
@@ -24,9 +24,9 @@ const char* format_string = " {%-12s, %d, %d, %d, %d, %8d, "
   "static_cast<RtecScheduler::Info_Type_t> (%d)}\n";
 
 int
-parse_args (int argc, char *argv [])
+parse_args (int argc, ACE_TCHAR *argv [])
 {
-  ACE_Get_Opt get_opt (argc, argv, "n:");
+  ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("n:"));
   int opt;
 
   while ((opt = get_opt ()) != EOF)
@@ -363,14 +363,14 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (my_name_client.init (orb.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            " (%P|%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
 
       CosNaming::NamingContext_var context =
         my_name_client.get_context ();
 
       if (ACE_Scheduler_Factory::use_config (context.in (),
-                                             service_name) < 0)
+                                             ACE_TEXT_ALWAYS_CHAR(service_name)) < 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            " (%P|%t) Unable to bind to the scheduling service.\n"),
                           1);
@@ -427,7 +427,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                                             deps.in (),
                                             configs.in (),
                                             anomalies.in (),
-                                            "Sched_Conf_Runtime.h",
+                                            ACE_TEXT("Sched_Conf_Runtime.h"),
                                             format_string);
     }
   catch (const CORBA::Exception& ex)
