@@ -1,4 +1,4 @@
-// $Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: client.cpp 86590 2009-09-02 09:26:55Z vzykov $
 
 #include "ace/Get_Opt.h"
 #include "test_i.h"
@@ -9,18 +9,18 @@
 #include "tao/Transport_Cache_Manager.h"
 #include "tao/Thread_Lane_Resources.h"
 
-ACE_RCSID(BiDirectional, client, "$Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(BiDirectional, client, "$Id: client.cpp 86590 2009-09-02 09:26:55Z vzykov $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 
 void do_nothing (void)
 {
 }
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -111,13 +111,15 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
         }
 
 
-      Callback_i callback_impl (orb.in ());
+      Callback_i *callback_impl = 0;
+      callback_impl = new Callback_i (orb.in ());
+      PortableServer::ServantBase_var safe (callback_impl);
 
       PortableServer::ObjectId_var id =
         PortableServer::string_to_ObjectId ("client_callback");
 
       child_poa->activate_object_with_id (id.in (),
-                                          &callback_impl);
+                                          callback_impl);
 
       CORBA::Object_var callback_object =
         child_poa->id_to_reference (id.in ());
