@@ -1,4 +1,4 @@
-// $Id: server.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: server.cpp 82853 2008-09-28 11:40:48Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "ace/OS_NS_stdio.h"
@@ -6,15 +6,15 @@
 #include "tao/BiDir_GIOP/BiDirGIOP.h"
 #include "tao/AnyTypeCode/Any.h"
 
-ACE_RCSID(BiDirectional, server, "$Id: server.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(BiDirectional, server, "$Id: server.cpp 82853 2008-09-28 11:40:48Z johnnyw $")
 
-const char *ior_output_file = 0;
+const ACE_TCHAR *ior_output_file = 0;
 int no_iterations = 10;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
