@@ -4,7 +4,7 @@
 /**
  * @file server_i.h
  *
- * server_i.h,v 1.4 2005/07/04 08:55:12 jwillemsen Exp
+ * $Id: server_i.h 77020 2007-02-12 13:56:49Z johnnyw $
  *
  * Header for the SSLIOP Callback test server implementation.
  *
@@ -30,16 +30,11 @@ public:
   server_i (CORBA::ORB_ptr orb);
   virtual ~server_i (void);
 
-  virtual void set_client (client_ptr c
-                           ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void set_client (client_ptr c);
 
-  virtual void test_request (const char *msg
-                             ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void test_request (const char *msg);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
 private:
 
