@@ -1,4 +1,4 @@
-// Client_Worker.h,v 1.3 2005/03/10 15:10:37 jwillemsen Exp
+// $Id: Client_Worker.h 76555 2007-01-24 15:39:09Z johnnyw $
 
 // ===========================================================================
 //
@@ -43,7 +43,7 @@ public:
   // thread entry point
 
 private:
-  void validate_connection (ACE_ENV_SINGLE_ARG_DECL_NOT_USED);
+  void validate_connection (void);
   // Validate the connection
 
 private:
