@@ -1,18 +1,18 @@
-// $Id: client.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "Client_Worker.h"
 
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 5;
 int do_shutdown = 0;
 int nthreads = 5;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:n:i:x");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:n:i:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -88,7 +88,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       client.thr_mgr ()->wait ();
 
       ACE_DEBUG ((LM_DEBUG,
-                  "(%P|%t) threads finished \n"));
+                  "(%P|%t) threads finished\n"));
 
       // Shut down the server if -x option given in command line
       if (do_shutdown)
