@@ -1,19 +1,18 @@
-// test_i.cpp,v 1.6 2005/01/31 23:19:31 mesnier_p Exp
+// $Id: test_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #include "test_i.h"
 #include "tao/debug.h"
 #include "ace/OS_NS_unistd.h"
 #if !defined(__ACE_INLINE__)
-#include "test_i.i"
+#include "test_i.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (MT_Server,
            test_i,
-           "test_i.cpp,v 1.6 2005/01/31 23:19:31 mesnier_p Exp")
+           "$Id: test_i.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 CORBA::Long
-Simple_Server_i::test_method (CORBA::Long x ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+Simple_Server_i::test_method (CORBA::Long x)
 {
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG, "Simple_Server: Request in thread %t\n"));
@@ -23,17 +22,15 @@ Simple_Server_i::test_method (CORBA::Long x ACE_ENV_ARG_DECL_NOT_USED)
 }
 
 void
-Simple_Server_i::shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+Simple_Server_i::shutdown (void)
 {
-  this->orb_->shutdown (0 ACE_ENV_ARG_PARAMETER);
+  this->orb_->shutdown (0);
 }
 
 //---------------------------------------------------------------------------
 
 CORBA::Long
-Another_One_i::test_method (CORBA::Long x ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+Another_One_i::test_method (CORBA::Long x)
 {
   if (TAO_debug_level > 0)
     ACE_DEBUG ((LM_DEBUG, "Another_One: Request in thread %t\n"));
