@@ -1,4 +1,4 @@
-// test_i.h,v 1.4 2005/01/31 23:19:31 mesnier_p Exp
+// $Id: test_i.h 77020 2007-02-12 13:56:49Z johnnyw $
 
 // ============================================================================
 //
@@ -31,11 +31,9 @@ public:
   // ctor
 
   // = The Simple_Server methods.
-  CORBA::Long test_method (CORBA::Long x ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  CORBA::Long test_method (CORBA::Long x);
 
-  void shutdown (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void shutdown (void);
 
 private:
   CORBA::ORB_var orb_;
@@ -56,8 +54,7 @@ public:
   // ctor
 
   // = The Simple_Server methods.
-  CORBA::Long test_method (CORBA::Long x ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  CORBA::Long test_method (CORBA::Long x);
 
 private:
   CORBA::ORB_var orb_;
@@ -65,7 +62,7 @@ private:
 };
 
 #if defined(__ACE_INLINE__)
-#include "test_i.i"
+#include "test_i.inl"
 #endif /* __ACE_INLINE__ */
 
 #endif /* TAO_MT_SERVER_TEST_I_H */
