@@ -4,7 +4,7 @@
 /**
  * @file constants.h
  *
- * $Id: constants.h 78874 2007-07-13 12:39:21Z mesnier_p $
+ * $Id: constants.h 83185 2008-10-13 10:00:27Z johnnyw $
  *
  * Set of constants shared between client and server
  *
@@ -19,11 +19,11 @@ namespace TAO_Mixed_Security_Test
 {
   const char *cert_file = "cacert.pem";
 
-  const char *permitted_ior_file = "permitted.ior";
-  const char *permitted_ior = "file://permitted.ior";
+  const ACE_TCHAR *permitted_ior_file = ACE_TEXT("permitted.ior");
+  const ACE_TCHAR *permitted_ior = ACE_TEXT("file://permitted.ior");
 
-  const char *restricted_ior_file = "restricted.ior";
-  const char *restricted_ior = "file://restricted.ior";
+  const ACE_TCHAR *restricted_ior_file = ACE_TEXT("restricted.ior");
+  const ACE_TCHAR *restricted_ior = ACE_TEXT("file://restricted.ior");
 }
 
 #endif
