@@ -1,15 +1,48 @@
-/* -*- C++ -*- $Id: MessengerClient.cpp 79751 2007-10-04 20:11:46Z johnc $ */
+/* -*- C++ -*- $Id: MessengerClient.cpp 87626 2009-11-19 08:28:24Z dbudko $ */
 
 #include "MessengerC.h"
 #include <iostream>
-int main( int argc, char *argv[] )
+#include "ace/Get_Opt.h"
+
+const ACE_TCHAR *ior = ACE_TEXT ("file://Messenger.ior");
+
+int
+parse_args (int argc, ACE_TCHAR *argv[])
+{
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
+  int c;
+
+  while ((c = get_opts ()) != -1)
+    switch (c)
+      {
+      case 'k':
+        ior = get_opts.opt_arg ();
+        break;
+
+      case '?':
+      default:
+        ACE_ERROR_RETURN ((LM_ERROR,
+                           "usage:  %s "
+                           "-k <ior> "
+                           "\n",
+                           argv [0]),
+                          -1);
+      }
+  // Indicates successful parsing of the command line
+  return 0;
+}
+
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try {
     // Initialize orb
-    CORBA::ORB_var orb = CORBA::ORB_init( argc, argv );
+    CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
+
+    if (parse_args (argc, argv) != 0)
+      return 1;
 
     // Destringify ior
-    CORBA::Object_var obj = orb->string_to_object( "file://Messenger.ior" );
+    CORBA::Object_var obj = orb->string_to_object( ior );
     if (CORBA::is_nil(obj.in())) {
       std::cerr << "Nil Messenger reference" << std::endl;
       return 1;
