@@ -2,7 +2,7 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# $Id: run_test.pl 74209 2006-08-24 10:41:11Z johnnyw $
+# $Id: run_test.pl 88080 2009-12-10 14:55:15Z dbudko $
 # -*- perl -*-
 
 # This is a Perl script that runs some Naming Service tests.
@@ -10,18 +10,25 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
 # It starts all the servers and clients as necessary.
 
 use lib "$ENV{ACE_ROOT}/bin";
-use PerlACE::Run_Test;
+use PerlACE::TestTarget;
 
-# Amount of delay (in seconds) between starting a server and a client
-# to allow proper server initialization.
-$sleeptime = 10;
+$status = 0;
+$debug_level = '0';
+
+foreach $i (@ARGV) {
+    if ($i eq '-debug') {
+        $debug_level = '10';
+    }
+}
+
+my $ns = PerlACE::TestTarget::create_target (1) || die "Create target 1 failed\n";
+my $cli = PerlACE::TestTarget::create_target (2) || die "Create target 2 failed\n";
 
 # The default host name.
-$TARGETHOSTNAME = "localhost";
+$TARGETHOSTNAME = $ns->HostName ();;
 
 $quiet = 0;
 $use_ssl = 1;
-$debug_level = 0;
 
 while (my $argument = shift) {
    if ($argument eq '-q') {
@@ -38,35 +45,53 @@ while (my $argument = shift) {
 
 # Variables for command-line arguments to client and server
 # executables.
-$ns_multicast_port = 10001 + PerlACE::uniqueid (); # Can not be 10000 on Chorus 4.0
-$ns_orb_port = 12000 + PerlACE::uniqueid ();
-$ns_ssl_port = 14000 + PerlACE::uniqueid ();
-$iorfile = PerlACE::LocalFile ("ns.ior");
-$persistent_ior_file = PerlACE::LocalFile ("pns.ior");
-$persistent_log_file = PerlACE::LocalFile ("test_log");
-$data_file = PerlACE::LocalFile ("test_run.data");
+$ns_multicast_port = $ns->RandomPort (); # Can not be 10000 on Chorus 4.0
+$ns_orb_port = 2000 + $ns->RandomPort ();
+$ns_ssl_port = 4000 + $ns->RandomPort ();
+$nsiorfile = "ns.ior";
+$cliconffile = "client.conf";
+$nsconffile = "server.conf";
+#$persistent_ior_file = "pns.ior";
+#$persistent_log_file = "test_log";
+#$data_file = "test_run.data";
+
+my $ns_nsiorfile = $ns->LocalFile ($nsiorfile);
+my $cli_nsiorfile = $cli->LocalFile ($nsiorfile);
+my $ns_nsconffile = $ns->LocalFile ($nsconffile);
+my $cli_cliconffile = $cli->LocalFile ($cliconffile);
+$ns->DeleteFile ($nsiorfile);
+$cli->DeleteFile ($nsiorfile);
 
-$status = 0;
 
 sub name_server
 {
-    my $args = "-ORBNameServicePort $ns_multicast_port -o $iorfile -m 1 @_";
+    my $args = "-ORBNameServicePort $ns_multicast_port -o $ns_nsiorfile -m 1 @_";
     my $prog = "../../../Naming_Service/Naming_Service";
-    $NS = new PerlACE::Process ($prog, $args);
+    $NS = $ns->CreateProcess ($prog, $args);
 
-    unlink $iorfile;
+    $ns->DeleteFile ($nsiorfile);
+    $cli->DeleteFile ($nsiorfile);
 
     print STDERR "CommandLine: server " . $NS->Arguments() . "\n\n" unless $quiet;
-    $ns_server = $NS->Spawn ();
+    $NS_status = $NS->Spawn ();
 
-    if ($ns_server != 0) {
-        print STDERR "ERROR: NS returned $ns_server\n";
+    if ($NS_status != 0) {
+        print STDERR "ERROR: Name Service returned $NS_status\n";
         exit 1;
     }
-
-    if (PerlACE::waitforfile_timed ($iorfile, $sleeptime) == -1) {
-        print STDERR "ERROR: cannot find IOR file <$iorfile>\n";
-        $NS->Kill (); 
+    if ($ns->WaitForFileTimed ($nsiorfile,$ns->ProcessStartWaitInterval()+45) == -1) {
+        print STDERR "ERROR: cannot find file <$ns_nsiorfile>\n";
+        $NS->Kill (); $NS->TimedWait (1);
+        exit 1;
+    }
+    if ($ns->GetFile ($nsiorfile) == -1) {
+        print STDERR "ERROR: cannot retrieve file <$ns_nsiorfile>\n";
+        $NS->Kill (); $NS->TimedWait (1);
+        exit 1;
+    }
+    if ($cli->PutFile ($nsiorfile) == -1) {
+        print STDERR "ERROR: cannot set file <$cli_nsiorfile>\n";
+        $NS->Kill (); $NS->TimedWait (1);
         exit 1;
     }
 }
@@ -76,13 +101,12 @@ sub client
     my $args = "@_"." ";
     my $prog = "client";
 
-    $CL = new PerlACE::Process ($prog, $args);
+    $CLI = $cli->CreateProcess ($prog, $args);
 
-    print STDERR "CommandLine: client " . $CL->Arguments() . "\n\n" unless $quiet;
-    $client = $CL->SpawnWaitKill (60);
-
-    if ($client != 0) {
-        print STDERR "ERROR: client returned $client\n";
+    print STDERR "CommandLine: client " . $CLI->Arguments() . "\n\n" unless $quiet;
+    $CLI_status = $CLI->SpawnWaitKill ($cli->ProcessStartWaitInterval()+45);
+    if ($CLI_status != 0) {
+        print STDERR "ERROR: client returned $CLI_status\n";
         $status = 1;
     }
 }
@@ -96,29 +120,29 @@ $orb_debug_level =  ($quiet || $debug_level == 0) ? "" : "-ORBDebugLevel $debug_
 # Options for all simple tests recognized by the 'client' program.
 @opts = (
          "-s -ORBInitRef NameService=corbaloc:ssliop:$TARGETHOSTNAME:$ns_ssl_port/NameService" 
-                . " -ORBSvcConf client.conf $orb_debug_level",
+                . " -ORBSvcConf $cli_cliconffile $orb_debug_level",
          "-t -ORBInitRef NameService=corbaloc:ssliop:$TARGETHOSTNAME:$ns_ssl_port/NameService"
-                . " -ORBSvcConf client.conf $orb_debug_level",
+                . " -ORBSvcConf $cli_cliconffile $orb_debug_level",
          "-i -ORBInitRef NameService=corbaloc:ssliop:$TARGETHOSTNAME:$ns_ssl_port/NameService"
-                . " -ORBSvcConf client.conf $orb_debug_level",
+                . " -ORBSvcConf $cli_cliconffile $orb_debug_level",
          "-e -ORBInitRef NameService=corbaloc:ssliop:$TARGETHOSTNAME:$ns_ssl_port/NameService"
-                . " -ORBSvcConf client.conf $orb_debug_level",
+                . " -ORBSvcConf $cli_cliconffile $orb_debug_level",
          "-y -ORBInitRef NameService=corbaloc:ssliop:$TARGETHOSTNAME:$ns_ssl_port/NameService"
-                . " -ORBSvcConf client.conf $orb_debug_level",
+                . " -ORBSvcConf $cli_cliconffile $orb_debug_level",
          
          );
 
 @server_opts = (
                 "-ORBEndpoint iiop://$TARGETHOSTNAME:$ns_orb_port/ssl_port=$ns_ssl_port"
-                        . " -ORBSvcConf server.conf $orb_debug_level",
+                        . " -ORBSvcConf $ns_nsconffile $orb_debug_level",
                 "-ORBEndpoint iiop://$TARGETHOSTNAME:$ns_orb_port/ssl_port=$ns_ssl_port"
-                        . " -ORBSvcConf server.conf $orb_debug_level",
+                        . " -ORBSvcConf $ns_nsconffile $orb_debug_level",
                 "-ORBEndpoint iiop://$TARGETHOSTNAME:$ns_orb_port/ssl_port=$ns_ssl_port" 
-                        . " -ORBSvcConf server.conf $orb_debug_level",
+                        . " -ORBSvcConf $ns_nsconffile $orb_debug_level",
                 "-ORBEndpoint iiop://$TARGETHOSTNAME:$ns_orb_port/ssl_port=$ns_ssl_port" 
-                        . " -ORBSvcConf server.conf $orb_debug_level",
+                        . " -ORBSvcConf $ns_nsconffile $orb_debug_level",
                 "-ORBEndpoint iiop://$TARGETHOSTNAME:$ns_orb_port/ssl_port=$ns_ssl_port" 
-                        . " -ORBSvcConf server.conf $orb_debug_level",
+                        . " -ORBSvcConf $ns_nsconffile $orb_debug_level",
                 
                 );
 
@@ -132,8 +156,6 @@ $orb_debug_level =  ($quiet || $debug_level == 0) ? "" : "-ORBDebugLevel $debug_
 
 $test_number = 0;
 
-unlink ($persistent_ior_file, $persistent_log_file);
-
 # Run server and client for each of the tests.  Client uses ior in a
 # file to bootstrap to the server.
 foreach $o (@opts) {
@@ -148,7 +170,12 @@ foreach $o (@opts) {
     name_server ($server_opts[$test_number]);
     client ($o);
 
-    $NS->Kill ();
+    $NS_status = $NS->TerminateWaitKill ($ns->ProcessStopWaitInterval());
+    if ($NS_status != 0) {
+        print STDERR "ERROR: Naming Service returned $NS_status\n";
+        $status = 1;
+        last;
+    }
 
     ## For some reason, only on Windows XP, we need to
     ## wait before starting another Naming_Service when
@@ -160,7 +187,7 @@ foreach $o (@opts) {
     $test_number++;
 }
 
-unlink ($persistent_ior_file, $persistent_log_file);
-unlink $iorfile;
+$ns->DeleteFile ($nsiorfile);
+$cli->DeleteFile ($nsiorfile);
 
 exit $status;
