@@ -1,4 +1,4 @@
-// $Id: Client_i.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: Client_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Client_i.h"
 
@@ -11,7 +11,7 @@
 #include "ace/OS_NS_fcntl.h"
 #include "ace/os_include/os_netdb.h"
 
-ACE_RCSID(Time_Service, Client_i, "$Id: Client_i.cpp 76589 2007-01-25 18:04:11Z elliott_c $")
+ACE_RCSID(Time_Service, Client_i, "$Id: Client_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 // Constructor.
 
@@ -196,7 +196,7 @@ Client_i::test_for_new_interval (void)
 // Reads the Time Service Server ior from a file
 
 int
-Client_i::read_ior (char *filename)
+Client_i::read_ior (ACE_TCHAR *filename)
 {
   // Open the file for reading.
   ACE_HANDLE f_handle = ACE_OS::open (filename, 0);
@@ -228,7 +228,7 @@ Client_i::read_ior (char *filename)
 int
 Client_i::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "dn:f:xk:");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("dn:f:xk:"));
   int c;
   int result;
 
@@ -244,7 +244,7 @@ Client_i::parse_args (void)
          this->loop_count_ = (u_int) ACE_OS::atoi (get_opts.opt_arg ());
          break;
        case 'k':  // ior provide on command line
-         this->ior_ = ACE_OS::strdup (get_opts.opt_arg ());
+         this->ior_ = ACE_OS::strdup (ACE_TEXT_ALWAYS_CHAR(get_opts.opt_arg ()));
          break;
        case 'f': // read the IOR from the file.
          result = this->read_ior (get_opts.opt_arg ());
@@ -315,7 +315,7 @@ Client_i::obtain_initial_references (void)
       if (my_name_client_.init (orb_.in ()) != 0)
         ACE_ERROR_RETURN ((LM_ERROR,
                            "[CLIENT] Process/Thread Id : (%P/%t) Unable to initialize "
-                           "the TAO_Naming_Client. \n"),
+                           "the TAO_Naming_Client.\n"),
                           -1);
 
       ACE_DEBUG ((LM_DEBUG,
@@ -334,7 +334,7 @@ Client_i::obtain_initial_references (void)
       clerk_name[1].id = CORBA::string_dup (name);
 
       ACE_DEBUG ((LM_DEBUG,
-                  "%s|\n",
+                  "%C|\n",
                   name));
 
       CORBA::Object_var temp_object =
@@ -362,18 +362,15 @@ Client_i::obtain_initial_references (void)
 // file, else it uses the Naming Service
 
 int
-Client_i::init (int argc, char **argv)
+Client_i::init (int argc, ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
 
-
   try
     {
       // Retrieve the ORB.
-      this->orb_ = CORBA::ORB_init (this->argc_,
-                                    this->argv_,
-                                    0);
+      this->orb_ = CORBA::ORB_init (this->argc_, this->argv_);
 
       // Parse command line and verify parameters.
       if (this->parse_args () == -1)
@@ -389,7 +386,7 @@ Client_i::init (int argc, char **argv)
 
           if (CORBA::is_nil (server_object.in ()))
             ACE_ERROR_RETURN ((LM_ERROR,
-                               "invalid ior <%s>\n",
+                               "invalid ior <%C>\n",
                                this->ior_),
                               -1);
           this->clerk_ =
