@@ -1,11 +1,11 @@
-// Simple_Dynamic.cpp,v 1.9 2002/10/25 00:40:19 bala Exp
+// $Id: Simple_Dynamic.cpp 77020 2007-02-12 13:56:49Z johnnyw $
 
 #ifndef TAO_SIMPLE_DYNAMIC_C
 #define TAO_SIMPLE_DYNAMIC_C
 
 #include "Simple_Dynamic.h"
 
-ACE_RCSID(Trading, Simple_Dynamic, "Simple_Dynamic.cpp,v 1.9 2002/10/25 00:40:19 bala Exp")
+ACE_RCSID(Trading, Simple_Dynamic, "$Id: Simple_Dynamic.cpp 77020 2007-02-12 13:56:49Z johnnyw $")
 
 template <class T>
 TAO_Simple_Dynamic_Property<T>::TAO_Simple_Dynamic_Property (const T& dp)
@@ -16,9 +16,7 @@ TAO_Simple_Dynamic_Property<T>::TAO_Simple_Dynamic_Property (const T& dp)
 template <class T> CORBA::Any*
 TAO_Simple_Dynamic_Property<T>::evalDP (const char*,
                                         CORBA::TypeCode_ptr,
-                                        const CORBA::Any&
-                                        ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CosTradingDynamic::DPEvalFailure))
+                                        const CORBA::Any&)
 {
   CORBA::Any* return_value = 0;
   ACE_NEW_RETURN (return_value, CORBA::Any, 0);
