@@ -1,9 +1,9 @@
-// $Id: import_test.cpp 78770 2007-07-04 05:19:15Z sowayaa $
+// $Id: import_test.cpp 87014 2009-10-08 14:10:09Z vzykov $
 
 #include "tao/Utils/ORB_Manager.h"
 #include "Offer_Importer.h"
 
-ACE_RCSID(Trading, import_test, "$Id: import_test.cpp 78770 2007-07-04 05:19:15Z sowayaa $")
+ACE_RCSID(Trading, import_test, "$Id: import_test.cpp 87014 2009-10-08 14:10:09Z vzykov $")
 
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
@@ -47,7 +47,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     }
   catch (const CORBA::Exception&)
     {
-      ACE_ERROR_RETURN ((LM_ERROR, "Trader Import Tests Failed."), -1);
+      ACE_ERROR_RETURN ((LM_ERROR, "Trader Import Tests Failed.\n"), -1);
     }
 
   return 0;
