@@ -1,4 +1,4 @@
-// $Id: client.cpp 76589 2007-01-25 18:04:11Z elliott_c $
+// $Id: client.cpp 82211 2008-06-27 11:00:06Z sma $
 //
 
 // ============================================================================
@@ -21,7 +21,7 @@
 
 #include "ior_corbaname_client_i.h"
 
-int main (int argc, char *argv [])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
 
   try
