@@ -1,4 +1,4 @@
-// $Id: anyop.cpp 78679 2007-06-30 06:08:24Z johnnyw $
+// $Id: anyop.cpp 82898 2008-10-01 18:41:20Z johnnyw $
 
 // ============================================================================
 //
@@ -32,10 +32,10 @@
 
 ACE_RCSID (Anyop,
            anyop,
-           "$Id: anyop.cpp 78679 2007-06-30 06:08:24Z johnnyw $")
+           "$Id: anyop.cpp 82898 2008-10-01 18:41:20Z johnnyw $")
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   int priority =
     (ACE_Sched_Params::priority_min (ACE_SCHED_FIFO)
@@ -50,11 +50,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
   try
     {
-      CORBA::ORB_var orb = CORBA::ORB_init (argc,
-                                            argv,
-                                            0);
+      CORBA::ORB_var orb = CORBA::ORB_init (argc, argv);
 
-      ACE_Get_Opt get_opt (argc, argv, "dien:");
+      ACE_Get_Opt get_opt (argc, argv, ACE_TEXT("dien:"));
       int opt;
 
       while ((opt = get_opt ()) != EOF)
@@ -154,9 +152,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -221,9 +219,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -289,9 +287,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -357,9 +355,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -433,9 +431,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -510,9 +508,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -586,9 +584,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -663,9 +661,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -737,9 +735,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -814,9 +812,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -884,9 +882,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
@@ -925,9 +923,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
         ACE_Basic_Stats stats;
         history.collect_basic_stats (stats);
-        stats.dump_results ("Total", gsf);
+        stats.dump_results (ACE_TEXT("Total"), gsf);
 
-        ACE_Throughput_Stats::dump_throughput ("Total",
+        ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
                                                gsf,
                                                test_end - test_start,
                                                stats.samples_count ());
