@@ -1,4 +1,4 @@
-// $Id: TestAppBase.h 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: TestAppBase.h 82859 2008-09-28 18:52:45Z johnnyw $
 #ifndef TESTAPPBASE_H
 #define TESTAPPBASE_H
 
@@ -15,7 +15,7 @@ class CSD_PT_TestInf_Export TestAppBase
     virtual ~TestAppBase();
 
     // Returns 0 for success, and -1 for failure.
-    int run(int argc, char* argv[]);
+    int run(int argc, ACE_TCHAR* argv[]);
 
     const char* name() const;
 
@@ -25,7 +25,7 @@ class CSD_PT_TestInf_Export TestAppBase
     TestAppBase(const char* name);
 
     // Returns -1 for failure, 0 for success
-    virtual int run_i(int argc, char* argv[]) = 0;
+    virtual int run_i(int argc, ACE_TCHAR* argv[]) = 0;
 
 
   private:
