@@ -1,4 +1,4 @@
-// Callback_i.cpp,v 1.8 2003/11/01 11:15:10 dhinton Exp
+// $Id: Callback_i.cpp 77010 2007-02-12 12:24:01Z johnnyw $
 
 #include "Callback_i.h"
 
@@ -8,7 +8,7 @@
 
 #include "ace/OS_NS_time.h"
 
-ACE_RCSID(Callback, Callback_i, "Callback_i.cpp,v 1.8 2003/11/01 11:15:10 dhinton Exp")
+ACE_RCSID(Callback, Callback_i, "$Id: Callback_i.cpp 77010 2007-02-12 12:24:01Z johnnyw $")
 
 int
 Callback_i::done (void)
@@ -19,9 +19,7 @@ Callback_i::done (void)
 
 void
 Callback_i::response (Test::TimeStamp time_stamp,
-                      const Test::Payload &
-                      ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                      const Test::Payload &)
 {
   ACE_hrtime_t now = ACE_OS::gethrtime ();
   ACE_GUARD (TAO_SYNCH_MUTEX, ace_mon, this->mutex_);
@@ -29,5 +27,5 @@ Callback_i::response (Test::TimeStamp time_stamp,
     return;
 
   this->remaining_samples_--;
-  this->history_.sample (now - time_stamp);
+  this->history_.sample (ACE_HRTIME_TO_U64(now) - time_stamp);
 }
