@@ -1,4 +1,4 @@
-// Callback_i.h,v 1.7 2002/01/29 20:20:56 okellogg Exp
+// $Id: Callback_i.h 77010 2007-02-12 12:24:01Z johnnyw $
 
 #ifndef TAO_CALLBACK_I_H
 #define TAO_CALLBACK_I_H
@@ -22,9 +22,7 @@ public:
   /// Implement the CORBA methods
   //@{
   void response (Test::TimeStamp,
-                 const Test::Payload &
-                 ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                 const Test::Payload &);
   //@}
 
 private:
