@@ -1,4 +1,4 @@
-// $Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: server.cpp 82850 2008-09-28 11:33:00Z johnnyw $
 
 #include "Server_i.h"
 
@@ -9,12 +9,12 @@
 #include "ace/Sched_Params.h"
 #include "ace/OS_NS_errno.h"
 
-ACE_RCSID(Callback, server, "$Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Callback, server, "$Id: server.cpp 82850 2008-09-28 11:33:00Z johnnyw $")
 
-const char *ior_file_name = "test.ior";
+const ACE_TCHAR *ior_file_name = ACE_TEXT("test.ior");
 
 /// Parse the arguments.
-static int parse_args (int argc, char *argv[]);
+static int parse_args (int argc, ACE_TCHAR *argv[]);
 
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
@@ -123,9 +123,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 // ****************************************************************
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
