@@ -1,4 +1,4 @@
-// $Id: client.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: client.cpp 83342 2008-10-21 12:53:19Z vzykov $
 
 
 // ============================================================================
@@ -31,7 +31,7 @@
 // interested in timing comparisons anyway.
 #include "../IDL_Cubit/cubitC.h"
 
-ACE_RCSID(DII_Cubit, client, "$Id: client.cpp 76591 2007-01-25 18:17:52Z elliott_c $")
+ACE_RCSID(DII_Cubit, client, "$Id: client.cpp 83342 2008-10-21 12:53:19Z vzykov $")
 
   // Some constants used below.
 const CORBA::ULong DEFAULT_LOOP_COUNT = 250;
@@ -61,7 +61,7 @@ public:
   ~DII_Cubit_Client (void);
   // Destructor.
 
-  int init (int argc, char **argv);
+  int init (int argc, ACE_TCHAR **argv);
   // Initialize the ORB and gets the Cubit objref.
 
   int run (void);
@@ -74,7 +74,7 @@ private:
   int parse_args (void);
   // Parses the arguments passed on the command line.
 
-  int read_ior (char *filename);
+  int read_ior (ACE_TCHAR *filename);
   // Function to read the cubit factory IOR from a file.
 
   void print_stats (const char *call_name,
@@ -109,7 +109,7 @@ private:
   int argc_;
   // # of arguments on the command line.
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // arguments from command line.
 
   CORBA::ULong loop_count_;
@@ -133,7 +133,7 @@ private:
   CORBA::ULong error_count_;
   // # of errors incurred in the lifetime of the application.
 
-  char *factory_IOR_;
+  ACE_CString factory_IOR_;
   // IOR of the factory used to make a Cubit object.
 
   FILE *cubit_factory_ior_file_;
@@ -152,7 +152,7 @@ DII_Cubit_Client::DII_Cubit_Client (void)
     obj_var_ (CORBA::Object::_nil ()),
     call_count_ (0),
     error_count_ (0),
-    factory_IOR_ (CORBA::string_dup (DEFAULT_FACTORY_IOR))
+    factory_IOR_ (DEFAULT_FACTORY_IOR)
 {
   // Initialize the array of pointers-to-member-functions.
   this->op_array_[0] = &DII_Cubit_Client::cube_short_dii;
@@ -170,7 +170,6 @@ DII_Cubit_Client::DII_Cubit_Client (void)
 // Destructor
 DII_Cubit_Client::~DII_Cubit_Client (void)
 {
-  CORBA::string_free (this->factory_IOR_);
 }
 
 // An array of messages to pass to print_stats, so we can step through
@@ -190,7 +189,7 @@ const char *DII_Cubit_Client::stats_messages_[] =
 };
 
 int
-DII_Cubit_Client::init (int argc, char **argv)
+DII_Cubit_Client::init (int argc, ACE_TCHAR **argv)
 {
   // Nice and safe.
   this->argc_ = argc;
@@ -212,7 +211,7 @@ DII_Cubit_Client::init (int argc, char **argv)
 
       // Get a factory object reference from the factory IOR.
       this->factory_var_ =
-        this->orb_var_->string_to_object (this->factory_IOR_);
+        this->orb_var_->string_to_object (this->factory_IOR_.c_str ());
 
       // Get a Cubit object with a DII request on the Cubit factory.
       CORBA::Request_var mc_req (this->factory_var_->_request ("make_cubit"));
@@ -252,7 +251,7 @@ DII_Cubit_Client::init (int argc, char **argv)
 int
 DII_Cubit_Client::parse_args (void)
 {
-  ACE_Get_Opt opts (argc_, argv_, "dn:i:f:x");
+  ACE_Get_Opt opts (argc_, argv_, ACE_TEXT("dn:i:f:x"));
   int c;
   int result;
 
@@ -266,7 +265,7 @@ DII_Cubit_Client::parse_args (void)
         this->loop_count_ = ACE_OS::atoi (opts.opt_arg ());
         break;
       case 'i':   // Get the IOR from the command line.
-        this->factory_IOR_ = opts.opt_arg ();
+        this->factory_IOR_ = ACE_TEXT_ALWAYS_CHAR(opts.opt_arg ());
         break;
       case 'f':   // Read the IOR from the file.
         result = this->read_ior (opts.opt_arg ());
@@ -297,7 +296,7 @@ DII_Cubit_Client::parse_args (void)
 
 // Get the factory IOR from the file created by the server.
 int
-DII_Cubit_Client::read_ior (char *filename)
+DII_Cubit_Client::read_ior (ACE_TCHAR *filename)
 {
   // Open the file for reading.
   this->f_handle_ = ACE_OS::open (filename,0);
@@ -312,9 +311,10 @@ DII_Cubit_Client::read_ior (char *filename)
 
   this->factory_IOR_ = ior_buffer.read ();
 
-  if (this->factory_IOR_ == 0)
+  if (this->factory_IOR_.length () == 0)
     ACE_ERROR_RETURN ((LM_ERROR,
-                       "Unable to allocate memory to read ior: %p\n"),
+                       ACE_TEXT ("Unable to allocate memory to read ior (%p)\n"),
+                       ACE_TEXT ("read")),
                       -1);
   return 0;
 }
@@ -788,7 +788,7 @@ DII_Cubit_Client::run (void)
 
 // Start the test.
 
-int main (int argc, char *argv[])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   DII_Cubit_Client cubit_client;
 
