@@ -1,4 +1,4 @@
-// $Id: Cubit_Client.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: Cubit_Client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Cubit_Client.h"
 #include "RTI_IO.h"
@@ -180,7 +180,7 @@ Cubit_Client::func (u_int i)
 // Reads the Cubit factory ior from a file
 
 int
-Cubit_Client::read_ior (const char *filename)
+Cubit_Client::read_ior (const ACE_TCHAR *filename)
 {
   // Open the file for reading.
   this->f_handle_ = ACE_OS::open (filename,0);
@@ -204,7 +204,7 @@ Cubit_Client::read_ior (const char *filename)
                         -1);
     }
 
-  this->cubit_factory_key_ = ACE_OS::strdup (data);
+  this->cubit_factory_key_ = ACE_OS::strdup (ACE_TEXT_CHAR_TO_TCHAR(data));
 
   ior_buffer.alloc ()->free (data);
 
@@ -216,7 +216,7 @@ Cubit_Client::read_ior (const char *filename)
 int
 Cubit_Client::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "b:t:z:ovdn:f:k:xsq");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("b:t:z:ovdn:f:k:xsq"));
   int c = 0;
   int result = 0;
   u_int test_mask = 0;
@@ -250,14 +250,14 @@ Cubit_Client::parse_args (void)
         break;
       case 'v':
         // For backward compatibility
-        test_mask = this->opt_to_mask ("void");
+        test_mask = this->opt_to_mask (ACE_TEXT("void"));
         if (test_mask == 0)
           return -1;
         this->enable_test (test_mask);
         break;
       case 'o':
         // For backward compatibility
-        test_mask = this->opt_to_mask ("one_way");
+        test_mask = this->opt_to_mask (ACE_TEXT("one_way"));
         if (test_mask == 0)
           return -1;
         this->enable_test (test_mask);
@@ -319,41 +319,41 @@ Cubit_Client::parse_args (void)
 }
 
 u_int
-Cubit_Client::opt_to_mask (const char *test_type)
+Cubit_Client::opt_to_mask (const ACE_TCHAR *test_type)
 {
-  if (ACE_OS::strcasecmp (test_type, "void") == 0)
+  if (ACE_OS::strcasecmp (test_type, ACE_TEXT("void")) == 0)
     return TAO_ENABLE_CUBIT_VOID;
-  else if (ACE_OS::strcasecmp (test_type, "octet") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("octet")) == 0)
     return TAO_ENABLE_CUBIT_OCTET;
-  else if (ACE_OS::strcasecmp (test_type, "short") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("short")) == 0)
     return TAO_ENABLE_CUBIT_SHORT;
-  else if (ACE_OS::strcasecmp (test_type, "long") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("long")) == 0)
     return TAO_ENABLE_CUBIT_LONG;
-  else if (ACE_OS::strcasecmp (test_type, "struct") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("struct")) == 0)
     return TAO_ENABLE_CUBIT_STRUCT;
-  else if (ACE_OS::strcasecmp (test_type, "union") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("union")) == 0)
     return TAO_ENABLE_CUBIT_UNION;
-  else if (ACE_OS::strcasecmp (test_type, "small_octet_seq") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("small_octet_seq")) == 0)
     return TAO_ENABLE_CUBIT_SMALL_OCTET_SEQ;
-  else if (ACE_OS::strcasecmp (test_type, "small_long_seq") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("small_long_seq")) == 0)
     return TAO_ENABLE_CUBIT_SMALL_LONG_SEQ;
-  else if (ACE_OS::strcasecmp (test_type, "small_struct_seq") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("small_struct_seq")) == 0)
     return TAO_ENABLE_CUBIT_SMALL_STRUCT_SEQ;
-  else if (ACE_OS::strcasecmp (test_type, "large_octet_seq") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("large_octet_seq")) == 0)
     return TAO_ENABLE_CUBIT_LARGE_OCTET_SEQ;
-  else if (ACE_OS::strcasecmp (test_type, "large_long_seq") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("large_long_seq")) == 0)
     return TAO_ENABLE_CUBIT_LARGE_LONG_SEQ;
-  else if (ACE_OS::strcasecmp (test_type, "large_struct_seq") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("large_struct_seq")) == 0)
     return TAO_ENABLE_CUBIT_LARGE_STRUCT_SEQ;
-  else if (ACE_OS::strcasecmp (test_type, "mixin") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("mixin")) == 0)
     return TAO_ENABLE_CUBIT_MIXIN;
-  else if (ACE_OS::strcasecmp (test_type, "rti_data") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("rti_data")) == 0)
     return TAO_ENABLE_CUBIT_RTI_DATA;
-  else if (ACE_OS::strcasecmp (test_type, "one_way") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("one_way")) == 0)
     return TAO_ENABLE_CUBIT_ONE_WAY;
-  else if (ACE_OS::strcasecmp (test_type, "any") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("any")) == 0)
     return TAO_ENABLE_CUBIT_ANY;
-  else if (ACE_OS::strcasecmp (test_type, "any_struct") == 0)
+  else if (ACE_OS::strcasecmp (test_type, ACE_TEXT("any_struct")) == 0)
     return TAO_ENABLE_CUBIT_ANY_STRUCT;
 
   ACE_ERROR_RETURN ((LM_ERROR,
@@ -975,7 +975,7 @@ Cubit_Client::cube_rti_data (int,
       if (TAO_debug_level > 0)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "Input: \n"));
+                      "Input:\n"));
 
           print_RtiPacket (input);
         }
@@ -992,7 +992,7 @@ Cubit_Client::cube_rti_data (int,
 
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "Output: \n"));
+                      "Output:\n"));
 
           print_RtiPacket (*vout.ptr ());
 
@@ -1045,7 +1045,7 @@ Cubit_Client::cube_any (int i)
       if (arg_long != ret_long)
         {
           ACE_ERROR ((LM_ERROR,
-                      "** cube_any(%d)  ERROR (got %d, expect %d) \n",
+                      "** cube_any(%d)  ERROR (got %d, expect %d)\n",
                       (CORBA::Long) this->func (i),
                       ret_long, arg_long));
 
@@ -1124,7 +1124,7 @@ Cubit_Client::print_stats (const char *call_name,
                            ACE_Profile_Timer::ACE_Elapsed_Time &elapsed_time)
 {
   ACE_DEBUG ((LM_DEBUG,
-              "%s:\n",
+              "%C:\n",
               call_name));
 
   if (this->quiet_)
@@ -1597,7 +1597,7 @@ Cubit_Client::~Cubit_Client (void)
 
 
 int
-Cubit_Client::init (int argc, char **argv)
+Cubit_Client::init (int argc, ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
