@@ -1,4 +1,4 @@
-// $Id: Cubit_i.cpp 77010 2007-02-12 12:24:01Z johnnyw $
+// $Id: Cubit_i.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 // ============================================================================
 //
@@ -360,7 +360,7 @@ Cubit_i::cube_rti_data (const Cubit::RtiPacket &input,
   if (TAO_debug_level > 0)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Input: \n"));
+                  "Input:\n"));
       print_RtiPacket (input);
     }
 
@@ -375,7 +375,7 @@ Cubit_i::cube_rti_data (const Cubit::RtiPacket &input,
   if (TAO_debug_level > 0)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Output: \n"));
+                  "Output:\n"));
       print_RtiPacket (*output.ptr ());
     }
 }
@@ -419,7 +419,7 @@ Cubit_i::cube_any_struct (const CORBA::Any & any)
 void Cubit_i::shutdown (void)
 {
   ACE_DEBUG ((LM_DEBUG,
-              "%s\n",
+              "%C\n",
               "Cubit_i is shutting down"));
 
   this->orb_->shutdown ();
