@@ -1,4 +1,4 @@
-// $Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: client.cpp 82993 2008-10-08 19:16:22Z johnnyw $
 
 #include "ace/config-all.h"
 
@@ -14,7 +14,7 @@
 
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(IDL_Cubit, client, "$Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(IDL_Cubit, client, "$Id: client.cpp 82993 2008-10-08 19:16:22Z johnnyw $")
 
 // This function runs the client test.
 
@@ -45,7 +45,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
   if (cubit_client.init (argc, argv) == -1)
     return 1;
 
-  int retval = cubit_client.run ();
+  int const retval = cubit_client.run ();
 
   ACE_TIMEPROBE_PRINT;
 
