@@ -1,4 +1,4 @@
-// $Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: server.cpp 82993 2008-10-08 19:16:22Z johnnyw $
 
 #include "ace/config-all.h"
 
@@ -19,8 +19,7 @@
 
 #include "tao/Strategies/advanced_resource.h"
 
-
-ACE_RCSID(IDL_Cubit, server, "$Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(IDL_Cubit, server, "$Id: server.cpp 82993 2008-10-08 19:16:22Z johnnyw $")
 
 // This runs the server test.
 
@@ -53,9 +52,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
               "\n\tIDL_Cubit: server\n\n"));
   try
     {
-      int ret = cubit_server.init (argc, argv);
-
-      if (ret == -1)
+      if (cubit_server.init (argc, argv)== -1)
         return -1;
 
       cubit_server.run ();
