@@ -1,4 +1,4 @@
-// $Id: Task_Client.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: Task_Client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "Task_Client.h"
 #include "Timer.h"
@@ -19,7 +19,7 @@ ACE_round (ACE_timer_t t)
   return static_cast<ACE_UINT32> (t);
 }
 
-ACE_RCSID(MT_Cubit, Task_Client, "$Id: Task_Client.cpp 76591 2007-01-25 18:17:52Z elliott_c $")
+ACE_RCSID(MT_Cubit, Task_Client, "$Id: Task_Client.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 Task_State::Task_State (void)
   : barrier_ (0),
@@ -53,9 +53,9 @@ Task_State::Task_State (void)
 }
 
 int
-Task_State::parse_args (int argc,char *argv[])
+Task_State::parse_args (int argc,ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt opts (argc, argv, "mu:n:t:d:rxof:g:1cl");
+  ACE_Get_Opt opts (argc, argv, ACE_TEXT("mu:n:t:d:rxof:g:1cl"));
   int c;
 
   while ((c = opts ()) != -1)
@@ -144,7 +144,7 @@ Task_State::parse_args (int argc,char *argv[])
                   "[-g <granularity>]     // choose the granularity of the timing of CORBA calls                      \n\t\t\t"
                   "[-c]                   // run the number of context switches test.                                 \n\t\t\t"
                   "[-l]                   // use direct function calls, as opposed to CORBA requests.  ONLY to be used with -u option.\n\t\t\t"
-                  "[-m]                   // use multiple priorities for the low priority clients.                    \n"
+                  "[-m]                   // use multiple priorities for the low priority clients.                   \n"
                   ,argv [0]));
       return -1;
     }
@@ -259,7 +259,7 @@ Task_State::~Task_State (void)
 Client::Client (ACE_Thread_Manager *thread_manager,
                 Task_State *ts,
                 int argc,
-                char **argv,
+                ACE_TCHAR **argv,
                 u_int id)
   : ACE_Task<ACE_SYNCH> (thread_manager),
     cubit_impl_ (CORBA::ORB::_nil (),
@@ -559,14 +559,14 @@ Client::init_orb (void)
 
   // Convert the argv vector into a string.
   ACE_ARGV tmp_args (this->argv_);
-  char tmp_buf[BUFSIZ];
+  ACE_TCHAR tmp_buf[BUFSIZ];
 
   ACE_OS::strcpy (tmp_buf,
                   tmp_args.buf ());
   // Add the argument.
   ACE_OS::strcat (tmp_buf,
-                  " -ORBRcvSock 32768 "
-                  " -ORBSndSock 32768 ");
+                  ACE_TEXT(" -ORBRcvSock 32768 ")
+                  ACE_TEXT(" -ORBSndSock 32768 "));
 
   ACE_DEBUG ((LM_DEBUG,
               tmp_buf));
@@ -574,7 +574,7 @@ Client::init_orb (void)
   // Convert back to argv vector style.
   ACE_ARGV tmp_args2 (tmp_buf);
   int argc = tmp_args2.argc ();
-  char **argv = tmp_args2.argv ();
+  ACE_TCHAR **argv = tmp_args2.argv ();
 
   char orbid[64];
   ACE_OS::sprintf (orbid, "orb:%d", this->id_);
@@ -651,7 +651,7 @@ Client::get_cubit (CORBA::ORB_ptr orb)
     orb->object_to_string (this->cubit_);
 
   ACE_DEBUG ((LM_DEBUG,
-              "(%t) CUBIT OBJECT connected to <%s>\n",
+              "(%t) CUBIT OBJECT connected to <%C>\n",
               str.in ()));
 
   return 0;
