@@ -1,4 +1,4 @@
-/* Timer.cpp,v 1.12 1999/09/23 16:29:21 levine Exp */
+/* $Id: Timer.cpp 76555 2007-01-24 15:39:09Z johnnyw $ */
 
 #include "Timer.h"
 #include "Task_Client.h"
@@ -38,19 +38,9 @@ ACE_timer_t
 MT_Cubit_Timer::get_elapsed (void)
 {
   ACE_timer_t real_time;
-#if defined (ACE_LACKS_FLOATING_POINT)
-# if defined (CHORUS_MVME)
-  real_time = (this->pstopTime_ - this->pstartTime_) / this->granularity_;
-# else /* CHORUS_MVME */
-  // Store the time in usecs.
-  real_time = (this->delta_.sec () * ACE_ONE_SECOND_IN_USECS  +
-               this->delta_.usec ()) / this->granularity_;
-# endif /* !CHORUS_MVME */
-#else  /* !ACE_LACKS_FLOATING_POINT */
   // Store the time in usecs.
   real_time = (ACE_timer_t) this->delta_.sec () * ACE_ONE_SECOND_IN_USECS  +
               (ACE_timer_t) this->delta_.usec ();
   real_time = real_time/this->granularity_;
-#endif /* !ACE_LACKS_FLOATING_POINT */
   return real_time; // in usecs.
 }
