@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: client.h 80362 2008-01-03 10:22:59Z johnnyw $
+// $Id: client.h 82867 2008-09-29 07:55:40Z johnnyw $
 
 // ============================================================================
 //
@@ -51,7 +51,7 @@ public:
   virtual ~Client_i (void);
   // destructor.
 
-  int init (int argc, char *argv[]);
+  int init (int argc, ACE_TCHAR *argv[]);
   // Initialize the state of <Client_i>.
 
   void run (void);
@@ -161,7 +161,7 @@ private:
   int argc_;
   // number of command line arguments.
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // command line argument array.
 
   ACE_Thread_Manager client_thread_manager_;
