@@ -1,5 +1,5 @@
 /* -*- C++ -*- */
-// $Id: server.h 64070 2005-02-18 09:07:14Z jwillemsen $
+// $Id: server.h 82863 2008-09-29 07:41:38Z johnnyw $
 
 // ============================================================================
 //
@@ -64,7 +64,7 @@ public:
   Server (void);
   // Default constructor.
 
-  int init (int argc, char **argv);
+  int init (int argc, ACE_TCHAR **argv);
   // Initialize the server state.
 
   int run (void);
@@ -92,7 +92,7 @@ private:
   int argc_;
   // Number of arguments for the servant.
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // Arguments for the ORB.
 
   char * *cubits_;
