@@ -1,5 +1,5 @@
 //
-// Roundtrip.h,v 1.3 2005/07/04 09:28:14 jwillemsen Exp
+// $Id: Roundtrip.h 77010 2007-02-12 12:24:01Z johnnyw $
 //
 
 #ifndef ROUNDTRIP_H
@@ -23,13 +23,9 @@ class Roundtrip
 
     // = The skeleton methods
     void test_method (Test::AMH_RoundtripResponseHandler_ptr _tao_rh,
-                      Test::Timestamp send_time
-                      ACE_ENV_ARG_DECL)
-        ACE_THROW_SPEC ((CORBA::SystemException));
+                      Test::Timestamp send_time);
 
-    void shutdown (Test::AMH_RoundtripResponseHandler_ptr _tao_rh
-                   ACE_ENV_ARG_DECL)
-        ACE_THROW_SPEC ((CORBA::SystemException));
+    void shutdown (Test::AMH_RoundtripResponseHandler_ptr _tao_rh);
 
  private:
     /// Use an ORB reference to conver strings to objects and shutdown
