@@ -1,4 +1,4 @@
-// $Id: client.cpp 78692 2007-06-30 06:12:30Z johnnyw $
+// $Id: client.cpp 82913 2008-10-02 19:22:25Z johnnyw $
 
 #include "TestC.h"
 #include "ace/Get_Opt.h"
@@ -11,17 +11,17 @@
 
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(Single_Threaded_Latency, client, "$Id: client.cpp 78692 2007-06-30 06:12:30Z johnnyw $")
+ACE_RCSID(Single_Threaded_Latency, client, "$Id: client.cpp 82913 2008-10-02 19:22:25Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 100;
 int do_dump_history = 0;
 int do_shutdown = 1;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "hxk:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("hxk:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -133,14 +133,14 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       if (do_dump_history)
         {
-          history.dump_samples ("HISTORY", gsf);
+          history.dump_samples (ACE_TEXT("HISTORY"), gsf);
         }
 
       ACE_Basic_Stats stats;
       history.collect_basic_stats (stats);
-      stats.dump_results ("Total", gsf);
+      stats.dump_results (ACE_TEXT("Total"), gsf);
 
-      ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                              test_end - test_start,
                                              stats.samples_count ());
 
