@@ -1,10 +1,10 @@
 //
-// $Id: Roundtrip_Handler.cpp 77010 2007-02-12 12:24:01Z johnnyw $
+// $Id: Roundtrip_Handler.cpp 82898 2008-10-01 18:41:20Z johnnyw $
 //
 #include "Roundtrip_Handler.h"
 #include "ace/OS_NS_time.h"
 
-ACE_RCSID(AMI_Latency, Roundtrip, "$Id: Roundtrip_Handler.cpp 77010 2007-02-12 12:24:01Z johnnyw $")
+ACE_RCSID(AMI_Latency, Roundtrip, "$Id: Roundtrip_Handler.cpp 82898 2008-10-01 18:41:20Z johnnyw $")
 
 Roundtrip_Handler::Roundtrip_Handler (int expected_callbacks)
   : pending_callbacks_ (expected_callbacks)
@@ -20,7 +20,7 @@ Roundtrip_Handler::pending_callbacks (void) const
 void
 Roundtrip_Handler::dump_results (ACE_UINT32 gsf)
 {
-  this->latency_stats_.dump_results ("AMI Latency", gsf);
+  this->latency_stats_.dump_results (ACE_TEXT("AMI Latency"), gsf);
 }
 
 void
