@@ -1,4 +1,4 @@
-// $Id: client.cpp 78669 2007-06-29 19:42:03Z johnnyw $
+// $Id: client.cpp 83000 2008-10-09 09:31:35Z johnnyw $
 
 #include "Client_Task.h"
 #include "ace/Get_Opt.h"
@@ -10,16 +10,16 @@
 
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(Thread_Per_Connection_Latency, client, "$Id: client.cpp 78669 2007-06-29 19:42:03Z johnnyw $")
+ACE_RCSID(Thread_Per_Connection_Latency, client, "$Id: client.cpp 83000 2008-10-09 09:31:35Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 1000;
 int do_shutdown = 1;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "xk:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("xk:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -120,14 +120,14 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       ACE_DEBUG ((LM_DEBUG, "done\n"));
 
       ACE_Basic_Stats totals;
-      task0.accumulate_and_dump (totals, "Task[0]", gsf);
-      task1.accumulate_and_dump (totals, "Task[1]", gsf);
-      task2.accumulate_and_dump (totals, "Task[2]", gsf);
-      task3.accumulate_and_dump (totals, "Task[3]", gsf);
+      task0.accumulate_and_dump (totals, ACE_TEXT("Task[0]"), gsf);
+      task1.accumulate_and_dump (totals, ACE_TEXT("Task[1]"), gsf);
+      task2.accumulate_and_dump (totals, ACE_TEXT("Task[2]"), gsf);
+      task3.accumulate_and_dump (totals, ACE_TEXT("Task[3]"), gsf);
 
-      totals.dump_results ("Total", gsf);
+      totals.dump_results (ACE_TEXT("Total"), gsf);
 
-      ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                              test_end - test_start,
                                              totals.samples_count ());
 
