@@ -1,10 +1,10 @@
 //
-// $Id: Client_Task.cpp 76641 2007-01-26 18:25:17Z elliott_c $
+// $Id: Client_Task.cpp 83000 2008-10-09 09:31:35Z johnnyw $
 //
 #include "Client_Task.h"
 #include "ace/OS_NS_time.h"
 
-ACE_RCSID(Thread_Pool_Latency, Client_Task, "$Id: Client_Task.cpp 76641 2007-01-26 18:25:17Z elliott_c $")
+ACE_RCSID(Thread_Pool_Latency, Client_Task, "$Id: Client_Task.cpp 83000 2008-10-09 09:31:35Z johnnyw $")
 
 Client_Task::Client_Task (Test::Roundtrip_ptr roundtrip,
                           int niterations)
@@ -39,7 +39,7 @@ Client_Task::svc (void)
 
 void
 Client_Task::accumulate_and_dump (ACE_Basic_Stats &totals,
-                                  const char *msg,
+                                  const ACE_TCHAR *msg,
                                   ACE_UINT32 gsf)
 {
   totals.accumulate (this->latency_);
