@@ -1,18 +1,18 @@
-// $Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: client.cpp 82850 2008-09-28 11:33:00Z johnnyw $
 
 #include "TestC.h"
 #include "ace/Get_Opt.h"
 #include "TestS.h"
 #include "Foo_i.h"
 
-ACE_RCSID(Hello, client, "$Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Hello, client, "$Id: client.cpp 82850 2008-09-28 11:33:00Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 static int n = 10;
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:n:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:n:"));
   int c;
 
   while ((c = get_opts ()) != -1)
