@@ -1,5 +1,5 @@
 //
-// Memory_Growth.h,v 1.4 2005/07/04 09:28:22 jwillemsen Exp
+// $Id: Memory_Growth.h 77010 2007-02-12 12:24:01Z johnnyw $
 //
 
 #ifndef MEMORY_GROWTH_H
@@ -22,11 +22,9 @@ public:
   Memory_Growth (CORBA::ORB_ptr orb);
 
   // = The skeleton methods
-  virtual void ping (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void ping (void);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
 private:
   /// Use an ORB reference to conver strings to objects and shutdown
