@@ -1,4 +1,4 @@
-// $Id: create_reference.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: create_reference.cpp 82913 2008-10-02 19:22:25Z johnnyw $
 
 #include "tao/PortableServer/PortableServer.h"
 #include "tao/ORB_Constants.h"
@@ -12,16 +12,16 @@
 #include "ace/OS_NS_stdio.h"
 #include "ace/OS_NS_errno.h"
 
-ACE_RCSID(Activation, server, "$Id: create_reference.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Activation, server, "$Id: create_reference.cpp 82913 2008-10-02 19:22:25Z johnnyw $")
 
 int niterations = 10000;
 int do_dump_history = 0;
 ACE_UINT32 gsf;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "hi:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("hi:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -117,12 +117,12 @@ object_creation_test (PortableServer::POA_ptr poa,
 
   if (do_dump_history)
     {
-      creation.dump_samples ("HISTORY", gsf);
+      creation.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats creation_stats;
   creation.collect_basic_stats (creation_stats);
-  creation_stats.dump_results ("Creation", gsf);
+  creation_stats.dump_results (ACE_TEXT("Creation"), gsf);
 }
 
 int
