@@ -2,11 +2,11 @@ eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
     & eval 'exec perl -S $0 $argv:q'
     if 0;
 
-# $Id: run_test.pl 73797 2006-07-28 14:35:40Z wotte $
+# $Id: run_test.pl 87837 2009-12-01 09:50:38Z dbudko $
 # -*- perl -*-
 
 use lib "$ENV{ACE_ROOT}/bin";
-use PerlACE::Run_Test;
+use PerlACE::TestTarget;
 
 $iterations = 10000;
 
@@ -14,8 +14,11 @@ print STDERR "================ Reference Creation Test\n";
 
 print STDERR "\nTesting with hints (default configuration)\n";
 
-$CR = new PerlACE::Process ("create_reference", " -i $iterations");
-$status = $CR->SpawnWaitKill (120);
+my $server = PerlACE::TestTarget::create_target (1) || die "Create target 1 failed\n";
+
+$SV = $server->CreateProcess ("create_reference", " -i $iterations");
+
+$status = $SV->SpawnWaitKill ($server->ProcessStartWaitInterval() + 100);
 
 if ($status != 0) {
     print STDERR "ERROR: create_reference returned $status\n";
@@ -26,8 +29,9 @@ print STDERR "\nTesting without hints (optimized configuration)\n";
 
 $no_active_hint_directive = "-ORBsvcconfdirective \"static Server_Strategy_Factory '-ORBActiveHintInIds 0'\"";
 
-$CR = new PerlACE::Process ("create_reference", " -i $iterations $no_active_hint_directive");
-$status = $CR->SpawnWaitKill (120);
+$SV->Arguments ("-i $iterations $no_active_hint_directive");
+
+$status = $SV->SpawnWaitKill ($server->ProcessStartWaitInterval() + 100);
 
 if ($status != 0) {
     print STDERR "ERROR: create_reference returned $status\n";
