@@ -1,4 +1,4 @@
-// client.cpp,v 1.5 2002/01/29 20:20:57 okellogg Exp
+// $Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $
 // ============================================================================
 //
 // = LIBRARY
@@ -19,10 +19,10 @@
 #include "demux_test_client.h"
 #include "tao/debug.h"
 
-ACE_RCSID(CodeGen, client, "client.cpp,v 1.5 2002/01/29 20:20:57 okellogg Exp")
+ACE_RCSID(CodeGen, client, "$Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
 
 int
-main (int argc, char *argv [])
+ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 {
 
   // Set TAO_debug_level to 0 to ensure silent running unless
@@ -31,28 +31,24 @@ main (int argc, char *argv [])
 
   Demux_Test_Client demux_test_client;
 
-  ACE_TRY_NEW_ENV;
+  try
     {
-      int r = demux_test_client.init (argc, argv
-                                      ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      int r = demux_test_client.init (argc, argv);
       if (r == -1)
         return -1;
 
-      demux_test_client.run (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+      demux_test_client.run ();
     }
-  ACE_CATCH (CORBA::SystemException, sysex)
+  catch (const CORBA::SystemException& sysex)
     {
-      ACE_PRINT_EXCEPTION (sysex, "System Exception");
+      sysex._tao_print_exception ("System Exception");
       return -1;
     }
-  ACE_CATCH (CORBA::UserException, userex)
+  catch (const CORBA::UserException& userex)
     {
-      ACE_PRINT_EXCEPTION (userex, "User Exception");
+      userex._tao_print_exception ("User Exception");
       return -1;
     }
-  ACE_ENDTRY;
 
   return 0;
 
