@@ -1,7 +1,7 @@
 #ifndef TAO_DEMUX_TEST_CLIENT_H
 #define TAO_DEMUX_TEST_CLIENT_H
 
-// $Id: demux_test_client.h 79669 2007-09-20 07:33:14Z johnnyw $
+// $Id: demux_test_client.h 83252 2008-10-15 11:09:34Z vzykov $
 // ============================================================================
 //
 // = LIBRARY
@@ -21,8 +21,10 @@
 // FUZZ: disable check_for_math_include
 
 #include "ace/Get_Opt.h"
+#include "ace/Vector_T.h"
 #include "demux_testC.h"
 #include "demux_test_macros.h"
+#include "tao/Intrusive_Ref_Count_Handle_T.h"
 
 class Demux_Test_Client
 {
@@ -50,7 +52,7 @@ public:
   ~Demux_Test_Client (void);
   // DTOR
 
-  int init (int argc, char *argv []);
+  int init (int argc, ACE_TCHAR *argv []);
   // initialize the client test bed
 
   int run (void);
@@ -82,7 +84,7 @@ private:
   int argc_;
   // number of command line arguments
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // the actual command line arguments
 
   CORBA::ORB_var orb_;
@@ -100,7 +102,9 @@ private:
   CORBA::ULong num_ops_;
   // number of operations
 
-  Demux_Test_var demux_test_[TAO_DEMUX_TEST_MAX_POAS][TAO_DEMUX_TEST_MAX_OBJS];
+  typedef TAO_Intrusive_Ref_Count_Handle<Demux_Test> Demux_Test_Var;
+  typedef ACE_Vector<Demux_Test_Var> Demux_Test_Container;
+  Demux_Test_Container demux_test_;
   // object references to the Demux_Test objects
 
   CORBA::ULong loop_count_;
