@@ -1,4 +1,4 @@
-//demux_test_i.h,v 1.4 2002/01/29 20:20:57 okellogg Exp
+//$Id: demux_test_i.h 77010 2007-02-12 12:24:01Z johnnyw $
 
 #if !defined (TAO_DEMUX_TEST_I_H)
 #define TAO_DEMUX_TEST_I_H
@@ -24,16 +24,14 @@ public:
   // dtor
 
   // Return the Default POA of this Servant
-  PortableServer::POA_ptr _default_POA (ACE_ENV_SINGLE_ARG_DECL_NOT_USED/*env*/)
+  PortableServer::POA_ptr _default_POA (/*env*/)
     {
       return PortableServer::POA::_duplicate (this->poa_.in ());
     };
 
-  virtual void M302 (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void M302 (void);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
 private:
   PortableServer::POA_var poa_;
