@@ -1,4 +1,4 @@
-// $Id: server.cpp 78669 2007-06-29 19:42:03Z johnnyw $
+// $Id: server.cpp 82148 2008-06-24 12:03:55Z sma $
 // ============================================================================
 //
 // = LIBRARY
@@ -19,10 +19,10 @@
 #include "demux_test_server.h"
 #include "tao/debug.h"
 
-ACE_RCSID(CodeGen, server, "$Id: server.cpp 78669 2007-06-29 19:42:03Z johnnyw $")
+ACE_RCSID(CodeGen, server, "$Id: server.cpp 82148 2008-06-24 12:03:55Z sma $")
 
 
-int main (int argc, ACE_TCHAR *argv [])
+int ACE_TMAIN (int argc, ACE_TCHAR *argv [])
 {
   // Set TAO_debug_level to 0 to ensure silent running unless
   // debugging is explicitly invoked
