@@ -1,5 +1,5 @@
 //
-// Simple.h,v 1.6 2005/07/04 09:28:30 jwillemsen Exp
+// $Id: Simple.h 77010 2007-02-12 12:24:01Z johnnyw $
 //
 
 #ifndef SIMPLE_H
@@ -23,8 +23,7 @@ public:
 
   // = The skeleton methods
 
-  virtual void destroy (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void destroy (void);
 };
 
 #if defined(_MSC_VER)
