@@ -1,4 +1,4 @@
-// $Id: collocated.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: collocated.cpp 82913 2008-10-02 19:22:25Z johnnyw $
 
 #include "Simple.h"
 #include "ace/Get_Opt.h"
@@ -9,15 +9,15 @@
 #include "ace/Sample_History.h"
 #include "ace/OS_NS_errno.h"
 
-ACE_RCSID(Activation, server, "$Id: collocated.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Activation, server, "$Id: collocated.cpp 82913 2008-10-02 19:22:25Z johnnyw $")
 
 int niterations = 10000;
 int do_dump_history = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "hi:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("hi:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -124,12 +124,12 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       if (do_dump_history)
         {
-          activation.dump_samples ("ACTIVATION_HISTORY", gsf);
+          activation.dump_samples (ACE_TEXT("ACTIVATION_HISTORY"), gsf);
         }
 
       ACE_Basic_Stats activation_stats;
       activation.collect_basic_stats (activation_stats);
-      activation_stats.dump_results ("Activation", gsf);
+      activation_stats.dump_results (ACE_TEXT("Activation"), gsf);
 
       ACE_Sample_History destruction (niterations);
 
@@ -147,12 +147,12 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       if (do_dump_history)
         {
-          destruction.dump_samples ("DESTRUCTION_HISTORY", gsf);
+          destruction.dump_samples (ACE_TEXT("DESTRUCTION_HISTORY"), gsf);
         }
 
       ACE_Basic_Stats destruction_stats;
       destruction.collect_basic_stats (destruction_stats);
-      destruction_stats.dump_results ("Destruction", gsf);
+      destruction_stats.dump_results (ACE_TEXT("Destruction"), gsf);
 
       root_poa->destroy (1, 1);
 
