@@ -1,4 +1,4 @@
-// $Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: server.cpp 82850 2008-09-28 11:33:00Z johnnyw $
 
 #include "Factory.h"
 #include "ace/Get_Opt.h"
@@ -6,14 +6,14 @@
 #include "ace/OS_NS_stdio.h"
 #include "ace/OS_NS_errno.h"
 
-ACE_RCSID(Activation, server, "$Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Activation, server, "$Id: server.cpp 82850 2008-09-28 11:33:00Z johnnyw $")
 
-const char *ior_output_file = "test.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
