@@ -1,4 +1,4 @@
-// $Id: PP_Test_Client.cpp 76591 2007-01-25 18:17:52Z elliott_c $
+// $Id: PP_Test_Client.cpp 83000 2008-10-09 09:31:35Z johnnyw $
 
 #include "PP_Test_Client.h"
 
@@ -13,7 +13,7 @@
 #include "ace/OS_NS_unistd.h"
 #include "ace/OS_NS_string.h"
 
-ACE_RCSID(IDL_Cubit, Cubit_Client, "$Id: PP_Test_Client.cpp 76591 2007-01-25 18:17:52Z elliott_c $")
+ACE_RCSID(IDL_Cubit, Cubit_Client, "$Id: PP_Test_Client.cpp 83000 2008-10-09 09:31:35Z johnnyw $")
 
 #if defined (ACE_ENABLE_TIMEPROBES)
 
@@ -73,7 +73,7 @@ PP_Test_Client::PP_Test_Client (int shutdown)
 // Reads the Cubit factory ior from a file
 
 int
-PP_Test_Client::read_ior (char *filename)
+PP_Test_Client::read_ior (ACE_TCHAR *filename)
 {
   // Open the file for reading.
   this->f_handle_ = ACE_OS::open (filename,0);
@@ -97,7 +97,7 @@ PP_Test_Client::read_ior (char *filename)
                         -1);
     }
 
-  this->factory_key_ = ACE_OS::strdup (data);
+  this->factory_key_ = ACE_OS::strdup (ACE_TEXT_CHAR_TO_TCHAR(data));
 
   ior_buffer.alloc ()->free (data);
 
@@ -109,7 +109,7 @@ PP_Test_Client::read_ior (char *filename)
 int
 PP_Test_Client::parse_args (void)
 {
-  ACE_Get_Opt get_opts (argc_, argv_, "ovdn:f:k:x");
+  ACE_Get_Opt get_opts (argc_, argv_, ACE_TEXT("ovdn:f:k:x"));
   int c;
   int result;
 
@@ -376,7 +376,7 @@ PP_Test_Client::~PP_Test_Client (void)
 }
 
 int
-PP_Test_Client::init (int argc, char **argv)
+PP_Test_Client::init (int argc, ACE_TCHAR **argv)
 {
   this->argc_ = argc;
   this->argv_ = argv;
