@@ -1,5 +1,5 @@
 // -*- c++ -*-
-// $Id: PP_Test_Client.h 53025 2003-10-28 18:36:05Z bala $
+// $Id: PP_Test_Client.h 83000 2008-10-09 09:31:35Z johnnyw $
 
 // ============================================================================
 //
@@ -50,12 +50,12 @@ public:
   int run (void);
   // Execute client example code.
 
-  int init (int argc, char **argv);
+  int init (int argc, ACE_TCHAR **argv);
   // Initialize the client communication endpoint with server.
   // <collocation_test_ior> is used to pass in the ior file name.
 
 private:
-  int read_ior (char *filename);
+  int read_ior (ACE_TCHAR *filename);
   // Function to read the cubit factory ior from a file.
 
   int parse_args (void);
@@ -79,13 +79,13 @@ private:
   int argc_;
   // # of arguments on the command line.
 
-  char **argv_;
+  ACE_TCHAR **argv_;
   // arguments from command line.
 
   CORBA::ORB_var orb_;
   // Remember our orb.
 
-  char *factory_key_;
+  ACE_TCHAR *factory_key_;
   // Key of factory obj ref.
 
   CORBA::ULong loop_count_;
