@@ -1,4 +1,4 @@
-// $Id: test_i.cpp 77010 2007-02-12 12:24:01Z johnnyw $
+// $Id: test_i.cpp 82079 2008-06-19 13:08:00Z sma $
 
 #include "test_i.h"
 #include "tao/debug.h"
@@ -8,7 +8,7 @@
 #include "test_i.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(Latency, test_i, "$Id: test_i.cpp 77010 2007-02-12 12:24:01Z johnnyw $")
+ACE_RCSID(Latency, test_i, "$Id: test_i.cpp 82079 2008-06-19 13:08:00Z sma $")
 
 void
 Test_i::test_method (CORBA::Long id)
@@ -23,8 +23,9 @@ void
 Test_i::shutdown (const char *orb_id)
 {
   int argc = 0;
+  ACE_TCHAR **argv = 0;
   CORBA::ORB_var orb = CORBA::ORB_init (argc,
-                                        0,
+                                        argv,
                                         orb_id);
 
   orb->shutdown (0);
