@@ -1,4 +1,4 @@
-// $Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $
 
 #include "test_i.h"
 #include "tao/RTCORBA/RTCORBA.h"
@@ -10,7 +10,7 @@
 #include "ace/Sched_Params.h"
 #include "ace/OS_NS_errno.h"
 
-ACE_RCSID(TPP, server, "$Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(TPP, server, "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")
 
 class Server : public ACE_Task_Base
 {
@@ -24,7 +24,7 @@ public:
   Server (void);
   // ctor
 
-  void set (Test_i *server, int priority, int argc, char *argv[]);
+  void set (Test_i *server, int priority, int argc, ACE_TCHAR *argv[]);
   // Set the test attributes.
 
   // = The ACE_Task_Base methods....
@@ -38,7 +38,7 @@ private:
   // used for creating the name of the orb.)
 
   int argc_;
-  char *argv_[256];
+  ACE_TCHAR *argv_[256];
 };
 
 // ****************************************************************
@@ -47,12 +47,12 @@ int nthreads = 0;
 const int MAX_THREADS = 128;
 Server servers[MAX_THREADS];
 int priorities[MAX_THREADS];
-const char *ior_output_file_base = "test.ior";
+const ACE_TCHAR *ior_output_file_base = ACE_TEXT("test.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:t:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:t:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -117,11 +117,11 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
   try
     {
-      char *argv_[256];
+      ACE_TCHAR *argv_[256];
       int argc_ = argc;
       for (int i = 0; i < argc; ++i)
         argv_[i] = argv[i];
-      orb = CORBA::ORB_init (argc_, argv_, "");
+      orb = CORBA::ORB_init (argc_, argv_);
 
       // Parse the arguments.
       if (parse_args (argc_, argv_) != 0)
@@ -180,7 +180,7 @@ void
 Server::set (Test_i *server,
              int priority,
              int argc,
-             char *argv[])
+             ACE_TCHAR *argv[])
 {
   server_ = server;
   priority_ = priority;
@@ -234,7 +234,7 @@ Server::svc (void)
       CORBA::String_var ior =
         orb->object_to_string (obj.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       // Get the file name to store the ior.
       char file_name[100];
