@@ -1,12 +1,21 @@
 eval '(exit $?0)' && eval 'exec perl -S $0 ${1+"$@"}'
-    & eval 'exec perl -S $0 $argv:q'
-    if 0;
+     & eval 'exec perl -S $0 $argv:q'
+     if 0;
 
-# $Id: run_test.pl 78111 2007-04-19 12:29:25Z johnnyw $
+# $Id: run_test.pl 87753 2009-11-25 09:05:43Z dbudko $
 # -*- perl -*-
 
 use lib "$ENV{ACE_ROOT}/bin";
-use PerlACE::Run_Test;
+use PerlACE::TestTarget;
+
+$status = 0;
+$debug_level = '0';
+
+foreach $i (@ARGV) {
+    if ($i eq '-debug') {
+        $debug_level = '10';
+    }
+}
 
 $iterations = 4000;
 $bufsize = 4000;
@@ -17,11 +26,6 @@ $shutdown = "";
 $all = 1;
 $other = "";
 
-$status = 0;
-
-$iorfile = PerlACE::LocalFile ("test.ior");
-unlink $iorfile;
-
 # Parse the arguments
 
 @types = ("none", "transport", "server", "target", "twoway -x");
@@ -69,31 +73,58 @@ for ($i = 0; $i <= $#ARGV; $i++) {
 }
 
 ###############################################################################
+my $server = PerlACE::TestTarget::create_target (1) || die "Create target 1 failed\n";
+my $client = PerlACE::TestTarget::create_target (2) || die "Create target 2 failed\n";
 
-unlink $iorfile;
+my $iorbase = "test.ior";
+my $server_iorfile = $server->LocalFile ($iorbase);
+my $client_iorfile = $client->LocalFile ($iorbase);
+$server->DeleteFile($iorbase);
+$client->DeleteFile($iorbase);
 
-$SV = new PerlACE::Process ("server");
-$CL = new PerlACE::Process ("client");
+$SV = $server->CreateProcess ("server", "-ORBdebuglevel $debug_level -o $server_iorfile");
+$CL = $client->CreateProcess ("client", "");
 
-$SV->Spawn ();
+$server_status = $SV->Spawn ();
 
-if (PerlACE::waitforfile_timed ($iorfile, $PerlACE::wait_interval_for_process_creation) == -1) {
-    print STDERR "ERROR: cannot find file <$iorfile>\n";
-    $SV->Kill (); 
+if ($server_status != 0) {
+    print STDERR "ERROR: server returned $server_status\n";
     exit 1;
 }
 
+if ($server->WaitForFileTimed ($iorbase,
+                               $server->ProcessStartWaitInterval()) == -1) {
+    print STDERR "ERROR: cannot find file <$server_iorfile>\n";
+    $SV->Kill (); $SV->TimedWait (1);
+    exit 1;
+}
+
+if ($server->GetFile ($iorbase) == -1) {
+    print STDERR "ERROR: cannot retrieve file <$server_iorfile>\n";
+    $SV->Kill (); $SV->TimedWait (1);
+    exit 1;
+}
+
+if ($client->PutFile ($iorbase) == -1) {
+    print STDERR "ERROR: cannot set file <$client_iorfile>\n";
+    $SV->Kill (); $SV->TimedWait (1);
+    exit 1;
+}
+
+# -*- perl -*-
 ###############################################################################
 
 if ($all == 1) {
     foreach $bufsize (@bufsizes) {
         print STDERR "\n***************** STARTING TEST ******************\n";
         
-        $CL->Arguments ("-ORBNodelay 0 -l $level -t none -i $iterations -m $bufsize");
+        $CL->Arguments ("-k file://$client_iorfile -ORBNodelay 0 -l $level ".
+                        "-t none -i $iterations -m $bufsize");
 
-        my $client = $CL->SpawnWaitKill (60);
-        if ($client != 0) {
-            print STDERR "ERROR: client returned $client\n";
+        my $client_status = $CL->SpawnWaitKill ($client->ProcessStartWaitInterval() + 45);
+
+        if ($client_status != 0) {
+            print STDERR "ERROR: client returned $client_status\n";
             $status = 1;
         }
     }
@@ -116,23 +147,27 @@ foreach $type (@types) {
         $shutdown = "-x";
     }
 
-    $CL->Arguments (" $transport -t $type -i $iterations -l $level -m $bufsize -w $work $shutdown ");
+    $CL->Arguments ("-k file://$client_iorfile $transport -t $type -i $iterations ".
+                    "-l $level -m $bufsize -w $work $shutdown ");
 
-    my $client = $CL->SpawnWaitKill (60);
-    if ($client != 0) {
-        print STDERR "ERROR: client returned $client\n";
+    my $client_status = $CL->SpawnWaitKill ($client->ProcessStartWaitInterval() + 45);
+
+    if ($client_status != 0) {
+        print STDERR "ERROR: client returned $client_status\n";
         $status = 1;
     }
 }
 
 ###############################################################################
 
-$server = $SV->WaitKill (5);
-if ($server != 0) {
-    print STDERR "ERROR: server returned $server\n";
+$server_status = $SV->WaitKill ($server->ProcessStopWaitInterval());
+
+if ($server_status != 0) {
+    print STDERR "ERROR: server returned $server_status\n";
     $status = 1;
 }
 
-unlink $iorfile;
+$server->DeleteFile($iorbase);
+$client->DeleteFile($iorbase);
 
 exit $status;
