@@ -1,4 +1,4 @@
-// $Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: server.cpp 87753 2009-11-25 09:05:43Z dbudko $
 
 #include "test_i.h"
 #include "ace/Get_Opt.h"
@@ -6,21 +6,21 @@
 #include "ace/OS_NS_stdio.h"
 #include "ace/OS_NS_errno.h"
 
-ACE_RCSID(Reliable, server, "$Id: server.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Reliable, server, "$Id: server.cpp 87753 2009-11-25 09:05:43Z dbudko $")
 
 // IOR file name
-static const char *ior_output_file = "test.ior";
+static const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
 
 static int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "f:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
     switch (c)
       {
-      case 'f':
+      case 'o':
         ior_output_file = get_opts.opt_arg ();
         break;
 
@@ -28,7 +28,7 @@ parse_args (int argc, char *argv[])
       default:
         ACE_ERROR_RETURN ((LM_ERROR,
                            "usage:  %s "
-                           "-f <ior file> "
+                           "-o <ior file> "
                            "\n",
                            argv [0]),
                           -1);
@@ -95,8 +95,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
     {
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc,
-                         argv,
-                         "");
+                         argv);
 
       // Get the command line options.
       if (parse_args (argc, argv) != 0)
@@ -124,7 +123,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
         orb->object_to_string (server.in ());
 
       ACE_DEBUG ((LM_DEBUG,
-                  "Activated as <%s>\n",
+                  "Activated as <%C>\n",
                   ior.in ()));
 
       FILE *output_file= ACE_OS::fopen (ior_output_file, "w");
