@@ -1,4 +1,4 @@
-// test_i.h,v 1.5 2002/01/29 20:20:57 okellogg Exp
+// $Id: test_i.h 77010 2007-02-12 12:24:01Z johnnyw $
 
 // ============================================================================
 //
@@ -31,20 +31,13 @@ public:
   // ctor
 
   // = The Test methods.
-  void oneway_payload_test (const Test::data &d
-                            ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void oneway_payload_test (const Test::data &d);
 
-  void oneway_work_test (CORBA::ULong work
-                         ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void oneway_work_test (CORBA::ULong work);
 
-  void twoway_work_test (CORBA::ULong work
-                         ACE_ENV_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void twoway_work_test (CORBA::ULong work);
 
-  void shutdown (ACE_ENV_SINGLE_ARG_DECL_WITH_DEFAULTS)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  void shutdown (void);
 
 private:
   CORBA::ORB_var orb_;
@@ -52,7 +45,7 @@ private:
 };
 
 #if defined(__ACE_INLINE__)
-#include "test_i.i"
+#include "test_i.inl"
 #endif /* __ACE_INLINE__ */
 
 #endif /* TAO_RELIABLE_TEST_I_H */
