@@ -1,4 +1,4 @@
-// $Id: client.cpp 80166 2007-12-03 13:53:49Z sowayaa $
+// $Id: client.cpp 83037 2008-10-09 19:25:37Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "ace/High_Res_Timer.h"
@@ -18,7 +18,7 @@
 #include "tests/RTCORBA/check_supported_priorities.cpp"
 #include "ace/Event.h"
 
-ACE_RCSID(Thread_Pool, client, "$Id: client.cpp 80166 2007-12-03 13:53:49Z sowayaa $")
+ACE_RCSID(Thread_Pool, client, "$Id: client.cpp 83037 2008-10-09 19:25:37Z johnnyw $")
 
 enum Priority_Setting
 {
@@ -26,9 +26,9 @@ enum Priority_Setting
   AFTER_THREAD_CREATION = 1
 };
 
-static const char *ior = "file://ior";
-static const char *rates_file = "rates";
-static const char *invocation_priorities_file = "empty-file";
+static const ACE_TCHAR *ior = ACE_TEXT("file://ior");
+static const ACE_TCHAR *rates_file = ACE_TEXT("rates");
+static const ACE_TCHAR *invocation_priorities_file = ACE_TEXT("empty-file");
 static int shutdown_server = 0;
 static int do_dump_history = 0;
 static ACE_UINT32 gsf = 0;
@@ -63,7 +63,7 @@ struct Synchronizers
 };
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
   ACE_Get_Opt get_opts (argc, argv,
                         "c:e:g:hi:k:m:p:q:r:t:u:v:w:x:y:z:" //client options
@@ -537,14 +537,14 @@ Paced_Worker::print_stats (ACE_hrtime_t test_end)
 
   if (do_dump_history)
     {
-      this->history_.dump_samples ("HISTORY", gsf);
+      this->history_.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   this->history_.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 
@@ -752,14 +752,14 @@ Continuous_Worker::print_stats (ACE_Sample_History &history,
 
       if (do_dump_history)
         {
-          history.dump_samples ("HISTORY", gsf);
+          history.dump_samples (ACE_TEXT("HISTORY"), gsf);
         }
 
       ACE_Basic_Stats stats;
       history.collect_basic_stats (stats);
-      stats.dump_results ("Total", gsf);
+      stats.dump_results (ACE_TEXT("Total"), gsf);
 
-      ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                              test_end - test_start,
                                              stats.samples_count ());
     }
@@ -788,14 +788,14 @@ Continuous_Worker::print_collective_stats (void)
                   this->collective_stats_.samples_count () /
                   continuous_workers));
 
-      this->collective_stats_.dump_results ("Collective", gsf);
+      this->collective_stats_.dump_results (ACE_TEXT("Collective"), gsf);
 
-      ACE_Throughput_Stats::dump_throughput ("Individual", gsf,
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Individual"), gsf,
                                              this->time_for_test_,
                                              this->collective_stats_.samples_count () /
                                              continuous_workers);
 
-      ACE_Throughput_Stats::dump_throughput ("Collective", gsf,
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Collective"), gsf,
                                              this->time_for_test_,
                                              this->collective_stats_.samples_count ());
     }
