@@ -1,4 +1,4 @@
-// $Id: client.cpp 78698 2007-06-30 06:20:26Z johnnyw $
+// $Id: client.cpp 83054 2008-10-10 12:30:04Z johnnyw $
 
 #include "TestC.h"
 #include "ace/Get_Opt.h"
@@ -11,20 +11,20 @@
 
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(AMH_Single_Threaded_Latency, client, "$Id: client.cpp 78698 2007-06-30 06:20:26Z johnnyw $")
+ACE_RCSID(AMH_Single_Threaded_Latency, client, "$Id: client.cpp 83054 2008-10-10 12:30:04Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 100;
 int do_dump_history = 0;
 int do_shutdown = 1;
 int sz = 512;
 
-const char *data_type = "octet";
+const ACE_TCHAR *data_type = ACE_TEXT("octet");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "t:s:hxk:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("t:s:hxk:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -33,16 +33,16 @@ parse_args (int argc, char *argv[])
       case 't':
         data_type = get_opts.opt_arg ();
 
-        if (ACE_OS::strcmp (data_type, "octet") != 0 &&
-            ACE_OS::strcmp (data_type, "char") != 0 &&
-            ACE_OS::strcmp (data_type, "long") != 0 &&
-            ACE_OS::strcmp (data_type, "short") != 0 &&
-            ACE_OS::strcmp (data_type, "double") != 0 &&
-            ACE_OS::strcmp (data_type, "longlong") != 0)
+        if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("char")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("long")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("short")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("double")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) != 0)
           return -1;
         break;
 
-	  case 's':
+      case 's':
         sz = ACE_OS::atoi (get_opts.opt_arg ());
         break;
 
@@ -66,8 +66,8 @@ parse_args (int argc, char *argv[])
       default:
         ACE_ERROR_RETURN ((LM_ERROR,
                            "usage:  %s "
-						   "-t <datatype> "
-						   "-s <size> "
+                           "-t <datatype> "
+                           "-s <size> "
                            "-k <ior> "
                            "-i <niterations> "
                            "-x (disable shutdown) "
@@ -110,14 +110,14 @@ test_octet_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -152,14 +152,14 @@ test_long_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -194,14 +194,14 @@ test_short_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -236,14 +236,14 @@ test_char_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -278,14 +278,14 @@ test_longlong_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -320,14 +320,14 @@ test_double_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -379,7 +379,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                             1);
         }
 
-	  Test::octet_load oc;
+      Test::octet_load oc;
 
       for (int j = 0; j < 100; ++j)
         {
@@ -388,27 +388,27 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                                                start);
         }
 
-      if (ACE_OS::strcmp (data_type, "octet") == 0 )
+      if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) == 0)
         {
           test_octet_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "char") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("char")) == 0)
         {
           test_char_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "long") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("long")) == 0)
         {
           test_long_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "short") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("short")) == 0)
         {
           test_short_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "double") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("double")) == 0)
         {
           test_double_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "longlong") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) == 0)
         {
           test_longlong_seq (roundtrip.in ());
         }
