@@ -1,4 +1,4 @@
-// $Id: client.cpp 78687 2007-06-30 06:10:58Z johnnyw $
+// $Id: client.cpp 83055 2008-10-10 12:45:33Z johnnyw $
 
 #include "tao/DynamicInterface/Request.h"
 #include "tao/Strategies/advanced_resource.h"
@@ -18,20 +18,20 @@
 
 ACE_RCSID (DII,
            client,
-           "$Id: client.cpp 78687 2007-06-30 06:10:58Z johnnyw $")
+           "$Id: client.cpp 83055 2008-10-10 12:45:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 100;
 int do_dump_history = 0;
 int do_shutdown = 1;
 int sz = 512;
 
-const char *data_type = "octet";
+const ACE_TCHAR *data_type = ACE_TEXT("octet");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "t:s:hxk:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("t:s:hxk:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -40,16 +40,16 @@ parse_args (int argc, char *argv[])
       case 't':
         data_type = get_opts.opt_arg ();
 
-        if (ACE_OS::strcmp (data_type, "octet") != 0 &&
-            ACE_OS::strcmp (data_type, "char") != 0 &&
-            ACE_OS::strcmp (data_type, "long") != 0 &&
-            ACE_OS::strcmp (data_type, "short") != 0 &&
-            ACE_OS::strcmp (data_type, "double") != 0 &&
-            ACE_OS::strcmp (data_type, "longlong") != 0)
+        if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("char")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("long")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("short")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("double")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) != 0)
           return -1;
         break;
 
-	  case 's':
+      case 's':
         sz = ACE_OS::atoi (get_opts.opt_arg ());
         break;
 
@@ -74,8 +74,8 @@ parse_args (int argc, char *argv[])
         ACE_ERROR_RETURN ((LM_ERROR,
                            "usage:  %s "
                            "-t <datatype> "
-						   "-s <size> "
-						   "-k <ior> "
+                           "-s <size> "
+                           "-k <ior> "
                            "-i <niterations> "
                            "-x (disable shutdown) "
                            "\n",
@@ -124,14 +124,14 @@ test_octet_seq (const CORBA::Object_var object)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -172,14 +172,14 @@ test_long_seq (const CORBA::Object_var object)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -220,14 +220,14 @@ test_short_seq (const CORBA::Object_var object)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -268,14 +268,14 @@ test_char_seq (const CORBA::Object_var object)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -316,14 +316,14 @@ test_double_seq (const CORBA::Object_var object)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -364,14 +364,14 @@ test_longlong_seq (const CORBA::Object_var object)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
 }
@@ -421,7 +421,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                             1);
         }
 
-	  Test::octet_load oc;
+      Test::octet_load oc;
 
       for (int j = 0; j < 100; ++j)
         {
@@ -436,41 +436,39 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
           request->invoke ();
         }
 
-	  // Test various sequence types
+      // Test various sequence types
 
-	  if (ACE_OS::strcmp (data_type, "octet") == 0 )
+      if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) == 0 )
         {
           test_octet_seq (object);
         }
-      else if (ACE_OS::strcmp (data_type, "char") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("char")) == 0)
         {
           test_char_seq (object);
         }
-      else if (ACE_OS::strcmp (data_type, "long") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("long")) == 0)
         {
           test_long_seq (object);
         }
-      else if (ACE_OS::strcmp (data_type, "short") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("short")) == 0)
         {
           test_short_seq (object);
         }
-      else if (ACE_OS::strcmp (data_type, "double") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("double")) == 0)
         {
           test_double_seq (object);
         }
-      else if (ACE_OS::strcmp (data_type, "longlong") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) == 0)
         {
           test_longlong_seq (object);
         }
 
-
       if (do_shutdown)
         {
           CORBA::Request_var request =
             object->_request ("shutdown");
 
           request->invoke ();
-
         }
     }
   catch (const CORBA::Exception& ex)
