@@ -1,4 +1,4 @@
-// $Id: client.cpp 78689 2007-06-30 06:11:23Z johnnyw $
+// $Id: client.cpp 83055 2008-10-10 12:45:33Z johnnyw $
 
 #include "tao/DynamicInterface/Request.h"  /* Must come first for G++
                                               3.4 or better */
@@ -19,21 +19,21 @@
 
 ACE_RCSID (Deferred,
            client,
-           "$Id: client.cpp 78689 2007-06-30 06:11:23Z johnnyw $")
+           "$Id: client.cpp 83055 2008-10-10 12:45:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 1000;
 int burst = 10;
 int do_shutdown = 1;
 int do_dump_history = 0;
 int sz = 512;
 
-const char *data_type = "octet";
+const ACE_TCHAR *data_type = ACE_TEXT("octet");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "t:s:hxk:i:b:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("t:s:hxk:i:b:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -42,12 +42,12 @@ parse_args (int argc, char *argv[])
       case 't':
         data_type = get_opts.opt_arg ();
 
-        if (ACE_OS::strcmp (data_type, "octet") != 0 &&
-            ACE_OS::strcmp (data_type, "char") != 0 &&
-            ACE_OS::strcmp (data_type, "long") != 0 &&
-            ACE_OS::strcmp (data_type, "short") != 0 &&
-            ACE_OS::strcmp (data_type, "double") != 0 &&
-            ACE_OS::strcmp (data_type, "longlong") != 0)
+        if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("char")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("long")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("short")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("double")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) != 0)
           return -1;
         break;
 
@@ -151,14 +151,14 @@ test_octet_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
   return 0;
@@ -220,14 +220,14 @@ test_long_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
   return 0;
@@ -289,14 +289,14 @@ test_short_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
   return 0;
@@ -358,14 +358,14 @@ test_char_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
   return 0;
@@ -427,14 +427,14 @@ test_longlong_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
   return 0;
@@ -496,14 +496,14 @@ test_double_seq (Test::Roundtrip_ptr roundtrip)
 
   if (do_dump_history)
     {
-      history.dump_samples ("HISTORY", gsf);
+      history.dump_samples (ACE_TEXT("HISTORY"), gsf);
     }
 
   ACE_Basic_Stats stats;
   history.collect_basic_stats (stats);
-  stats.dump_results ("Total", gsf);
+  stats.dump_results (ACE_TEXT("Total"), gsf);
 
-  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
+  ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"), gsf,
                                          test_end - test_start,
                                          stats.samples_count ());
   return 0;
@@ -570,27 +570,27 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
           // Test various sequence types
 
-          if (ACE_OS::strcmp (data_type, "octet") == 0 )
+      if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) == 0)
         {
           test_octet_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "char") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("char")) == 0)
         {
           test_char_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "long") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("long")) == 0)
         {
           test_long_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "short") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("short")) == 0)
         {
           test_short_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "double") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("double")) == 0)
         {
           test_double_seq (roundtrip.in ());
         }
-      else if (ACE_OS::strcmp (data_type, "longlong") == 0)
+      else if (ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) == 0)
         {
           test_longlong_seq (roundtrip.in ());
         }
