@@ -1,16 +1,16 @@
 //
-// $Id: Client_Task.cpp 76626 2007-01-26 13:50:03Z elliott_c $
+// $Id: Client_Task.cpp 83055 2008-10-10 12:45:33Z johnnyw $
 //
 #include "Client_Task.h"
 #include "ace/OS_NS_time.h"
 
-ACE_RCSID(Thread_Per_Connection_Latency, Client_Task, "$Id: Client_Task.cpp 76626 2007-01-26 13:50:03Z elliott_c $")
+ACE_RCSID(Thread_Per_Connection_Latency, Client_Task, "$Id: Client_Task.cpp 83055 2008-10-10 12:45:33Z johnnyw $")
 
-Client_Task::Client_Task (const char *data_type,
+Client_Task::Client_Task (const ACE_TCHAR *data_type,
                           int size,
                           Test::Roundtrip_ptr roundtrip,
                           int niterations)
-  : data_type_ (CORBA::string_dup (data_type))
+  : data_type_ (data_type)
   , size_ (size)
   , roundtrip_ (Test::Roundtrip::_duplicate (roundtrip))
   , niterations_ (niterations)
@@ -24,27 +24,27 @@ Client_Task::svc (void)
     {
       this->validate_connection ();
 
-      if (ACE_OS::strcmp (this->data_type_.in (), "octet") == 0 )
+      if (ACE_OS::strcmp (this->data_type_, ACE_TEXT("octet")) == 0)
         {
           this->test_octet_seq ();
         }
-      if (ACE_OS::strcmp (this->data_type_.in (), "long") == 0 )
+      if (ACE_OS::strcmp (this->data_type_, ACE_TEXT("long")) == 0)
         {
           this->test_long_seq ();
         }
-      if (ACE_OS::strcmp (this->data_type_.in (), "short") == 0 )
+      if (ACE_OS::strcmp (this->data_type_, ACE_TEXT("short")) == 0)
         {
           this->test_short_seq ();
         }
-      if (ACE_OS::strcmp (this->data_type_.in (), "char") == 0 )
+      if (ACE_OS::strcmp (this->data_type_, ACE_TEXT("char")) == 0)
         {
           this->test_char_seq ();
         }
-      if (ACE_OS::strcmp (this->data_type_.in (), "longlong") == 0 )
+      if (ACE_OS::strcmp (this->data_type_, ACE_TEXT("longlong")) == 0)
         {
           this->test_longlong_seq ();
         }
-      if (ACE_OS::strcmp (this->data_type_.in (), "double") == 0 )
+      if (ACE_OS::strcmp (this->data_type_, ACE_TEXT("double")) == 0)
         {
           this->test_double_seq ();
         }
@@ -58,7 +58,7 @@ Client_Task::svc (void)
 
 void
 Client_Task::accumulate_and_dump (ACE_Basic_Stats &totals,
-                                  const char *msg,
+                                  const ACE_TCHAR *msg,
                                   ACE_UINT32 gsf)
 {
   totals.accumulate (this->latency_);
