@@ -1,4 +1,4 @@
-// $Id: client.cpp 78669 2007-06-29 19:42:03Z johnnyw $
+// $Id: client.cpp 83055 2008-10-10 12:45:33Z johnnyw $
 
 #include "Client_Task.h"
 #include "ace/Get_Opt.h"
@@ -10,19 +10,19 @@
 
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(Thread_Per_Connection_Latency, client, "$Id: client.cpp 78669 2007-06-29 19:42:03Z johnnyw $")
+ACE_RCSID(Thread_Per_Connection_Latency, client, "$Id: client.cpp 83055 2008-10-10 12:45:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 1000;
 int do_shutdown = 1;
 int sz = 512;
 
-const char *data_type = "octet";
+const ACE_TCHAR *data_type = ACE_TEXT("octet");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "t:s:xk:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("t:s:xk:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -31,16 +31,16 @@ parse_args (int argc, char *argv[])
       case 't':
         data_type = get_opts.opt_arg ();
 
-        if (ACE_OS::strcmp (data_type, "octet") != 0 &&
-            ACE_OS::strcmp (data_type, "char") != 0 &&
-            ACE_OS::strcmp (data_type, "long") != 0 &&
-            ACE_OS::strcmp (data_type, "short") != 0 &&
-            ACE_OS::strcmp (data_type, "double") != 0 &&
-            ACE_OS::strcmp (data_type, "longlong") != 0)
+        if (ACE_OS::strcmp (data_type, ACE_TEXT("octet")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("char")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("long")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("short")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("double")) != 0 &&
+            ACE_OS::strcmp (data_type, ACE_TEXT("longlong")) != 0)
           return -1;
         break;
 
-	  case 's':
+      case 's':
         sz = ACE_OS::atoi (get_opts.opt_arg ());
         break;
 
@@ -61,8 +61,8 @@ parse_args (int argc, char *argv[])
         ACE_ERROR_RETURN ((LM_ERROR,
                            "usage:  %s "
                            "-t <datatype> "
-						   "-s <size> "
-						   "-k <ior> "
+                           "-s <size> "
+                           "-k <ior> "
                            "-i <niterations> "
                            "-x (disable shutdown) "
                            "\n",
@@ -119,41 +119,42 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                             1);
         }
 
-	  /// Begin the test
+      /// Begin the test
 
-	  ACE_DEBUG ((LM_DEBUG, "Starting threads\n"));
+      ACE_DEBUG ((LM_DEBUG, "Starting threads\n"));
 
-	  Client_Task task0(data_type, sz, roundtrip.in (), niterations);
-	  Client_Task task1(data_type, sz, roundtrip.in (), niterations);
-	  Client_Task task2(data_type, sz, roundtrip.in (), niterations);
-	  Client_Task task3(data_type, sz, roundtrip.in (), niterations);
+      Client_Task task0(data_type, sz, roundtrip.in (), niterations);
+      Client_Task task1(data_type, sz, roundtrip.in (), niterations);
+      Client_Task task2(data_type, sz, roundtrip.in (), niterations);
+      Client_Task task3(data_type, sz, roundtrip.in (), niterations);
 
-	  ACE_hrtime_t test_start = ACE_OS::gethrtime ();
-	  task0.activate(THR_NEW_LWP | THR_JOINABLE);
-	  task1.activate(THR_NEW_LWP | THR_JOINABLE);
-	  task2.activate(THR_NEW_LWP | THR_JOINABLE);
-	  task3.activate(THR_NEW_LWP | THR_JOINABLE);
+      ACE_hrtime_t test_start = ACE_OS::gethrtime ();
+      task0.activate(THR_NEW_LWP | THR_JOINABLE);
+      task1.activate(THR_NEW_LWP | THR_JOINABLE);
+      task2.activate(THR_NEW_LWP | THR_JOINABLE);
+      task3.activate(THR_NEW_LWP | THR_JOINABLE);
 
-	  task0.thr_mgr()->wait ();
-	  ACE_hrtime_t test_end = ACE_OS::gethrtime ();
+      task0.thr_mgr()->wait ();
+      ACE_hrtime_t test_end = ACE_OS::gethrtime ();
 
-	  ACE_DEBUG ((LM_DEBUG, "Threads finished\n"));
+      ACE_DEBUG ((LM_DEBUG, "Threads finished\n"));
 
-	  ACE_DEBUG ((LM_DEBUG, "High resolution timer calibration...."));
-	  ACE_UINT32 gsf = ACE_High_Res_Timer::global_scale_factor ();
-	  ACE_DEBUG ((LM_DEBUG, "done\n"));
+      ACE_DEBUG ((LM_DEBUG, "High resolution timer calibration...."));
+      ACE_UINT32 gsf = ACE_High_Res_Timer::global_scale_factor ();
+      ACE_DEBUG ((LM_DEBUG, "done\n"));
 
-	  ACE_Basic_Stats totals;
-	  task0.accumulate_and_dump (totals, "Task[0]", gsf);
-	  task1.accumulate_and_dump (totals, "Task[1]", gsf);
-	  task2.accumulate_and_dump (totals, "Task[2]", gsf);
-	  task3.accumulate_and_dump (totals, "Task[3]", gsf);
+      ACE_Basic_Stats totals;
+      task0.accumulate_and_dump (totals, ACE_TEXT("Task[0]"), gsf);
+      task1.accumulate_and_dump (totals, ACE_TEXT("Task[1]"), gsf);
+      task2.accumulate_and_dump (totals, ACE_TEXT("Task[2]"), gsf);
+      task3.accumulate_and_dump (totals, ACE_TEXT("Task[3]"), gsf);
 
-	  totals.dump_results ("Total", gsf);
+      totals.dump_results (ACE_TEXT("Total"), gsf);
 
-	  ACE_Throughput_Stats::dump_throughput ("Total", gsf,
-											 test_end - test_start,
-											 totals.samples_count ());
+      ACE_Throughput_Stats::dump_throughput (ACE_TEXT("Total"),
+                                             gsf,
+                                             test_end - test_start,
+                                             totals.samples_count ());
 
       if (do_shutdown)
         {
