@@ -1,5 +1,5 @@
 //
-// Receiver.h,v 1.7 2005/07/04 09:28:53 jwillemsen Exp
+// $Id: Receiver.h 77010 2007-02-12 12:24:01Z johnnyw $
 //
 
 #ifndef THROUGHPUT_RECEIVER_H
@@ -23,12 +23,9 @@ public:
   Receiver (void);
 
   // = The skeleton methods
-  virtual void receive_data (const Test::Message &message
-                             ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void receive_data (const Test::Message &message);
 
-  virtual void done (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void done (void);
 
 private:
   /// The timestamp for the first message
