@@ -1,22 +1,22 @@
-// $Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $
+// $Id: client.cpp 82850 2008-09-28 11:33:00Z johnnyw $
 
 #include "TestC.h"
 #include "ace/High_Res_Timer.h"
 #include "ace/Get_Opt.h"
 #include "tao/Strategies/advanced_resource.h"
 
-ACE_RCSID(Throughput, client, "$Id: client.cpp 78652 2007-06-29 12:25:06Z sowayaa $")
+ACE_RCSID(Throughput, client, "$Id: client.cpp 82850 2008-09-28 11:33:00Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int message_size  = 2048;
 int message_count = 10 * 1024;
 int test_runs   = 6;
 int do_shutdown = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:b:i:n:x");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:b:i:n:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
