@@ -1,4 +1,4 @@
-// $Id: Acceptor_Registry.cpp 79109 2007-07-31 07:23:49Z johnnyw $
+// $Id: Acceptor_Registry.cpp 86811 2009-09-28 06:32:45Z johnnyw $
 
 #include "tao/Acceptor_Registry.h"
 #include "tao/Profile.h"
@@ -27,7 +27,7 @@
 
 ACE_RCSID (tao,
            Acceptor_Registry,
-           "$Id: Acceptor_Registry.cpp 79109 2007-07-31 07:23:49Z johnnyw $")
+           "$Id: Acceptor_Registry.cpp 86811 2009-09-28 06:32:45Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -48,7 +48,7 @@ TAO_Acceptor_Registry::~TAO_Acceptor_Registry (void)
 size_t
 TAO_Acceptor_Registry::endpoint_count (void)
 {
-  int count = 0;
+  size_t count = 0;
   const TAO_AcceptorSetIterator end = this->end ();
 
   for (TAO_AcceptorSetIterator i = this->begin (); i != end; ++i)
@@ -59,12 +59,11 @@ TAO_Acceptor_Registry::endpoint_count (void)
   return count;
 }
 
-int
+bool
 TAO_Acceptor_Registry::is_collocated (const TAO_MProfile &mprofile)
 {
-  const TAO_AcceptorSetIterator end = this->end ();
-
-  const CORBA::ULong count = mprofile.profile_count ();
+  TAO_AcceptorSetIterator const end = this->end ();
+  CORBA::ULong const count = mprofile.profile_count ();
 
   // If at least one endpoint in one of the profiles matches one of
   // the acceptors, we are collocated.
@@ -91,20 +90,20 @@ TAO_Acceptor_Registry::is_collocated (const TAO_MProfile &mprofile)
                 {
                   if ((*i)->is_collocated (endp))
                     {
-                      return 1;
+                      return true;
                     }
                 }
             }
         }
     }
 
-  return 0;
+  return false;
 }
 
 TAO_Acceptor*
 TAO_Acceptor_Registry::get_acceptor (CORBA::ULong tag)
 {
-  TAO_AcceptorSetIterator end = this->end ();
+  TAO_AcceptorSetIterator const end = this->end ();
   TAO_AcceptorSetIterator acceptor = this->begin ();
 
   for (; acceptor != end; ++acceptor)
@@ -160,8 +159,8 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
             {
               ACE_ERROR ((LM_ERROR,
                           ACE_TEXT ("(%P|%t) Invalid endpoint ")
-                          ACE_TEXT ("specification: <%s>.\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (iop.c_str ())));
+                          ACE_TEXT ("specification: <%C>.\n"),
+                          iop.c_str ()));
             }
 
           throw ::CORBA::BAD_PARAM (
@@ -247,8 +246,8 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
             {
               ACE_ERROR ((LM_ERROR,
                           ACE_TEXT ("(%P|%t) Invalid endpoint ")
-                          ACE_TEXT ("specification: <%s>.\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (iop.c_str ())));
+                          ACE_TEXT ("specification: <%C>.\n"),
+                          iop.c_str ()));
             }
 
           throw ::CORBA::BAD_PARAM (
@@ -283,7 +282,7 @@ TAO_Acceptor_Registry::open (TAO_ORB_Core *orb_core,
               // increment slot past the "://" (i.e. add 3)
               ACE_CString addrs = iop.substring (slot + 3);
 
-              const int result = this->open_i (orb_core,
+              int const result = this->open_i (orb_core,
                                                reactor,
                                                addrs,
                                                factory,
@@ -382,8 +381,8 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
                       ACE_ERROR ((
                           LM_ERROR,
                           ACE_TEXT ("TAO (%P|%t) unable to create ")
-                          ACE_TEXT ("an acceptor for <%s>\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR ((*i)->protocol_name ().c_str ())
+                          ACE_TEXT ("an acceptor for <%C>\n"),
+                          (*i)->protocol_name ().c_str ()
                         ));
                     }
 
@@ -393,9 +392,10 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
               if ((*i)->factory ()->tag () == IOP::TAG_INTERNET_IOP)
                 {
                   // Open first acceptor on IPv4 ANY
-                  ACE_INET_Addr addr(static_cast<unsigned short> (0)); // IPv4 ANY
+                  ACE_INET_Addr addr(static_cast<unsigned short> (0));
 
-                  TAO_IIOP_Acceptor* iiop_acceptor = dynamic_cast<TAO_IIOP_Acceptor*> (acceptor);
+                  TAO_IIOP_Acceptor* iiop_acceptor =
+                    dynamic_cast<TAO_IIOP_Acceptor*> (acceptor);
 
                   if (!iiop_acceptor)
                     return -1;
@@ -404,8 +404,8 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
 
                   if (this->open_default_i (orb_core,
                                             reactor,
-                                            TAO_DEF_GIOP_MAJOR,  // default major
-                                            TAO_DEF_GIOP_MINOR,  // default minor
+                                            TAO_DEF_GIOP_MAJOR,
+                                            TAO_DEF_GIOP_MINOR,
                                             i,
                                             acceptor,
                                             options) != 0)
@@ -414,7 +414,8 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
                     }
 
                   // record the port chosen for the IPv4 acceptor
-                  u_short port = iiop_acceptor->default_address ().get_port_number ();
+                  u_short port =
+                    iiop_acceptor->default_address ().get_port_number ();
 
                   // Create second acceptor for IPV6 traffic
                   acceptor =
@@ -427,40 +428,43 @@ int TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
                           ACE_ERROR ((
                               LM_ERROR,
                               ACE_TEXT ("TAO (%P|%t) unable to create ")
-                              ACE_TEXT ("an acceptor for <%s>\n"),
-                              ACE_TEXT_CHAR_TO_TCHAR ((*i)->protocol_name ().c_str ())
+                              ACE_TEXT ("an acceptor for <%C>\n"),
+                              (*i)->protocol_name ().c_str ()
                             ));
                         }
 
                       return -1;
                     }
 
-                  addr.set (port, ACE_IPV6_ANY, AF_INET6); // IPv6 ANY on specified port
-
-                  iiop_acceptor = dynamic_cast<TAO_IIOP_Acceptor*> (acceptor);
- 
-                  if (!iiop_acceptor)
-                    return -1;
-
-                  iiop_acceptor->set_default_address (addr);
-
-                  if (this->open_default_i (orb_core,
-                                            reactor,
-                                            TAO_DEF_GIOP_MAJOR,  // default major
-                                            TAO_DEF_GIOP_MINOR,  // default minor
-                                            i,
-                                            acceptor,
-                                            options) != 0)
+                  if (ACE::ipv6_enabled() &&
+                      addr.set (port, ACE_IPV6_ANY, 1, AF_INET6) == 0)
                     {
-                      return -1;
+                      iiop_acceptor =
+                        dynamic_cast<TAO_IIOP_Acceptor*> (acceptor);
+
+                      if (!iiop_acceptor)
+                        return -1;
+
+                      iiop_acceptor->set_default_address (addr);
+
+                      if (this->open_default_i (orb_core,
+                          reactor,
+                          TAO_DEF_GIOP_MAJOR,
+                          TAO_DEF_GIOP_MINOR,
+                          i,
+                          acceptor,
+                          options) != 0)
+                        {
+                          return -1;
+                        }
                     }
                 }
               else
                 {
                   if (this->open_default_i (orb_core,
                                             reactor,
-                                            TAO_DEF_GIOP_MAJOR,  // default major
-                                            TAO_DEF_GIOP_MINOR,  // default minor
+                                            TAO_DEF_GIOP_MAJOR,
+                                            TAO_DEF_GIOP_MINOR,
                                             i,
                                             acceptor,
                                             options) != 0)
@@ -550,8 +554,7 @@ TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
   // default endpoint.
 
   // Make an acceptor
-  TAO_Acceptor *acceptor =
-    (*factory)->factory ()->make_acceptor ();
+  TAO_Acceptor *acceptor = (*factory)->factory ()->make_acceptor ();
 
   if (acceptor == 0)
     {
@@ -560,8 +563,8 @@ TAO_Acceptor_Registry::open_default (TAO_ORB_Core *orb_core,
           ACE_ERROR ((
               LM_ERROR,
               ACE_TEXT ("TAO (%P|%t) unable to create ")
-              ACE_TEXT ("an acceptor for <%s>\n"),
-              ACE_TEXT_CHAR_TO_TCHAR ((*factory)->protocol_name ().c_str ())
+              ACE_TEXT ("an acceptor for <%C>\n"),
+              (*factory)->protocol_name ().c_str ()
             ));
         }
 
@@ -588,11 +591,7 @@ TAO_Acceptor_Registry::open_default_i (TAO_ORB_Core *orb_core,
                                        const char *options)
 {
   // Initialize the acceptor to listen on a default endpoint.
-  if (acceptor->open_default (orb_core,
-                              reactor,
-                              major,
-                              minor,
-                              options) == -1)
+  if (acceptor->open_default (orb_core, reactor, major, minor, options) == -1)
     {
       delete acceptor;
 
@@ -600,9 +599,9 @@ TAO_Acceptor_Registry::open_default_i (TAO_ORB_Core *orb_core,
         {
           ACE_ERROR ((
               LM_ERROR,
-              ACE_TEXT ("TAO (%P|%t) unable to open ")
-              ACE_TEXT ("default acceptor for <%s>%p\n"),
-              ACE_TEXT_CHAR_TO_TCHAR ((*factory)->protocol_name ().c_str ()),
+              ACE_TEXT ("TAO (%P|%t) - Unable to open ")
+              ACE_TEXT ("default acceptor for <%C>%p\n"),
+              (*factory)->protocol_name ().c_str (),
               ACE_TEXT ("")
             ));
         }
@@ -622,14 +621,11 @@ TAO_Acceptor_Registry::close_all (void)
 
   for (TAO_AcceptorSetIterator i = this->begin (); i != end; ++i)
     {
-      if (*i == 0)
+      if (*i != 0)
         {
-          continue;
+          (*i)->close ();
+          delete *i;
         }
-
-      (*i)->close ();
-
-      delete *i;
     }
 
   this->size_ = 0;
@@ -685,21 +681,19 @@ TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
                                bool ignore_address)
 {
   ACE_CString options_tmp;
-  this->extract_endpoint_options (addrs,
-                                  options_tmp,
-                                  (*factory)->factory ());
+  this->extract_endpoint_options (addrs, options_tmp, (*factory)->factory ());
 
   const char *options = 0;
 
   if (options_tmp.length () > 0)
-    options = options_tmp.c_str ();
+    {
+      options = options_tmp.c_str ();
+    }
 
   char *last_addr = 0;
   ACE_Auto_Basic_Array_Ptr<char> addr_str (addrs.rep ());
 
-  const char *astr = ACE_OS::strtok_r (addr_str.get (),
-                                       ",",
-                                       &last_addr);
+  const char *astr = ACE_OS::strtok_r (addr_str.get (), ",", &last_addr);
 
   // Iterate over the addrs specified in the endpoint.
 
@@ -711,8 +705,7 @@ TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
       // the specified protocol.
       ACE_CString address (astr == 0 ? "" : astr);
 
-      TAO_Acceptor *acceptor =
-        (*factory)->factory ()->make_acceptor ();
+      TAO_Acceptor *acceptor = (*factory)->factory ()->make_acceptor ();
 
       if (acceptor != 0)
         {
@@ -720,9 +713,7 @@ TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
           // exists.
           int major = TAO_DEF_GIOP_MAJOR;
           int minor = TAO_DEF_GIOP_MINOR;
-          this->extract_endpoint_version (address,
-                                          major,
-                                          minor);
+          this->extract_endpoint_version (address, major, minor);
 
           // Check for existence of endpoint.
           if (ignore_address || address.length () == 0)
@@ -765,8 +756,8 @@ TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
                               ACE_ERROR ((
                                   LM_ERROR,
                                   ACE_TEXT ("TAO (%P|%t) unable to create ")
-                                  ACE_TEXT ("an acceptor for <%s>\n"),
-                                  ACE_TEXT_CHAR_TO_TCHAR ((*factory)->protocol_name ().c_str ())
+                                  ACE_TEXT ("an acceptor for <%C>\n"),
+                                  (*factory)->protocol_name ().c_str ()
                                 ));
                             }
 
@@ -851,16 +842,16 @@ TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
             {
               /* Need to save the errno value from the acceptor->open(),
                * because errno will get reset when we delete acceptor */
-              const int errno_value = errno;
+              int const errno_value = errno;
               delete acceptor;
 
               if (TAO_debug_level > 0)
                 {
                   ACE_ERROR ((LM_ERROR,
-                              ACE_TEXT ("TAO (%P|%t) ")
-                              ACE_TEXT ("unable to open acceptor ")
-                              ACE_TEXT ("for <%s>%p\n"),
-                              ACE_TEXT_CHAR_TO_TCHAR (address.c_str ()),
+                              ACE_TEXT ("TAO (%P|%t) - ")
+                              ACE_TEXT ("Unable to open acceptor ")
+                              ACE_TEXT ("for <%C>%p\n"),
+                              address.c_str (),
                               ACE_TEXT ("")));
                 }
 
@@ -880,8 +871,8 @@ TAO_Acceptor_Registry::open_i (TAO_ORB_Core *orb_core,
             {
               ACE_ERROR ((LM_ERROR,
                           ACE_TEXT ("TAO (%P|%t) unable to create ")
-                          ACE_TEXT ("an acceptor for <%s>.\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (address.c_str ())));
+                          ACE_TEXT ("an acceptor for <%C>.\n"),
+                          address.c_str ()));
             }
 
           throw ::CORBA::NO_MEMORY (
