@@ -1,4 +1,4 @@
-// $Id: Adapter_Registry.cpp 77636 2007-03-09 12:56:14Z johnnyw $
+// $Id: Adapter_Registry.cpp 81410 2008-04-24 09:22:08Z johnnyw $
 
 #include "tao/Object.h"
 #include "tao/Stub.h"
@@ -6,6 +6,7 @@
 #include "tao/Adapter.h"
 #include "tao/SystemException.h"
 #include "tao/debug.h"
+#include "tao/TAO_Server_Request.h"
 
 #include "ace/Log_Msg.h"
 #include "ace/OS_NS_string.h"
@@ -13,7 +14,7 @@
 
 ACE_RCSID (tao,
            Adapter_Registry,
-           "$Id: Adapter_Registry.cpp 77636 2007-03-09 12:56:14Z johnnyw $")
+           "$Id: Adapter_Registry.cpp 81410 2008-04-24 09:22:08Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -118,7 +119,7 @@ TAO_Adapter_Registry::dispatch (TAO::ObjectKey &key,
         }
     }
 
-  if (CORBA::is_nil (forward_to))
+  if (!request.is_forwarded ())
     {
       throw ::CORBA::OBJECT_NOT_EXIST ();
     }
@@ -181,7 +182,6 @@ TAO_Adapter_Registry::find_adapter (const char *name) const
       return *i;
 
   return 0;
-
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
