@@ -4,7 +4,7 @@
 /**
  *  @file    Adapter_Registry.h
  *
- *  $Id: Adapter_Registry.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: Adapter_Registry.h 84838 2009-03-16 13:07:49Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@uci.edu)
  */
@@ -61,20 +61,17 @@ public:
    * is invoked in an innapropriate context (think shutting down the
    * POA while performing an upcall).
    */
-  void close (int wait_for_completion
-             );
+  void close (int wait_for_completion);
 
   /**
    * Verify if the close() call can be invoked in the current
    * context for *all* adapters.
    * Raise the right exception if not.
    */
-  void check_close (int wait_for_completion
-                   );
+  void check_close (int wait_for_completion);
 
   /// Insert a new adapter into the registry.
-  void insert (TAO_Adapter *adapter
-              );
+  void insert (TAO_Adapter *adapter);
 
   /**
    * Dispatch the request to all the adapters.
@@ -83,12 +80,10 @@ public:
    */
   void dispatch (TAO::ObjectKey &key,
                  TAO_ServerRequest &request,
-                 CORBA::Object_out forward_to
-                );
+                 CORBA::Object_out forward_to);
 
   /// Create a collocated object using the given profile and stub.
-  CORBA::Object_ptr create_collocated_object (TAO_Stub *,
-                                              const TAO_MProfile &);
+  CORBA::Object_ptr create_collocated_object (TAO_Stub *, const TAO_MProfile &);
 
   /// Initialize a collocated object using the given stub and object
   /// pointer for lazily evaluated object references.
@@ -109,6 +104,10 @@ private:
   size_t adapters_count_;
   TAO_Adapter **adapters_;
   //@}
+
+private:
+  ACE_UNIMPLEMENTED_FUNC (void operator= (const TAO_Adapter_Registry &))
+  ACE_UNIMPLEMENTED_FUNC (TAO_Adapter_Registry (const TAO_Adapter_Registry &))
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
