@@ -1,4 +1,4 @@
-// $Id: TypeCode_CDR_Extraction.cpp 79322 2007-08-13 10:43:10Z sma $
+// $Id: TypeCode_CDR_Extraction.cpp 84293 2009-02-02 09:16:35Z sma $
 
 #include "tao/AnyTypeCode/TypeCode_CDR_Extraction.h"
 
@@ -31,7 +31,7 @@
 
 ACE_RCSID (AnyTypeCode,
            TypeCode_CDR_Extraction,
-           "$Id: TypeCode_CDR_Extraction.cpp 79322 2007-08-13 10:43:10Z sma $")
+           "$Id: TypeCode_CDR_Extraction.cpp 84293 2009-02-02 09:16:35Z sma $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -109,6 +109,20 @@ namespace
     return true;
   }
 
+  class TAO_InputCDRByteOrderGuard
+  {
+    TAO_InputCDR &cdr_;
+    CORBA::Boolean byte_order_;
+  public:
+    TAO_InputCDRByteOrderGuard (TAO_InputCDR & cdr):
+      cdr_ (cdr),
+      byte_order_ (cdr.byte_order ()) {}
+    ~TAO_InputCDRByteOrderGuard ()
+    {
+      cdr_.reset_byte_order (byte_order_);
+    }
+  };
+
   // ---------------------------------------------------------
 
   CORBA::ULong const TYPECODE_INDIRECTION = 0xffffffffU;
@@ -324,6 +338,7 @@ TAO::TypeCodeFactory::tc_objref_factory (CORBA::TCKind kind,
 {
   // The remainder of a tk_objref TypeCode is encoded in a CDR
   // encapsulation.
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -410,6 +425,7 @@ TAO::TypeCodeFactory::tc_struct_factory (CORBA::TCKind kind,
 
   // The remainder of a tk_struct/tk_except TypeCode is encoded in
   // a CDR encapsulation.
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -453,6 +469,7 @@ TAO::TypeCodeFactory::tc_struct_factory (CORBA::TCKind kind,
 
       size_t const len = recursive_tc.size ();
 
+      bool assigned_params = false;
       for (size_t i = 0; i < len; ++i)
         {
           TAO::TypeCodeFactory::TC_Info & info = recursive_tc[i];
@@ -463,10 +480,20 @@ TAO::TypeCodeFactory::tc_struct_factory (CORBA::TCKind kind,
           if (!rtc)
             return false;  // Should never occur.
 
-          rtc->struct_parameters (name.in (), fields, nfields);
+          assigned_params |= rtc->struct_parameters (name.in (), fields, nfields);
         }
 
-      tc = recursive_tc[0].type;
+      // If no parameters were assigned then the reference in the
+      // fields variable will be released when the variable is destroyed.
+      // Increment the reference count.
+      if ( !assigned_params)
+        {
+          tc = CORBA::TypeCode::_duplicate(recursive_tc[0].type);
+        }
+      else
+        {
+          tc = recursive_tc[0].type;
+        }
     }
   else
     {
@@ -491,6 +518,7 @@ TAO::TypeCodeFactory::tc_union_factory (CORBA::TCKind /* kind */,
   // The remainder of a tk_enum TypeCode is encoded in a CDR
   // encapsulation.
 
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -632,7 +660,7 @@ TAO::TypeCodeFactory::tc_union_factory (CORBA::TCKind /* kind */,
         case CORBA::tk_boolean:
           {
             CORBA::Boolean label;
-            if (!(cdr >> CORBA::Any::to_boolean (label)))
+             if (!(cdr >> CORBA::Any::to_boolean (label)))
               return false;
 
             typedef TypeCode::Case_T<CORBA::Boolean,
@@ -665,10 +693,10 @@ TAO::TypeCodeFactory::tc_union_factory (CORBA::TCKind /* kind */,
             CORBA::ULongLong label;
             if (!(cdr >> label))
               return false;
-
+ 
             typedef TypeCode::Case_T<CORBA::ULongLong,
                                      CORBA::String_var,
-                                     CORBA::TypeCode_var> case_type;
+                                      CORBA::TypeCode_var> case_type;
 
             ACE_NEW_RETURN (the_case,
                             case_type (label),
@@ -712,6 +740,7 @@ TAO::TypeCodeFactory::tc_union_factory (CORBA::TCKind /* kind */,
 
       size_t const len = recursive_tc.size ();
 
+      bool assigned_params = false;
       for (size_t i = 0; i < len; ++i)
         {
           TAO::TypeCodeFactory::TC_Info & info = recursive_tc[i];
@@ -722,14 +751,25 @@ TAO::TypeCodeFactory::tc_union_factory (CORBA::TCKind /* kind */,
           if (!rtc)
             return false;  // Should never occur.
 
-          rtc->union_parameters (name.in (),
-                                 discriminant_type,
-                                 cases,     // Will be copied.
-                                 ncases,
-                                 default_index);
+          assigned_params |= rtc->union_parameters (name.in (),
+                                                    discriminant_type,
+                                                    cases,  // Will be copied.
+                                                    ncases,
+                                                    default_index);
+
         }
 
-      tc = recursive_tc[0].type;
+      // If no parameters were assigned then the reference in the
+      // cases variable  will be released when the variable is destroyed.
+      // Increment the reference count.
+      if ( !assigned_params)
+        {
+          tc = CORBA::TypeCode::_duplicate(recursive_tc[0].type);
+        }
+      else
+        {
+          tc = recursive_tc[0].type;
+        }
     }
   else
     {
@@ -754,7 +794,7 @@ TAO::TypeCodeFactory::tc_enum_factory (CORBA::TCKind /* kind */,
 {
   // The remainder of a tk_enum TypeCode is encoded in a CDR
   // encapsulation.
-
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -835,7 +875,7 @@ TAO::TypeCodeFactory::tc_sequence_factory (CORBA::TCKind kind,
 
   // The remainder of a tk_sequence TypeCode is encoded in a CDR
   // encapsulation.
-
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -875,7 +915,7 @@ TAO::TypeCodeFactory::tc_alias_factory (CORBA::TCKind kind,
 {
   // The remainder of a tk_alias or tk_value_box TypeCode is encoded
   // in a CDR encapsulation.
-
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -995,7 +1035,7 @@ TAO::TypeCodeFactory::tc_value_factory (CORBA::TCKind kind,
 {
   // The remainder of a tk_value/tk_event TypeCode is encoded in a
   // CDR encapsulation
-
+  TAO_InputCDRByteOrderGuard boguard (cdr);
   if (!start_cdr_encap_extraction (cdr))
     return false;
 
@@ -1050,6 +1090,7 @@ TAO::TypeCodeFactory::tc_value_factory (CORBA::TCKind kind,
         recursive_typecode_type;
 
       size_t const len = recursive_tc.size ();
+      bool assigned_params = false;
 
       for (size_t i = 0; i < len; ++i)
         {
@@ -1061,13 +1102,23 @@ TAO::TypeCodeFactory::tc_value_factory (CORBA::TCKind kind,
           if (!rtc)
             return false;  // Should never occur.
 
-          rtc->valuetype_parameters (name.in (),
-                                     type_modifier,
-                                     concrete_base,
-                                     fields,     // Will be copied.
-                                     nfields);
+          assigned_params |= rtc->valuetype_parameters (name.in (),
+                                                        type_modifier,
+                                                        concrete_base,
+                                                        fields, // Will be copied.
+                                                        nfields);
+        }
+      // If no parameters were assigned then the reference in the
+      // fields variable will be released when the variable is destroyed.
+      // Increment the reference count.
+      if ( !assigned_params)
+        {
+          tc = CORBA::TypeCode::_duplicate(recursive_tc[0].type);
+        }
+      else
+        {
+          tc = recursive_tc[0].type;
         }
-      tc = recursive_tc[0].type;
     }
   else
     {
@@ -1255,11 +1306,15 @@ namespace
              || kind == CORBA::tk_union
              || kind == CORBA::tk_value
              || kind == CORBA::tk_event
-             || kind == CORBA::tk_alias)
+             || kind == CORBA::tk_alias))
+      {
+        return false;
+      }
 
-        // Currently all recursive TypeCodes have complex parameter
-        // lists, meaning they are encoded as CDR encapsulations.
-        || !start_cdr_encap_extraction (indir_stream))
+      // Currently all recursive TypeCodes have complex parameter
+      // lists, meaning they are encoded as CDR encapsulations.
+      TAO_InputCDRByteOrderGuard boguard (indir_stream);
+      if (!start_cdr_encap_extraction (indir_stream))
       {
         return false;
       }
