@@ -1,7 +1,7 @@
-// Array_VarOut_T.cpp,v 1.6 2004/09/03 06:00:37 ossama Exp
+// $Id: Array_VarOut_T.cpp 73210 2006-06-21 12:14:14Z jwillemsen $
 
-#ifndef TAO_ARRAY_VAROUT_T_C
-#define TAO_ARRAY_VAROUT_T_C
+#ifndef TAO_ARRAY_VAROUT_T_CPP
+#define TAO_ARRAY_VAROUT_T_CPP
 
 #include "tao/Array_VarOut_T.h"
 
@@ -9,9 +9,8 @@
 #include "tao/Array_VarOut_T.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (tao,
-           Array_VarOut_T,
-           "Array_VarOut_T.cpp,v 1.6 2004/09/03 06:00:37 ossama Exp")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 template<typename T, typename T_slice, typename TAG>
 TAO_FixedArray_Var_T<T,T_slice,TAG> &
@@ -21,7 +20,7 @@ TAO_FixedArray_Var_T<T,T_slice,TAG>::operator= (T_slice * p)
   if (this->ptr_ != p)
     {
       // Delete our stuff and assume ownership of p.
-      TAO::Array_Traits<T,T_slice,TAG>::free (this->ptr_);
+      TAO::Array_Traits<FORANY>::free (this->ptr_);
       this->ptr_ = p;
     }
 
@@ -36,10 +35,10 @@ TAO_FixedArray_Var_T<T,T_slice,TAG>::operator= (
 {
   if (this != &p)
     {
-      TAO::Array_Traits<T,T_slice,TAG>::free (this->ptr_);
+      TAO::Array_Traits<FORANY>::free (this->ptr_);
 
       // Deep copy.
-      this->ptr_ = TAO::Array_Traits<T,T_slice,TAG>::dup (p.in ());
+      this->ptr_ = TAO::Array_Traits<FORANY>::dup (p.in ());
     }
 
   return *this;
@@ -55,7 +54,7 @@ TAO_VarArray_Var_T<T,T_slice,TAG>::operator= (T_slice * p)
   if (this->ptr_ != p)
     {
       // Delete our stuff and assume ownership of p.
-      TAO::Array_Traits<T,T_slice,TAG>::free (this->ptr_);
+      TAO::Array_Traits<FORANY>::free (this->ptr_);
       this->ptr_ = p;
     }
 
@@ -70,10 +69,10 @@ TAO_VarArray_Var_T<T,T_slice,TAG>::operator= (
 {
   if (this != &p)
     {
-      TAO::Array_Traits<T,T_slice,TAG>::free (this->ptr_);
+      TAO::Array_Traits<FORANY>::free (this->ptr_);
 
       // Deep copy.
-      this->ptr_ = TAO::Array_Traits<T,T_slice,TAG>::dup (p.in ());
+      this->ptr_ = TAO::Array_Traits<FORANY>::dup (p.in ());
     }
 
   return *this;
@@ -88,7 +87,9 @@ TAO_Array_Forany_T<T,T_slice,TAG>::_tao_any_destructor (
   )
 {
   T_slice * tmp = static_cast<T_slice *> (_tao_void_pointer);
-  TAO::Array_Traits<T,T_slice,TAG>::free (tmp);
+  TAO::Array_Traits<FORANY>::free (tmp);
 }
 
-#endif /* TAO_ARRAY_VAROUT_T_C */
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#endif /* TAO_ARRAY_VAROUT_T_CPP */
