@@ -12,7 +12,7 @@
 
 ACE_RCSID (tao,
            Asynch_Queued_Message,
-           "$Id: Asynch_Queued_Message.cpp 79169 2007-08-02 08:41:23Z johnnyw $")
+           "$Id: Asynch_Queued_Message.cpp 85406 2009-05-20 09:07:56Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -28,7 +28,9 @@ TAO_Asynch_Queued_Message::TAO_Asynch_Queued_Message (
   , abs_timeout_ (ACE_Time_Value::zero)
 {
   if (timeout != 0)// && *timeout != ACE_Time_Value::zero)
-    this->abs_timeout_ = ACE_High_Res_Timer::gettimeofday_hr () + *timeout;
+    {
+      this->abs_timeout_ = ACE_High_Res_Timer::gettimeofday_hr () + *timeout;
+    }
   // @@ Use a pool for these guys!!
   ACE_NEW (this->buffer_, char[this->size_]);
 
@@ -153,7 +155,7 @@ TAO_Asynch_Queued_Message::clone (ACE_Allocator *alloc)
           // This debug is for testing purposes!
           ACE_DEBUG ((LM_DEBUG,
                       "TAO (%P|%t) - Asynch_Queued_Message::clone\n"
-                      "Using global pool for allocation \n"));
+                      "Using global pool for allocation\n"));
         }
 
       ACE_NEW_RETURN (qm,
@@ -204,4 +206,10 @@ TAO_Asynch_Queued_Message::is_expired (const ACE_Time_Value &now) const
   return false;
 }
 
+void
+TAO_Asynch_Queued_Message::copy_if_necessary (const ACE_Message_Block*)
+{
+  // It's never necessary for asynchronously queued messages
+}
+
 TAO_END_VERSIONED_NAMESPACE_DECL
