@@ -1,4 +1,4 @@
-// $Id: Asynch_Reply_Dispatcher_Base.cpp 76962 2007-02-08 16:29:30Z johnnyw $
+// $Id: Asynch_Reply_Dispatcher_Base.cpp 85001 2009-03-31 10:06:45Z msmit $
 
 #include "tao/Asynch_Reply_Dispatcher_Base.h"
 #include "tao/Pluggable_Messaging_Utils.h"
@@ -12,16 +12,16 @@
 
 ACE_RCSID (tao,
            Asynch_Reply_Dispatcher_Base,
-           "$Id: Asynch_Reply_Dispatcher_Base.cpp 76962 2007-02-08 16:29:30Z johnnyw $")
+           "$Id: Asynch_Reply_Dispatcher_Base.cpp 85001 2009-03-31 10:06:45Z msmit $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // Constructor.
 TAO_Asynch_Reply_Dispatcher_Base::TAO_Asynch_Reply_Dispatcher_Base (
     TAO_ORB_Core *orb_core,
-    ACE_Allocator *allocator
-  )
-  : db_ (sizeof buf_,
+    ACE_Allocator *allocator)
+  : TAO_Reply_Dispatcher (allocator)
+  , db_ (sizeof buf_,
          ACE_Message_Block::MB_DATA,
          this->buf_,
          orb_core->input_cdr_buffer_allocator (),
@@ -36,9 +36,7 @@ TAO_Asynch_Reply_Dispatcher_Base::TAO_Asynch_Reply_Dispatcher_Base (
                 orb_core)
   , transport_ (0)
   , lock_ (0)
-  , refcount_ (1)
   , is_reply_dispatched_ (false)
-  , allocator_ (allocator)
 {
   // @@ NOTE: Need a seperate option for this..
   this->lock_ =
@@ -67,60 +65,6 @@ TAO_Asynch_Reply_Dispatcher_Base::transport (TAO_Transport *t)
   this->transport_->add_reference ();
 }
 
-// Must override pure virtual method in TAO_Reply_Dispatcher.
-int
-TAO_Asynch_Reply_Dispatcher_Base::dispatch_reply (
-    TAO_Pluggable_Reply_Params & /*params*/)
-{
-  return 0;
-}
-
-void
-TAO_Asynch_Reply_Dispatcher_Base::connection_closed (void)
-{
-}
-
-void
-TAO_Asynch_Reply_Dispatcher_Base::reply_timed_out (void)
-{
-}
-
-void
-TAO_Asynch_Reply_Dispatcher_Base::incr_refcount (void)
-{
-  ACE_GUARD (ACE_Lock,
-             mutex,
-             *this->lock_);
-  ++this->refcount_;
-}
-
-void
-TAO_Asynch_Reply_Dispatcher_Base::decr_refcount (void)
-{
-  {
-    ACE_GUARD (ACE_Lock,
-               mutex,
-               *this->lock_);
-    --this->refcount_;
-
-    if (this->refcount_ > 0)
-      return;
-  }
-
-  if (this->allocator_)
-    {
-      ACE_DES_FREE (this,
-                    this->allocator_->free,
-                    TAO_Asynch_Reply_Dispatcher_Base);
-    }
-  else
-    {
-      delete this;
-    }
-
-  return;
-}
-
 bool
 TAO_Asynch_Reply_Dispatcher_Base::try_dispatch_reply (void)
 {
