@@ -1,4 +1,4 @@
-//Base_Transport_Property.cpp,v 1.4 2004/06/02 07:38:05 ossama Exp
+//$Id: Base_Transport_Property.cpp 76572 2007-01-24 19:14:17Z johnnyw $
 
 #include "tao/Base_Transport_Property.h"
 #include "ace/OS_Memory.h"
@@ -9,40 +9,38 @@
 
 ACE_RCSID (tao,
            Base_Transport_Property,
-           "Base_Transport_Property.cpp,v 1.4 2004/06/02 07:38:05 ossama Exp")
+           "$Id: Base_Transport_Property.cpp 76572 2007-01-24 19:14:17Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Base_Transport_Property::~TAO_Base_Transport_Property (void)
 {
 }
 
-
 TAO_Transport_Descriptor_Interface *
 TAO_Base_Transport_Property::duplicate (void)
 {
   // Get a copy of the underlying endpoint
-  TAO_Endpoint *endpt = this->endpoint_->duplicate ();
+  TAO_Endpoint *const endpt = this->endpoint_->duplicate ();
   if (endpt == 0)
     return 0;
 
   // Construct a copy of our class
   TAO_Base_Transport_Property *prop = 0;
-  ACE_NEW_RETURN (prop,
-                  TAO_Base_Transport_Property (endpt,
-                                               1),
-                  0);
+  ACE_NEW_RETURN (prop, TAO_Base_Transport_Property (endpt, true), 0);
   return prop;
 }
 
 
 CORBA::Boolean
-TAO_Base_Transport_Property::is_equivalent (
-    const TAO_Transport_Descriptor_Interface *rhs)
+TAO_Base_Transport_Property::is_equivalent
+  (const TAO_Transport_Descriptor_Interface *rhs)
 {
   const TAO_Base_Transport_Property *other_desc =
     dynamic_cast<const TAO_Base_Transport_Property *> (rhs);
 
   if (other_desc == 0)
-    return 0;
+    return false;
 
   return this->endpoint_->is_equivalent (other_desc->endpoint_);
 }
@@ -53,3 +51,5 @@ TAO_Base_Transport_Property::hash (void) const
 {
   return this->endpoint_->hash ();
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
