@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    BiDir_Adapter.h
  *
- *  BiDir_Adapter.h,v 1.13 2005/07/20 07:46:42 jwillemsen Exp
+ *  $Id: BiDir_Adapter.h 78292 2007-05-09 19:20:32Z johnnyw $
  *
  *  @author  Balachandran Natarajan <parsons@cs.wustl.edu>
  */
@@ -19,17 +19,13 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/SystemException.h"
+#include "tao/TAO_Export.h"
+#include "tao/orbconf.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-class TAO_ORB_Core;
 class TAO_Policy_Validator;
 
-namespace CORBA
-{
-  class ORB;
-  typedef ORB *ORB_ptr;
-}
-
 /**
  * @class TAO_BiDir_Adapter
  *
@@ -45,10 +41,11 @@ public:
   /// The virtual destructor
   virtual ~TAO_BiDir_Adapter (void);
 
-  virtual void load_policy_validators (TAO_Policy_Validator &validator ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException)) = 0;
-
+  virtual void load_policy_validators (TAO_Policy_Validator &validator) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
+
 #endif /* TAO_BIDIR_ADAPTER_H */
