@@ -4,7 +4,7 @@
 /**
  *  @file BiDir_ORBInitializer.h
  *
- *  $Id: BiDir_ORBInitializer.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: BiDir_ORBInitializer.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author Balachandran Natarajan <bala@cs.wustl.edu>
  */
@@ -35,7 +35,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// Messaging ORB initializer.
 class TAO_BiDir_ORBInitializer
   : public virtual PortableInterceptor::ORBInitializer
-  , public virtual TAO_Local_RefCounted_Object
+  , public virtual ::CORBA::LocalObject
 {
 public:
 
