@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: Bind_Dispatcher_Guard.cpp 79829 2007-10-23 12:39:52Z johnnyw $
+// $Id: Bind_Dispatcher_Guard.cpp 82593 2008-08-11 15:39:24Z johnnyw $
 
 #include "tao/Bind_Dispatcher_Guard.h"
 
@@ -9,7 +9,7 @@
 
 ACE_RCSID (tao,
            Bind_Dispatcher_Guard,
-           "$Id: Bind_Dispatcher_Guard.cpp 79829 2007-10-23 12:39:52Z johnnyw $")
+           "$Id: Bind_Dispatcher_Guard.cpp 82593 2008-08-11 15:39:24Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -18,11 +18,10 @@ TAO_Bind_Dispatcher_Guard::TAO_Bind_Dispatcher_Guard (CORBA::ULong request_id,
                                                       TAO_Transport_Mux_Strategy *tms)
   : status_(TAO_Bind_Dispatcher_Guard::UNBIND),
     request_id_(request_id),
-    rd_(rd),
     tms_(tms)
 {
   int const retval =
-    this->tms_->bind_dispatcher (this->request_id_, this->rd_);
+    this->tms_->bind_dispatcher (this->request_id_, rd);
 
   if (retval == -1)
     this->status_ = TAO_Bind_Dispatcher_Guard::NO_UNBIND;
