@@ -1,12 +1,13 @@
-#include "Blocked_Connect_Strategy.h"
-#include "Connection_Handler.h"
+#include "tao/Blocked_Connect_Strategy.h"
+#include "tao/Connection_Handler.h"
 
 #include "ace/Synch_Options.h"
 
 ACE_RCSID(tao,
           Blocked_Connect_Strategy,
-          "Blocked_Connect_Strategy.cpp,v 1.6 2004/08/09 11:52:49 jwillemsen Exp")
+          "$Id: Blocked_Connect_Strategy.cpp 73141 2006-06-20 06:07:59Z jwillemsen $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Blocked_Connect_Strategy::TAO_Blocked_Connect_Strategy (
     TAO_ORB_Core *orb_core)
@@ -14,11 +15,6 @@ TAO_Blocked_Connect_Strategy::TAO_Blocked_Connect_Strategy (
 {
 }
 
-TAO_Blocked_Connect_Strategy::~TAO_Blocked_Connect_Strategy (void)
-{
-}
-
-
 void
 TAO_Blocked_Connect_Strategy::synch_options (ACE_Time_Value *timeout,
                                              ACE_Synch_Options &options)
@@ -37,19 +33,13 @@ TAO_Blocked_Connect_Strategy::synch_options (ACE_Time_Value *timeout,
     }
 }
 
-
 int
-TAO_Blocked_Connect_Strategy::wait (TAO_Connection_Handler *,
-                                    ACE_Time_Value * )
+TAO_Blocked_Connect_Strategy::wait_i (TAO_LF_Event *,
+                                      TAO_Transport *,
+                                      ACE_Time_Value * )
 {
   // We cannot wait for connection completion
   return -1;
 }
 
-int
-TAO_Blocked_Connect_Strategy::wait (TAO_Transport *,
-                                    ACE_Time_Value *)
-{
-  // We cannot wait for connection completion
-  return -1;
-}
+TAO_END_VERSIONED_NAMESPACE_DECL
