@@ -4,7 +4,7 @@
 /**
  *  @file Blocked_Connect_Strategy.h
  *
- *  Blocked_Connect_Strategy.h,v 1.7 2004/08/09 11:52:49 jwillemsen Exp
+ *  $Id: Blocked_Connect_Strategy.h 73141 2006-06-20 06:07:59Z jwillemsen $
  *
  *  @author Balachandran Natarajan <bala@cs.wustl.edu>
  */
@@ -14,12 +14,14 @@
 #define TAO_BLOCKED_CONNECT_STRATEGY_H
 #include /**/ "ace/pre.h"
 
-#include "Connect_Strategy.h"
+#include "tao/Connect_Strategy.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Blocked_Connect_Strategy
  *
@@ -27,16 +29,12 @@
  *  during connects
  *
  */
-
 class TAO_Export TAO_Blocked_Connect_Strategy : public TAO_Connect_Strategy
 {
 public:
-  /// Contructor
+  /// Constructor
   TAO_Blocked_Connect_Strategy (TAO_ORB_Core *orb);
 
-  /// Destructor
-  ~TAO_Blocked_Connect_Strategy (void);
-
   /*
    * Concrete implementation for this class. Please see
    * Connect_Strategy.h for details
@@ -44,13 +42,14 @@ public:
   virtual void synch_options (ACE_Time_Value *val,
                               ACE_Synch_Options &opt);
 
-  virtual int wait (TAO_Connection_Handler *ch,
+protected:
+  virtual int wait_i (TAO_LF_Event *ev,
+                      TAO_Transport *t,
                      ACE_Time_Value *val);
 
-  virtual int wait (TAO_Transport *t,
-                     ACE_Time_Value *val);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 #endif /*TAO_BLOCKED_CONNECT_STRATEGY_H*/
