@@ -6,7 +6,7 @@
  * @brief Details can be found in the documentation for
  * TAO::details::generic_sequence
  *
- * $Id: Bounded_Reference_Allocation_Traits_T.h 79349 2007-08-15 11:21:50Z johnnyw $
+ * $Id: Bounded_Reference_Allocation_Traits_T.h 84506 2009-02-18 11:15:38Z vzykov $
  *
  * @author Carlos O'Ryan
  */
@@ -37,6 +37,15 @@ struct bounded_reference_allocation_traits
   }
 
   inline static value_type * allocbuf(CORBA::ULong /* maximum */)
+  {
+    value_type * buffer = new value_type[MAX];
+    // no throw
+    reference_traits::initialize_range(buffer, buffer + MAX);
+
+    return buffer;
+  }
+
+  inline static value_type * allocbuf_noinit(CORBA::ULong /* maximum */)
   {
     value_type * buffer = new value_type[MAX];
     // no throw
