@@ -5,13 +5,14 @@
  *
  * @brief Extract the sequence
  *
- * $Id: Bounded_Sequence_CDR_T.h 77525 2007-03-05 11:02:51Z johnnyw $
+ * $Id: Bounded_Sequence_CDR_T.h 86953 2009-10-06 10:13:34Z vzykov $
  *
  * @author Carlos O'Ryan
  * @author Johnny Willemsen
  */
 
 #include "tao/orbconf.h"
+#include "tao/SystemException.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -198,6 +199,26 @@ namespace TAO {
     return true;
   }
 
+  template <typename stream, CORBA::ULong MAX>
+  bool demarshal_sequence(stream & strm, TAO::bounded_value_sequence <CORBA::LongLong, MAX> & target) {
+    typedef TAO::bounded_value_sequence <CORBA::LongLong, MAX> sequence;
+    ::CORBA::ULong new_length = 0;
+    if (!(strm >> new_length)) {
+      return false;
+    }
+    if ((new_length > strm.length()) || (new_length > target.maximum ())) {
+      return false;
+    }
+    sequence tmp;
+    tmp.length(new_length);
+    typename sequence::value_type * buffer = tmp.get_buffer();
+    if (!strm.read_longlong_array (buffer, new_length)) {
+      return false;
+    }
+    tmp.swap(target);
+    return true;
+  }
+
   template <typename stream, CORBA::ULong MAX>
   bool demarshal_sequence(stream & strm, TAO::bounded_value_sequence <CORBA::ULongLong, MAX> & target) {
     typedef TAO::bounded_value_sequence <CORBA::ULongLong, MAX> sequence;
@@ -284,6 +305,7 @@ namespace TAO {
   bool demarshal_sequence(stream & strm, TAO::bounded_basic_string_sequence <charT, MAX> & target) {
     typedef typename TAO::bounded_basic_string_sequence <charT, MAX> sequence;
     typedef typename sequence::element_traits::string_var string_var;
+    typedef typename sequence::allocation_traits sequence_allocation_traits;
     ::CORBA::ULong new_length = 0;
     if (!(strm >> new_length)) {
       return false;
@@ -291,8 +313,9 @@ namespace TAO {
     if ((new_length > strm.length()) || (new_length > target.maximum ())) {
       return false;
     }
-    sequence tmp;
-    tmp.length(new_length);
+    sequence tmp(new_length,
+                 sequence_allocation_traits::allocbuf_noinit(new_length),
+                 true);
     for(CORBA::ULong i = 0; i < new_length; ++i) {
       string_var string;
       if (!(strm >> string.inout ())) {
@@ -306,9 +329,11 @@ namespace TAO {
     return true;
   }
 
-  template <typename stream, typename object_t, typename object_t_var, CORBA::ULong MAX>
-  bool demarshal_sequence(stream & strm, TAO::bounded_object_reference_sequence<object_t, object_t_var, MAX> & target) {
-    typedef typename TAO::bounded_object_reference_sequence<object_t, object_t_var, MAX> sequence;
+  template <typename stream, typename charT, CORBA::ULong MAX, CORBA::ULong BD_STR_MAX>
+  bool demarshal_sequence(stream & strm, TAO::bounded_bd_string_sequence <charT, MAX, BD_STR_MAX> & target) {
+    typedef typename TAO::bounded_bd_string_sequence <charT, MAX, BD_STR_MAX> sequence;
+    typedef typename sequence::element_traits::string_var string_var;
+    typedef typename sequence::allocation_traits sequence_allocation_traits;
     ::CORBA::ULong new_length = 0;
     if (!(strm >> new_length)) {
       return false;
@@ -316,8 +341,40 @@ namespace TAO {
     if ((new_length > strm.length()) || (new_length > target.maximum ())) {
       return false;
     }
-    sequence tmp;
-    tmp.length(new_length);
+    sequence tmp(new_length,
+                 sequence_allocation_traits::allocbuf_noinit(new_length),
+                 true);
+    for(CORBA::ULong i = 0; i < new_length; ++i) {
+      string_var string;
+      if (!(strm >> string.inout ())) {
+        return false;
+      }
+      else {
+        if (string.in () != 0 &&
+            ACE_OS::strlen (string.in ()) > tmp.bd_string_maximum ()) {
+          throw ::CORBA::BAD_PARAM ();
+        }
+        tmp[i] = string._retn ();
+      }
+    }
+    tmp.swap(target);
+    return true;
+  }
+
+  template <typename stream, typename object_t, typename object_t_var, CORBA::ULong MAX>
+  bool demarshal_sequence(stream & strm, TAO::bounded_object_reference_sequence<object_t, object_t_var, MAX> & target) {
+    typedef typename TAO::bounded_object_reference_sequence<object_t, object_t_var, MAX> sequence;
+    typedef typename sequence::allocation_traits sequence_allocation_traits;
+    ::CORBA::ULong new_length = 0;
+    if (!(strm >> new_length)) {
+      return false;
+    }
+    if ((new_length > strm.length()) || (new_length > target.maximum ())) {
+      return false;
+    }
+    sequence tmp(new_length,
+                 sequence_allocation_traits::allocbuf_noinit(new_length),
+                 true);
     typename sequence::value_type * buffer = tmp.get_buffer();
     for(CORBA::ULong i = 0; i < new_length; ++i) {
       if (!(strm >> buffer[i])) {
@@ -333,7 +390,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Short, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_short_array (source.get_buffer (), length);
@@ -342,7 +399,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Long, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_long_array (source.get_buffer (), length);
@@ -351,7 +408,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::ULong, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_ulong_array (source.get_buffer (), length);
@@ -360,7 +417,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::UShort, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_ushort_array (source.get_buffer (), length);
@@ -369,7 +426,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Octet, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_octet_array (source.get_buffer (), length);
@@ -378,7 +435,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Char, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_char_array (source.get_buffer (), length);
@@ -388,7 +445,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::WChar, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_wchar_array (source.get_buffer (), length);
@@ -398,7 +455,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Float, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_float_array (source.get_buffer (), length);
@@ -407,16 +464,25 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Double, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_double_array (source.get_buffer (), length);
   }
 
+  template <typename stream, CORBA::ULong MAX>
+  bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::LongLong, MAX> & source) {
+    ::CORBA::ULong const length = source.length ();
+    if (length > source.maximum () || !(strm << length)) {
+      return false;
+    }
+    return strm.write_longlong_array (source.get_buffer (), length);
+  }
+
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::ULongLong, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_ulonglong_array (source.get_buffer (), length);
@@ -425,7 +491,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::LongDouble, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_longdouble_array (source.get_buffer (), length);
@@ -434,7 +500,7 @@ namespace TAO {
   template <typename stream, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <CORBA::Boolean, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     return strm.write_boolean_array (source.get_buffer (), length);
@@ -443,7 +509,7 @@ namespace TAO {
   template <typename stream, typename value_t, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_value_sequence <value_t, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     for(CORBA::ULong i = 0; i < length; ++i) {
@@ -457,7 +523,7 @@ namespace TAO {
   template <typename stream, typename charT, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_basic_string_sequence <charT, MAX> & source) {
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     for(CORBA::ULong i = 0; i < length; ++i) {
@@ -468,11 +534,29 @@ namespace TAO {
     return true;
   }
 
+  template <typename stream, typename charT, CORBA::ULong MAX, CORBA::ULong BD_STR_MAX>
+  bool marshal_sequence(stream & strm, const TAO::bounded_bd_string_sequence <charT, MAX, BD_STR_MAX> & source) {
+    ::CORBA::ULong const length = source.length ();
+    if (length > source.maximum () || !(strm << length)) {
+      return false;
+    }
+    for(CORBA::ULong i = 0; i < length; ++i) {
+      if (source[i].in () != 0 &&
+          ACE_OS::strlen (source[i]) > source.bd_string_maximum ()) {
+        throw ::CORBA::BAD_PARAM ();
+      }
+      if (!(strm << source[i])) {
+        return false;
+      }
+    }
+    return true;
+  }
+
   template <typename stream, typename object_t, typename object_t_var, CORBA::ULong MAX>
   bool marshal_sequence(stream & strm, const TAO::bounded_object_reference_sequence<object_t, object_t_var, MAX> & source) {
     typedef typename TAO::bounded_object_reference_sequence<object_t, object_t_var, MAX>::object_type object_type;
     ::CORBA::ULong const length = source.length ();
-    if (!(strm << length)) {
+    if (length > source.maximum () || !(strm << length)) {
       return false;
     }
     for(CORBA::ULong i = 0; i < length; ++i) {
