@@ -3,7 +3,7 @@
 /**
  *  @file    CORBA_methods.h
  *
- *  $Id: CORBA_methods.h 76872 2007-02-02 13:41:21Z johnnyw $
+ *  $Id: CORBA_methods.h 81865 2008-06-09 11:50:30Z sma $
  *
  *  Declarations of common methods in the CORBA namespace.
  *
@@ -55,6 +55,15 @@ namespace CORBA
   extern TAO_Export ORB_ptr ORB_init (int & argc,
                                       char * argv[],
                                       const char * orb_name = 0);
+#if defined (ACE_USES_WCHAR)
+  extern TAO_Export ORB_ptr ORB_init (int & argc,
+                                      wchar_t * argv[],
+                                      const char * orb_name = 0);
+
+  extern TAO_Export ORB_ptr ORB_init (int & argc,
+                                      wchar_t * argv[],
+                                      const wchar_t * orb_name);
+#endif
 
   TAO_NAMESPACE_INLINE_FUNCTION Boolean is_nil (Environment_ptr);
   TAO_NAMESPACE_INLINE_FUNCTION void release (Environment_ptr);
