@@ -1,4 +1,4 @@
-// $Id: CSD_FW_Server_Request_Wrapper.cpp 79705 2007-09-24 07:45:37Z johnnyw $
+// $Id: CSD_FW_Server_Request_Wrapper.cpp 81140 2008-03-28 09:19:19Z vzykov $
 #include "tao/CSD_Framework/CSD_FW_Server_Request_Wrapper.h"
 #include "tao/debug.h"
 #include "tao/ORB_Constants.h"
@@ -9,7 +9,7 @@
 
 ACE_RCSID (CSD_Framework,
            FW_Server_Request_Wrapper,
-           "$Id: CSD_FW_Server_Request_Wrapper.cpp 79705 2007-09-24 07:45:37Z johnnyw $")
+           "$Id: CSD_FW_Server_Request_Wrapper.cpp 81140 2008-03-28 09:19:19Z vzykov $")
 
 #if !defined (__ACE_INLINE__)
 # include "tao/CSD_Framework/CSD_FW_Server_Request_Wrapper.inl"
@@ -177,6 +177,10 @@ TAO::CSD::FW_Server_Request_Wrapper::clone (TAO_ServerRequest*& request)
   // ACTION: Assignment performs reference-counted copy of object ref.
   clone_obj->forward_location_ = request->forward_location_;
 
+  // TYPE: bool
+  // ACTION: Primitive data type assignment
+  clone_obj->is_forwarded_ = request->is_forwarded_;
+
   // TYPE: TAO_InputCDR*
   // ACTION: This *must* be "cloned".
   if (request->incoming_ != 0)
