@@ -4,7 +4,7 @@
 /**
  *  @file CSD_ORBInitializer.h
  *
- *  $Id: CSD_ORBInitializer.h 78787 2007-07-05 08:02:28Z johnnyw $
+ *  $Id: CSD_ORBInitializer.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -38,7 +38,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_CSD_ORBInitializer
   : public virtual PortableInterceptor::ORBInitializer
-  , public virtual TAO_Local_RefCounted_Object
+  , public virtual ::CORBA::LocalObject
 {
 public:
   virtual void pre_init (PortableInterceptor::ORBInitInfo_ptr info);
