@@ -4,7 +4,7 @@
 /**
  *  @file   Cleanup_Func_Registry.h
  *
- *  Cleanup_Func_Registry.h,v 1.7 2005/05/30 12:24:57 jwillemsen Exp
+ *  $Id: Cleanup_Func_Registry.h 78190 2007-04-25 08:52:32Z johnnyw $
  *
  *  @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -15,14 +15,19 @@
 
 #include /**/ "ace/pre.h"
 
-#include "TAO_Export.h"
+#include /**/ "tao/TAO_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include /**/ "tao/Versioned_Namespace.h"
+
 #include "ace/Array_Base.h"
 
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Cleanup_Func_Registry
  *
@@ -32,18 +37,15 @@
  * invoking the corresponding cleanup function on each object.  Hence,
  * there is a tight coupling between this class and the TAO ORB Core.
  */
-class TAO_Export TAO_Cleanup_Func_Registry
+class TAO_Cleanup_Func_Registry
 {
   friend class TAO_ORB_Core;
 
 public:
 
-  /// Constructor
+  /// Constructor.
   TAO_Cleanup_Func_Registry (void);
 
-  /// Destructor
-  ~TAO_Cleanup_Func_Registry (void);
-
   /// Return the number of registered cleanup functions.
   size_t size (void) const;
 
@@ -54,8 +56,7 @@ protected:
   /// corresponding thread specific object in the ORB Core TSS
   /// resources.  The slot_id is returned via the second reference
   /// argument.  This method returns 0 on failure, and -1 on failure.
-  int register_cleanup_function (ACE_CLEANUP_FUNC func,
-                                 size_t &slot_id);
+  int register_cleanup_function (ACE_CLEANUP_FUNC func, size_t &slot_id);
 
   /// Invoke the corresponding cleanup function on each
   /// thread-specific object.
@@ -65,9 +66,8 @@ private:
 
   /// Prevent copying through the copy constructor and the assignment
   /// operator.
-  ACE_UNIMPLEMENTED_FUNC (
-    TAO_Cleanup_Func_Registry (const TAO_Cleanup_Func_Registry &))
-  ACE_UNIMPLEMENTED_FUNC (void operator= (const TAO_Cleanup_Func_Registry &))
+  TAO_Cleanup_Func_Registry (const TAO_Cleanup_Func_Registry &);
+  void operator= (const TAO_Cleanup_Func_Registry &);
 
 private:
 
@@ -79,8 +79,10 @@ private:
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-# include "Cleanup_Func_Registry.inl"
+# include "tao/Cleanup_Func_Registry.inl"
 #endif  /* __ACE_INLINE__ */
 
 
