@@ -4,7 +4,7 @@
 /**
  *  @file    ClientRequestInterceptor_Adapter.h
  *
- *  $Id: ClientRequestInterceptor_Adapter.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: ClientRequestInterceptor_Adapter.h 85371 2009-05-18 13:39:38Z sma $
  *
  *   This file an adapter class to simplify the support of
  *   interceptors.
@@ -21,6 +21,7 @@
 #include /**/ "ace/pre.h"
 
 #include /**/ "tao/TAO_Export.h"
+#include "tao/RequestInterceptor_Adapter.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -61,6 +62,7 @@ namespace TAO
    * specification/chapter.
    */
   class TAO_Export ClientRequestInterceptor_Adapter
+    : public RequestInterceptor_Adapter
   {
   public:
     virtual ~ClientRequestInterceptor_Adapter (void);
@@ -99,13 +101,10 @@ namespace TAO
       PortableInterceptor::ClientRequestInterceptor_ptr interceptor,
       const CORBA::PolicyList& policies) = 0;
 
-    virtual void destroy_interceptors (void) = 0;
-
     /// Convert TAO Invocation status to a PI status
-    virtual PortableInterceptor::ReplyStatus reply_status (
+    virtual PortableInterceptor::ReplyStatus pi_reply_status (
       TAO::Invocation_Base const &invocation_base) = 0;
   };
-
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
