@@ -4,7 +4,7 @@
 /**
  * @file CDR_Encaps_Codec.h
  *
- * $Id: CDR_Encaps_Codec.h 77455 2007-02-28 12:43:12Z johnnyw $
+ * $Id: CDR_Encaps_Codec.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  * @author Ossama Othman <ossama@uci.edu>
  */
@@ -45,7 +45,7 @@ class TAO_Codeset_Translator_Base;
  */
 class TAO_CDR_Encaps_Codec
   : public virtual IOP::Codec,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
 
