@@ -1,11 +1,10 @@
-/* -*- C++ -*- */
-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Codeset.h
  *
- *  Codeset.h,v 1.1 2005/07/15 03:38:23 mesnier_p Exp
+ *  $Id: Codeset.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -17,12 +16,15 @@
 
 #include /**/ "ace/pre.h"
 
-#include "codeset_export.h"
+#include "tao/Codeset/codeset_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Codeset_Export TAO_Codeset_Initializer
 {
@@ -34,6 +36,8 @@ public:
 static int
 TAO_Requires_Codeset_Initializer = TAO_Codeset_Initializer::init ();
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_CODESET_H */
