@@ -4,7 +4,7 @@
 /**
  *  @file   Codeset_Descriptor.h
  *
- *  Codeset_Descriptor.h,v 1.1 2005/07/17 21:50:46 mesnier_p Exp
+ *  $Id: Codeset_Descriptor.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  @author Phil Mesnier
  */
@@ -15,7 +15,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "codeset_export.h"
+#include "tao/Codeset/codeset_export.h"
 #include "ace/CDR_Base.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
@@ -24,6 +24,8 @@
 
 #include "tao/Codeset_Descriptor_Base.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_Codeset_Translator_Factory;
 
 class TAO_Codeset_Export TAO_Codeset_Descriptor
@@ -56,6 +58,8 @@ private:
   Translator_Node *trans_base_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_CODESET_DESCRIPTOR_H */
