@@ -1,4 +1,4 @@
-// $Id: Codeset_Manager_i.cpp 79259 2007-08-08 12:29:57Z johnnyw $
+// $Id: Codeset_Manager_i.cpp 84860 2009-03-17 10:17:38Z johnnyw $
 
 #include "tao/TAO_Server_Request.h"
 #include "tao/operation_details.h"
@@ -14,6 +14,7 @@
 #include "tao/Codeset/Codeset_Translator_Factory.h"
 #include "tao/Codeset/Codeset.h"
 #include "tao/Codeset/CodeSetContextC.h"
+#include "tao/Codeset/Codeset_Service_Context_Handler.h"
 
 #include "ace/Dynamic_Service.h"
 #include "ace/Codeset_Registry.h"
@@ -23,7 +24,7 @@
 
 ACE_RCSID (Codeset,
            Codeset_Manager_i,
-           "$Id: Codeset_Manager_i.cpp 79259 2007-08-08 12:29:57Z johnnyw $")
+           "$Id: Codeset_Manager_i.cpp 84860 2009-03-17 10:17:38Z johnnyw $")
 
 
 // These numbers are assigned by the OpenGroup, a database is
@@ -207,11 +208,15 @@ TAO_Codeset_Manager_i::process_service_context (TAO_ServerRequest &request)
     }
   if (TAO_debug_level > 2)
     {
+      ACE_CString tcs_c_locale;
+      ACE_CString tcs_w_locale;
+      ACE_Codeset_Registry::registry_to_locale (tcs_c, tcs_c_locale, 0, 0);
+      ACE_Codeset_Registry::registry_to_locale (tcs_w, tcs_w_locale, 0, 0);
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - Codeset_Manager_i::")
                   ACE_TEXT ("process_service_context, ")
-                  ACE_TEXT ("using tcsc = %08x, tcsw = %08x\n"),
-                  tcs_c,tcs_w));
+                  ACE_TEXT ("using tcsc <%C> (%08x), tcsw <%C> (%08x)\n"),
+                  tcs_c_locale.c_str (), tcs_c, tcs_w_locale.c_str (), tcs_w));
     }
 
   request.transport()->char_translator(this->get_char_trans (tcs_c));
@@ -241,19 +246,26 @@ TAO_Codeset_Manager_i::generate_service_context (TAO_Operation_Details &opd,
 
   if (TAO_debug_level > 2)
     {
+      ACE_CString tcs_c_locale;
+      ACE_CString tcs_w_locale;
+      ACE_Codeset_Registry::registry_to_locale (codeset_cntx.char_data, tcs_c_locale, 0, 0);
+      ACE_Codeset_Registry::registry_to_locale (codeset_cntx.wchar_data, tcs_w_locale, 0, 0);
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - Codeset_Manager_i::")
                   ACE_TEXT ("generate_service_context, ")
-                  ACE_TEXT ("using tcs_c = %08x, tcs_w = %08x\n"),
+                  ACE_TEXT ("using tcs_c <%C> (%08x), tcs_w <%C> (%08x)\n"),
+                  tcs_c_locale.c_str (),
                   codeset_cntx.char_data,
+                  tcs_w_locale.c_str (),
                   codeset_cntx.wchar_data));
     }
 
   TAO_OutputCDR codeset_cdr;
-  codeset_cdr << TAO_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER);
-  codeset_cdr << codeset_cntx;
-
-  service_cntx.set_context (IOP::CodeSets,codeset_cdr);
+  if ((codeset_cdr << TAO_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER)) &&
+      (codeset_cdr << codeset_cntx))
+    {
+      service_cntx.set_context (IOP::CodeSets,codeset_cdr);
+    }
 }
 
 /// Checks whether the NCS is a part of CCS
@@ -301,7 +313,7 @@ TAO_Codeset_Manager_i::isCompatible(CONV_FRAME::CodeSetId cs1,
 /// returns the TCS for Char / Wchar
 CONV_FRAME::CodeSetId
 TAO_Codeset_Manager_i::computeTCS (CONV_FRAME::CodeSetComponent &remote,
-                                   CONV_FRAME::CodeSetComponent &local )
+                                   CONV_FRAME::CodeSetComponent &local)
 {
   if (remote.native_code_set == local.native_code_set)
     {
@@ -336,7 +348,7 @@ TAO_Codeset_Manager_i::computeTCS (CONV_FRAME::CodeSetComponent &remote,
 }
 
 void
-TAO_Codeset_Manager_i::open(void)
+TAO_Codeset_Manager_i::open(TAO_ORB_Core& core)
 {
 #if 0
   // These translators help comply with the CORBA 3.0.2 specifcation
@@ -375,6 +387,11 @@ TAO_Codeset_Manager_i::open(void)
                     ));
     }
 #endif
+  //
+  TAO_Codeset_Service_Context_Handler* h = 0;
+  ACE_NEW (h,
+           TAO_Codeset_Service_Context_Handler());
+  core.service_context_registry ().bind (IOP::CodeSets, h);
 
   // add in from the service configurator
   this->codeset_info_.ForCharData.native_code_set =
@@ -419,7 +436,7 @@ TAO_Codeset_Manager_i::init_ccs (TAO_Codeset_Descriptor& cd,
     {
       tlist->translator_factory_ =
         ACE_Dynamic_Service<TAO_Codeset_Translator_Factory>::instance
-        (ACE_TEXT_ALWAYS_CHAR (tlist->name_));
+        (tlist->name_);
 
       if (tlist->translator_factory_ == 0)
         {
