@@ -4,7 +4,7 @@
 /*
  *  @file Codeset_Manager_i.h
  *
- *  $Id: Codeset_Manager_i.h 72380 2006-04-26 21:21:54Z jeliazkov_i $
+ *  $Id: Codeset_Manager_i.h 84860 2009-03-17 10:17:38Z johnnyw $
  *
  *  Interface for the TAO CodeSet Manager.
  *
@@ -94,7 +94,7 @@ public:
   /// initialization.  This will traverse the list of named codeset
   /// translator factories and add any of those that have a native
   /// codeset id matching the manager's native codeset id.
-  void open(void);
+  void open(TAO_ORB_Core& core);
 
   virtual TAO_Codeset_Descriptor_Base *char_codeset_descriptor (void);
   virtual TAO_Codeset_Descriptor_Base *wchar_codeset_descriptor (void);
