@@ -1,4 +1,4 @@
-// $Id: UTF16_BOM_Translator.cpp 73646 2006-07-19 13:20:57Z elliott_c $
+// $Id: UTF16_BOM_Translator.cpp 82545 2008-08-06 19:15:30Z parsons $
 
 // ============================================================================
 //    Manages the transformation between native and transmitted UTF-16. It is
@@ -19,7 +19,7 @@
 
 ACE_RCSID (Codeset,
            TAO_UTF16_BOM_Translator,
-           "$Id: UTF16_BOM_Translator.cpp 73646 2006-07-19 13:20:57Z elliott_c $")
+           "$Id: UTF16_BOM_Translator.cpp 82545 2008-08-06 19:15:30Z parsons $")
 
 
   // ****************************************************************
@@ -360,14 +360,19 @@ TAO_UTF16_BOM_Translator::write_wstring (ACE_OutputCDR & cdr,
     {
       // pre GIOP 1.2:  include null terminator in length
       ACE_CDR::ULong l = len + 1;
+      
       if (this->write_4 (cdr, &l))
-        if (x != 0)
-          return this->write_wchar_array_i (cdr, x, len + 1);
-        else
-          {
-            ACE_UTF16_T s = 0;
-            return this->write_2 (cdr,&s);
-          }
+        {
+          if (x != 0)
+            {
+              return this->write_wchar_array_i (cdr, x, len + 1);
+            }
+          else
+            {
+              ACE_UTF16_T s = 0;
+              return this->write_2 (cdr,&s);
+            }
+        }
     }
 
   return 0;
