@@ -4,7 +4,7 @@
 /**
  *  @file   ZlibCompressor.h
  *
- *  $Id: ZlibCompressor.h 77779 2007-03-23 11:48:02Z johnnyw $
+ *  $Id: ZlibCompressor.h 82351 2008-07-22 08:15:32Z johnnyw $
  *
  *  See http://www.zlib.net/manual.html for the zlib interface itself
  *
@@ -37,12 +37,12 @@ namespace TAO
                       ::Compression::CompressorFactory_ptr compressor_factory);
 
       virtual void compress (
-          const ::CORBA::OctetSeq & source,
-          ::CORBA::OctetSeq & target);
+          const ::Compression::Buffer & source,
+          ::Compression::Buffer & target);
 
       virtual void decompress (
-          const ::CORBA::OctetSeq & source,
-          ::CORBA::OctetSeq & target);
+          const ::Compression::Buffer & source,
+          ::Compression::Buffer & target);
   };
 }
 
