@@ -4,7 +4,7 @@
 /**
  *  @file    Condition.h
  *
- *  $Id: Condition.h 71473 2006-03-10 07:19:20Z jtc $
+ *  $Id: Condition.h 84489 2009-02-17 14:04:16Z johnnyw $
  *
  *  @author From ACE to TAO by Balachandran Natarajan <bala@cs.wustl.edu>
  */
@@ -36,7 +36,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  * @brief Same as to the ACE_Condition variable wrapper
  *
  * This class differs from ACE_Condition in that it uses a
- * TAO_SYNCH_CONDITION instead of ACE_cond_t  under the hood to
+ * TAO_SYNCH_CONDITION instead of ACE_cond_t under the hood to
  * provide blocking.
  */
 template <class MUTEX>
@@ -99,7 +99,7 @@ private:
   MUTEX *mutex_;
 
   /// A flag to indicate whether the lock needs to be deleted.
-  int delete_lock_;
+  bool delete_lock_;
 
   /// Condition variable.
   TAO_SYNCH_CONDITION *cond_;
