@@ -1,8 +1,10 @@
+// -*- C++ -*-
+
 // ================================================================
 /**
  *  @file   Connection_Purging_Strategy.h
  *
- *  Connection_Purging_Strategy.h,v 1.7 2003/10/28 18:29:13 bala Exp
+ *  $Id: Connection_Purging_Strategy.h 74014 2006-08-14 13:52:22Z johnnyw $
  *
  *  @author Chad Elliott (elliott_c@ociweb.com)
  */
@@ -13,12 +15,16 @@
 
 #include /**/ "ace/pre.h"
 
-#include "TAO_Export.h"
+#include /**/ "tao/TAO_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include /**/ "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_Transport;
 
 // ****************************************************************
@@ -52,6 +58,8 @@ private:
   int cache_maximum_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
 # include "tao/Connection_Purging_Strategy.inl"
 #endif /* __ACE_INLINE__ */
