@@ -1,12 +1,12 @@
 // -*- C++ -*-
 //
-// $Id: DynUnion_i.h 77779 2007-03-23 11:48:02Z johnnyw $
+// $Id: DynUnion_i.h 81429 2008-04-24 18:49:54Z johnnyw $
 
 //=============================================================================
 /**
  *  @file    DynUnion_i.h
  *
- *  $Id: DynUnion_i.h 77779 2007-03-23 11:48:02Z johnnyw $
+ *  $Id: DynUnion_i.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author Jeff Parsons <parsons@cs.wustl.edu>
  */
@@ -41,7 +41,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 class TAO_DynamicAny_Export TAO_DynUnion_i
   : public virtual DynamicAny::DynUnion,
     public virtual TAO_DynCommon,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
   /// Constructor.
