@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    DII_Invocation.h
  *
- *  DII_Invocation.h,v 1.17 2005/06/24 12:34:00 jwillemsen Exp
+ *  $Id: DII_Invocation.h 80108 2007-11-27 11:22:38Z johnnyw $
  *
  *  @brief The DII invocation classes.
  *
@@ -16,9 +16,10 @@
 
 #ifndef TAO_DII_INVOCATION_H
 #define TAO_DII_INVOCATION_H
+
 #include /**/ "ace/pre.h"
 
-#include "dynamicinterface_export.h"
+#include "tao/DynamicInterface/dynamicinterface_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 #  pragma once
@@ -27,12 +28,18 @@
 #include "tao/Synch_Invocation.h"
 #include "tao/Messaging/Asynch_Invocation.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_DII_Deferred_Reply_Dispatcher;
+class TAO_DII_Asynch_Reply_Dispatcher;
+
+namespace Dynamic
+{
+  class ParameterList;
+}
 
 namespace TAO
 {
-  /**
-   */
   class TAO_DynamicInterface_Export DII_Invocation:
     public Synch_Twoway_Invocation
   {
@@ -47,23 +54,14 @@ namespace TAO
                     bool response_expected = true);
 
 #if TAO_HAS_INTERCEPTORS ==1
-    virtual Dynamic::ParameterList *arguments (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+    virtual Dynamic::ParameterList *arguments (void);
 #endif /*TAO_HAS_INTERCEPTORS == 1*/
 
-    Invocation_Status remote_invocation (
-        ACE_Time_Value *max_wait_time
-        ACE_ENV_ARG_DECL
-      )
-      ACE_THROW_SPEC ((CORBA::Exception));
+    Invocation_Status remote_invocation (ACE_Time_Value *max_wait_time);
+
+    virtual Invocation_Status handle_user_exception (TAO_InputCDR &cdr);
 
-    virtual Invocation_Status handle_user_exception (
-        TAO_InputCDR &cdr
-        ACE_ENV_ARG_DECL
-      )
-      ACE_THROW_SPEC ((CORBA::Exception));
   private:
-
     CORBA::ExceptionList *excp_list_;
 
     /// Back pointer to the DII request that created us.
@@ -71,12 +69,8 @@ namespace TAO
 
   };
 
-
-  /*
-   *
-   */
-  class TAO_DynamicInterface_Export DII_Deferred_Invocation :
-    public Asynch_Remote_Invocation
+  class TAO_DynamicInterface_Export DII_Deferred_Invocation
+    : public Asynch_Remote_Invocation
   {
   public:
     friend class DII_Deferred_Invocation_Adapter;
@@ -89,23 +83,55 @@ namespace TAO
                              bool response_expected = true);
 
 #if TAO_HAS_INTERCEPTORS ==1
-    virtual Dynamic::ParameterList *arguments (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException));
+    virtual Dynamic::ParameterList *arguments (void);
 #endif /*TAO_HAS_INTERCEPTORS == 1*/
 
-    Invocation_Status remote_invocation (
-        ACE_Time_Value *max_wait_time
-        ACE_ENV_ARG_DECL
-      )
-      ACE_THROW_SPEC ((CORBA::Exception));
+    Invocation_Status remote_invocation (ACE_Time_Value *max_wait_time);
 
   private:
-
     /// Back pointer to the DII request that created us.
     CORBA::Request_ptr host_;
-
   };
+
+  /**
+   * @class TAO_GIOP_DII_Asynch_Invocation
+   *
+   * @brief This class is responsible to send the asynchronous
+   * invocation.
+   *
+   * This class is responsible to send the asynchronous
+   * invocation. This class connects (or looks up a connection from the cache)
+   * to the remote server, builds the CDR stream for the Request, send
+   * the CDR stream and returns.
+   *
+   */
+  class TAO_DynamicInterface_Export TAO_GIOP_DII_Asynch_Invocation
+    : public TAO::Asynch_Remote_Invocation
+  {
+  public:
+    TAO_GIOP_DII_Asynch_Invocation (TAO_Stub *data,
+                                    TAO_ORB_Core* orb_core,
+                                    CORBA::Boolean argument_flag,
+                                    const CORBA::Request_ptr req,
+                                    CORBA::Object_ptr reply_handler,
+                                    int byte_order = TAO_ENCAP_BYTE_ORDER);
+
+    int invoke (void);
+
+  private:
+    /// Implementation of the invoke() methods, handles the basic
+    /// send/reply code and the system exceptions.
+    int invoke_i (void);
+
+
+    /// Reply dispatcher for the current synchronous Asynch_Invocation.
+    TAO_DII_Asynch_Reply_Dispatcher *rd_;
+  };
+
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
-#endif /* TAO_ASYNCH_INVOCATION_H */
+
+#endif /* TAO_DII_INVOCATION_H */
