@@ -1,4 +1,4 @@
-// $Id: DII_Reply_Dispatcher.cpp 79705 2007-09-24 07:45:37Z johnnyw $
+// $Id: DII_Reply_Dispatcher.cpp 85001 2009-03-31 10:06:45Z msmit $
 
 #include "tao/DynamicInterface/DII_Reply_Dispatcher.h"
 #include "tao/DynamicInterface/Request.h"
@@ -9,7 +9,7 @@
 
 ACE_RCSID(DynamicInterface,
           DII_Reply_Dispatcher,
-          "$Id: DII_Reply_Dispatcher.cpp 79705 2007-09-24 07:45:37Z johnnyw $")
+          "$Id: DII_Reply_Dispatcher.cpp 85001 2009-03-31 10:06:45Z msmit $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -49,7 +49,7 @@ TAO_DII_Deferred_Reply_Dispatcher::dispatch_reply (
           ACE_ERROR ((
             LM_ERROR,
             "TAO (%P|%t) - DII_Deferred_Reply_Dispatcher::dispatch_reply "
-            "clone_from failed \n"));
+            "clone_from failed\n"));
         }
       return -1;
     }
@@ -90,7 +90,7 @@ TAO_DII_Deferred_Reply_Dispatcher::dispatch_reply (
     }
 
   // This was dynamically allocated. Now the job is done.
-  (void) this->decr_refcount ();
+  this->intrusive_remove_ref (this);
 
   return 1;
 }
@@ -122,7 +122,7 @@ TAO_DII_Deferred_Reply_Dispatcher::connection_closed (void)
         }
     }
 
-  (void) this->decr_refcount ();
+  this->intrusive_remove_ref (this);
 }
 
 TAO_DII_Asynch_Reply_Dispatcher::TAO_DII_Asynch_Reply_Dispatcher (
@@ -202,7 +202,7 @@ TAO_DII_Asynch_Reply_Dispatcher::dispatch_reply (
         }
     }
   // This was dynamically allocated. Now the job is done.
-  (void) this->decr_refcount ();
+  this->intrusive_remove_ref (this);
 
   return 1;
 }
@@ -236,6 +236,6 @@ TAO_DII_Asynch_Reply_Dispatcher::connection_closed (void)
         }
     }
 
-  (void) this->decr_refcount ();
+  this->intrusive_remove_ref (this);
 }
 TAO_END_VERSIONED_NAMESPACE_DECL
