@@ -1,13 +1,15 @@
-// Dynamic_Adapter_Impl.cpp,v 1.13 2005/02/18 09:07:10 jwillemsen Exp
+// $Id: Dynamic_Adapter_Impl.cpp 76995 2007-02-11 12:51:42Z johnnyw $
 
-#include "Dynamic_Adapter_Impl.h"
+#include "tao/DynamicInterface/Dynamic_Adapter_Impl.h"
 
-ACE_RCSID(DynamicInterface, TAO_Dynamic_Adapter_Impl, "Dynamic_Adapter_Impl.cpp,v 1.13 2005/02/18 09:07:10 jwillemsen Exp")
+ACE_RCSID(DynamicInterface, TAO_Dynamic_Adapter_Impl, "$Id: Dynamic_Adapter_Impl.cpp 76995 2007-02-11 12:51:42Z johnnyw $")
 
-#include "Request.h"
-#include "Server_Request.h"
+#include "tao/DynamicInterface/Request.h"
+#include "tao/DynamicInterface/Server_Request.h"
 #include "tao/ORB_Core.h"
-#include "tao/Exception.h"
+#include "tao/SystemException.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Dynamic_Adapter_Impl::TAO_Dynamic_Adapter_Impl (void)
 {
@@ -26,9 +28,7 @@ TAO_Dynamic_Adapter_Impl::create_request (
     CORBA::NamedValue_ptr result,
     CORBA::ExceptionList_ptr exceptions,
     CORBA::Request_ptr &request,
-    CORBA::Flags req_flags
-    ACE_ENV_ARG_DECL
-  )
+    CORBA::Flags req_flags)
 {
   ACE_NEW_THROW_EX (request,
                     CORBA::Request (obj,
@@ -38,7 +38,7 @@ TAO_Dynamic_Adapter_Impl::create_request (
                                     result,
                                     req_flags,
                                     exceptions
-                                    ACE_ENV_ARG_PARAMETER),
+                                   ),
                     CORBA::NO_MEMORY (
                         CORBA::SystemException::_tao_minor_code (
                             TAO::VMCID,
@@ -51,15 +51,14 @@ TAO_Dynamic_Adapter_Impl::create_request (
 CORBA::Request_ptr
 TAO_Dynamic_Adapter_Impl::request (CORBA::Object_ptr obj,
                                    CORBA::ORB_ptr orb,
-                                   const char *operation
-                                   ACE_ENV_ARG_DECL)
+                                   const char *operation)
 {
   CORBA::Request_ptr req = CORBA::Request::_nil ();
   ACE_NEW_THROW_EX (req,
                     CORBA::Request (obj,
                                     orb,
                                     operation
-                                    ACE_ENV_ARG_PARAMETER),
+                                   ),
                     CORBA::NO_MEMORY (
                         CORBA::SystemException::_tao_minor_code (
                             TAO::VMCID,
@@ -67,7 +66,6 @@ TAO_Dynamic_Adapter_Impl::request (CORBA::Object_ptr obj,
                           ),
                         CORBA::COMPLETED_MAYBE
                       ));
-  ACE_CHECK_RETURN (CORBA::Request::_nil ());
 
   return req;
 }
@@ -119,9 +117,7 @@ TAO_Dynamic_Adapter_Impl::server_request_release (CORBA::ServerRequest_ptr req)
 
 void
 TAO_Dynamic_Adapter_Impl::create_exception_list (
-    CORBA::ExceptionList_ptr &list
-    ACE_ENV_ARG_DECL
-  )
+    CORBA::ExceptionList_ptr &list)
 {
   ACE_NEW_THROW_EX (list,
                     CORBA::ExceptionList,
@@ -141,6 +137,8 @@ TAO_Dynamic_Adapter_Impl::Initializer (void)
   return ACE_Service_Config::process_directive (ace_svc_desc_TAO_Dynamic_Adapter_Impl);
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 ACE_STATIC_SVC_DEFINE (
     TAO_Dynamic_Adapter_Impl,
     ACE_TEXT ("Concrete_Dynamic_Adapter"),
