@@ -1,44 +1,40 @@
 // -*- C++ -*-
-//
-// ExceptionList.h,v 1.16 2005/05/16 15:05:47 jwillemsen Exp
 
-// ============================================================================
-//
-// = LIBRARY
-//    DynamicInterface
-//
-// = FILENAME
-//    ExceptionList.h
-//
-// = DESCRIPTION
-//    This file defines the ExceptionList datatype used in
-//    dynamic invocations.
-//
-// = AUTHOR
-//     Copyright 1994-1995 by Sun Microsystems Inc.
-//
-// ============================================================================
+//=============================================================================
+/**
+ *  @file    ExceptionList.h
+ *
+ *  $Id: ExceptionList.h 77028 2007-02-12 14:49:05Z johnnyw $
+ *
+ *  This file defines the ExceptionList datatype used in
+ *  dynamic invocations.
+ *
+ *
+ *  @author  Copyright 1994-1995 by Sun Microsystems Inc.
+ */
+//=============================================================================
+
 
 #ifndef TAO_CORBA_EXCEPTIONLIST_H
 #define TAO_CORBA_EXCEPTIONLIST_H
 
 #include /**/ "ace/pre.h"
 
-#include "dynamicinterface_export.h"
+#include "tao/DynamicInterface/dynamicinterface_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "DII_CORBA_methods.h"
-#include "tao/Pseudo_VarOut_T.h"
+#include "tao/DynamicInterface/DII_CORBA_methods.h"
+#include "tao/AnyTypeCode/AnyTypeCode_methods.h"
 #include "tao/orbconf.h"
 #include "tao/Basic_Types.h"
 #include "tao/default_environment.h"
+#include "tao/Pseudo_VarOut_T.h"
 
 #include "ace/Unbounded_Queue.h"
 #include "ace/Atomic_Op.h"
-#include "ace/CORBA_macros.h"
 #include "ace/Synch_Traits.h"
 
 #if defined (TAO_EXPORT_MACRO)
@@ -46,10 +42,12 @@
 #endif
 #define TAO_EXPORT_MACRO TAO_DynamicInterface_Export
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace CORBA
 {
   typedef TAO_Pseudo_Var_T<ExceptionList> ExceptionList_var;
-  typedef TAO_Pseudo_Out_T<ExceptionList, ExceptionList_var> ExceptionList_out;
+  typedef TAO_Pseudo_Out_T<ExceptionList> ExceptionList_out;
 
   /**
    * @class ExceptionList
@@ -68,8 +66,7 @@ namespace CORBA
 
     /// Constructor - initialize given a length and an array of
     /// TypeCodes.
-    ExceptionList (CORBA::ULong len,
-                   CORBA::TypeCode_ptr *tc_list);
+    ExceptionList (CORBA::ULong len, CORBA::TypeCode_ptr *tc_list);
 
     /// Destructor.
     ~ExceptionList (void);
@@ -94,12 +91,10 @@ namespace CORBA
     void add_consume (CORBA::TypeCode_ptr tc);
 
     /// Return the typecode at slot i. Raises the "Bounds" exception.
-    CORBA::TypeCode_ptr item (CORBA::ULong slot
-                              ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+    CORBA::TypeCode_ptr item (CORBA::ULong slot);
 
     /// Remove the typecode at slot i. Raises the "Bounds" exception.
-    void remove (CORBA::ULong slot
-                 ACE_ENV_ARG_DECL_WITH_DEFAULTS);
+    void remove (CORBA::ULong slot);
 
     /// Increment and decrement ref counts.
     void _incr_refcnt (void);
@@ -108,6 +103,7 @@ namespace CORBA
     /// Useful for template programming.
     typedef CORBA::ExceptionList_ptr _ptr_type;
     typedef CORBA::ExceptionList_var _var_type;
+    typedef CORBA::ExceptionList_out _out_type;
 
   private:
     // = Not allowed.
@@ -122,8 +118,10 @@ namespace CORBA
   };
 }  // End CORBA namespace
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-# include "ExceptionList.inl"
+# include "tao/DynamicInterface/ExceptionList.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
