@@ -1,23 +1,22 @@
-// Unknown_User_Exception.cpp,v 1.18 2005/05/25 19:26:46 ossama Exp
+// $Id: Unknown_User_Exception.cpp 80384 2008-01-07 15:44:01Z mcorino $
 
-#include "Unknown_User_Exception.h"
+#include "tao/DynamicInterface/Unknown_User_Exception.h"
 
-#include "tao/Any.h"
-#include "tao/Environment.h"
-#include "tao/TypeCode_Constants.h"
-#include "tao/Null_RefCount_Policy.h"
-#include "tao/TypeCode_Struct_Field.h"
-#include "tao/Struct_TypeCode_Static.h"
+#include "tao/AnyTypeCode/Any.h"
 #include "tao/SystemException.h"
+#include "tao/AnyTypeCode/TypeCode_Constants.h"
+#include "tao/AnyTypeCode/Null_RefCount_Policy.h"
+#include "tao/AnyTypeCode/TypeCode_Struct_Field.h"
+#include "tao/AnyTypeCode/Struct_TypeCode_Static.h"
 
 #include "ace/OS_NS_string.h"
 #include "ace/OS_Memory.h"
 
-
 ACE_RCSID (DynamicInterface,
            Unknown_User_Exception,
-           "Unknown_User_Exception.cpp,v 1.18 2005/05/25 19:26:46 ossama Exp")
+           "$Id: Unknown_User_Exception.cpp 80384 2008-01-07 15:44:01Z mcorino $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 CORBA::UnknownUserException::UnknownUserException (void)
   : CORBA::UserException ("IDL:omg.org/CORBA/UnknownUserException:1.0",
@@ -55,16 +54,6 @@ CORBA::UnknownUserException::exception (void)
   return *this->exception_;
 }
 
-int
-CORBA::UnknownUserException::_is_a (const char *interface_id) const
-{
-  return
-    ((ACE_OS::strcmp (interface_id,
-                      "IDL:omg.org/CORBA/UnknownUserException:1.0")
-        == 0)
-      || UserException::_is_a (interface_id));
-}
-
 CORBA::UnknownUserException *
 CORBA::UnknownUserException::_downcast (CORBA::Exception *ex)
 {
@@ -80,7 +69,7 @@ CORBA::UnknownUserException::_downcast (CORBA::Exception const * ex)
 void
 CORBA::UnknownUserException::_raise (void) const
 {
-  TAO_RAISE (*this);
+  throw *this;
 }
 
 CORBA::Exception *
@@ -96,25 +85,28 @@ CORBA::UnknownUserException::_tao_duplicate (void) const
 }
 
 void
-CORBA::UnknownUserException::_tao_encode (
-    TAO_OutputCDR &
-    ACE_ENV_ARG_DECL
-  ) const
+CORBA::UnknownUserException::_tao_encode (TAO_OutputCDR &) const
 {
-  ACE_THROW (CORBA::MARSHAL ());
+  throw ::CORBA::MARSHAL ();
 }
 
 void
-CORBA::UnknownUserException::_tao_decode (TAO_InputCDR &
-                                         ACE_ENV_ARG_DECL)
+CORBA::UnknownUserException::_tao_decode (TAO_InputCDR &)
 {
-  ACE_THROW (CORBA::MARSHAL ());
+  throw ::CORBA::MARSHAL ();
+}
+
+const char *
+CORBA::UnknownUserException::_rep_id (void) const
+{
+  return this->exception_->_tao_get_typecode ()->id ();
 }
 
 CORBA::TypeCode_ptr
 CORBA::UnknownUserException::_tao_type (void) const
 {
-  return CORBA::_tc_UnknownUserException;
+  //return CORBA::_tc_UnknownUserException;
+  return this->exception_->_tao_get_typecode ();
 }
 
 namespace TAO
@@ -144,3 +136,5 @@ namespace CORBA
   CORBA::TypeCode_ptr const _tc_UnknownUserException =
     &TAO::TypeCode::tc_UnknownUserException;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
