@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Dynamic_Adapter.h
  *
- *  Dynamic_Adapter.h,v 1.16 2005/06/24 12:34:10 jwillemsen Exp
+ *  $Id: Dynamic_Adapter.h 80376 2008-01-06 07:37:06Z johnnyw $
  *
  *  @author  Jeff Parsons <parsons@cs.wustl.edu>
  */
@@ -20,11 +20,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "ace/CORBA_macros.h"
-
-#include "tao/TAO_Export.h"
+#include /**/ "tao/TAO_Export.h"
 #include "tao/Basic_Types.h"
-#include "ace/CORBA_macros.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace CORBA
 {
@@ -53,8 +52,6 @@ namespace CORBA
   typedef ServerRequest *ServerRequest_ptr;
 
   typedef ULong Flags;
-
-  class Environment;
 }
 
 /**
@@ -81,13 +78,11 @@ public:
                                CORBA::NamedValue_ptr result,
                                CORBA::ExceptionList_ptr exceptions,
                                CORBA::Request_ptr &request,
-                               CORBA::Flags req_flags
-                               ACE_ENV_ARG_DECL) = 0;
+                               CORBA::Flags req_flags) = 0;
 
   virtual CORBA::Request_ptr request (CORBA::Object_ptr obj,
                                       CORBA::ORB_ptr orb,
-                                      const char *op
-                                      ACE_ENV_ARG_DECL) = 0;
+                                      const char *op) = 0;
 
   // CORBA::is_nil and CORBA::release for Context, Request, and ServerRequest.
 
@@ -104,10 +99,10 @@ public:
   virtual void server_request_release (CORBA::ServerRequest_ptr req) = 0;
 
   // CORBA::ORB::create_exception_list.
-  virtual void create_exception_list (CORBA::ExceptionList_ptr &
-                                      ACE_ENV_ARG_DECL) = 0;
+  virtual void create_exception_list (CORBA::ExceptionList_ptr &) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
 #endif /* TAO_DYNAMIC_ADAPTER_H */
