@@ -4,7 +4,7 @@
 /**
  *  @file   Endpoint.h
  *
- *  Endpoint.h,v 1.15 2004/11/28 05:44:15 bala Exp
+ *  $Id: Endpoint.h 74014 2006-08-14 13:52:22Z johnnyw $
  *
  * Endpoint interface, part of TAO pluggable protocol framework.
  *
@@ -23,10 +23,20 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/TAO_Export.h"
+#include /**/ "tao/TAO_Export.h"
 #include "tao/Basic_Types.h"
 #include "tao/orbconf.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+class TAO_ORB_Core;
+
+/*
+ * Includes and forward decls for specializing TAO's
+ * endpoint implementation.
+ */
+//@@ TAO_ENDPOINT_SPL_INCLUDE_FORWARD_DECL_ADD_HOOK
+
 /**
  * @class TAO_Endpoint
  *
@@ -71,12 +81,29 @@ public:
    */
   virtual CORBA::Boolean is_equivalent (const TAO_Endpoint *other_endpoint) = 0;
 
-  /// Endpoints can be stringed in a list.
+  /// Endpoints can be linked in a list.
   /**
    * @return The next endpoint in the list, if any.
    */
   virtual TAO_Endpoint *next (void) = 0;
 
+  /**
+   * Return the next endpoint in the list, but use protocol-specific
+   * filtering to constrain the value. The orb core is needed to supply
+   * any sort of filter arguments, and the root endpoint is needed in case
+   * the algorithm needs to rewind. If the supplied root is 0, then this
+   * is assumed to be the candidate next endpoint.
+   *
+   * To use this, the caller starts off the change with root == 0. This
+   * is a bit of a violation in logic, a more correct implementation would
+   * accept this == 0 and a non-null root.
+   * To do iteration using next_filtered, do:
+   *   for (TAO_Endpoint *ep = root_endpoint->next_filtered (orb_core, 0);
+   *        ep != 0;
+   *        ep = ep->next_filtered(orb_core, root_endpoint)) { }
+   */
+  virtual TAO_Endpoint *next_filtered (TAO_ORB_Core *, TAO_Endpoint *root);
+
   /// Return a string representation for the address.
   /**
    * The purpose of this method is to provide a general interface to
@@ -93,7 +120,13 @@ public:
   virtual TAO_Endpoint *duplicate (void) = 0;
 
   /// Return a hash value for this object.
-  virtual CORBA::ULong hash (void) = 0;
+  virtual CORBA::ULong hash (void)  = 0;
+
+  /*
+   * Hook to add public methods from derived class onto base
+   * Endpoint class.
+   */
+  //@@ TAO_ENDPOINT_SPL_PUBLIC_METHODS_ADD_HOOK
 
 protected:
 
@@ -111,7 +144,7 @@ protected:
 
   /// IOP tag, identifying the protocol for which this endpoint
   /// contains addressing info.
-  CORBA::ULong tag_;
+  CORBA::ULong const tag_;
 
   /**
    * CORBA priority of the acceptor this Endpoint is representing.
@@ -123,13 +156,22 @@ protected:
 private:
 
   /// Endpoints should not be copied.
-  ACE_UNIMPLEMENTED_FUNC (TAO_Endpoint (const TAO_Endpoint&))
-  ACE_UNIMPLEMENTED_FUNC (void operator= (const TAO_Endpoint&))
+  TAO_Endpoint (const TAO_Endpoint&);
+  void operator= (const TAO_Endpoint&);
+
+  /*
+   * Addition of private members from derived class.
+   */
+  //@@ TAO_ENDPOINT_SPL_PRIVATE_DATA_ADD_HOOK
+
 };
 
+//@@ TAO_ENDPOINT_SPL_EXTERN_ADD_HOOK
+
+TAO_END_VERSIONED_NAMESPACE_DECL
 
 #if defined (__ACE_INLINE__)
-# include "tao/Endpoint.i"
+# include "tao/Endpoint.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
