@@ -1,4 +1,4 @@
-// $Id: Exception.cpp 74664 2006-10-10 09:21:04Z johnnyw $
+// $Id: Exception.cpp 84489 2009-02-17 14:04:16Z johnnyw $
 
 #include "tao/Exception.h"
 #include "tao/SystemException.h"
@@ -27,7 +27,7 @@
 
 ACE_RCSID (tao,
            Exception,
-           "$Id: Exception.cpp 74664 2006-10-10 09:21:04Z johnnyw $")
+           "$Id: Exception.cpp 84489 2009-02-17 14:04:16Z johnnyw $")
 
 
 // ****************************************************************
@@ -66,11 +66,14 @@ CORBA::Exception::~Exception (void)
 CORBA::Exception &
 CORBA::Exception::operator= (const CORBA::Exception &src)
 {
-  this->id_ = CORBA::string_dup (src.id_);
-  ACE_ASSERT (this->id_.in () != 0);
+  if (this != &src)
+    {
+      this->id_ = CORBA::string_dup (src.id_);
+      ACE_ASSERT (this->id_.in () != 0);
 
-  this->name_ = CORBA::string_dup (src.name_);
-  ACE_ASSERT (this->name_.in () != 0);
+      this->name_ = CORBA::string_dup (src.name_);
+      ACE_ASSERT (this->name_.in () != 0);
+    }
 
   return *this;
 }
@@ -92,10 +95,10 @@ CORBA::Exception::_tao_print_exception (const char *user_provided_info,
                                         FILE *) const
 {
   ACE_ERROR ((LM_ERROR,
-              ACE_TEXT ("(%P|%t) EXCEPTION, %s\n")
-              ACE_TEXT ("%s\n"),
-              ACE_TEXT_CHAR_TO_TCHAR (user_provided_info),
-              ACE_TEXT_CHAR_TO_TCHAR (this->_info ().c_str ())));
+              ACE_TEXT ("(%P|%t) EXCEPTION, %C\n")
+              ACE_TEXT ("%C\n"),
+              user_provided_info,
+              this->_info ().c_str ()));
 }
 
 #if defined (ACE_USES_WCHAR)
