@@ -4,7 +4,7 @@
 /**
  *  @file    Exception_Data.h
  *
- *  Exception_Data.h,v 1.2 2003/10/28 18:29:13 bala Exp
+ *  $Id: Exception_Data.h 69150 2005-11-02 07:13:04Z ossama $
  *
  *  @author  balachandran Natarajan <bala@dre.vanderbilt.edu>
  */
@@ -13,13 +13,22 @@
 #ifndef TAO_EXCEPTION_DATA_H
 #define TAO_EXCEPTION_DATA_H
 #include /**/ "ace/pre.h"
-#include "ace/config-all.h"
 
+#include "ace/config-all.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/orbconf.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+namespace CORBA
+{
+  class TypeCode;
+  typedef TypeCode *TypeCode_ptr;
+}
 
 namespace TAO
 {
@@ -46,10 +55,14 @@ namespace TAO
     /// The allocator for this exception.
     TAO_Exception_Alloc alloc;
 
+#if TAO_HAS_INTERCEPTORS == 1
     /// The typecode pointer for this exception.
     CORBA::TypeCode_ptr tc_ptr;
+#endif /* TAO_HAS_INTERCEPTORS */
   };
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /*TAO_EXCEPTION_DATA_H*/
