@@ -1,4 +1,4 @@
-// $Id: Exclusive_TMS.cpp 76551 2007-01-24 13:42:44Z johnnyw $
+// $Id: Exclusive_TMS.cpp 85012 2009-04-02 10:05:46Z msmit $
 
 #include "tao/Exclusive_TMS.h"
 #include "tao/Reply_Dispatcher.h"
@@ -7,14 +7,13 @@
 
 ACE_RCSID (tao,
            Exclusive_TMS,
-           "$Id: Exclusive_TMS.cpp 76551 2007-01-24 13:42:44Z johnnyw $")
+           "$Id: Exclusive_TMS.cpp 85012 2009-04-02 10:05:46Z msmit $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Exclusive_TMS::TAO_Exclusive_TMS (TAO_Transport *transport)
   : TAO_Transport_Mux_Strategy (transport),
     request_id_generator_ (0),
-    has_request_ (false),
     request_id_ (0),
     rd_ (0)
 {
@@ -56,23 +55,27 @@ TAO_Exclusive_TMS::request_id (void)
 // Bind the handler with the request id.
 int
 TAO_Exclusive_TMS::bind_dispatcher (CORBA::ULong request_id,
-                                    TAO_Reply_Dispatcher *rd)
+                                    ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd)
 {
-  this->has_request_ = true;
   this->request_id_ = request_id;
-  this->rd_ = rd;
+  this->rd_ = rd.get ();
 
   return 0;
 }
 
+bool
+TAO_Exclusive_TMS::has_request (void)
+{
+  return this->rd_ != 0;
+}
+
 int
 TAO_Exclusive_TMS::unbind_dispatcher (CORBA::ULong request_id)
 {
-  if (!this->has_request_ || this->request_id_ != request_id)
+  if (!this->rd_ || this->request_id_ != request_id)
     return -1;
-  this->has_request_ = false;
-  this->request_id_ = 0;
-  this->rd_ = 0;
+
+  this->rd_.release ();
 
   return 0;
 }
@@ -81,11 +84,11 @@ int
 TAO_Exclusive_TMS::dispatch_reply (TAO_Pluggable_Reply_Params &params)
 {
   // Check the ids.
-  if (!this->has_request_ || this->request_id_ != params.request_id_)
+  if (!this->rd_ || this->request_id_ != params.request_id_)
     {
       if (TAO_debug_level > 0)
         ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("(%P|%t) TAO_Exclusive_TMS::dispatch_reply - <%d != %d>\n"),
+                    ACE_TEXT ("TAO (%P|%t) - Exclusive_TMS::dispatch_reply - <%d != %d>\n"),
                     this->request_id_, params.request_id_));
 
       // The return value 0 informs the transport that the mux strategy
@@ -93,16 +96,40 @@ TAO_Exclusive_TMS::dispatch_reply (TAO_Pluggable_Reply_Params &params)
       return 0;
     }
 
-  TAO_Reply_Dispatcher *rd = this->rd_;
-  this->has_request_ = false;
+  ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd (this->rd_.get ());
   this->request_id_ = 0; // @@ What is a good value???
-  this->rd_ = 0;
+  this->rd_.release ();
 
   // Dispatch the reply.
   // Returns 1 on success, -1 on failure.
   return rd->dispatch_reply (params);
 }
 
+int
+TAO_Exclusive_TMS::reply_timed_out (CORBA::ULong request_id)
+{
+  // Check the ids.
+  if (!this->rd_ || this->request_id_ != request_id)
+    {
+      if (TAO_debug_level > 0)
+        ACE_DEBUG ((LM_DEBUG,
+                    ACE_TEXT ("TAO (%P|%t) - Exclusive_TMS::reply_timed_out - <%d != %d>\n"),
+                    this->request_id_, request_id));
+
+      // The return value 0 informs the transport that the mux strategy
+      // did not find the right reply handler.
+      return 0;
+    }
+  
+  ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd (this->rd_.get ());
+  this->request_id_ = 0; // @@ What is a good value???
+  this->rd_.release ();
+
+  rd->reply_timed_out ();
+
+  return 0;
+}
+
 bool
 TAO_Exclusive_TMS::idle_after_send (void)
 {
