@@ -4,7 +4,7 @@
 /**
  *  @file    Exclusive_TMS.h
  *
- *  $Id: Exclusive_TMS.h 78996 2007-07-23 12:12:55Z johnnyw $
+ *  $Id: Exclusive_TMS.h 85012 2009-04-02 10:05:46Z msmit $
  *
  *  @author  Alexander Babu Arulanthu <alex@cs.wustl.edu>
  */
@@ -25,6 +25,7 @@
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Pluggable_Reply_Params;
+class TAO_Reply_Dispatcher;
 
 /**
  * @class TAO_Exclusive_TMS
@@ -55,14 +56,16 @@ public:
   //@{
   virtual CORBA::ULong request_id (void);
   virtual int bind_dispatcher (CORBA::ULong request_id,
-                               TAO_Reply_Dispatcher *rh);
+                               ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd);
   virtual int unbind_dispatcher (CORBA::ULong request_id);
 
   virtual int dispatch_reply (TAO_Pluggable_Reply_Params &params);
+  virtual int reply_timed_out (CORBA::ULong request_id);
 
   virtual bool idle_after_send (void);
   virtual bool idle_after_reply (void);
   virtual void connection_closed (void);
+  virtual bool has_request (void);
   //@}
 
 protected:
@@ -70,15 +73,12 @@ protected:
   /// request_id().
   CORBA::ULong request_id_generator_;
 
-  /// If false then the request id and reply dispatcher below are
-  /// meaningless
-  bool has_request_;
-
   /// Request id for the current request.
   CORBA::ULong request_id_;
 
-  /// Reply Dispatcher corresponding to the request.
-  TAO_Reply_Dispatcher *rd_;
+  /// Reply Dispatcher corresponding to the request. If this is zero we don't
+  /// have a reply, if it not zero we have one
+  ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd_;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
