@@ -4,7 +4,7 @@
 /**
  *  @file    Fault_Tolerance_Service.h
  *
- *  $Id: Fault_Tolerance_Service.h 74168 2006-08-22 09:51:53Z smcqueen $
+ *  $Id: Fault_Tolerance_Service.h 84840 2009-03-16 15:11:55Z johnnyw $
  *
  *  A collection of the ORB and ORB core related properties that are
  *  specific to FT service. The TAO_ORB_Core holds an instance of this
@@ -55,6 +55,10 @@ public:
   /// Return the underlying callback object
   TAO_Service_Callbacks *service_callback (void);
 
+private:
+  void operator= (const TAO_Fault_Tolerance_Service &);
+  TAO_Fault_Tolerance_Service (const TAO_Fault_Tolerance_Service &);
+
 private:
 
   /// hook to callback on to the service
