@@ -1,4 +1,4 @@
-// $Id: GIOP_Message_Base.cpp 79727 2007-09-26 18:12:47Z johnnyw $
+// $Id: GIOP_Message_Base.cpp 88212 2009-12-17 10:23:30Z mcorino $
 
 #include "tao/GIOP_Message_Base.h"
 #include "tao/operation_details.h"
@@ -12,6 +12,7 @@
 #include "tao/Request_Dispatcher.h"
 #include "tao/Codeset_Manager.h"
 #include "tao/SystemException.h"
+#include "tao/ZIOP_Adapter.h"
 #include "ace/Min_Max.h"
 
 /*
@@ -21,7 +22,7 @@
 
 ACE_RCSID (tao,
            GIOP_Message_Base,
-           "$Id: GIOP_Message_Base.cpp 79727 2007-09-26 18:12:47Z johnnyw $")
+           "$Id: GIOP_Message_Base.cpp 88212 2009-12-17 10:23:30Z mcorino $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -41,11 +42,25 @@ TAO_GIOP_Message_Base::TAO_GIOP_Message_Base (TAO_ORB_Core *orb_core,
                  TAO_DEF_GIOP_MAJOR,
                  TAO_DEF_GIOP_MINOR)
 {
+#if defined (TAO_HAS_MONITOR_POINTS) && (TAO_HAS_MONITOR_POINTS == 1)
+  const int nibbles = 2 * sizeof (size_t);
+  char hex_string[nibbles + 1];
+  ACE_OS::sprintf (hex_string,
+                   "%8.8X",
+                   transport->id ());
+  hex_string[nibbles] = '\0';
+  ACE_CString monitor_name ("OutputCDR_");
+  monitor_name += hex_string;
+  this->out_stream_.register_monitor (monitor_name.c_str ());
+#endif /* TAO_HAS_MONITOR_POINTS==1 */
 }
 
 
 TAO_GIOP_Message_Base::~TAO_GIOP_Message_Base (void)
 {
+#if defined (TAO_HAS_MONITOR_POINTS) && (TAO_HAS_MONITOR_POINTS == 1)
+  this->out_stream_.unregister_monitor ();
+#endif /* TAO_HAS_MONITOR_POINTS==1 */
 }
 
 void
@@ -78,7 +93,7 @@ TAO_GIOP_Message_Base::generate_request_header (
       if (TAO_debug_level)
         {
           ACE_ERROR ((LM_ERROR,
-                      ACE_TEXT ("(%P|%t) Error in writing GIOP header \n")));
+                      ACE_TEXT ("(%P|%t) Error in writing GIOP header\n")));
         }
 
       return -1;
@@ -93,7 +108,7 @@ TAO_GIOP_Message_Base::generate_request_header (
     {
       if (TAO_debug_level)
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) Error in writing request header \n")));
+                    ACE_TEXT ("(%P|%t) Error in writing request header\n")));
 
       return -1;
     }
@@ -120,7 +135,7 @@ TAO_GIOP_Message_Base::generate_locate_request_header (
     {
       if (TAO_debug_level)
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) Error in writing GIOP header \n")));
+                    ACE_TEXT ("(%P|%t) Error in writing GIOP header\n")));
 
       return -1;
     }
@@ -131,7 +146,7 @@ TAO_GIOP_Message_Base::generate_locate_request_header (
     {
       if (TAO_debug_level)
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) Error in writing locate request header \n")));
+                    ACE_TEXT ("(%P|%t) Error in writing locate request header\n")));
 
 
       return -1;
@@ -155,7 +170,7 @@ TAO_GIOP_Message_Base::generate_reply_header (
     {
       if (TAO_debug_level)
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) Error in writing GIOP header \n")));
+                    ACE_TEXT ("(%P|%t) Error in writing GIOP header\n")));
 
       return -1;
     }
@@ -213,7 +228,7 @@ TAO_GIOP_Message_Base::generate_fragment_header (TAO_OutputCDR & cdr,
     {
       if (TAO_debug_level)
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("(%P|%t) Error in writing GIOP header \n")));
+                    ACE_TEXT ("(%P|%t) Error in writing GIOP header\n")));
 
       return -1;
     }
@@ -222,13 +237,74 @@ TAO_GIOP_Message_Base::generate_fragment_header (TAO_OutputCDR & cdr,
 }
 
 int
-TAO_GIOP_Message_Base::format_message (TAO_OutputCDR &stream)
+TAO_GIOP_Message_Base::dump_consolidated_msg (TAO_OutputCDR &stream)
 {
-  // Ptr to first buffer.
+  // Check whether the output cdr stream is build up of multiple
+  // messageblocks. If so, consolidate them to one block that can be
+  // dumped
+  ACE_Message_Block* consolidated_block = 0;
   char *buf = const_cast <char*> (stream.buffer ());
+  size_t const total_len = stream.total_length ();
+  if (stream.begin()->cont () != 0)
+    {
+      ACE_NEW_RETURN (consolidated_block, ACE_Message_Block, 0);
+      ACE_CDR::consolidate (consolidated_block, stream.begin ());
+      buf = (char *) (consolidated_block->rd_ptr ());
+    }
 
+  this->dump_msg ("send", reinterpret_cast <u_char *> (buf), total_len);
+
+  delete consolidated_block;
+  consolidated_block = 0;
+
+  return 0;
+}
+
+int
+TAO_GIOP_Message_Base::format_message (TAO_OutputCDR &stream, TAO_Stub* stub)
+{
   this->set_giop_flags (stream);
 
+  bool log_msg = TAO_debug_level > 9;
+
+#if defined (TAO_HAS_ZIOP) && TAO_HAS_ZIOP ==1
+  TAO_ZIOP_Adapter* ziop_adapter = this->orb_core_->ziop_adapter ();
+
+  // Ziop adapter found and not compressed yet
+  if (ziop_adapter)
+    {
+      if (TAO_debug_level > 9)
+        {
+          this->dump_consolidated_msg (stream);
+        }
+      bool compressed;
+      if (stub)
+        {
+          compressed = ziop_adapter->marshal_data (stream, *stub);
+        }
+      else
+        {
+          compressed = ziop_adapter->marshal_data (stream, *this->orb_core_);
+        }
+
+        if (TAO_debug_level > 9)
+          {
+            if (!compressed)
+              ACE_DEBUG ((LM_DEBUG,
+                          ACE_TEXT ("TAO (%P|%t) - ")
+                          ACE_TEXT ("TAO_GIOP_Message_Base::format_message, ")
+                          ACE_TEXT ("GIOP message not compressed\n")));
+            // no need to log. If compressed->ZIOP library dumps message
+            // if not compressed (due to failure or policy settings)
+            // message hasn't changed and was allready dumped
+            // prior to compression...
+            log_msg = false;
+          }
+    }
+#else
+  ACE_UNUSED_ARG (stub);
+#endif
+
   // Length of all buffers.
   size_t const total_len = stream.total_length ();
 
@@ -239,6 +315,8 @@ TAO_GIOP_Message_Base::format_message (TAO_OutputCDR &stream)
   // this particular environment and that isn't handled by the
   // networking infrastructure (e.g., IPSEC).
 
+  char *buf = const_cast <char*> (stream.buffer ());
+
   CORBA::ULong bodylen = static_cast <CORBA::ULong>
                            (total_len - TAO_GIOP_MESSAGE_HEADER_LEN);
 
@@ -254,25 +332,9 @@ TAO_GIOP_Message_Base::format_message (TAO_OutputCDR &stream)
                      buf + TAO_GIOP_MESSAGE_SIZE_OFFSET);
 #endif /* ACE_ENABLE_SWAP_ON_WRITE */
 
-  if (TAO_debug_level >= 5)
+  if (log_msg)
     {
-      // Check whether the output cdr stream is build up of multiple
-      // messageblocks. If so, consolidate them to one block that can be
-      // dumped
-      ACE_Message_Block* consolidated_block = 0;
-      if (stream.begin()->cont () != 0)
-        {
-          ACE_NEW_RETURN (consolidated_block, ACE_Message_Block, 0);
-          ACE_CDR::consolidate (consolidated_block, stream.begin ());
-          buf = (char *) (consolidated_block->rd_ptr ());
-        }
-      ///
-      this->dump_msg ("send", reinterpret_cast <u_char *> (buf), total_len);
-
-      //
-      delete consolidated_block;
-      consolidated_block = 0;
-      //
+      this->dump_consolidated_msg (stream);
     }
 
   return 0;
@@ -585,18 +647,11 @@ TAO_GIOP_Message_Base::process_request_message (TAO_Transport *transport,
                         qd->giop_version ().major_version (),
                         qd->giop_version ().minor_version ());
 
-  // Get the read and write positions before we steal data.
+  // Get the read and write positions and header before we steal data.
   size_t rd_pos = qd->msg_block ()->rd_ptr () - qd->msg_block ()->base ();
-  size_t const wr_pos = qd->msg_block ()->wr_ptr () - qd->msg_block ()->base ();
+  size_t wr_pos = qd->msg_block ()->wr_ptr () - qd->msg_block ()->base ();
   rd_pos += TAO_GIOP_MESSAGE_HEADER_LEN;
 
-  if (TAO_debug_level >= 5)
-    {
-      this->dump_msg ("recv",
-                      reinterpret_cast <u_char *> (qd->msg_block ()->rd_ptr ()),
-                      qd->msg_block ()->length ());
-    }
-
   // Create a input CDR stream. We do the following
   //  1 - If the incoming message block has a data block with a flag
   //      DONT_DELETE  (for the data block) we create an input CDR
@@ -607,11 +662,10 @@ TAO_GIOP_Message_Base::process_request_message (TAO_Transport *transport,
   // we pass it on to the higher layers of the ORB. So we dont to any
   // copies at all here. The same is also done in the higher layers.
 
-  ACE_Message_Block::Message_Flags flg = 0;
   ACE_Data_Block *db = 0;
 
   // Get the flag in the message block
-  flg = qd->msg_block ()->self_flags ();
+  ACE_Message_Block::Message_Flags flg = qd->msg_block ()->self_flags ();
 
   if (ACE_BIT_ENABLED (flg, ACE_Message_Block::DONT_DELETE))
     {
@@ -624,9 +678,24 @@ TAO_GIOP_Message_Base::process_request_message (TAO_Transport *transport,
       // heap.
       db = qd->msg_block ()->data_block ()->duplicate ();
     }
+  db->size (qd->msg_block ()->length ());
+
+#if defined (TAO_HAS_ZIOP) && TAO_HAS_ZIOP ==1
+  if (qd->state ().compressed ())
+    {
+      if (!this->decompress (&db, *qd, rd_pos, wr_pos))
+        return -1;
+    }
+#endif
+  if (TAO_debug_level > 9)
+    { //due to alignment data block has an offset which needs to be corrected
+      this->dump_msg ("recv",
+                      reinterpret_cast <u_char *> (db->base () + rd_pos - TAO_GIOP_MESSAGE_HEADER_LEN),
+                      db->size ()  + rd_pos - TAO_GIOP_MESSAGE_HEADER_LEN);
+    }
 
   TAO_InputCDR input_cdr (db,
-                          flg,
+                          db->flags (),
                           rd_pos,
                           wr_pos,
                           qd->byte_order (),
@@ -664,6 +733,32 @@ TAO_GIOP_Message_Base::process_request_message (TAO_Transport *transport,
     }
 }
 
+#if defined (TAO_HAS_ZIOP) && TAO_HAS_ZIOP ==1
+bool
+TAO_GIOP_Message_Base::decompress (ACE_Data_Block **db, TAO_Queued_Data& qd,
+                                   size_t& rd_pos, size_t& wr_pos)
+{
+  TAO_ZIOP_Adapter* adapter = this->orb_core_->ziop_adapter ();
+  if (adapter)
+    {
+      if (!adapter->decompress (db, qd, *this->orb_core_))
+        return false;
+      rd_pos = TAO_GIOP_MESSAGE_HEADER_LEN;
+      wr_pos = (*db)->size();
+    }
+  else
+    {
+      if (TAO_debug_level > 0)
+        ACE_ERROR ((LM_ERROR,
+                    ACE_TEXT ("TAO (%P|%t) ERROR: Unable to decompress ")
+                    ACE_TEXT ("data.\n")));
+
+      return false;
+    }
+  return true;
+}
+#endif
+
 int
 TAO_GIOP_Message_Base::process_reply_message (
     TAO_Pluggable_Reply_Params &params,
@@ -675,23 +770,47 @@ TAO_GIOP_Message_Base::process_reply_message (
 
   // Get the read and write positions before we steal data.
   size_t rd_pos = qd->msg_block ()->rd_ptr () - qd->msg_block ()->base ();
-  size_t const wr_pos = qd->msg_block ()->wr_ptr () - qd->msg_block ()->base ();
+  size_t wr_pos = qd->msg_block ()->wr_ptr () - qd->msg_block ()->base ();
   rd_pos += TAO_GIOP_MESSAGE_HEADER_LEN;
 
-  if (TAO_debug_level >= 5)
+  ACE_Data_Block *db = 0;
+
+  // Get the flag in the message block
+  ACE_Message_Block::Message_Flags flg = qd->msg_block ()->self_flags ();
+
+  if (ACE_BIT_ENABLED (flg, ACE_Message_Block::DONT_DELETE))
+    {
+      // Use the same datablock
+      db = qd->msg_block ()->data_block ();
+    }
+  else
+    {
+      // Use a duplicated datablock as the datablock has come off the
+      // heap.
+      db = qd->msg_block ()->data_block ()->duplicate ();
+    }
+  db->size (qd->msg_block ()->length ());
+
+#if defined (TAO_HAS_ZIOP) && TAO_HAS_ZIOP ==1
+   if (qd->state ().compressed ())
+    {
+      if (!this->decompress (&db, *qd, rd_pos, wr_pos))
+        return -1;
+    }
+#endif
+  if (TAO_debug_level > 9)
     {
       this->dump_msg ("recv",
-                      reinterpret_cast <u_char *> (qd->msg_block ()->rd_ptr ()),
-                      qd->msg_block ()->length ());
+                      reinterpret_cast <u_char *> (db->base () + rd_pos - TAO_GIOP_MESSAGE_HEADER_LEN),
+                      db->size ()  + rd_pos - TAO_GIOP_MESSAGE_HEADER_LEN);
     }
 
-
   // Create a empty buffer on stack
   // NOTE: We use the same data block in which we read the message and
   // we pass it on to the higher layers of the ORB. So we dont to any
   // copies at all here.
-  TAO_InputCDR input_cdr (qd->msg_block ()->data_block (),
-                          ACE_Message_Block::DONT_DELETE,
+  TAO_InputCDR input_cdr (db,
+                          db->flags (),
                           rd_pos,
                           wr_pos,
                           qd->byte_order (),
@@ -738,7 +857,6 @@ TAO_GIOP_Message_Base::process_reply_message (
                     ACE_TEXT ("dispatch reply failed\n"),
                     params.transport_->id ()));
     }
-
   return retval;
 }
 
@@ -757,6 +875,10 @@ TAO_GIOP_Message_Base::generate_exception_reply (
       this->generate_reply_header (cdr, params);
       x._tao_encode (cdr);
     }
+  catch (const ::CORBA::BAD_PARAM&)
+    {
+      throw;
+    }
   catch (const ::CORBA::Exception&)
     {
       // Now we know that while handling the error an other error
@@ -827,11 +949,10 @@ TAO_GIOP_Message_Base::process_request (
 
   CORBA::ULong request_id = 0;
   CORBA::Boolean response_required = false;
-  int parse_error = 0;
 
   try
     {
-      parse_error = parser->parse_request_header (request);
+      int const parse_error = parser->parse_request_header (request);
 
       // Throw an exception if the
       if (parse_error != 0)
@@ -865,7 +986,7 @@ TAO_GIOP_Message_Base::process_request (
 
 //@@ TAO_DISPATCH_RESOLUTION_OPT_COMMENT_HOOK_END
 
-      if (!CORBA::is_nil (forward_to.in ()))
+      if (request.is_forwarded ())
         {
           CORBA::Boolean const permanent_forward_condition =
               this->orb_core_->is_permanent_forward_condition
@@ -887,7 +1008,7 @@ TAO_GIOP_Message_Base::process_request (
 
           output.message_attributes (request_id,
                                      0,
-                                     TAO_Transport::TAO_REPLY,
+                                     TAO_REPLY,
                                      0);
 
           // Make the GIOP header and Reply header
@@ -905,9 +1026,9 @@ TAO_GIOP_Message_Base::process_request (
 
           output.more_fragments (false);
 
-          int result = transport->send_message (output,
-                                                0,
-                                                TAO_Transport::TAO_REPLY);
+          int const result = transport->send_message (output,
+                                                      0,
+                                                      TAO_REPLY);
           if (result == -1)
             {
               if (TAO_debug_level > 0)
@@ -1081,7 +1202,7 @@ TAO_GIOP_Message_Base::process_locate_request (TAO_Transport *transport,
           server_request,
           forward_to);
 
-      if (!CORBA::is_nil (forward_to.in ()))
+      if (server_request.is_forwarded ())
         {
           status_info.status = GIOP::OBJECT_FORWARD;
           status_info.forward_location_var = forward_to;
@@ -1101,23 +1222,11 @@ TAO_GIOP_Message_Base::process_locate_request (TAO_Transport *transport,
         }
       else
         {
-          status_info.forward_location_var = server_request.forward_location ();
-
-          if (!CORBA::is_nil (status_info.forward_location_var.in ()))
-            {
-              status_info.status = GIOP::OBJECT_FORWARD;
-              ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("TAO (%P|%t) - TAO_GIOP_Message_Base::process_locate_request, ")
-                          ACE_TEXT ("forwarding\n")));
-            }
-          else
-            {
-              // Normal exception, so the object is not here
-              status_info.status = GIOP::UNKNOWN_OBJECT;
-              ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("TAO (%P|%t) - TAO_GIOP_Message_Base::process_locate_request, ")
-                          ACE_TEXT ("not here\n")));
-            }
+          // Normal exception, so the object is not here
+          status_info.status = GIOP::UNKNOWN_OBJECT;
+          ACE_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("TAO (%P|%t) - TAO_GIOP_Message_Base::process_locate_request, ")
+                      ACE_TEXT ("not here\n")));
         }
     }
 
@@ -1172,7 +1281,7 @@ TAO_GIOP_Message_Base::make_send_locate_reply (TAO_Transport *transport,
   // Send the message
   int const result = transport->send_message (output,
                                               0,
-                                              TAO_Transport::TAO_REPLY);
+                                              TAO_REPLY);
 
   // Print out message if there is an error
   if (result == -1)
@@ -1211,7 +1320,7 @@ TAO_GIOP_Message_Base::send_error (TAO_Transport *transport)
     0, 0, 0, 0
   };
 
-  if (TAO_debug_level >= 5)
+  if (TAO_debug_level > 9)
     {
       this->dump_msg ("send_error",
                       reinterpret_cast <const u_char *> (error_message),
@@ -1321,32 +1430,13 @@ TAO_GIOP_Message_Base::
   // @@ should recv and discard queued data for portability; note
   // that this won't block (long) since we never set SO_LINGER
 
-  if (TAO_debug_level >= 5)
+  if (TAO_debug_level > 9)
     {
       this->dump_msg ("send_close_connection",
                       reinterpret_cast <const u_char *> (close_message),
                       TAO_GIOP_MESSAGE_HEADER_LEN);
     }
 
-#if 0
-  // @@CJC I don't think we need this check b/c the transport's send()
-  // will simply return -1.  However, I guess we could create something
-  // like TAO_Tranport::is_closed() that returns whether the connection
-  // is already closed.  The problem with that, however, is that it's
-  // entirely possible that is_closed() could return TRUE, and then the
-  // transport could get closed down btw. the time it gets called and the
-  // time that the send actually occurs.
-  ACE_HANDLE which = transport->handle ();
-  if (which == ACE_INVALID_HANDLE)
-    {
-      if (TAO_debug_level > 0)
-        ACE_DEBUG ((LM_DEBUG,
-           ACE_TEXT ("TAO (%P|%t) TAO_GIOP_Message_Base::send_close_connection -")
-           ACE_TEXT (" connection already closed\n")));
-      return;
-    }
-#endif
-
   ACE_Data_Block data_block (TAO_GIOP_MESSAGE_HEADER_LEN,
                              ACE_Message_Block::MB_DATA,
                              close_message,
@@ -1364,7 +1454,7 @@ TAO_GIOP_Message_Base::
       if (TAO_debug_level > 0)
         ACE_ERROR ((LM_ERROR,
            ACE_TEXT ("(%P|%t) error closing connection %u, errno = %d\n"),
-           transport->id (), errno));
+           transport->id (), ACE_ERRNO_GET));
     }
 
   transport->close_connection ();
@@ -1408,7 +1498,7 @@ TAO_GIOP_Message_Base::send_reply_exception (
 
   output.more_fragments (false);
 
-  return transport->send_message (output, 0, TAO_Transport::TAO_REPLY);
+  return transport->send_message (output, 0, TAO_REPLY);
 }
 
 void
@@ -1416,6 +1506,11 @@ TAO_GIOP_Message_Base::dump_msg (const char *label,
                                  const u_char *ptr,
                                  size_t len)
 {
+    if (TAO_debug_level < 10)
+      {
+        return;
+      }
+
     static const char digits[] = "0123456789ABCD";
     static const char *names[] =
     {
@@ -1436,11 +1531,11 @@ TAO_GIOP_Message_Base::dump_msg (const char *label,
       message_name = names[slot];
 
     // Byte order.
-    int byte_order = ptr[TAO_GIOP_MESSAGE_FLAGS_OFFSET] & 0x01;
+    int const byte_order = ptr[TAO_GIOP_MESSAGE_FLAGS_OFFSET] & 0x01;
 
     // Get the version info
-    CORBA::Octet major = ptr[TAO_GIOP_VERSION_MAJOR_OFFSET];
-    CORBA::Octet minor = ptr[TAO_GIOP_VERSION_MINOR_OFFSET];
+    CORBA::Octet const major = ptr[TAO_GIOP_VERSION_MAJOR_OFFSET];
+    CORBA::Octet const minor = ptr[TAO_GIOP_VERSION_MINOR_OFFSET];
 
     // request/reply id.
     CORBA::ULong tmp = 0;
@@ -1461,38 +1556,54 @@ TAO_GIOP_Message_Base::dump_msg (const char *label,
             tmp_id = (char * ) (ptr + TAO_GIOP_MESSAGE_HEADER_LEN);
           }
 #if !defined (ACE_DISABLE_SWAP_ON_READ)
-      if (byte_order == TAO_ENCAP_BYTE_ORDER)
-        {
-          id = reinterpret_cast <ACE_CDR::ULong*> (tmp_id);
-        }
-      else
-        {
-          ACE_CDR::swap_4 (tmp_id, reinterpret_cast <char*> (id));
-        }
+        if (byte_order == TAO_ENCAP_BYTE_ORDER)
+          {
+            id = reinterpret_cast <ACE_CDR::ULong*> (tmp_id);
+          }
+        else
+          {
+            ACE_CDR::swap_4 (tmp_id, reinterpret_cast <char*> (id));
+          }
 #else
-      id = reinterpret_cast <ACE_CDR::ULong*> (tmp_id);
+        id = reinterpret_cast <ACE_CDR::ULong*> (tmp_id);
 #endif /* ACE_DISABLE_SWAP_ON_READ */
 
       }
+    else if (ptr[TAO_GIOP_MESSAGE_TYPE_OFFSET] == GIOP::CancelRequest ||
+             ptr[TAO_GIOP_MESSAGE_TYPE_OFFSET] == GIOP::LocateRequest ||
+             ptr[TAO_GIOP_MESSAGE_TYPE_OFFSET] == GIOP::LocateReply)
+      {
+        tmp_id = (char * ) (ptr + TAO_GIOP_MESSAGE_HEADER_LEN);
+#if !defined (ACE_DISABLE_SWAP_ON_READ)
+        if (byte_order == TAO_ENCAP_BYTE_ORDER)
+          {
+            id = reinterpret_cast <ACE_CDR::ULong*> (tmp_id);
+          }
+        else
+          {
+            ACE_CDR::swap_4 (tmp_id, reinterpret_cast <char*> (id));
+          }
+#else
+        id = reinterpret_cast <ACE_CDR::ULong*> (tmp_id);
+#endif /* ACE_DISABLE_SWAP_ON_READ */
+      }
 
     // Print.
     ACE_DEBUG ((LM_DEBUG,
-                "TAO (%P|%t) - GIOP_Message_Base::dump_msg, "
-                "%s GIOP v%c.%c msg, %d data bytes, %s endian, "
-                "Type %s[%u]\n",
-                ACE_TEXT_CHAR_TO_TCHAR (label),
+                ACE_TEXT("TAO (%P|%t) - GIOP_Message_Base::dump_msg, ")
+                ACE_TEXT("%C GIOP message v%c.%c, %d data bytes, %s endian, ")
+                ACE_TEXT("Type %C[%u]\n"),
+                label,
                 digits[ptr[TAO_GIOP_VERSION_MAJOR_OFFSET]],
                 digits[ptr[TAO_GIOP_VERSION_MINOR_OFFSET]],
                 len - TAO_GIOP_MESSAGE_HEADER_LEN ,
                 (byte_order == TAO_ENCAP_BYTE_ORDER) ? ACE_TEXT("my") : ACE_TEXT("other"),
-                ACE_TEXT_CHAR_TO_TCHAR(message_name),
+                message_name,
                 *id));
-
-    if (TAO_debug_level >= 10)
-      ACE_HEX_DUMP ((LM_DEBUG,
-                      (const char *) ptr,
-                      len,
-                      ACE_TEXT ("GIOP message")));
+    ACE_HEX_DUMP ((LM_DEBUG,
+                   (const char *) ptr,
+                   len,
+                   ACE_TEXT ("GIOP message")));
 }
 
 int
@@ -1768,7 +1879,7 @@ TAO_GIOP_Message_Base::consolidate_fragmented_message (
           return -1;
         }
 
-      const CORBA::ULong request_id = tmp_request_id;
+      CORBA::ULong const request_id = tmp_request_id;
 
       while (this->fragment_stack_.pop (head) != -1)
         {
