@@ -4,7 +4,7 @@
 /**
  *  @file   GIOP_Message_Generator_Parser_11.h
  *
- *  $Id: GIOP_Message_Generator_Parser_11.h 74111 2006-08-18 09:15:13Z johnnyw $
+ *  $Id: GIOP_Message_Generator_Parser_11.h 80805 2008-03-03 14:53:30Z johnnyw $
  *
  *  @author Balachandran Natarajan <bala@cs.wustl.edu>
  */
@@ -32,7 +32,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  *  the 1.0 class.
  *
  */
-class TAO_Export TAO_GIOP_Message_Generator_Parser_11
+class TAO_GIOP_Message_Generator_Parser_11
   : public TAO_GIOP_Message_Generator_Parser_10
 {
 public:
