@@ -4,7 +4,7 @@
 /**
  *  @file   GIOP_Message_Generator_Parser_Impl.h
  *
- *  $Id: GIOP_Message_Generator_Parser_Impl.h 69150 2005-11-02 07:13:04Z ossama $
+ *  $Id: GIOP_Message_Generator_Parser_Impl.h 80805 2008-03-03 14:53:30Z johnnyw $
  *
  *  @author Balachandran Natarajan <bala@cs.wustl.edu>
  */
@@ -38,7 +38,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  *  versions in the higher versions.
  */
 
-class TAO_Export TAO_GIOP_Message_Generator_Parser_Impl
+class TAO_GIOP_Message_Generator_Parser_Impl
 {
 public:
 
