@@ -25,7 +25,7 @@
 
 ACE_RCSID (tao,
            IIOP_Acceptor,
-           "$Id: IIOP_Acceptor.cpp 78995 2007-07-23 11:59:20Z johnnyw $")
+           "$Id: IIOP_Acceptor.cpp 85630 2009-06-12 18:44:52Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -39,16 +39,23 @@ TAO_IIOP_Acceptor::TAO_IIOP_Acceptor (void)
     version_ (TAO_DEF_GIOP_MAJOR, TAO_DEF_GIOP_MINOR),
     orb_core_ (0),
     reuse_addr_ (1),
-#if defined (ACE_HAS_IPV6)
+#if defined (ACE_HAS_IPV6) && !defined (ACE_USES_IPV4_IPV6_MIGRATION)
     default_address_ (static_cast<unsigned short> (0), ACE_IPV6_ANY, AF_INET6),
 #else
     default_address_ (static_cast<unsigned short> (0), static_cast<ACE_UINT32> (INADDR_ANY)),
-#endif /* ACE_HAS_IPV6 */
-    base_acceptor_ (),
+#endif /* ACE_HAS_IPV6  && !ACE_USES_IPV4_IPV6_MIGRATION */
+    base_acceptor_ (this),
     creation_strategy_ (0),
     concurrency_strategy_ (0),
     accept_strategy_ (0)
 {
+#if defined (ACE_HAS_IPV6) && defined (ACE_USES_IPV4_IPV6_MIGRATION)
+  if (ACE::ipv6_enabled())
+    default_address_.set (
+      static_cast<unsigned short> (0),
+      ACE_IPV6_ANY,
+      AF_INET6);
+#endif /* ACE_HAS_IPV6 && ACE_USES_IPV4_IPV6_MIGRATION */
 }
 
 //@@ TAO_ACCEPTOR_SPL_COPY_HOOK_END
@@ -136,7 +143,7 @@ TAO_IIOP_Acceptor::create_new_profile (const TAO::ObjectKey &object_key,
       // Do not add any tagged components to the profile if configured
       // by the user not to do so, or if an IIOP 1.0 endpoint is being
       // created (IIOP 1.0 did not support tagged components).
-      if (this->orb_core_->orb_params ()->std_profile_components () == 0
+      if (!this->orb_core_->orb_params ()->std_profile_components ()
           || (this->version_.major == 1 && this->version_.minor == 0))
         continue;
 
@@ -159,7 +166,7 @@ TAO_IIOP_Acceptor::create_shared_profile (const TAO::ObjectKey &object_key,
   TAO_Profile *pfile = 0;
   TAO_IIOP_Profile *iiop_profile = 0;
 
-  // First see if <mprofile> already contains a IIOP profile.
+  // First see if @a mprofile already contains a IIOP profile.
   for (TAO_PHandle i = 0; i != mprofile.profile_count (); ++i)
     {
       pfile = mprofile.get_profile (i);
@@ -195,7 +202,7 @@ TAO_IIOP_Acceptor::create_shared_profile (const TAO::ObjectKey &object_key,
       // Do not add any tagged components to the profile if configured
       // by the user not to do so, or if an IIOP 1.0 endpoint is being
       // created (IIOP 1.0 did not support tagged components).
-      if (this->orb_core_->orb_params ()->std_profile_components () != 0
+      if (this->orb_core_->orb_params ()->std_profile_components ()
           && (this->version_.major >= 1 && this->version_.minor >= 1))
         {
           iiop_profile->tagged_components ().set_orb_type (TAO_ORB_TYPE);
@@ -274,7 +281,7 @@ TAO_IIOP_Acceptor::open (TAO_ORB_Core *orb_core,
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - ")
-                  ACE_TEXT ("IIOP_Acceptor::open, address==%s, options=%s\n"),
+                  ACE_TEXT ("IIOP_Acceptor::open, address==%C, options=%C\n"),
                   address, options));
     }
 
@@ -348,7 +355,7 @@ TAO_IIOP_Acceptor::open (TAO_ORB_Core *orb_core,
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - ")
-                  ACE_TEXT ("IIOP_Acceptor::open, specified host=%s:%d\n"),
+                  ACE_TEXT ("IIOP_Acceptor::open, specified host=%C:%d\n"),
                   (specified_hostname.length() == 0 ? "<null>" : specified_hostname.c_str()),
                   addr.get_port_number ()));
     }
@@ -372,8 +379,8 @@ TAO_IIOP_Acceptor::open (TAO_ORB_Core *orb_core,
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("TAO (%P|%t) - ")
                       ACE_TEXT ("IIOP_Acceptor::open, ")
-                      ACE_TEXT ("Overriding address in IOR with %s\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR (this->hostname_in_ior_)));
+                      ACE_TEXT ("Overriding address in IOR with %C\n"),
+                      this->hostname_in_ior_));
         }
       specified_hostname = this->hostname_in_ior_;
     }
@@ -389,8 +396,7 @@ TAO_IIOP_Acceptor::open (TAO_ORB_Core *orb_core,
   if (this->addrs_[0].set (addr) != 0)
     return -1;
 
-  return this->open_i (addr,
-                       reactor);
+  return this->open_i (addr, reactor);
 }
 
 int
@@ -452,7 +458,7 @@ TAO_IIOP_Acceptor::open_i (const ACE_INET_Addr& addr,
                   ACCEPT_STRATEGY (this->orb_core_),
                   -1);
 
-  unsigned short requested_port = addr.get_port_number ();
+  unsigned short const requested_port = addr.get_port_number ();
   if (requested_port == 0)
     {
       // don't care, i.e., let the OS choose an ephemeral port
@@ -465,10 +471,10 @@ TAO_IIOP_Acceptor::open_i (const ACE_INET_Addr& addr,
                                      this->reuse_addr_) == -1)
         {
           if (TAO_debug_level > 0)
-            ACE_DEBUG ((LM_DEBUG,
+            ACE_ERROR ((LM_ERROR,
                         ACE_TEXT ("TAO (%P|%t) - IIOP_Acceptor::open_i, ")
-                        ACE_TEXT ("%p, "),
-                        ACE_TEXT ("cannot open acceptor\n")));
+                        ACE_TEXT ("%p\n"),
+                        ACE_TEXT ("cannot open acceptor")));
           return -1;
         }
     }
@@ -553,8 +559,8 @@ TAO_IIOP_Acceptor::open_i (const ACE_INET_Addr& addr,
       if (TAO_debug_level > 0)
         ACE_ERROR ((LM_ERROR,
                     ACE_TEXT ("TAO (%P|%t) - IIOP_Acceptor::open_i, ")
-                    ACE_TEXT ("%p"),
-                    ACE_TEXT ("cannot get local addr\n")));
+                    ACE_TEXT ("%p\n"),
+                    ACE_TEXT ("cannot get local addr")));
       return -1;
     }
 
@@ -579,18 +585,25 @@ TAO_IIOP_Acceptor::open_i (const ACE_INET_Addr& addr,
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("TAO (%P|%t) - IIOP_Acceptor::open_i, ")
-                      ACE_TEXT ("listening on: <%s:%u>\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR(this->hosts_[i]),
+                      ACE_TEXT ("listening on: <%C:%u>\n"),
+                      this->hosts_[i],
                       this->addrs_[i].get_port_number ()));
         }
     }
 
+  // In the event that an accept() fails, we can examine the reason.  If
+  // the reason warrants it, we can try accepting again at a later time.
+  // The amount of time we wait to accept again is governed by this orb
+  // parameter.
+  this->set_error_retry_delay (
+    this->orb_core_->orb_params ()->accept_error_delay());
+
   return 0;
 }
 
 int
 TAO_IIOP_Acceptor::hostname (TAO_ORB_Core *orb_core,
-                             ACE_INET_Addr &addr,
+                             const ACE_INET_Addr &addr,
                              char *&host,
                              const char *specified_hostname)
 {
@@ -599,7 +612,7 @@ TAO_IIOP_Acceptor::hostname (TAO_ORB_Core *orb_core,
       if (TAO_debug_level >= 5)
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("TAO (%P|%t) IIOP_Acceptor - ")
-                      ACE_TEXT ("Overriding the hostname with <%s>\n"),
+                      ACE_TEXT ("Overriding the hostname with <%C>\n"),
                       this->hostname_in_ior_));
 
       host = CORBA::string_dup (this->hostname_in_ior_);
@@ -784,7 +797,7 @@ TAO_IIOP_Acceptor::parse_address (const char *address,
 
 
 int
-TAO_IIOP_Acceptor::dotted_decimal_address (ACE_INET_Addr &addr,
+TAO_IIOP_Acceptor::dotted_decimal_address (const ACE_INET_Addr &addr,
                                            char *&host)
 {
   int result = 0;
@@ -818,8 +831,8 @@ TAO_IIOP_Acceptor::dotted_decimal_address (ACE_INET_Addr &addr,
         ACE_ERROR ((LM_ERROR,
                     ACE_TEXT ("TAO (%P|%t) - ")
                     ACE_TEXT ("IIOP_Acceptor::dotted_decimal_address, ")
-                    ACE_TEXT ("- %p, "),
-                    ACE_TEXT ("cannot determine hostname\n")));
+                    ACE_TEXT ("- %p\n"),
+                    ACE_TEXT ("cannot determine hostname")));
       return -1;
     }
 
@@ -1173,7 +1186,7 @@ TAO_IIOP_Acceptor::parse_options (const char *str)
                   argc));
       for (int i = 0; i < argc; i++)
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT("\t%s\n"),
+                    ACE_TEXT("\t%C\n"),
                     argv[i]->c_str()));
       result = -1;
     }
@@ -1195,9 +1208,9 @@ TAO_IIOP_Acceptor::parse_options_i (int &argc,
       if (slot == len - 1
           || slot == ACE_CString::npos)
         ACE_ERROR_RETURN ((LM_ERROR,
-                           ACE_TEXT ("TAO (%P|%t) - IIOP option <%s> is ")
+                           ACE_TEXT ("TAO (%P|%t) - IIOP option <%C> is ")
                            ACE_TEXT ("missing a value.\n"),
-                           ACE_TEXT_CHAR_TO_TCHAR(argv[i]->c_str ())),
+                           argv[i]->c_str ()),
                           -1);
 
       ACE_CString name = argv[i]->substring (0, slot);
@@ -1215,7 +1228,7 @@ TAO_IIOP_Acceptor::parse_options_i (int &argc,
           if (range < 1 || range > ACE_MAX_DEFAULT_PORT)
             ACE_ERROR_RETURN ((LM_ERROR,
                                ACE_TEXT ("TAO (%P|%t) Invalid IIOP endpoint ")
-                               ACE_TEXT ("portspan: <%s>\n")
+                               ACE_TEXT ("portspan: <%C>\n")
                                ACE_TEXT ("Valid range 1 -- %d\n"),
                                value.c_str (), ACE_MAX_DEFAULT_PORT),
                               -1);
