@@ -1,3 +1,4 @@
+
 #include "tao/IIOP_Connection_Handler.h"
 
 #if defined (TAO_HAS_IIOP) && (TAO_HAS_IIOP != 0)
@@ -17,10 +18,43 @@
 
 ACE_RCSID (tao,
            IIOP_Connection_Handler,
-           "$Id: IIOP_Connection_Handler.cpp 80288 2007-12-17 20:05:04Z johnnyw $")
+           "$Id: IIOP_Connection_Handler.cpp 85817 2009-06-26 20:44:58Z mitza $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
+
+#ifdef TAO_LOG_CH_REF_COUNTS
+ACE_Event_Handler::Reference_Count
+TAO_IIOP_Connection_Handler::add_reference (void)
+{
+  Reference_Count rc = TAO_IIOP_SVC_HANDLER::add_reference ();
+  if (TAO_debug_level > 9)
+    {
+      ACE_DEBUG ((LM_DEBUG,
+                  ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler[%d]::")
+                  ACE_TEXT("add_reference, up to %d\n"),
+                  this->transport (), rc));
+    }
+  return rc;
+
+}
+
+ACE_Event_Handler::Reference_Count
+TAO_IIOP_Connection_Handler::remove_reference (void)
+{
+  TAO_Transport *tport = this->transport ();
+  Reference_Count rc = TAO_IIOP_SVC_HANDLER::remove_reference ();
+  if (TAO_debug_level > 9)
+    {
+      ACE_DEBUG ((LM_DEBUG,
+                  ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler[%d]::")
+                  ACE_TEXT("remove_reference, down to %d\n"), tport, rc));
+    }
+  return rc;
+}
+#endif /*TAO_LOG_CH_REF_COUNTS*/
+
+
 TAO_IIOP_Connection_Handler::TAO_IIOP_Connection_Handler (ACE_Thread_Manager *t)
   : TAO_IIOP_SVC_HANDLER (t, 0 , 0),
     TAO_Connection_Handler (0),
@@ -45,6 +79,14 @@ TAO_IIOP_Connection_Handler::TAO_IIOP_Connection_Handler (
   ACE_NEW (specific_transport,
            TAO_IIOP_Transport (this, orb_core));
 
+  if (TAO_debug_level > 9)
+    {
+      ACE_DEBUG ((LM_DEBUG,
+                  ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler[%d] ctor, ")
+                  ACE_TEXT("this=%@\n"),
+                  static_cast<TAO_Transport *> (specific_transport), this));
+    }
+
   // store this pointer (indirectly increment ref count)
   this->transport (specific_transport);
 }
@@ -96,6 +138,8 @@ TAO_IIOP_Connection_Handler::open (void*)
     this->orb_core ()->orb_params ()->sock_keepalive ();
   protocol_properties.dont_route_ =
    this->orb_core ()->orb_params ()->sock_dontroute ();
+  protocol_properties.hop_limit_ =
+   this->orb_core ()->orb_params ()->ip_hoplimit ();
 
   TAO_Protocols_Hooks *tph = this->orb_core ()->get_protocols_hooks ();
 
@@ -161,6 +205,59 @@ TAO_IIOP_Connection_Handler::open (void*)
     }
 #endif /* ! ACE_LACKS_SO_DONTROUTE */
 
+  if (protocol_properties.hop_limit_ >= 0)
+    {
+      int result = 0;
+#if defined (ACE_HAS_IPV6)
+      ACE_INET_Addr local_addr;
+      if (this->peer ().get_local_addr (local_addr) == -1)
+        {
+          result = -1;
+        }
+      else if (local_addr.get_type () == AF_INET6)
+        {
+#if defined (ACE_WIN32)
+          DWORD hop_limit =
+            static_cast<DWORD> (protocol_properties.hop_limit_);
+#else
+          int hop_limit =
+            static_cast<int> (protocol_properties.hop_limit_);
+#endif
+          result = this->peer ().set_option (
+            IPPROTO_IPV6,
+            IPV6_UNICAST_HOPS,
+            (void *) &hop_limit,
+            sizeof (hop_limit));
+        }
+      else
+#endif /* ACE_HAS_IPV6 */
+        {
+#if defined (ACE_WIN32)
+          DWORD hop_limit =
+            static_cast<DWORD> (protocol_properties.hop_limit_);
+#else
+          int hop_limit =
+            static_cast<int> (protocol_properties.hop_limit_);
+#endif
+          result = this->peer ().set_option (
+            IPPROTO_IP,
+            IP_TTL,
+            (void *) &hop_limit,
+            sizeof (hop_limit));
+        }
+
+      if (result != 0)
+        {
+          if (TAO_debug_level)
+            {
+              ACE_ERROR ((LM_ERROR,
+                          ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler::open, ")
+                          ACE_TEXT("couldn't set hop limit\n\n")));
+            }
+          return -1;
+        }
+    }
+
   if (this->transport ()->wait_strategy ()->non_blocking ()
       || this->transport ()->opened_as () == TAO::TAO_SERVER_ROLE)
     {
@@ -182,7 +279,7 @@ TAO_IIOP_Connection_Handler::open (void*)
   if (TAO_debug_level > 2)
     ACE_DEBUG ((LM_DEBUG,
                 ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler::open, ")
-                ACE_TEXT("The local addr is <%s:%d> \n"),
+                ACE_TEXT("The local addr is <%C:%d>\n"),
                 local_addr.get_host_addr (),
                 local_addr.get_port_number()));
 
@@ -330,7 +427,12 @@ TAO_IIOP_Connection_Handler::handle_timeout (const ACE_Time_Value &,
 
   int const ret = this->close ();
   this->reset_state (TAO_LF_Event::LFS_TIMEOUT);
-
+  if (TAO_debug_level > 9)
+    {
+      ACE_DEBUG ((LM_DEBUG, "TAO (%P|%t) - TAO_IIOP_Connection_Handler[%d]::"
+                  "handle_timeout reset state to LFS_TIMEOUT\n",
+                  this->transport ()-> id()));
+    }
   return ret;
 }
 
@@ -342,9 +444,9 @@ TAO_IIOP_Connection_Handler::handle_close (ACE_HANDLE, ACE_Reactor_Mask)
 }
 
 int
-TAO_IIOP_Connection_Handler::close (u_long)
+TAO_IIOP_Connection_Handler::close (u_long flags)
 {
-  return this->close_handler ();
+  return this->close_handler (flags);
 }
 
 int
@@ -374,7 +476,7 @@ TAO_IIOP_Connection_Handler::add_transport_to_cache (void)
     this->orb_core ()->lane_resources ().transport_cache ();
 
   // Idle the transport..
-  return cache.cache_idle_transport (&prop, this->transport ());
+  return cache.cache_transport (&prop, this->transport ());
 }
 
 int
@@ -382,7 +484,7 @@ TAO_IIOP_Connection_Handler::process_listen_point_list (
     IIOP::ListenPointList &listen_list)
 {
   // Get the size of the list
-  CORBA::ULong const len = listen_list.length ();
+  CORBA::ULong len = listen_list.length ();
 
   if (TAO_debug_level > 0 && len == 0)
     {
@@ -392,20 +494,43 @@ TAO_IIOP_Connection_Handler::process_listen_point_list (
                   ACE_TEXT("Received list of size 0, check client config.\n")));
     }
 
+  // @@ We can only handle a single endpoint for now because the
+  // transport is recached for each endpoint, loosing older
+  // information. This means that when more than one listen_point is
+  // sent, the cache will end up only being associated with the last
+  // address.  This poses a problem at invocation time because the
+  // default endpoint selector steps through the profiles/endpoints
+  // sequentially and will try and possibly succeed in connecting to
+  // one of the earlier endpoints.  My assumption is that when this
+  // method is called, it is before the first attempt to connect to
+  // any object in the target process, thus the first listen point in
+  // the list will correspond with the first profile and thus that
+  // should match the cache.
+  //
+  // Probably what needs to be done to make this model work well is to
+  // allow the transport cache to have multiple keys reference the
+  // same transport so that rather than recaching, we simply add a
+  // key.
+  len = 1;
   for (CORBA::ULong i = 0; i < len; ++i)
     {
       IIOP::ListenPoint listen_point = listen_list[i];
-      ACE_INET_Addr addr (listen_point.port,
-                          listen_point.host.in ());
+
+      // since the supplied host/port could be unresolvable, the assigning
+      // constructor of the INET addr should not be as it will emit an error
+      // if the underlying set fails. An unresolvable address in this case
+      // is OK, as it will only be used to find an already cached transport.
+      ACE_INET_Addr addr;
+      (void)addr.set(listen_point.port, listen_point.host.in ());
 
       if (TAO_debug_level > 0)
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler::")
                       ACE_TEXT("process_listen_point_list, ")
-                      ACE_TEXT("Listening port [%d] on [%s]\n"),
+                      ACE_TEXT("Listening port [%d] on [%C]\n"),
                       listen_point.port,
-                      ACE_TEXT_CHAR_TO_TCHAR(listen_point.host.in ())));
+                      listen_point.host.in ()));
         }
 
       // Construct an  IIOP_Endpoint object using the host as provided
@@ -451,8 +576,8 @@ TAO_IIOP_Connection_Handler::set_tos (int tos)
           if (TAO_debug_level)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          "TAO (%P|%t) - IIOP_Connection_Handler::"
-                          "set_dscp_codepoint -> IPV6_TCLASS not supported yet\n"));
+                          ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler::")
+                          ACE_TEXT("set_dscp_codepoint -> IPV6_TCLASS not supported yet\n")));
             }
           return 0;
         }
@@ -472,8 +597,8 @@ TAO_IIOP_Connection_Handler::set_tos (int tos)
       if (TAO_debug_level)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      "TAO (%P|%t) - IIOP_Connection_Handler::"
-                      "set_dscp_codepoint -> dscp: %x; result: %d; %s\n",
+                      ACE_TEXT("TAO (%P|%t) - IIOP_Connection_Handler::")
+                      ACE_TEXT("set_dscp_codepoint -> dscp: %x; result: %d; %C\n"),
                       tos,
                       result,
                       result == -1 ? "try running as superuser" : ""));
@@ -543,6 +668,11 @@ TAO_IIOP_Connection_Handler::abort (void)
     }
 }
 
+int
+TAO_IIOP_Connection_Handler::handle_write_ready (const ACE_Time_Value *timeout)
+{
+  return ACE::handle_write_ready (this->peer ().get_handle (), timeout);
+}
 
 
 //@@ CONNECTION_HANDLER_SPL_COPY_HOOK_END
