@@ -21,7 +21,7 @@
 
 ACE_RCSID (tao,
            IIOP_Connector,
-           "$Id: IIOP_Connector.cpp 80199 2007-12-05 14:49:58Z johnnyw $")
+           "$Id: IIOP_Connector.cpp 86593 2009-09-02 14:58:00Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -188,41 +188,62 @@ TAO_IIOP_Connector::make_connection (TAO::Profile_Transport_Resolver *r,
   TAO_IIOP_Connection_Handler *svc_handler = 0;
   TAO_IIOP_Endpoint *iiop_endpoint =
     this->remote_endpoint (desc.endpoint());
-  int result = -1;
   if (iiop_endpoint == 0)
     return 0;
 
-  result = this->begin_connection (svc_handler, r, iiop_endpoint, timeout);
+  int const result =
+    this->begin_connection (svc_handler, r, iiop_endpoint, timeout);
+
+  // Make sure that we always do a remove_reference
+  ACE_Event_Handler_var svc_handler_auto_ptr (svc_handler);
 
   if (result == -1 && errno != EWOULDBLOCK)
     {
-      // connect completed unsuccessfully
-      svc_handler->remove_reference();
-       // Give users a clue to the problem.
+      // Give users a clue to the problem.
       if (TAO_debug_level > 1)
         {
           ACE_ERROR ((LM_ERROR,
-                      ACE_TEXT ("TAO (%P|%t) IIOP_Connector::make_connection, ")
-                      ACE_TEXT("connection to <%s:%d> failed (%p)\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR (iiop_endpoint->host ()),
+                      ACE_TEXT ("TAO (%P|%t) - IIOP_Connector::make_connection, ")
+                      ACE_TEXT("connection to <%C:%d> failed (%p)\n"),
+                      iiop_endpoint->host (),
                       iiop_endpoint->port (),
                       ACE_TEXT("errno")));
         }
-    return 0;
+      return 0;
     }
+
   TAO_IIOP_Connection_Handler **sh_ptr = &svc_handler;
   TAO_IIOP_Endpoint **ep_ptr = &iiop_endpoint;
   TAO_LF_Multi_Event mev;
   mev.add_event (svc_handler);
 
-  return this->complete_connection (result,
-                                    desc,
-                                    sh_ptr,
-                                    ep_ptr,
-                                    1U,
-                                    r,
-                                    &mev,
-                                    timeout);
+  TAO_Transport *transport =
+    this->complete_connection (result,
+                               desc,
+                               sh_ptr,
+                               ep_ptr,
+                               1U,
+                               r,
+                               &mev,
+                               timeout);
+
+  // If complete_connection was unsuccessful then remove
+  // the last reference that we have to the svc_handler.
+  if (transport == 0)
+    {
+      if (TAO_debug_level > 1)
+        {
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) - IIOP_Connector::make_connection, ")
+                      ACE_TEXT ("connection to <%C:%d> completed unsuccessfully\n"),
+                      iiop_endpoint->host (),
+                      iiop_endpoint->port ()));
+        }
+      return 0;
+    }
+
+  svc_handler_auto_ptr.release ();
+  return transport;
 }
 
 TAO_Transport *
@@ -300,13 +321,24 @@ TAO_IIOP_Connector::make_parallel_connection (
 
   TAO_Transport *winner = 0;
   if (count > 0) // only complete if at least one pending or success
-    winner = this->complete_connection (result,
-                                        desc,
-                                        shlist,
-                                        eplist,
-                                        count,r,
-                                        &mev,
-                                        timeout);
+    {
+      // Make sure that we always do a remove_reference for every member
+      // of the list
+      TAO_IIOP_Connection_Handler_Array_Guard svc_handler_auto_ptr (shlist, count);
+
+      winner = this->complete_connection (result,
+                                          desc,
+                                          shlist,
+                                          eplist,
+                                          count,r,
+                                          &mev,
+                                          timeout);
+
+      // We add here an extra reference so that when svc_handler_auto_ptr
+      // will go out of scope the winner will be still alive.
+      if (winner)
+        winner->add_reference ();
+    }
 
   delete [] shlist; // reference reductions should have been done already
   delete [] eplist;
@@ -319,69 +351,82 @@ TAO_IIOP_Connector::begin_connection (TAO_IIOP_Connection_Handler *&svc_handler,
                                       TAO_IIOP_Endpoint *iiop_endpoint,
                                       ACE_Time_Value *timeout)
 {
-  const ACE_INET_Addr &remote_address =
-    iiop_endpoint->object_addr ();
+  const ACE_INET_Addr &remote_address = iiop_endpoint->object_addr ();
 
   u_short port = 0;
-  const ACE_UINT32 ia_any = INADDR_ANY;
+  ACE_UINT32 const ia_any = INADDR_ANY;
   ACE_INET_Addr local_addr(port, ia_any);
 
   if (iiop_endpoint->is_preferred_network ())
-    local_addr.set (port,
-                    iiop_endpoint->preferred_network ());
+    {
+      local_addr.set (port, iiop_endpoint->preferred_network ());
+    }
 #if defined (ACE_HAS_IPV6)
   else if (remote_address.get_type () == AF_INET6)
-    local_addr.set (port,
-                    ACE_IPV6_ANY);
+    {
+      local_addr.set (port, ACE_IPV6_ANY);
+    }
 #endif /* ACE_HAS_IPV6 */
 
   if (TAO_debug_level > 2)
     ACE_DEBUG ((LM_DEBUG,
                 ACE_TEXT ("TAO (%P|%t) - IIOP_Connector::begin_connection, ")
-                ACE_TEXT ("to <%s:%d> which should %s\n"),
-                ACE_TEXT_CHAR_TO_TCHAR(iiop_endpoint->host()),
+                ACE_TEXT ("to <%C:%d> which should %s\n"),
+                iiop_endpoint->host(),
                 iiop_endpoint->port(),
                 r->blocked_connect () ? ACE_TEXT("block") : ACE_TEXT("nonblock")));
 
   // Get the right synch options
   ACE_Synch_Options synch_options;
 
-  this->active_connect_strategy_->synch_options (timeout,
-                                                 synch_options);
+  this->active_connect_strategy_->synch_options (timeout, synch_options);
 
   // The code used to set the timeout to zero, with the intent of
   // polling the reactor for connection completion. However, the side-effect
   // was to cause the connection to timeout immediately.
-
   svc_handler = 0;
 
-  int result =
+  int const result =
     this->base_connector_.connect (svc_handler,
                                    remote_address,
                                    synch_options,
                                    local_addr);
 
-  // The connect() method creates the service handler and bumps the
-  // #REFCOUNT# up one extra.  There are four possibilities from
-  // calling connect(): (a) connection succeeds immediately - in this
-  // case, the #REFCOUNT# on the handler is two; (b) connection
-  // completion is pending - in this case, the #REFCOUNT# on the
-  // handler is also two; (c) connection fails immediately - in this
-  // case, the #REFCOUNT# on the handler is one since close() gets
-  // called on the handler; (d) the connect immediately returns when we
-  // have specified that it shouldn't block.
-  //
-  // The extra reference count in
-  // TAO_Connect_Creation_Strategy::make_svc_handler() is needed in
-  // the case when connection completion is pending and we are going
-  // to wait on a variable in the handler to changes, signifying
-  // success or failure.  Note, that this increment cannot be done
-  // once the connect() returns since this might be too late if
-  // another thread pick up the completion and potentially deletes the
-  // handler before we get a chance to increment the reference count.
   return result;
 }
 
+namespace
+{
+  /// RAII holder for a TAO_Transport list
+  class TList_Holder
+  {
+  public:
+    TList_Holder (size_t count)
+      : tlist_ (0)
+    {
+      // Resources are acquired during initialization (RAII)
+      ACE_NEW (tlist_, TAO_Transport*[count]);
+    }
+
+    ~TList_Holder (void)
+    {
+      // Resources are unacquired during uninitialization
+      delete [] tlist_;
+    }
+
+    operator TAO_Transport** (void)
+    {
+      return tlist_;
+    }
+
+  private:
+    TAO_Transport** tlist_;
+  private:
+    ACE_UNIMPLEMENTED_FUNC (void operator= (const TList_Holder &))
+    ACE_UNIMPLEMENTED_FUNC (TList_Holder (const TList_Holder &))
+  };
+}
+
 TAO_Transport *
 TAO_IIOP_Connector::complete_connection (int result,
                                          TAO_Transport_Descriptor_Interface &desc,
@@ -392,12 +437,9 @@ TAO_IIOP_Connector::complete_connection (int result,
                                          TAO_LF_Multi_Event *mev,
                                          ACE_Time_Value *timeout)
 {
-  // Make sure that we always do a remove_reference for every member
-  // of the list
-  TAO_IIOP_Connection_Handler_Array_Guard svc_handler_auto_ptr (sh_list,count);
+  TList_Holder tlist(count);
+
   TAO_Transport *transport  = 0;
-  TAO_Transport **tlist = 0;
-  ACE_NEW_RETURN (tlist,TAO_Transport*[count],0);
 
   //  populate the transport list
   for (unsigned i = 0; i < count; i++)
@@ -405,17 +447,28 @@ TAO_IIOP_Connector::complete_connection (int result,
 
   if (result != -1)
     {
-      // We received a compeleted connection and 0 or more pending.
+      // We received a completed connection and 0 or more pending.
       // the winner is the last member of the list, because the
       // iterator stopped on a successful connect.
       transport = tlist[count-1];
+      desc.reset_endpoint (ep_list[count-1]);
+      TAO::Transport_Cache_Manager &tcm =
+        this->orb_core ()->lane_resources ().transport_cache ();
+      if (tcm.cache_transport (&desc, transport) == -1)
+        {
+          // Cache is full, so close the connection again
+          sh_list[count-1]->close ();
+          transport = 0;
+        }
     }
   else
     {
       if (count == 1)
         {
           transport = tlist[0];
+          desc.reset_endpoint(ep_list[0]);
           if (!this->wait_for_connection_completion (r,
+                                                     desc,
                                                      transport,
                                                      timeout))
             {
@@ -461,8 +514,6 @@ TAO_IIOP_Connector::complete_connection (int result,
   ACE_OS::nanosleep (&ts);
 #endif // INDUCE_BUG_2654_A
 
-  int retval = -1;
-
   // At this point, the connection has been successfully created
   // connected or not connected, but we have a connection.
   TAO_IIOP_Connection_Handler *svc_handler = 0;
@@ -470,33 +521,19 @@ TAO_IIOP_Connector::complete_connection (int result,
 
   if (transport != 0)
     {
-      if (count == 1)
+      for (unsigned i = 0; i < count; i++)
         {
-          svc_handler = sh_list[0];
-          iiop_endpoint = ep_list[0];
-        }
-      else
-        {
-          for (unsigned i = 0; i < count; i++)
+          if (transport == tlist[i])
             {
-              if (transport == tlist[i])
-                {
-                  svc_handler = sh_list[i];
-                  iiop_endpoint = ep_list[i];
-                  break;
-                }
+              svc_handler = sh_list[i];
+              iiop_endpoint = ep_list[i];
+              break;
             }
         }
     }
-
-
-  // Done with the transport list. It was a temporary that did not
-  // affect the reference count.
-  delete [] tlist;
-
-  // In case of errors transport is zero
-  if (transport == 0)
+  else
     {
+      // In case of errors transport is zero
       // Give users a clue to the problem.
       if (TAO_debug_level > 3)
         {
@@ -504,8 +541,8 @@ TAO_IIOP_Connector::complete_connection (int result,
             {
               ACE_ERROR ((LM_ERROR,
                           ACE_TEXT ("TAO (%P|%t) - IIOP_Connector::complete_connection,")
-                          ACE_TEXT (" connection to <%s:%d> failed (%p)\n"),
-                          ACE_TEXT_CHAR_TO_TCHAR (ep_list[i]->host ()),
+                          ACE_TEXT (" connection to <%C:%d> failed (%p)\n"),
+                          ep_list[i]->host (),
                           ep_list[i]->port (),
                           ACE_TEXT("errno")));
             }
@@ -534,7 +571,7 @@ TAO_IIOP_Connector::complete_connection (int result,
       if (TAO_debug_level > 0)
         ACE_DEBUG((LM_DEBUG,
                    ACE_TEXT("TAO (%P|%t) - IIOP_Connector::make_connection, ")
-                   ACE_TEXT("transport in error before cache! \n")));
+                   ACE_TEXT("transport in error before cache!\n")));
       transport->connection_handler()->cancel_pending_connection();
       return 0;
     }
@@ -543,10 +580,10 @@ TAO_IIOP_Connector::complete_connection (int result,
     {
     ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - IIOP_Connector::make_connection, ")
-                  ACE_TEXT ("new %s connection to <%s:%d> on Transport[%d]\n"),
+                  ACE_TEXT ("new %s connection to <%C:%d> on Transport[%d]\n"),
                   transport->is_connected() ?
                   ACE_TEXT("connected") : ACE_TEXT("not connected"),
-                  ACE_TEXT_CHAR_TO_TCHAR (iiop_endpoint->host ()),
+                  iiop_endpoint->host (),
                 iiop_endpoint->port (),
                 svc_handler->peer ().get_handle ()));
     }
@@ -559,10 +596,10 @@ TAO_IIOP_Connector::complete_connection (int result,
   struct timespec ts = udelay;
   ACE_OS::nanosleep (&ts);
 #endif // INDUCE_BUG_2654_C
+  int retval = 0;
 
-
-  // Add the handler to Cache
-  if (count == 1 || desc.reset_endpoint(iiop_endpoint))
+  // Only for parallel connect, update the cache to show this in idle state
+  if (count > 1 && desc.reset_endpoint (iiop_endpoint))
     {
       retval = this->orb_core ()->
         lane_resources ().transport_cache ().cache_transport (&desc,
@@ -570,7 +607,7 @@ TAO_IIOP_Connector::complete_connection (int result,
     }
 
   // Failure in adding to cache
-  if (retval != 0)
+  if (retval == -1)
     {
       // Close the handler.
       svc_handler->close ();
@@ -595,7 +632,7 @@ TAO_IIOP_Connector::complete_connection (int result,
       if (TAO_debug_level > 0)
         ACE_DEBUG((LM_DEBUG,
                    ACE_TEXT("TAO (%P|%t) - IIOP_Connector::make_connection, ")
-                   ACE_TEXT("transport in error after cache! \n")));
+                   ACE_TEXT("transport in error after cache!\n")));
       svc_handler->cancel_pending_connection();
       transport->purge_entry();
       return 0;
@@ -610,25 +647,10 @@ TAO_IIOP_Connector::complete_connection (int result,
   ACE_OS::nanosleep (&ts);
 #endif // INDUCE_BUG_2654_D
 
-  if (transport->is_connected () &&
-      transport->wait_strategy ()->register_handler () != 0)
+  // Have the transport register itself with the wait strategy and
+  // deal with the transport cache if there is a failure.
+  if (!transport->register_if_necessary ())
     {
-      // Registration failures.
-
-      // Purge from the connection cache, if we are not in the cache, this
-      // just does nothing.
-      (void) transport->purge_entry ();
-
-      // Close the handler.
-      (void) transport->close_connection ();
-
-      if (TAO_debug_level > 0)
-        ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("TAO (%P|%t) IIOP_Connector [%d]::make_connection, ")
-                    ACE_TEXT ("could not register the transport ")
-                    ACE_TEXT ("in the reactor.\n"),
-                    transport->id ()));
-
       return 0;
     }
 
