@@ -4,12 +4,12 @@
 
 #include "tao/IIOP_Acceptor.h"
 #include "tao/IIOP_Connector.h"
-#include "tao/IOP_IORC.h"
+#include "tao/IOPC.h"
 #include "ace/OS_NS_strings.h"
 
 ACE_RCSID (tao,
            IIOP_Factory,
-           "$Id: IIOP_Factory.cpp 74199 2006-08-23 12:50:53Z johnnyw $")
+           "$Id: IIOP_Factory.cpp 84281 2009-01-30 15:01:17Z wotte $")
 
 
 static const char the_prefix[] = "iiop";
@@ -80,8 +80,6 @@ TAO_IIOP_Protocol_Factory::requires_explicit_endpoint (void) const
   return 0;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 ACE_STATIC_SVC_DEFINE (TAO_IIOP_Protocol_Factory,
                        ACE_TEXT ("IIOP_Factory"),
                        ACE_SVC_OBJ_T,
@@ -92,4 +90,7 @@ ACE_STATIC_SVC_DEFINE (TAO_IIOP_Protocol_Factory,
 
 ACE_FACTORY_DEFINE (TAO, TAO_IIOP_Protocol_Factory)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+
 #endif /* TAO_HAS_IIOP && TAO_HAS_IIOP != 0 */
