@@ -13,7 +13,7 @@
 
 ACE_RCSID (tao,
            IIOP_Profile,
-           "$Id: IIOP_Profile.cpp 78128 2007-04-20 08:07:58Z johnnyw $")
+           "$Id: IIOP_Profile.cpp 86712 2009-09-15 07:55:56Z sma $")
 
 #include "ace/os_include/os_netdb.h"
 
@@ -58,6 +58,7 @@ TAO_IIOP_Profile::TAO_IIOP_Profile (const ACE_INET_Addr &addr,
                  version),
     endpoint_ (addr,
                orb_core->orb_params ()->use_dotted_decimal_addresses ()),
+    last_endpoint_ (&this->endpoint_),
     count_ (1)
 {
 }
@@ -73,6 +74,7 @@ TAO_IIOP_Profile::TAO_IIOP_Profile (const char* host,
                  object_key,
                  version),
     endpoint_ (host, port, addr),
+    last_endpoint_ (&this->endpoint_),
     count_ (1)
 {
 }
@@ -83,6 +85,7 @@ TAO_IIOP_Profile::TAO_IIOP_Profile (TAO_ORB_Core *orb_core)
                  TAO_GIOP_Message_Version (TAO_DEF_GIOP_MAJOR,
                                            TAO_DEF_GIOP_MINOR)),
     endpoint_ (),
+    last_endpoint_ (&this->endpoint_),
     count_ (1)
 {
 }
@@ -118,7 +121,7 @@ TAO_IIOP_Profile::decode_profile (TAO_InputCDR& cdr)
       const char* csv = this->orb_core()->orb_params()->preferred_interfaces();
       bool const enforce =
         this->orb_core()->orb_params()->enforce_pref_interfaces();
-      this->count_ += this->endpoint_.preferred_interfaces(csv, enforce);
+      this->count_ += this->endpoint_.preferred_interfaces(csv, enforce, *this);
 
       return 1;
     }
@@ -147,7 +150,8 @@ TAO_IIOP_Profile::parse_string_i (const char *ior)
   // Length of host string.
   CORBA::ULong length_host = 0;
 
-  const char *cp_pos = ACE_OS::strchr (ior, ':');  // Look for a port
+  const char *cp_pos_overrun = ACE_OS::strchr (ior, ':');  // Look for a port
+  const char *cp_pos = (cp_pos_overrun < okd) ? cp_pos_overrun : 0; // but before object key
 #if defined (ACE_HAS_IPV6)
   // IPv6 numeric address in host string?
   bool ipv6_in_host = false;
@@ -160,7 +164,8 @@ TAO_IIOP_Profile::parse_string_i (const char *ior)
     {
       // In this case we have to find the end of the numeric address and
       // start looking for the port separator from there.
-      const char *cp_pos_a = ACE_OS::strchr(ior, ']');
+      const char *cp_pos_a_overrun = ACE_OS::strchr(ior, ']');
+      const char *cp_pos_a = (cp_pos_a_overrun < okd) ? cp_pos_a_overrun : 0; // before object key
       if (cp_pos_a == 0)
         {
           // No valid IPv6 address specified.
@@ -394,8 +399,8 @@ TAO_IIOP_Profile::endpoint_count (void) const
 void
 TAO_IIOP_Profile::add_endpoint (TAO_IIOP_Endpoint *endp)
 {
-  endp->next_ = this->endpoint_.next_;
-  this->endpoint_.next_ = endp;
+  this->last_endpoint_->next_ = endp;
+  this->last_endpoint_ = endp;
 
   ++this->count_;
 }
@@ -416,27 +421,35 @@ TAO_IIOP_Profile::remove_endpoint (TAO_IIOP_Endpoint *endp)
           // since the assignment operator does not copy the next_
           // pointer, we must do it by hand
           this->endpoint_.next_ = n->next_;
+          if (this->last_endpoint_ == n)
+            {
+              this->last_endpoint_ = &this->endpoint_;
+            }
           delete n;
         }
       return;
     }
 
-  TAO_IIOP_Endpoint* last = &this->endpoint_;
+  TAO_IIOP_Endpoint* prev = &this->endpoint_;
   TAO_IIOP_Endpoint* cur = this->endpoint_.next_;
 
   while (cur != 0)
   {
     if (cur == endp)
       break;
-    last = cur;
+    prev = cur;
     cur = cur->next_;
   }
 
   if (cur != 0)
   {
-    last->next_ = cur->next_;
+    prev->next_ = cur->next_;
     cur->next_ = 0;
     --this->count_;
+    if (this->last_endpoint_ == cur)
+      {
+        this->last_endpoint_ = prev;
+      }
     delete cur;
   }
 }
@@ -578,7 +591,6 @@ TAO_IIOP_Profile::create_profile_body (TAO_OutputCDR &encap) const
 #endif /* ACE_HAS_IPV6 */
   encap.write_string (this->endpoint_.host ());
 
-
   // UNSIGNED SHORT port number
   encap.write_ushort (this->endpoint_.port ());
 
@@ -589,11 +601,10 @@ TAO_IIOP_Profile::create_profile_body (TAO_OutputCDR &encap) const
     {
       ACE_ERROR ((LM_ERROR,
                   "(%P|%t) TAO - IIOP_Profile::create_profile_body "
-                  "no object key marshalled \n"));
+                  "no object key marshalled\n"));
     }
 
-  if (this->version_.major > 1
-      || this->version_.minor > 0)
+  if (this->version_.major > 1 || this->version_.minor > 0)
     this->tagged_components ().encode (encap);
 }
 
@@ -631,17 +642,17 @@ TAO_IIOP_Profile::encode_alternate_endpoints (void)
           ACE_CString tmp;
           size_t len = pos - host;
           tmp.set (endpoint->host (), len, 1);
-          if ((out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER) == 0)
-              || (out_cdr << tmp.c_str () == 0)
-              || (out_cdr << endpoint->port () == 0))
+          if (!(out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER))
+              || !(out_cdr << tmp.c_str ())
+              || !(out_cdr << endpoint->port ()))
             return -1;
           out_cdr.write_string (len, endpoint->host ());
         }
       else
 #endif /* ACE_HAS_IPV6 */
-      if ((out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER) == 0)
-                || (out_cdr << endpoint->host () == 0)
-          || (out_cdr << endpoint->port () == 0))
+      if (!(out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER))
+          || !(out_cdr << endpoint->host ())
+          || !(out_cdr << endpoint->port ()))
         return -1;
 
       IOP::TaggedComponent tagged_component;
@@ -732,9 +743,8 @@ TAO_IIOP_Profile::encode_endpoints (void)
 
   // Encode the data structure.
   TAO_OutputCDR out_cdr;
-  if ((out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER)
-       == 0)
-      || (out_cdr << endpoints) == 0)
+  if (!(out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER))
+      || !(out_cdr << endpoints))
     return -1;
 
   this->set_tagged_components (out_cdr);
@@ -759,14 +769,14 @@ TAO_IIOP_Profile::decode_endpoints (void)
 
       // Extract the Byte Order.
       CORBA::Boolean byte_order;
-      if ((in_cdr >> ACE_InputCDR::to_boolean (byte_order)) == 0)
+      if (!(in_cdr >> ACE_InputCDR::to_boolean (byte_order)))
         return -1;
       in_cdr.reset_byte_order (static_cast<int> (byte_order));
 
       // Extract endpoints sequence.
       TAO::IIOPEndpointSequence endpoints;
 
-      if ((in_cdr >> endpoints) == 0)
+      if (!(in_cdr >> endpoints))
         return -1;
 
       // Get the priority of the first endpoint (head of the list.
@@ -811,7 +821,7 @@ TAO_IIOP_Profile::decode_endpoints (void)
 
       // Extract the Byte Order.
       CORBA::Boolean byte_order;
-      if ((in_cdr >> ACE_InputCDR::to_boolean (byte_order)) == 0)
+      if (!(in_cdr >> ACE_InputCDR::to_boolean (byte_order)))
         return -1;
 
       in_cdr.reset_byte_order (static_cast<int>(byte_order));
@@ -819,8 +829,7 @@ TAO_IIOP_Profile::decode_endpoints (void)
       CORBA::String_var host;
       CORBA::Short port;
 
-      if ((in_cdr >> host.out()) == 0 ||
-          (in_cdr >> port) == 0)
+      if (!(in_cdr >> host.out()) || !(in_cdr >> port))
         return -1;
 
       TAO_IIOP_Endpoint *endpoint = 0;
