@@ -4,7 +4,7 @@
 /**
  *  @file   IORInfo.h
  *
- *  $Id: IORInfo.h 79241 2007-08-07 12:42:30Z johnnyw $
+ *  $Id: IORInfo.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author Ossama Othman <ossama@uci.edu>
  */
@@ -44,7 +44,7 @@ class TAO_Root_POA;
  */
 class TAO_IORInfo
   : public virtual PortableInterceptor::IORInfo,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
 
