@@ -6,7 +6,7 @@
 
 ACE_RCSID (IORManipulation,
            IORManip_Loader,
-           "$Id: IORManip_Loader.cpp 79212 2007-08-06 05:13:12Z johnnyw $")
+           "$Id: IORManip_Loader.cpp 84281 2009-01-30 15:01:17Z wotte $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -16,9 +16,7 @@ TAO_IORManip_Loader::TAO_IORManip_Loader (void)
 }
 
 CORBA::Object_ptr
-TAO_IORManip_Loader::create_object (CORBA::ORB_ptr,
-                                    int,
-                                    ACE_TCHAR *[])
+TAO_IORManip_Loader::create_object (CORBA::ORB_ptr, int, ACE_TCHAR *[])
 {
   CORBA::Object_ptr obj;
   ACE_NEW_RETURN (obj,
@@ -33,7 +31,6 @@ TAO_IORManip_Loader::Initializer (void)
   return ACE_Service_Config::process_directive (ace_svc_desc_TAO_IORManip_Loader);
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 ACE_STATIC_SVC_DEFINE (TAO_IORManip_Loader,
                        ACE_TEXT ("IORManip_Loader"),
@@ -42,3 +39,5 @@ ACE_STATIC_SVC_DEFINE (TAO_IORManip_Loader,
                        ACE_Service_Type::DELETE_THIS | ACE_Service_Type::DELETE_OBJ,
                        0)
 ACE_FACTORY_DEFINE (TAO_IORManip, TAO_IORManip_Loader)
+
+TAO_END_VERSIONED_NAMESPACE_DECL
