@@ -4,7 +4,7 @@
 /**
  *  @file    IORManipulation.h
  *
- *  $Id: IORManipulation.h 77028 2007-02-12 14:49:05Z johnnyw $
+ *  $Id: IORManipulation.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  This class implements IOR interface to the ORB
  *
@@ -37,76 +37,51 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_IOR_Manipulation_impl
   : public TAO_IOP::TAO_IOR_Manipulation,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
-  // = TITLE
-  //     IOR Manipulation class
-  //
-  // = DESCRIPTION
-  //
-  //
 public:
 
-  /// constructor
+  /// Constructor
   TAO_IOR_Manipulation_impl (void);
 
   virtual CORBA::Object_ptr merge_iors (
-    const TAO_IOP::TAO_IOR_Manipulation::IORList & iors
-    );
+    const TAO_IOP::TAO_IOR_Manipulation::IORList & iors);
 
   virtual CORBA::Object_ptr add_profiles (
-      CORBA::Object_ptr ior1,
-      CORBA::Object_ptr ior2
-      );
+      CORBA::Object_ptr ior1, CORBA::Object_ptr ior2);
 
   virtual CORBA::Object_ptr remove_profiles (
-    CORBA::Object_ptr group,
-    CORBA::Object_ptr ior2
-    );
+    CORBA::Object_ptr group, CORBA::Object_ptr ior2);
 
   virtual CORBA::Boolean set_property (
-      TAO_IOP::TAO_IOR_Property_ptr prop,
-      CORBA::Object_ptr group
-      )
-;
+      TAO_IOP::TAO_IOR_Property_ptr prop, CORBA::Object_ptr group);
 
   // @@ note awkward argument order
   virtual CORBA::Boolean set_primary (
       TAO_IOP::TAO_IOR_Property_ptr prop,
       CORBA::Object_ptr new_primary,
-      CORBA::Object_ptr group
-      )
-;
+      CORBA::Object_ptr group);
 
   virtual CORBA::Object_ptr get_primary (
-      TAO_IOP::TAO_IOR_Property_ptr prop,
-      CORBA::Object_ptr group
-      )
-;
+      TAO_IOP::TAO_IOR_Property_ptr prop, CORBA::Object_ptr group);
 
   virtual CORBA::Boolean is_primary_set (
       TAO_IOP::TAO_IOR_Property_ptr prop,
-      CORBA::Object_ptr group
-      )
-;
+      CORBA::Object_ptr group);
 
    virtual CORBA::Boolean remove_primary_tag (
        TAO_IOP::TAO_IOR_Property_ptr prop,
-       CORBA::Object_ptr iogr
-       );
+       CORBA::Object_ptr iogr);
 
   virtual CORBA::ULong is_in_ior (
     CORBA::Object_ptr ior1,
-    CORBA::Object_ptr ior2
-    );
+    CORBA::Object_ptr ior2);
 
-  virtual CORBA::ULong get_profile_count (
-    CORBA::Object_ptr group
-    );
+  virtual CORBA::ULong get_profile_count (CORBA::Object_ptr group);
 
 protected:
 
-  /// destructor
+  /// Destructor
   ~TAO_IOR_Manipulation_impl (void);
 
 };
