@@ -1,11 +1,11 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 
 //=============================================================================
 /**
  *  @file    IORTable.h
  *
- *  IORTable.h,v 1.6 2005/07/04 12:05:28 jwillemsen Exp
+ *  $Id: IORTable.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -17,12 +17,16 @@
 
 #include /**/ "ace/pre.h"
 
-#include "iortable_export.h"
+#include "tao/IORTable/iortable_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_IORTable_Export TAO_IORTable_Initializer
 {
 public:
@@ -33,8 +37,10 @@ public:
 static int
 TAO_Requires_IORTable_Initializer = TAO_IORTable_Initializer::init ();
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #define TAO_IORTABLE_SAFE_INCLUDE
-#include "IORTableC.h"
+#include "tao/IORTable/IORTableC.h"
 #undef TAO_IORTABLE_SAFE_INCLUDE
 
 #include /**/ "ace/post.h"
