@@ -1,7 +1,7 @@
 /**
  * @file Table_Adapter.cpp
  *
- * $Id: Table_Adapter.cpp 77409 2007-02-26 23:48:49Z ossama $
+ * $Id: Table_Adapter.cpp 84215 2009-01-22 18:31:17Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  *
@@ -15,10 +15,11 @@
 #include "tao/Stub.h"
 #include "tao/ORB.h"
 #include "tao/Profile.h"
+#include "tao/TAO_Server_Request.h"
 
 ACE_RCSID (IORTable,
            Table_Adapter,
-           "$Id: Table_Adapter.cpp 77409 2007-02-26 23:48:49Z ossama $")
+           "$Id: Table_Adapter.cpp 84215 2009-01-22 18:31:17Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -99,7 +100,7 @@ TAO_Table_Adapter::priority (void) const
 
 int
 TAO_Table_Adapter::dispatch (TAO::ObjectKey &key,
-                             TAO_ServerRequest &,
+                             TAO_ServerRequest &request,
                              CORBA::Object_out forward_to)
 {
   TAO_IOR_Table_Impl_var rootref;
@@ -113,8 +114,13 @@ TAO_Table_Adapter::dispatch (TAO::ObjectKey &key,
     rootref = this->root_;
   }
 
-  return this->find_object (key, forward_to) ? TAO_Adapter::DS_FORWARD
-                                             : TAO_Adapter::DS_MISMATCHED_KEY;
+  if (this->find_object (key, forward_to))
+    {
+      request.forward_location (forward_to);
+      return TAO_Adapter::DS_FORWARD;
+    }
+  else
+    return TAO_Adapter::DS_MISMATCHED_KEY;
 }
 
 const char *
@@ -186,7 +192,7 @@ TAO_Table_Adapter::initialize_collocated_object (TAO_Stub *stub)
   return ! found;
 }
 
-CORBA::Long
+bool
 TAO_Table_Adapter::find_object (TAO::ObjectKey &key,
                                 CORBA::Object_out forward_to)
 {
@@ -199,9 +205,9 @@ TAO_Table_Adapter::find_object (TAO::ObjectKey &key,
     }
   catch (const ::IORTable::NotFound&)
     {
-      return 0;
+      return false;
     }
-  return 1;
+  return true;
 }
 
 // ****************************************************************
