@@ -1,4 +1,4 @@
-// $Id: ImR_Client.cpp 77879 2007-04-02 18:14:06Z elliott_c $
+// $Id: ImR_Client.cpp 85171 2009-04-25 06:33:24Z dai_y $
 
 #include "tao/ImR_Client/ImR_Client.h"
 
@@ -13,7 +13,7 @@
 
 ACE_RCSID (ImR_Client,
            ImR_Client,
-           "$Id: ImR_Client.cpp 77879 2007-04-02 18:14:06Z elliott_c $")
+           "$Id: ImR_Client.cpp 85171 2009-04-25 06:33:24Z dai_y $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -113,8 +113,8 @@ namespace TAO
 
       if (TAO_debug_level > 0)
         ACE_DEBUG ((LM_DEBUG,
-                    "Informing IMR that we are running at: %s\n",
-                    ACE_TEXT_CHAR_TO_TCHAR (partial_ior.c_str())));
+                    "Informing IMR that we are running at: %C\n",
+                    partial_ior.c_str()));
 
       try
         {
@@ -122,7 +122,18 @@ namespace TAO
           TAO::Portable_Server::Non_Servant_Upcall non_servant_upcall (*poa);
           ACE_UNUSED_ARG (non_servant_upcall);
 
-          imr_locator->server_is_running (poa->name().c_str (),
+          ACE_CString serverId = poa->orb_core ().server_id ();
+          ACE_CString name;
+          if (serverId.empty ())
+          {
+            name = poa->name();
+          }
+          else
+          {
+            name = serverId + ":" + poa->name();
+          }
+
+          imr_locator->server_is_running (name.c_str (),
                                           partial_ior.c_str(),
                                           svr.in());
         }
@@ -227,8 +238,6 @@ namespace TAO
   }
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 ACE_STATIC_SVC_DEFINE (
   ImR_Client_Adapter_Impl,
   ACE_TEXT ("Concrete_ImR_Client_Adapter"),
@@ -241,3 +250,6 @@ ACE_FACTORY_NAMESPACE_DEFINE (
   TAO_IMR_Client,
   ImR_Client_Adapter_Impl,
   TAO::ImR_Client::ImR_Client_Adapter_Impl)
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
