@@ -4,7 +4,7 @@
 /**
  *  @file   Invocation_Endpoint_Selectors.h
  *
- *  Invocation_Endpoint_Selectors.h,v 1.20 2005/01/04 09:49:07 jwillemsen Exp
+ *  $Id: Invocation_Endpoint_Selectors.h 79829 2007-10-23 12:39:52Z johnnyw $
  *
  * Strategies for selecting profile/endpoint from an IOR for making an
  * invocation.
@@ -17,16 +17,22 @@
 #define TAO_INVOCATION_ENDPOINT_SELECTOR_H
 
 #include /**/ "ace/pre.h"
-#include "ace/CORBA_macros.h"
+
+#include /**/ "tao/TAO_Export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/TAO_Export.h"
+#include /**/ "tao/Versioned_Namespace.h"
+
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
+class ACE_Time_Value;
+ACE_END_VERSIONED_NAMESPACE_DECL
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_MProfile;
-class ACE_Time_Value;
 
 namespace TAO
 {
@@ -36,7 +42,6 @@ namespace TAO
 namespace CORBA
 {
   class Exception;
-  class Environment;
 }
 /**
  * @class TAO_Invocation_Endpoint_Selector
@@ -55,16 +60,13 @@ namespace CORBA
 class TAO_Export TAO_Invocation_Endpoint_Selector
 {
 public:
-  /// Constructor.
-  TAO_Invocation_Endpoint_Selector (void);
 
   /// Destructor.
   virtual ~TAO_Invocation_Endpoint_Selector (void);
 
   /// Select the endpoint and set @a r's @c profile_
   virtual void select_endpoint (TAO::Profile_Transport_Resolver *r,
-                                ACE_Time_Value *val
-                                ACE_ENV_ARG_DECL) = 0;
+                                ACE_Time_Value *val) = 0;
 
 };
 
@@ -82,20 +84,20 @@ public:
  * profile in the IOR.  If that doesn't work, try the next
  * profile, and so on.
  */
-class TAO_Export TAO_Default_Endpoint_Selector :
-  public TAO_Invocation_Endpoint_Selector
+class TAO_Export TAO_Default_Endpoint_Selector
+  : public TAO_Invocation_Endpoint_Selector
 {
 public:
-  /// Constructor.
-  TAO_Default_Endpoint_Selector (void);
 
   /// Destructor.
   virtual ~TAO_Default_Endpoint_Selector (void);
 
   virtual void select_endpoint (TAO::Profile_Transport_Resolver *r,
-                                ACE_Time_Value *val
-                                ACE_ENV_ARG_DECL);
+                                ACE_Time_Value *val);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
+
 #endif  /* TAO_INVOCATION_ENDPOINT_SELECTOR_H */
