@@ -4,7 +4,7 @@
 /**
  *  @file    Invocation_Utils.h
  *
- *  $Id: Invocation_Utils.h 77463 2007-02-28 21:31:26Z zhangw $
+ *  $Id: Invocation_Utils.h 86232 2009-07-24 21:52:20Z dai_y $
  *
  *
  *  @author Balachandran Natarajan <bala@dre.vanderbilt.edu>
@@ -70,6 +70,16 @@ namespace TAO
     TAO_DII_DEFERRED_INVOCATION,
     TAO_DII_ASYNCH_INVOCATION
   };
+
+  enum Forward_Once_Exception
+    {
+      FOE_NON              = 0x0,
+      FOE_OBJECT_NOT_EXIST = 0x1,  
+      FOE_COMM_FAILURE     = 0x2,   
+      FOE_TRANSIENT        = 0x4,   
+      FOE_INV_OBJREF       = 0x8,   
+      FOE_ALL              = 0xFFFFFFFF
+    };
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
