@@ -4,7 +4,7 @@
 /**
  *  @file LF_Connect_Strategy.h
  *
- *  LF_Connect_Strategy.h,v 1.8 2004/08/09 11:52:49 jwillemsen Exp
+ *  $Id: LF_Connect_Strategy.h 76687 2007-01-29 19:18:13Z johnnyw $
  *
  *  @author Balachandran Natarajan <bala@cs.wustl.edu>
  */
@@ -15,15 +15,20 @@
 
 #include /**/ "ace/pre.h"
 
-#include "Connect_Strategy.h"
+#include "tao/Connect_Strategy.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-class TAO_Connector;
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 class ACE_Time_Value;
 class ACE_Synch_Options;
+ACE_END_VERSIONED_NAMESPACE_DECL
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+class TAO_LF_Event;
 
 /**
  * @class TAO_LF_Connect_Strategy
@@ -45,18 +50,15 @@ public:
    * Concrete implementation for this class. Please see
    * Connect_Strategy.h for details
    */
-  virtual void synch_options (ACE_Time_Value *val,
-                              ACE_Synch_Options &opt);
-
-  virtual int wait (TAO_Connection_Handler *ch,
-                    ACE_Time_Value *val);
-
-  virtual int wait (TAO_Transport *ch,
-                    ACE_Time_Value *val);
+  virtual void synch_options (ACE_Time_Value *val, ACE_Synch_Options &opt);
 
+protected:
+  virtual int wait_i (TAO_LF_Event *ev, TAO_Transport *t, ACE_Time_Value *val);
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /*TAO_LF_CONNECT_STRATEGY_H*/
