@@ -1,4 +1,4 @@
-// $Id: LF_Event_Binder.cpp 69150 2005-11-02 07:13:04Z ossama $
+// $Id: LF_Event_Binder.cpp 82657 2008-08-25 23:32:27Z mitza $
 
 #include "tao/LF_Event_Binder.h"
 
@@ -8,13 +8,13 @@
 
 ACE_RCSID (tao,
            LF_Event_Binder,
-           "$Id: LF_Event_Binder.cpp 69150 2005-11-02 07:13:04Z ossama $")
+           "$Id: LF_Event_Binder.cpp 82657 2008-08-25 23:32:27Z mitza $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_LF_Event_Binder::~TAO_LF_Event_Binder (void)
 {
-  this->event_->unbind ();
+  this->event_->unbind (follower_);
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
