@@ -4,7 +4,7 @@
 /**
  *  @file LF_Event_Binder.h
  *
- *  $Id: LF_Event_Binder.h 76687 2007-01-29 19:18:13Z johnnyw $
+ *  $Id: LF_Event_Binder.h 84840 2009-03-16 15:11:55Z johnnyw $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -40,9 +40,14 @@ public:
   /// Destructor
   ~TAO_LF_Event_Binder (void);
 
+private:
+  void operator= (const TAO_LF_Event_Binder &);
+  TAO_LF_Event_Binder (const TAO_LF_Event_Binder &);
+
 private:
   /// Keep a reference to the leader follower
   TAO_LF_Event * const event_;
+  TAO_LF_Follower * const follower_;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
