@@ -4,7 +4,7 @@
 /**
  *  @file LF_Follower_Auto_Adder.h
  *
- *  LF_Follower_Auto_Adder.h,v 1.5 2003/10/28 18:29:15 bala Exp
+ *  $Id: LF_Follower_Auto_Adder.h 76687 2007-01-29 19:18:13Z johnnyw $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -23,6 +23,8 @@
 
 #include "tao/Leader_Follower.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @brief Implement an auto_adder-like class for the TAO_LF_Followers
  * allocated via a TAO_Leader_Follower set.
@@ -33,8 +35,7 @@ class TAO_Export TAO_LF_Follower_Auto_Adder
 {
 public:
   /// Constructor
-  TAO_LF_Follower_Auto_Adder (TAO_Leader_Follower &,
-                              TAO_LF_Follower *follower);
+  TAO_LF_Follower_Auto_Adder (TAO_Leader_Follower &, TAO_LF_Follower *follower);
 
   /// Destructor
   ~TAO_LF_Follower_Auto_Adder (void);
@@ -47,6 +48,8 @@ private:
   TAO_LF_Follower *follower_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
 # include "tao/LF_Follower_Auto_Adder.inl"
 #endif /* __ACE_INLINE__ */
