@@ -1,5 +1,4 @@
-// -*- C++ -*-
-// LF_Follower_Auto_Ptr.cpp,v 1.3 2003/10/28 18:29:15 bala Exp
+// $Id: LF_Follower_Auto_Ptr.cpp 69150 2005-11-02 07:13:04Z ossama $
 
 #include "tao/LF_Follower_Auto_Ptr.h"
 
@@ -7,11 +6,15 @@
 # include "tao/LF_Follower_Auto_Ptr.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (tao, 
-           LF_Follower_Auto_Ptr, 
-           "LF_Follower_Auto_Ptr.cpp,v 1.3 2003/10/28 18:29:15 bala Exp")
+ACE_RCSID (tao,
+           LF_Follower_Auto_Ptr,
+           "$Id: LF_Follower_Auto_Ptr.cpp 69150 2005-11-02 07:13:04Z ossama $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_LF_Follower_Auto_Ptr::~TAO_LF_Follower_Auto_Ptr (void)
 {
   this->leader_follower_.release_follower (this->follower_);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
