@@ -4,7 +4,7 @@
 /**
  *  @file LF_Invocation_Event.h
  *
- *  LF_Invocation_Event.h,v 1.4 2005/01/04 09:51:46 jwillemsen Exp
+ *  $Id: LF_Invocation_Event.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -15,12 +15,14 @@
 
 #include /**/ "ace/pre.h"
 
-#include "LF_Event.h"
+#include "tao/LF_Event.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_LF_Invocation_Event
  *
@@ -77,6 +79,8 @@ private:
   int is_state_final (void);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_LF_INVOCATION_EVENT_H */
