@@ -1,4 +1,4 @@
-// $Id: LF_Strategy_Complete.cpp 72136 2006-04-19 09:10:19Z jwillemsen $
+// $Id: LF_Strategy_Complete.cpp 84404 2009-02-11 14:15:14Z johnnyw $
 
 #include "tao/LF_Strategy_Complete.h"
 #include "tao/LF_Follower.h"
@@ -8,7 +8,7 @@
 
 ACE_RCSID (tao,
            LF_Strategy_Complete,
-           "$Id: LF_Strategy_Complete.cpp 72136 2006-04-19 09:10:19Z jwillemsen $")
+           "$Id: LF_Strategy_Complete.cpp 84404 2009-02-11 14:15:14Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -44,7 +44,7 @@ TAO_LF_Strategy_Complete::reset_event_loop_thread (int call_reset,
 
   if (result == -1)
     ACE_ERROR ((LM_ERROR,
-                ACE_TEXT ("TAO (%P|%t) Failed to wake up ")
+                ACE_TEXT ("TAO (%P|%t) - Failed to wake up ")
                 ACE_TEXT ("a follower thread\n")));
 }
 
