@@ -4,7 +4,7 @@
 /**
  *  @file Leader_Follower_Flushing_Strategy.h
  *
- *  Leader_Follower_Flushing_Strategy.h,v 1.4 2003/10/28 18:29:15 bala Exp
+ *  $Id: Leader_Follower_Flushing_Strategy.h 80603 2008-02-11 22:14:39Z johnc $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -15,19 +15,21 @@
 
 #include /**/ "ace/pre.h"
 
-#include "Flushing_Strategy.h"
+#include "tao/Flushing_Strategy.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Leader_Follower_Flushing_Strategy
  *
  * @brief Implement a flushing strategy that uses the Leader/Follower
  *        set.
  */
-class TAO_Export TAO_Leader_Follower_Flushing_Strategy 
+class TAO_Leader_Follower_Flushing_Strategy
   : public TAO_Flushing_Strategy
 {
 public:
@@ -36,9 +38,11 @@ public:
   virtual int flush_message (TAO_Transport *transport,
                              TAO_Queued_Message *msg,
                              ACE_Time_Value *max_wait_time);
-  virtual int flush_transport (TAO_Transport *transport);
+  virtual int flush_transport (TAO_Transport *transport, ACE_Time_Value *max_wait_time);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_LEADER_FOLLOWER_FLUSHING_STRATEGY_H */
