@@ -19,7 +19,7 @@
 
 ACE_RCSID (tao,
            MCAST_Parser,
-           "$Id: MCAST_Parser.cpp 79727 2007-09-26 18:12:47Z johnnyw $")
+           "$Id: MCAST_Parser.cpp 84281 2009-01-30 15:01:17Z wotte $")
 
 
 static const char mcast_prefix[] = "mcast:";
@@ -45,7 +45,7 @@ TAO_MCAST_Parser::parse_string (const char *ior, CORBA::ORB_ptr orb)
   char const * const mcast_name =
     ior + sizeof (::mcast_prefix) + 1;
 
-  assign_to_variables (mcast_name);
+  this->assign_to_variables (mcast_name);
 
   /*
    * Now that we got the global variables.
@@ -141,7 +141,7 @@ TAO_MCAST_Parser::multicast_query (char* & buf,
           ACE_TCHAR addr[64];
           my_addr.addr_to_string (addr, sizeof(addr));
           ACE_DEBUG ((LM_DEBUG,
-                      "(%P|%t) TAO_MCAST_Parser: acceptor local address %s.\n",
+                      ACE_TEXT(" TAO (%P|%t) - MCAST_Parser: acceptor local address %s.\n"),
                       addr));
         }
 
@@ -314,8 +314,8 @@ TAO_MCAST_Parser::multicast_query (char* & buf,
                                         ACE_TEXT ("error reading ior")));
                           else if (TAO_debug_level > 0)
                             ACE_DEBUG ((LM_DEBUG,
-                                        ACE_TEXT ("%N: service resolved to IOR <%s>\n"),
-                                        ACE_TEXT_CHAR_TO_TCHAR (buf)));
+                                        ACE_TEXT ("%N: service resolved to IOR <%C>\n"),
+                                        buf));
                         }
                     }
                 }
@@ -324,8 +324,8 @@ TAO_MCAST_Parser::multicast_query (char* & buf,
         if (result == -1)
           {
             ACE_ERROR ((LM_ERROR,
-                        ACE_TEXT("\nmulticast discovery of %s failed.\n"),
-                        ACE_TEXT_CHAR_TO_TCHAR (service_name)));
+                        ACE_TEXT("\nmulticast discovery of %C failed.\n"),
+                        service_name));
 
             if (ACE_OS::strcasecmp (service_name,
                                     "NameService") == 0)
@@ -441,7 +441,7 @@ TAO_MCAST_Parser::assign_to_variables (char const * mcast_name)
       int const the_port =
         ACE_OS::atoi (mcast_name_cstring.substring (0, pos_colon2).c_str ());
 
-      if (the_port > 0 && the_port < 0xffffL)
+      if (the_port >= 0 && the_port <= ACE_MAX_DEFAULT_PORT)
         this->mcast_port_ = the_port;
     }
 
@@ -478,8 +478,6 @@ TAO_MCAST_Parser::assign_to_variables (char const * mcast_name)
     mcast_name_cstring.substring (1, mcast_name_cstring.length() - 1).c_str ();
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 ACE_STATIC_SVC_DEFINE (TAO_MCAST_Parser,
                        ACE_TEXT ("MCAST_Parser"),
                        ACE_SVC_OBJ_T,
@@ -490,4 +488,7 @@ ACE_STATIC_SVC_DEFINE (TAO_MCAST_Parser,
 
 ACE_FACTORY_DEFINE (TAO, TAO_MCAST_Parser)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+
 #endif /* TAO_HAS_MCAST_PARSER == 1 */
