@@ -4,7 +4,7 @@
 /**
  *  @file   AMH_Response_Handler.h
  *
- *  $Id: AMH_Response_Handler.h 80158 2007-12-02 16:12:30Z sowayaa $
+ *  $Id: AMH_Response_Handler.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author Mayur Deshpande <mayur@ics.uci.edu>
  */
@@ -71,7 +71,7 @@ class TAO_Messaging_Export TAO_AMH_Response_Handler
 //    isn't consistent with the specified semantics detailed in the
 //    CCM spec.  Please remove this and place it where appropriate in
 //    your AMH tests and examples.
-  : public TAO_Local_RefCounted_Object
+  : public ::CORBA::LocalObject
 {
 public:
 
