@@ -1,4 +1,4 @@
-// $Id: Asynch_Timeout_Handler.cpp 71473 2006-03-10 07:19:20Z jtc $
+// $Id: Asynch_Timeout_Handler.cpp 82605 2008-08-12 16:31:20Z johnnyw $
 
 
 #include "tao/Messaging/Asynch_Timeout_Handler.h"
@@ -9,30 +9,23 @@
 
 ACE_RCSID (Messaging,
            Asynch_Timeout_Handler,
-           "$Id: Asynch_Timeout_Handler.cpp 71473 2006-03-10 07:19:20Z jtc $")
+           "$Id: Asynch_Timeout_Handler.cpp 82605 2008-08-12 16:31:20Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Asynch_Timeout_Handler::TAO_Asynch_Timeout_Handler (
-  TAO_Asynch_Reply_Dispatcher_Base *rd,
   ACE_Reactor *reactor)
-  : rd_ (rd),
-    tms_ (0),
+  : tms_ (0),
     request_id_ (0),
     reactor_ (reactor)
 {
   // Enable reference counting on the event handler.
   this->reference_counting_policy ().value (
     ACE_Event_Handler::Reference_Counting_Policy::ENABLED);
-
-  // We own a reference
-  (void) this->rd_->incr_refcount ();
 }
 
 TAO_Asynch_Timeout_Handler::~TAO_Asynch_Timeout_Handler ()
 {
-  // Forget rd's reference
-  (void) this->rd_->decr_refcount ();
 }
 
 
@@ -54,9 +47,28 @@ int
 TAO_Asynch_Timeout_Handler::handle_timeout (const ACE_Time_Value &,
                                             const void *)
 {
-  this->tms_->unbind_dispatcher (request_id_);
-
-  this->rd_->reply_timed_out ();
+  // Check if there was a reply dispatcher registered in the tms, if not
+  // the reply already got dispatched by another thread
+  if (this->tms_->reply_timed_out (this->request_id_) == 0)
+    {
+      if (TAO_debug_level >= 4)
+        {
+          ACE_DEBUG ((LM_DEBUG,
+                      ACE_TEXT ("TAO_Messaging (%P|%t) - Asynch_Timeout_Handler")
+                      ACE_TEXT ("::handle_timeout, request %d timed out\n"),
+                                this->request_id_));
+        }
+    }
+  else
+    {
+      if (TAO_debug_level >= 1)
+        {
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO_Messaging (%P|%t) - Asynch_Timeout_Handler")
+                      ACE_TEXT ("::handle_timeout, unable to dispatch timed out request %d\n"),
+                                this->request_id_));
+        }
+    }
 
   // reset any possible timeout errno
   errno = 0;
