@@ -1,5 +1,5 @@
 
-// $Id: Messaging_Loader.cpp 78128 2007-04-20 08:07:58Z johnnyw $
+// $Id: Messaging_Loader.cpp 87582 2009-11-16 16:04:12Z vzykov $
 
 #include "tao/Messaging/Messaging_Loader.h"
 #include "tao/Messaging/Messaging_ORBInitializer.h"
@@ -9,12 +9,13 @@
 #include "tao/ORB_Core.h"
 #include "tao/ORBInitializer_Registry.h"
 
-ACE_RCSID (Messaging, Messaging_Loader, "$Id: Messaging_Loader.cpp 78128 2007-04-20 08:07:58Z johnnyw $")
+ACE_RCSID (Messaging, Messaging_Loader, "$Id: Messaging_Loader.cpp 87582 2009-11-16 16:04:12Z vzykov $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Messaging_Loader::TAO_Messaging_Loader (void)
+  : initialized_ (false)
 {
 }
 
@@ -28,11 +29,10 @@ TAO_Messaging_Loader::init (int,
 {
   ACE_TRACE ("TAO_Messaging_Loader::init");
 
-  static bool called_once = false;
-
-  if (called_once == true)
+  if (this->initialized_)
     return 0;
-  called_once = true;
+
+  this->initialized_ = true;
 
   PortableInterceptor::ORBInitializer_ptr temp_orb_initializer =
     PortableInterceptor::ORBInitializer::_nil ();
@@ -66,7 +66,6 @@ TAO_Messaging_Loader::init (int,
   return 0;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 /////////////////////////////////////////////////////////////////////
 
@@ -78,3 +77,5 @@ ACE_STATIC_SVC_DEFINE (TAO_Messaging_Loader,
                        ACE_Service_Type::DELETE_THIS
                        | ACE_Service_Type::DELETE_OBJ,
                        0)
+
+TAO_END_VERSIONED_NAMESPACE_DECL
