@@ -4,7 +4,7 @@
 /**
  *  @file    Messaging_Loader.h
  *
- *  $Id: Messaging_Loader.h 76920 2007-02-05 20:23:47Z johnnyw $
+ *  $Id: Messaging_Loader.h 87582 2009-11-16 16:04:12Z vzykov $
  */
 //=============================================================================
 
@@ -38,12 +38,17 @@ public:
 
   /// Initialize the Messaging loader hooks.
   virtual int init (int argc, ACE_TCHAR* []);
+
+private:
+  /// Set to true after init is called.
+  bool initialized_;
 };
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 ACE_STATIC_SVC_DECLARE_EXPORT (TAO_Messaging, TAO_Messaging_Loader)
 ACE_FACTORY_DECLARE (TAO_Messaging, TAO_Messaging_Loader)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_MESSAGING_LOADER_H */
