@@ -1,46 +1,41 @@
-#include "Messaging_PolicyFactory.h"
+#include "tao/Messaging/Messaging_PolicyFactory.h"
 
 ACE_RCSID (Messaging,
            Messaging_PolicyFactory,
-           "Messaging_PolicyFactory.cpp,v 1.9 2004/09/29 21:51:47 irfan Exp")
+           "$Id: Messaging_PolicyFactory.cpp 79231 2007-08-06 18:32:54Z johnnyw $")
 
-#include "Messaging_Policy_i.h"
-#include "Connection_Timeout_Policy_i.h"
+#include "tao/Messaging/Messaging_Policy_i.h"
+#include "tao/Messaging/Connection_Timeout_Policy_i.h"
+#include "tao/Messaging/Buffering_Constraint_Policy.h"
 
 #include "tao/PolicyC.h"
-#include "tao/Buffering_Constraint_Policy.h"
-#include "tao/Any.h"
+#include "tao/AnyTypeCode/Any.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 CORBA::Policy_ptr
 TAO_Messaging_PolicyFactory::create_policy (
     CORBA::PolicyType type,
-    const CORBA::Any &value
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   CORBA::PolicyError))
+    const CORBA::Any &value)
 {
 #if (TAO_HAS_RELATIVE_ROUNDTRIP_TIMEOUT_POLICY == 1)
   if (type == Messaging::RELATIVE_RT_TIMEOUT_POLICY_TYPE)
-    return TAO_RelativeRoundtripTimeoutPolicy::create (value
-                                                       ACE_ENV_ARG_PARAMETER);
+    return TAO_RelativeRoundtripTimeoutPolicy::create (value);
 #endif /* TAO_HAS_RELATIVE_ROUNDTRIP_TIMEOUT_POLICY == 1 */
 
 #if (TAO_HAS_CONNECTION_TIMEOUT_POLICY == 1)
   if (type == TAO::CONNECTION_TIMEOUT_POLICY_TYPE)
-    return TAO_ConnectionTimeoutPolicy::create (value
-                                                ACE_ENV_ARG_PARAMETER);
+    return TAO_ConnectionTimeoutPolicy::create (value);
 #endif /* TAO_HAS_RELATIVE_ROUNDTRIP_TIMEOUT_POLICY == 1 */
 
 #if (TAO_HAS_SYNC_SCOPE_POLICY == 1)
   if (type == Messaging::SYNC_SCOPE_POLICY_TYPE)
-    return TAO_Sync_Scope_Policy::create (value
-                                          ACE_ENV_ARG_PARAMETER);
+    return TAO_Sync_Scope_Policy::create (value);
 #endif  /* TAO_HAS_SYNC_SCOPE_POLICY == 1 */
 
 #if (TAO_HAS_BUFFERING_CONSTRAINT_POLICY == 1)
   if (type == TAO::BUFFERING_CONSTRAINT_POLICY_TYPE)
-    return TAO_Buffering_Constraint_Policy::create (value
-                                                    ACE_ENV_ARG_PARAMETER);
+    return TAO_Buffering_Constraint_Policy::create (value);
 #endif /* TAO_HAS_BUFFERING_CONSTRAINT_POLICY == 1 */
 
   if (
@@ -73,11 +68,11 @@ TAO_Messaging_PolicyFactory::create_policy (
       type == Messaging::MAX_HOPS_POLICY_TYPE ||
 #endif  /* TAO_HAS_MAX_HOPS_POLICY == 1 */
       type == Messaging::QUEUE_ORDER_POLICY_TYPE)
-    ACE_THROW_RETURN (CORBA::PolicyError (CORBA::UNSUPPORTED_POLICY),
-                      CORBA::Policy::_nil ());
+    throw ::CORBA::PolicyError (CORBA::UNSUPPORTED_POLICY);
 
   ACE_UNUSED_ARG (value);
 
-  ACE_THROW_RETURN (CORBA::PolicyError (CORBA::BAD_POLICY_TYPE),
-                    CORBA::Policy::_nil ());
+  throw ::CORBA::PolicyError (CORBA::BAD_POLICY_TYPE);
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
