@@ -4,7 +4,7 @@
 /**
  * @file Messaging_PolicyFactory.h
  *
- * $Id: Messaging_PolicyFactory.h 79231 2007-08-06 18:32:54Z johnnyw $
+ * $Id: Messaging_PolicyFactory.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@uci.edu>
  * @author Ossama Othman <ossama@uci.edu>
@@ -38,7 +38,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// Policy factory for all Messaging related policies.
 class TAO_Messaging_PolicyFactory
   : public virtual PortableInterceptor::PolicyFactory,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
   virtual CORBA::Policy_ptr create_policy (CORBA::PolicyType type,
