@@ -4,7 +4,7 @@
 /**
  *  @file    Muxed_TMS.h
  *
- *  $Id: Muxed_TMS.h 78997 2007-07-23 12:21:34Z johnnyw $
+ *  $Id: Muxed_TMS.h 85012 2009-04-02 10:05:46Z msmit $
  *
  *  @author  Alexander Babu Arulanthu <alex@cs.wustl.edu>
  */
@@ -25,11 +25,15 @@
 #include "ace/Hash_Map_Manager_T.h"
 #include "ace/Null_Mutex.h"
 
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
+template <class X> class ACE_Intrusive_Auto_Ptr;
+ACE_END_VERSIONED_NAMESPACE_DECL
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_ORB_Core;
 class TAO_Pluggable_Reply_Params;
+class TAO_Reply_Dispatcher;
 
 /**
  * @class TAO_Muxed_TMS
@@ -59,16 +63,22 @@ public:
   // = Please read the documentation in the TAO_Transport_Mux_Strategy
   //   class.
   virtual int bind_dispatcher (CORBA::ULong request_id,
-                               TAO_Reply_Dispatcher *rh);
+                               ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd);
   virtual int unbind_dispatcher (CORBA::ULong request_id);
 
   virtual int dispatch_reply (TAO_Pluggable_Reply_Params &params);
+  virtual int reply_timed_out (CORBA::ULong request_id);
 
   virtual bool idle_after_send (void);
   virtual bool idle_after_reply (void);
   virtual void connection_closed (void);
+  virtual bool has_request (void);
 
-protected:
+private:
+  void operator= (const TAO_Muxed_TMS &);
+  TAO_Muxed_TMS (const TAO_Muxed_TMS &);
+
+private:
   /// Lock to protect the state of the object
   ACE_Lock *lock_;
 
@@ -81,7 +91,7 @@ protected:
   TAO_ORB_Core * const orb_core_;
 
   typedef ACE_Hash_Map_Manager_Ex <CORBA::ULong,
-                                   TAO_Reply_Dispatcher *,
+                                   ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher>,
                                    ACE_Hash <CORBA::ULong>,
                                    ACE_Equal_To <CORBA::ULong>,
                                    ACE_Null_Mutex>
@@ -90,8 +100,7 @@ protected:
   /// Table of <Request ID, Reply Dispatcher> pairs.
   REQUEST_DISPATCHER_TABLE dispatcher_table_;
 
-protected:
-  int clear_cache (void);
+  int clear_cache_i (void);
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
