@@ -4,7 +4,7 @@
 /**
  *  @file    New_Leader_Generator.h
  *
- *  New_Leader_Generator.h,v 1.7 2005/06/10 21:26:18 ossama Exp
+ *  $Id: New_Leader_Generator.h 74014 2006-08-14 13:52:22Z johnnyw $
  *
  *  @author Irfan Pyarali
  */
@@ -15,13 +15,15 @@
 
 #include /**/ "ace/pre.h"
 
-#include "tao/TAO_Export.h"
+#include /**/ "tao/TAO_Export.h"
 #include "tao/orbconf.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_New_Leader_Generator
  *
@@ -42,6 +44,8 @@ public:
   virtual void no_leaders_available (void) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_NEW_LEADER_GENERATOR_H */
