@@ -1,10 +1,10 @@
-  // "$Id: ORB.cpp 80288 2007-12-17 20:05:04Z johnnyw $"
+// "$Id: ORB.cpp 89152 2010-02-23 09:57:24Z vzykov $"
 
 #include "tao/ORB.h"
 
 ACE_RCSID (tao,
            ORB,
-           "$Id: ORB.cpp 80288 2007-12-17 20:05:04Z johnnyw $")
+           "$Id: ORB.cpp 89152 2010-02-23 09:57:24Z vzykov $")
 
 #include "tao/ORB_Table.h"
 #include "tao/Connector_Registry.h"
@@ -19,7 +19,6 @@ ACE_RCSID (tao,
 #include "tao/ORBInitializer_Registry_Adapter.h"
 #include "tao/PolicyFactory_Registry_Adapter.h"
 #include "tao/NVList_Adapter.h"
-#include "tao/TAO_Singleton_Manager.h"
 #include "tao/Policy_Current.h"
 #include "tao/Policy_Manager.h"
 #include "tao/Valuetype_Adapter.h"
@@ -49,14 +48,6 @@ ACE_RCSID (tao,
 
 static const char ior_prefix[] = "IOR:";
 
-// = Static initialization.
-
-namespace
-{
-  // Count of the number of ORBs.
-  int orb_init_count = 0;
-}
-
 // ****************************************************************
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -171,8 +162,8 @@ CORBA::ORB::destroy (void)
   if (TAO_debug_level > 2)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("CORBA::ORB::destroy() called on ORB <%s>.\n"),
-                  ACE_TEXT_CHAR_TO_TCHAR (this->orb_core ()->orbid ())));
+                  ACE_TEXT ("CORBA::ORB::destroy() called on ORB <%C>.\n"),
+                  this->orb_core ()->orbid ()));
     }
 
   this->orb_core ()->destroy ();
@@ -917,6 +908,10 @@ CORBA::ORB::resolve_initial_references (const char *name,
     {
       result = this->orb_core ()->resolve_compression_manager ();
     }
+  else if (ACE_OS::strcmp (name, TAO_OBJID_MONITOR) == 0)
+    {
+      result = this->orb_core ()->resolve_monitor ();
+    }
 #if TAO_HAS_INTERCEPTORS == 1
   else if (ACE_OS::strcmp (name, TAO_OBJID_PICurrent) == 0)
     {
@@ -931,8 +926,7 @@ CORBA::ORB::resolve_initial_references (const char *name,
       // Search the object reference table.  This search must occur before
       // the InitRef table search, since it may contain local objects.
       result =
-        this->orb_core ()->object_ref_table ().resolve_initial_reference (
-          name);
+        this->orb_core ()->object_ref_table ().resolve_initial_reference (name);
     }
 
   if (!CORBA::is_nil (result.in ()))
@@ -955,12 +949,15 @@ CORBA::ORB::resolve_initial_references (const char *name,
 
   // Look for an environment variable called "<name>IOR".
   //
+  static const char ior_string[] = "IOR";
+
   CORBA::String_var ior_env_var_name =
-    CORBA::string_alloc (static_cast<CORBA::ULong> (ACE_OS::strlen (name) + 3));
+    CORBA::string_alloc (
+      static_cast<CORBA::ULong> (ACE_OS::strlen (name) + sizeof (ior_string)));
 
   ACE_OS::strcpy (ior_env_var_name.inout (), name);
 
-  ACE_OS::strcat (ior_env_var_name.inout (), "IOR");
+  ACE_OS::strcat (ior_env_var_name.inout (), ior_string);
 
   ACE_CString service_ior = ACE_OS::getenv (ior_env_var_name.in ());
 
@@ -1022,6 +1019,21 @@ CORBA::ORB::register_initial_reference (const char * id, CORBA::Object_ptr obj)
   if (table.register_initial_reference (id, obj) == -1)
     throw ::CORBA::ORB::InvalidName ();
 }
+
+CORBA::Object_ptr
+CORBA::ORB::unregister_initial_reference (const char * id)
+{
+  if (id == 0 || ACE_OS::strlen (id) == 0)
+    throw ::CORBA::ORB::InvalidName ();
+
+  TAO_Object_Ref_Table &table = this->orb_core_->object_ref_table ();
+  CORBA::Object_ptr obj = table.unregister_initial_reference (id);
+
+  if (CORBA::is_nil (obj))
+    throw ::CORBA::ORB::InvalidName ();
+
+  return obj;
+}
 #endif
 
 CORBA::ORB::ObjectIdList_ptr
@@ -1029,8 +1041,7 @@ CORBA::ORB::list_initial_services (void)
 {
   this->check_shutdown ();
 
-  return
-    this->orb_core ()->list_initial_references ();
+  return this->orb_core ()->list_initial_references ();
 }
 
 void
@@ -1053,24 +1064,6 @@ CORBA::ORB::check_shutdown (void)
     }
 }
 
-// ****************************************************************
-
-void
-TAO::ORB::init_orb_globals (void)
-{
-  // This method should be invoked atomically.  It is the caller's
-  // responsibility to ensure that this condition is satisfied.
-
-  // Prevent multiple initializations.
-  if (orb_init_count != 0)
-    {
-      return;
-    }
-  else
-    {
-      ++orb_init_count;
-    }
-}
 
 CORBA::ORB_ptr
 CORBA::ORB::_tao_make_ORB (TAO_ORB_Core * orb_core)
@@ -1091,7 +1084,7 @@ namespace TAO
   bool
   parse_orb_opt (ACE_Argv_Type_Converter& command_line,
                  const ACE_TCHAR* orb_opt,
-                 ACE_CString& opt_arg)
+                 ACE_TString& opt_arg)
   {
 
     if (opt_arg.length () > 0)
@@ -1114,8 +1107,7 @@ namespace TAO
             arg_shifter.consume_arg ();
             if (arg_shifter.is_parameter_next ())
               {
-                opt_arg =
-                  ACE_TEXT_ALWAYS_CHAR (arg_shifter.get_current ());
+                opt_arg = arg_shifter.get_current ();
                 arg_shifter.consume_arg ();
               }
           }
@@ -1126,64 +1118,129 @@ namespace TAO
             // The rest of the argument is the ORB id...
             // but we should skip an optional space...
             if (current_arg[opt_len] == ' ')
-              opt_arg =
-                ACE_TEXT_ALWAYS_CHAR (current_arg + opt_len + 1);
+              opt_arg = current_arg + opt_len + 1;
             else
-              opt_arg = ACE_TEXT_ALWAYS_CHAR (current_arg + opt_len);
+              opt_arg = current_arg + opt_len;
           }
         else
           arg_shifter.ignore_arg ();
       }
     return found;
   }
+
+  ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt>
+  find_orb_context (const ACE_TString& orbconfig_string)
+    {
+      const ACE_TCHAR *arg = orbconfig_string.c_str ();
+
+      // Need a local repo? Make one which typically should not be as
+      // big as the default repository
+      if  (ACE_OS::strcasecmp (arg, ACE_TEXT("LOCAL")) == 0)
+        {
+          ACE_Service_Gestalt* gestalt = 0;
+          ACE_NEW_THROW_EX (gestalt,
+                            ACE_Service_Gestalt
+                            (ACE_Service_Gestalt::MAX_SERVICES / 4, true),
+                            CORBA::NO_MEMORY
+                            (CORBA::SystemException::_tao_minor_code (0,
+                                                                      ENOMEM),
+                             CORBA::COMPLETED_NO));
+          return ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> (gestalt);
+        }
+
+      if  (ACE_OS::strcasecmp (arg, ACE_TEXT("CURRENT")) == 0)
+        {
+          return ACE_Service_Config::current ();
+        }
+
+      // Explicit global case?
+      if  (orbconfig_string.is_empty () || ACE_OS::strcasecmp (arg, ACE_TEXT("GLOBAL")) == 0)
+        {
+          return ACE_Service_Config::global ();
+        }
+
+      // Someone else's context?
+      const ACE_TCHAR *shared = ACE_TEXT("ORB:");
+      size_t const shared_len = ACE_OS::strlen(shared);
+      if (ACE_OS::strncmp (arg, shared, shared_len) == 0)
+        {
+          ACE_TString orbid (orbconfig_string.substr (shared_len));
+
+          // Get ORB Core
+          TAO_ORB_Core_Auto_Ptr oc (TAO::ORB_Table::instance ()->find (
+            ACE_TEXT_ALWAYS_CHAR(orbid.c_str ())));
+          if (oc.get () != 0)
+              return oc->configuration ();
+
+          if (TAO_debug_level > 0)
+              ACE_ERROR ((LM_ERROR,
+              ACE_TEXT ("ERROR: Unable to find ORB: %s. Invalid shared ")
+              ACE_TEXT ("configuration argument \"%s\"\n"),
+                orbid.c_str (), arg));
+
+          throw ::CORBA::BAD_PARAM
+            (CORBA::SystemException::_tao_minor_code
+             ( TAO_ORB_CORE_INIT_LOCATION_CODE,
+               ENOTSUP),
+             CORBA::COMPLETED_NO);
+        }
+
+
+      // Unknown value
+      if (TAO_debug_level > 0)
+            ACE_ERROR ((LM_ERROR,
+                        ACE_TEXT ("ERROR: -ORBGestalt unknown value <%s>\n"),
+                        orbconfig_string.c_str()));
+
+      throw ::CORBA::BAD_PARAM
+          (CORBA::SystemException::_tao_minor_code
+           ( TAO_ORB_CORE_INIT_LOCATION_CODE,
+             EINVAL),
+           CORBA::COMPLETED_NO);
+     }
 }
 
 // ORB initialization, per OMG document 98-12-01.
+// NOTE we also define wide character versions as a conveniance, IF
+// we are building wide character applications.
+// The first two versions are wrappers to the actual third and final
+// implimentation of ORB_init() which is the "native" char form.
+
+#if defined (ACE_USES_WCHAR)
+// Provide the narrow char version as well as the above wide char version.
 CORBA::ORB_ptr
-CORBA::ORB_init (int &argc, char *argv[], const char *orbid)
+CORBA::ORB_init (int &argc,
+                 ACE_ANTI_TCHAR *argv[],
+                 const char *orbid)
 {
-  // Use this string variable to hold the orbid
-  ACE_CString orbid_string (orbid);
+  ACE_Argv_Type_Converter command_line (argc, argv);
+  return CORBA::ORB_init (command_line.get_argc (),
+                          command_line.get_TCHAR_argv (),
+                          orbid);
+}
 
-  // Copy command line parameter not to use original.
-  ACE_Argv_Type_Converter command_line(argc, argv);
-
-  {
-    // Using ACE_Static_Object_Lock::instance() precludes ORB_init()
-    // from being called within a static object CTOR.
-    ACE_MT (ACE_GUARD_RETURN (TAO_SYNCH_RECURSIVE_MUTEX,
-                              guard,
-                              *ACE_Static_Object_Lock::instance (),
-                              CORBA::ORB::_nil ()));
-
-    // Make sure TAO's singleton manager is initialized.
-    // We need to initialize before TAO_default_environment() is called
-    // since that call instantiates a TAO_TSS_Singleton.
-    if (TAO_Singleton_Manager::instance ()->init () == -1)
-      {
-        return CORBA::ORB::_nil ();
-      }
-
-    TAO::ORB::init_orb_globals ();
-  }
-
-  // Make sure the following is done after the global ORB
-  // initialization since we need to have exceptions initialized.
+CORBA::ORB_ptr
+CORBA::ORB_init (int &argc,
+                 wchar_t *argv[],
+                 const wchar_t *orbid)
+{
+  return CORBA::ORB_init (argc, argv, ACE_TEXT_ALWAYS_CHAR (orbid));
+}
+#endif
 
+CORBA::ORB_ptr
+CORBA::ORB_init (int &argc, ACE_TCHAR *argv[], const char *orbid)
+{
   // It doesn't make sense for argc to be zero and argv to be
   // non-empty/zero, or for argc to be greater than zero and argv be
   // zero.
-  size_t const argv0_len =
-    (command_line.get_TCHAR_argv ()
-     ? (*command_line.get_TCHAR_argv ()
-        ? ACE_OS::strlen (*command_line.get_TCHAR_argv ())
-        : 0)
-     : 0);
+  size_t const argv0_len = (argv ? (*argv
+                                        ? ACE_OS::strlen (*argv)
+                                        : 0)
+                                     : 0);
 
-  if ((command_line.get_argc () == 0 && argv0_len != 0)
-      || (command_line.get_argc () != 0
-          && (command_line.get_TCHAR_argv () == 0
-              || command_line.get_TCHAR_argv ()[0] == 0)))
+  if ((argc == 0 && argv0_len != 0)
+      || (argc != 0  && (argv == 0 || argv[0] == 0)))
     {
       throw ::CORBA::BAD_PARAM (
         CORBA::SystemException::_tao_minor_code (
@@ -1192,11 +1249,31 @@ CORBA::ORB_init (int &argc, char *argv[], const char *orbid)
         CORBA::COMPLETED_NO);
     }
 
+  // Scan the parameters to find any we could interpret to
+  // use for initializing the global context. Note that if
+  // the global context has been initialized already, the
+  // parameters may either be ignored, or later used to initialize
+  // a local configuration context. The chosen action depends on
+  // weather we want the ORB to share the global context or
+  // have its own, private (or local) context.
+  if (TAO::ORB::open_global_services (argc, argv) == -1)
+    {
+        return CORBA::ORB::_nil ();
+    }
+
+  // Copy command line parameter not to corrupt the original.
+  ACE_Argv_Type_Converter command_line (argc, argv);
+
+  // Make sure the following is done after the global ORB
+  // initialization since we need to have exceptions initialized.
+
+  // Use this string variable to hold the orbid
+  ACE_TString orbid_string (ACE_TEXT_CHAR_TO_TCHAR(orbid));
   TAO::parse_orb_opt (command_line, ACE_TEXT("-ORBid"), orbid_string);
 
   // Get ORB Core
-  TAO_ORB_Core_Auto_Ptr oc (
-    TAO::ORB_Table::instance ()->find (orbid_string.c_str ()));
+  TAO_ORB_Core_Auto_Ptr oc (TAO::ORB_Table::instance ()->find (
+    ACE_TEXT_ALWAYS_CHAR(orbid_string.c_str ())));
 
     // The ORB was already initialized.  Just return that one.
   if (oc.get () != 0)
@@ -1204,83 +1281,20 @@ CORBA::ORB_init (int &argc, char *argv[], const char *orbid)
       return CORBA::ORB::_duplicate (oc->orb ());
     }
 
-
   // Determine the service object registry this ORB will use. The choises
   // are: (a) the legacy (global); (b) its own, local, or (c) share somebody
-  // else's configuration
-
-  // By default use the process (application?) global configuration context
-  ACE_Service_Gestalt* gestalt = ACE_Service_Config::current ();
-
-  // Use this string variable to hold the config identity
-  ACE_CString orbconfig_string;
-  ACE_Auto_Ptr<ACE_Service_Gestalt> guard_gestalt(0);
-
-  if (TAO::parse_orb_opt (command_line,
-                         ACE_TEXT("-ORBGestalt"),
-                         orbconfig_string))
-    {
-      const ACE_TCHAR *arg = ACE_TEXT_CHAR_TO_TCHAR(orbconfig_string.c_str ());
-      const ACE_TCHAR *local = ACE_TEXT("LOCAL");
-      const ACE_TCHAR *shared = ACE_TEXT("ORB:");
-      // Need a local repo? Make one which typically should not be as
-      // big as the default repository
-      if  (ACE_OS::strcasecmp (arg,local) == 0)
-        {
-          ACE_NEW_THROW_EX (gestalt,
-                            ACE_Service_Gestalt
-                            (ACE_Service_Gestalt::MAX_SERVICES / 4, true),
-                            CORBA::NO_MEMORY
-                            (CORBA::SystemException::_tao_minor_code (0,
-                                                                      ENOMEM),
-                             CORBA::COMPLETED_NO));
-          guard_gestalt.reset(gestalt);
-        }
-      else if (ACE_OS::strncmp (arg, shared, sizeof (shared) - 1) == 0)
-        {
-          // @TODO: At some point, we need to implement a lookup of an
-          // existing configuration context based on the orbid
-          // following the "ORB:" It may be the case that contexts may
-          // be initialized separate from the ORB of the same ID, in
-          // which case we would need some sort of table of contexts
-          // at which point we would either find this one or make a
-          // new one. And making a new one would require assigning it
-          // to the guard_gestalt just like the local.
-          if (TAO_debug_level > 0)
-            {
-              ACE_ERROR ((LM_ERROR,
-                          ACE_TEXT ("ERROR: Sharing ORB configuration ")
-                          ACE_TEXT ("contexts is not yet supported\n")));
-            }
-
-          throw ::CORBA::BAD_PARAM
-            (CORBA::SystemException::_tao_minor_code
-             ( TAO_ORB_CORE_INIT_LOCATION_CODE,
-               ENOTSUP),
-             CORBA::COMPLETED_NO);
-        }
-      else
-        {
-          if (TAO_debug_level > 0)
-            {
-              ACE_ERROR ((LM_ERROR,
-                          ACE_TEXT ("ERROR: -ORBGestalt unknown value <%s>\n"),
-                          orbconfig_string.c_str()));
-            }
-
-          throw ::CORBA::BAD_PARAM
-            (CORBA::SystemException::_tao_minor_code
-             ( TAO_ORB_CORE_INIT_LOCATION_CODE,
-               EINVAL),
-             CORBA::COMPLETED_NO);
-        }
-    }
+  // else's configuration. By default use the process-wide (global) context
+    // Use this string variable to hold the configuration identity key
+  ACE_TString orbconfig_string;
+  TAO::parse_orb_opt (command_line, ACE_TEXT("-ORBGestalt"), orbconfig_string);
+  ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> gestalt = TAO::find_orb_context (orbconfig_string);
 
   // An ORB corresponding to the desired ORBid doesn't exist so create
   // a new one.
   TAO_ORB_Core * tmp = 0;
   ACE_NEW_THROW_EX (tmp,
-                    TAO_ORB_Core (orbid_string.c_str (), gestalt),
+                    TAO_ORB_Core (ACE_TEXT_ALWAYS_CHAR(orbid_string.c_str ()),
+                      gestalt),
                     CORBA::NO_MEMORY (
                       CORBA::SystemException::_tao_minor_code (0,
                                                                ENOMEM),
@@ -1292,10 +1306,6 @@ CORBA::ORB_init (int &argc, char *argv[], const char *orbid)
   // out of scope.
   oc.reset (tmp);
 
-  // The ORB now owns its configuration and the auto pointer is not
-  // necessary anymore.
-  guard_gestalt.release ();
-
   // Having the ORB's default static services be shared among all ORBs
   // is tempting from the point of view of reducing the dynamic
   // footprint. However, if the ORB in a DLL and the rest of that
@@ -1320,7 +1330,7 @@ CORBA::ORB_init (int &argc, char *argv[], const char *orbid)
   if (result != 0 && errno != ENOENT)
     {
       ACE_ERROR ((LM_ERROR,
-                  ACE_TEXT ("(%P|%t) %p\n"),
+                  ACE_TEXT ("TAO (%P|%t) %p\n"),
                   ACE_TEXT ("Unable to initialize the ")
                   ACE_TEXT ("Service Configurator")));
       throw ::CORBA::INITIALIZE (
@@ -1361,12 +1371,12 @@ CORBA::ORB_init (int &argc, char *argv[], const char *orbid)
   if (TAO_debug_level > 2)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT("TAO (%P|%t) created new ORB <%s>\n"),
-                  ACE_TEXT_CHAR_TO_TCHAR (orbid_string.c_str ())));
+                  ACE_TEXT("TAO (%P|%t) - Created new ORB <%s>\n"),
+                  orbid_string.c_str ()));
     }
 
   // Before returning remember to store the ORB into the table...
-  if (TAO::ORB_Table::instance ()->bind (orbid_string.c_str (),
+  if (TAO::ORB_Table::instance ()->bind (ACE_TEXT_ALWAYS_CHAR(orbid_string.c_str ()),
                                          oc.get ()) != 0)
     throw ::CORBA::INTERNAL (0, CORBA::COMPLETED_NO);
 
@@ -1495,25 +1505,24 @@ CORBA::ORB::object_to_string (CORBA::Object_ptr obj)
 
       TAO_MProfile &mp = obj->_stubobj ()->base_profiles ();
 
-      if (mp.profile_count () == 0)
+      // Try the profiles until one returns a string
+      for (CORBA::ULong index = 0; index < mp.profile_count(); ++index)
         {
-          if (TAO_debug_level > 0)
-            ACE_ERROR ((LM_ERROR,
-                        ACE_TEXT ("(%P|%t) Cannot stringify given ")
-                        ACE_TEXT ("object.  No profiles.\n")));
-
-
-          throw ::CORBA::MARSHAL (
-            CORBA::SystemException::_tao_minor_code (
-              0,
-              EINVAL),
-            CORBA::COMPLETED_NO);
+          char * result = mp.get_profile (index)->to_string();
+          if (result)
+            return result;
         }
 
-      // For now we just use the first profile.
-      TAO_Profile *profile = mp.get_profile (0);
+      if (TAO_debug_level > 0)
+        ACE_ERROR ((LM_ERROR,
+                    ACE_TEXT ("TAO (%P|%t) - Cannot stringify given ")
+                    ACE_TEXT ("object. No or only unknown profiles.\n")));
 
-      return profile->to_string ();
+      throw ::CORBA::MARSHAL (
+        CORBA::SystemException::_tao_minor_code (
+          0,
+          EINVAL),
+        CORBA::COMPLETED_NO);
     }
 }
 
@@ -1548,6 +1557,14 @@ CORBA::ORB::string_to_object (const char *str)
     return this->url_ior_string_to_object (str);
 }
 
+#if defined (ACE_USES_WCHAR)
+CORBA::Object_ptr
+CORBA::ORB::string_to_object (const wchar_t *str)
+{
+  return this->string_to_object (ACE_TEXT_ALWAYS_CHAR (str));
+}
+#endif
+
 // ****************************************************************
 
 char *
@@ -1640,7 +1657,7 @@ CORBA::ORB::ior_string_to_object (const char *str)
   // Create deencapsulation stream ... then unmarshal objref from that
   // stream.
 
-  int byte_order = *(mb.rd_ptr ());
+  int const byte_order = *(mb.rd_ptr ());
   mb.rd_ptr (1);
   mb.wr_ptr (len);
   TAO_InputCDR stream (&mb,
@@ -1670,10 +1687,7 @@ CORBA::ORB::url_ior_string_to_object (const char* str)
 
   TAO_Connector_Registry *conn_reg = this->orb_core_->connector_registry ();
 
-  int const retv = conn_reg->make_mprofile (str, mprofile);
-  // Return nil.
-
-  if (retv != 0)
+  if (conn_reg->make_mprofile (str, mprofile) != 0)
     {
       throw ::CORBA::INV_OBJREF (
         CORBA::SystemException::_tao_minor_code (
@@ -1690,11 +1704,11 @@ CORBA::ORB::url_ior_string_to_object (const char* str)
   // Figure out if the servant is collocated.
   CORBA::Object_ptr obj = this->orb_core_->create_object (safe_objdata.get ());
 
-  if (CORBA::is_nil (obj))
-    return CORBA::Object::_nil ();
-
-  // Transfer ownership to the CORBA::Object
-  (void) safe_objdata.release ();
+  if (!CORBA::is_nil (obj))
+    {
+      // Transfer ownership to the CORBA::Object
+      (void) safe_objdata.release ();
+    }
 
   return obj;
 }
@@ -1708,25 +1722,9 @@ CORBA::ValueFactory
 CORBA::ORB::register_value_factory (const char *repository_id,
                                     CORBA::ValueFactory factory)
 {
-  TAO_Valuetype_Adapter *vta = this->orb_core ()->valuetype_adapter ();
+  this->check_shutdown ();
 
-  if (vta)
-    {
-      int const result = vta->vf_map_rebind (repository_id, factory);
-
-      if (result == 0) // No previous factory found
-        {
-          return 0;
-        }
-
-      if (result == -1)
-        {
-          // Error on bind.
-          throw ::CORBA::MARSHAL ();
-        }
-    }
-
-  return factory;    // previous factory was found
+  return this->orb_core_->register_value_factory (repository_id, factory);
 }
 #endif
 
@@ -1734,13 +1732,9 @@ CORBA::ORB::register_value_factory (const char *repository_id,
 void
 CORBA::ORB::unregister_value_factory (const char *repository_id)
 {
-  TAO_Valuetype_Adapter *vta = this->orb_core ()->valuetype_adapter ();
+  this->check_shutdown ();
 
-  if (vta)
-    {
-      // Dont care whther it was successful or not!
-      (void) vta->vf_map_unbind (repository_id);
-    }
+  this->orb_core_->unregister_value_factory (repository_id);
 }
 #endif
 
@@ -1748,14 +1742,9 @@ CORBA::ORB::unregister_value_factory (const char *repository_id)
 CORBA::ValueFactory
 CORBA::ORB::lookup_value_factory (const char *repository_id)
 {
-  TAO_Valuetype_Adapter *vta = this->orb_core ()->valuetype_adapter ();
+  this->check_shutdown ();
 
-  if (vta)
-    {
-      return vta->vf_map_find (repository_id);
-    }
-
-  return 0;
+  return this->orb_core_->lookup_value_factory (repository_id);
 }
 #endif
 
