@@ -4,7 +4,7 @@
 /**
  *  @file    ORB.h
  *
- *  $Id: ORB.h 80288 2007-12-17 20:05:04Z johnnyw $
+ *  $Id: ORB.h 83897 2008-11-28 11:09:38Z johnnyw $
  *
  *  Header file for CORBA's ORB type.
  *
@@ -216,6 +216,15 @@ namespace CORBA
      */
     CORBA::Object_ptr string_to_object (const char *str);
 
+#if defined (ACE_USES_WCHAR)
+    /**
+     * Turn a string-ified object reference back into an object
+     * pointer.  Typically these strings are created using
+     * object_to_string(), but not necessarily locally.
+     * This is a TAO specific extension.
+     */
+    CORBA::Object_ptr string_to_object (const wchar_t *str);
+#endif
     /**
      * Turn an object reference into a string.  Each type of ORB,
      * e.g. an IIOP ORB, must implement this.  This can be used by
@@ -471,6 +480,9 @@ namespace CORBA
 #if !defined(CORBA_E_MICRO)
     /// Register an object reference with the ORB.
     void register_initial_reference (const char * id, CORBA::Object_ptr obj);
+
+    /// Unregister an object reference with the ORB.
+    CORBA::Object_ptr unregister_initial_reference (const char * id);
 #endif
 
     /// Returns a sequence of ObjectIds that lists which objects have
@@ -492,9 +504,10 @@ namespace CORBA
     CORBA::Policy_ptr _create_policy (CORBA::PolicyType type);
 #endif
 
-    // Reference counting...
+    /// Reference counting...
     unsigned long _incr_refcnt (void);
     unsigned long _decr_refcnt (void);
+    unsigned long _refcnt (void) const;
 
     /// Set the IOR flag.
     void _use_omg_ior_format (CORBA::Boolean ior);
@@ -579,15 +592,6 @@ namespace CORBA
   };
 }  // End namespace CORBA
 
-namespace TAO
-{
-  namespace ORB
-  {
-    /// Initialize the ORB globals correctly, i.e., only when they
-    /// haven't been initialized yet.
-    void init_orb_globals (void);
-  }
-}
 
 TAO_END_VERSIONED_NAMESPACE_DECL
 
