@@ -4,7 +4,7 @@
 /**
  *  @file  ORB_Constants.h
  *
- *  ORB_Constants.h,v 1.7 2005/02/28 14:42:40 jwillemsen Exp
+ *  $Id: ORB_Constants.h 76562 2007-01-24 18:37:07Z johnnyw $
  *
  *  Constants needed by various files.
  *
@@ -24,6 +24,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 // A hash define for the regular two way operation.
 #define TAO_TWOWAY_RESPONSE_FLAG 255
 
@@ -42,13 +44,13 @@ namespace CORBA
    * @c 2 is done as follows:
    *
    * @verbatim
-   *   throw (CORBA::BAD_PARAM (CORBA::OMGVMCID | 2, CORBA::COMPLETED_NO);
+   *   throw ::CORBA::BAD_PARAM (CORBA::OMGVMCID | 2, CORBA::COMPLETED_NO);
    * @endverbatim
    *
    * *NOT* as:
    *
    * @verbatim
-   *   throw (CORBA::BAD_PARAM (2, CORBA::COMPLETED_NO);
+   *   throw ::CORBA::BAD_PARAM (2, CORBA::COMPLETED_NO);
    * @endverbatim
    */
   const ULong OMGVMCID = 0x4f4d0000U;
@@ -177,8 +179,8 @@ const CORBA::ULong TAO_TAG_SHMEM_PROFILE = 0x54414f02U;
 /// UDP
 const CORBA::ULong TAO_TAG_DIOP_PROFILE = 0x54414f04U;
 
-/// Unreliable IP Multicast
-const CORBA::ULong TAO_TAG_UIPMC_PROFILE = 0x54414f0CU;
+/// COIOP
+const CORBA::ULong TAO_TAG_COIOP_PROFILE = 0x54414f05U;
 
 /// SCIOP
 const CORBA::ULong TAO_TAG_SCIOP_PROFILE = 0x54414f0EU;
@@ -234,6 +236,8 @@ const CORBA::ULong TAO_RTCORBA_THREAD_CREATION_LOCATION_CODE  = (0x15U << 7);
 //@}
 //@}
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_ORB_CONSTANTS_H */
