@@ -4,7 +4,7 @@
 /**
  *  @file   ORB_Core.h
  *
- *  $Id: ORB_Core.h 80573 2008-02-05 22:02:41Z smcqueen $
+ *  $Id: ORB_Core.h 89152 2010-02-23 09:57:24Z vzykov $
  *
  *  @author DOC Center - Washington University at St. Louis
  *  @author DOC Laboratory - University of California at Irvine
@@ -36,13 +36,14 @@
 #include "tao/Invocation_Utils.h"
 #include "tao/Adapter_Registry.h"
 #include "tao/ORB_Core_TSS_Resources.h"
+#include "tao/Service_Context_Handler_Registry.h"
 #include "ace/Array_Map.h"
 
 #include "ace/Thread_Manager.h"
 #include "ace/Lock_Adapter_T.h"
 #include "ace/TSS_T.h"
 
-#include "ace/Service_Object.h"
+#include "ace/Service_Config.h"
 
 ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 class ACE_Data_Block;
@@ -81,6 +82,7 @@ class TAO_Message_State_Factory;
 class TAO_Protocols_Hooks;
 class TAO_Network_Priority_Protocols_Hooks;
 class TAO_BiDir_Adapter;
+class TAO_ZIOP_Adapter;
 
 class TAO_Flushing_Strategy;
 
@@ -159,12 +161,12 @@ class TAO_Export TAO_ORB_Core
 {
   friend class TAO_ORB_Core_Auto_Ptr;
   friend CORBA::ORB_ptr CORBA::ORB_init (int &,
-                                         char *argv[],
+                                         ACE_TCHAR *argv[],
                                          const char *);
 public:
 
   /// Constructor.
-  TAO_ORB_Core (const char* id, ACE_Service_Gestalt* g);
+  TAO_ORB_Core (const char* id, ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> g);
 
   /// Accessor for the ORB parameters.
   TAO_ORB_Parameters *orb_params (void);
@@ -175,7 +177,7 @@ public:
    * object we should add a "Resolver" to the ORB, so the "POACurrent"
    * object returns a per-ORB object.
    * @par
-   * Similarly, each ORB should implement the TSS pattern to put   the
+   * Similarly, each ORB should implement the TSS pattern to put the
    * POA_Current_Impl in a void* slot.  The current approach *does*
    * decouple the POA from the ORB, but it cannot add new adapters or
    * other components transparently.
@@ -200,6 +202,11 @@ public:
   /// yet
   TAO::ORBInitializer_Registry_Adapter *orbinitializer_registry (void);
 
+  TAO_ZIOP_Adapter *ziop_adapter () const;
+  void ziop_adapter (TAO_ZIOP_Adapter *adapter);
+
+  TAO_Service_Context_Registry &service_context_registry (void);
+
   /// Get the protocol factories
   TAO_ProtocolFactorySet *protocol_factories (void);
 
@@ -216,7 +223,7 @@ public:
   CORBA::Object_ptr root_poa (void);
 
   /// Get the adapter registry
-  TAO_Adapter_Registry *adapter_registry (void);
+  TAO_Adapter_Registry &adapter_registry (void);
 
   /// @name Collocation Strategies
   //@{
@@ -530,6 +537,12 @@ public:
 
   void set_sync_scope_hook (Sync_Scope_Hook hook);
 
+  /// Default Sync_Scope_Hook.
+  static void default_sync_scope_hook (TAO_ORB_Core *,
+                                       TAO_Stub *,
+                                       bool &has_synchronization,
+                                       Messaging::SyncScope &scope);
+
   /// Handle to the factory for protocols_hooks_..
   TAO_Protocols_Hooks *protocols_hooks_;
 
@@ -578,7 +591,7 @@ public:
   /// Check if ORB has shutdown.  If it has, throw an exception.
   void check_shutdown (void);
 
-  /// Returns the <timeout> value used by the server threads to poll
+  /// Returns the @a timeout value used by the server threads to poll
   /// the shutdown flag. If the return value is zero then the server
   /// threads block forever.
   int thread_per_connection_timeout (ACE_Time_Value &timeout) const;
@@ -653,9 +666,14 @@ public:
   /// Resolve the IOR Manipulation reference for this ORB.
   CORBA::Object_ptr resolve_ior_manipulation (void);
 
+  TAO_ZIOP_Adapter* ziop_adapter_i (void);
+
   /// Resolve the IOR Table reference for this ORB.
   CORBA::Object_ptr resolve_ior_table (void);
 
+  /// Resolve the Monitor reference for this ORB.
+  CORBA::Object_ptr resolve_monitor (void);
+
   /// Resolve an initial reference via the -ORBInitRef and
   // -ORBDefaultInitRef options.
   CORBA::Object_ptr resolve_rir (const char *name);
@@ -675,13 +693,14 @@ public:
   /// Reference counting...
   unsigned long _incr_refcnt (void);
   unsigned long _decr_refcnt (void);
+  unsigned long _refcnt (void) const;
 
   /// Register the handle of an open connection with the ORB Core
   /// handle set.  This handle set will be used to explicitly remove
   /// corresponding event handlers from the reactor.
   int register_handle (ACE_HANDLE handle);
 
-  /// Remove <handle> from the ORB Core's handle set so that it
+  /// Remove @a handle from the ORB Core's handle set so that it
   /// isn't included in the set that is passed to the reactor upon ORB
   /// destruction.
   int remove_handle (ACE_HANDLE handle);
@@ -726,12 +745,6 @@ public:
    */
   CORBA::ULong hash_service (TAO_Profile *this_p, CORBA::ULong max);
 
-  /// Call the service layers with the Service Context to check
-  /// whether they would like to add something to the list.
-  void service_context_list (TAO_Stub *stub,
-                             TAO_Service_Context &service_context,
-                             CORBA::Boolean retstart);
-
   /// Return a reference to the Fault Tolerant service object.
   TAO_Fault_Tolerance_Service &fault_tolerance_service (void);
 
@@ -807,6 +820,21 @@ public:
   /// Return the valuetype adapter
   TAO_Valuetype_Adapter *valuetype_adapter (void);
 
+#if !defined(CORBA_E_MICRO)
+  // Value factory operations  (CORBA 2.3 ptc/98-10-05 Ch. 4.2 p.4-7)
+  CORBA::ValueFactory register_value_factory (
+    const char *repository_id,
+    CORBA::ValueFactory factory);
+#endif
+
+#if !defined(CORBA_E_MICRO)
+  void unregister_value_factory (const char * repository_id);
+#endif
+
+#if !defined(CORBA_E_MICRO)
+  CORBA::ValueFactory lookup_value_factory (const char *repository_id);
+#endif
+
   /// Get the IOR Interceptor adapter. If not created, this method will try
   /// to create one.
   TAO_IORInterceptor_Adapter *ior_interceptor_adapter (void);
@@ -863,10 +891,6 @@ public:
   /// Choose to be not a default ORB when there is more than one ORB.
   void not_default (const char * orb_id);
 
-  /// This strategy is the default, no explicit queueing and no explicit
-  /// flush
-  TAO::Transport_Queueing_Strategy *default_transport_queueing_strategy (void);
-
   /// Verify condition for  permanent forward is given,
   /// both parameters must provide group attributes.
   CORBA::Boolean is_permanent_forward_condition
@@ -940,6 +964,9 @@ protected:
   /// Obtain and cache the IORManipulation factory object reference.
   void resolve_iormanipulation_i (void);
 
+  /// Obtain and cache the Monitor object reference.
+  void resolve_monitor_i (void);
+
   /// Search the Dynamic service list for well known services that has
   /// callbacks  which can be dynamically loaded.
   void services_callbacks_init (void);
@@ -951,7 +978,7 @@ protected:
 
   /// Pointer to the list of protocol loaded into this ORB instance.
   /// Helper method to hold the common code part for -ORBEndpoint and
-  /// -ORBListenEndpoint options.
+  /// -ORBListenEndpoints options.
   int set_endpoint_helper (const ACE_CString &lane,
                            const ACE_CString &endpoints);
 
@@ -1026,6 +1053,9 @@ protected:
   /// The cached object reference for the IORTable.
   CORBA::Object_ptr ior_table_;
 
+  /// The cached object reference for the Monitor.
+  CORBA::Object_ptr monitor_;
+
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
   /// The cached object reference for the RTCORBA::RTORB.
   CORBA::Object_var rt_orb_;
@@ -1085,7 +1115,7 @@ protected:
 
   /// Fault Tolerant service hook.
   TAO_Fault_Tolerance_Service ft_service_;
-  
+
   //@}
 
   /// TRUE transmits a full TAG_FT_GROUP component in place of the FT_GROUP_VERSION
@@ -1172,9 +1202,6 @@ protected:
 
 #endif /* TAO_HAS_BUFFERING_CONSTRAINT_POLICY == 1 */
 
-  /// This strategy will not queue by default and not flush
-  TAO::Transport_Queueing_Strategy *default_transport_queueing_strategy_;
-
   /// Number of outstanding references to this object.
   ACE_Atomic_Op<TAO_SYNCH_MUTEX, unsigned long> refcount_;
 
@@ -1184,6 +1211,9 @@ protected:
   /// Registry containing all orb initializers
   TAO::ORBInitializer_Registry_Adapter *orbinitializer_registry_;
 
+  /// Registry containing all service context handlers
+  TAO_Service_Context_Registry service_context_registry_;
+
 #if (TAO_HAS_INTERCEPTORS == 1)
   /// Cached pointer/reference to the PICurrent object.
   /**
@@ -1217,6 +1247,12 @@ protected:
   /// Bir Dir GIOP policy value
   CORBA::Boolean bidir_giop_policy_;
 
+  /// ZIOP Adapter
+  TAO_ZIOP_Adapter *ziop_adapter_;
+
+  /// ZIOP enabled or not
+  CORBA::Boolean ziop_enabled_;
+
   /// Hold the flushing strategy
   TAO_Flushing_Strategy *flushing_strategy_;
 
@@ -1224,7 +1260,7 @@ protected:
   TAO_Codeset_Manager *codeset_manager_;
 
   /// ORB's service configuration
-  ACE_Service_Gestalt *config_;
+  ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> config_;
 
   /// The hook to be set for the SyncScopePolicy
   Sync_Scope_Hook sync_scope_hook_;
@@ -1345,11 +1381,11 @@ TAO_Export TAO_ORB_Core * TAO_ORB_Core_instance (void);
 
 // ****************************************************************
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 ACE_STATIC_SVC_DECLARE_EXPORT (TAO, TAO_ORB_Core_Static_Resources)
 ACE_FACTORY_DECLARE (TAO, TAO_ORB_Core_Static_Resources)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
 # include "tao/ORB_Core.inl"
 #endif /* __ACE_INLINE__ */
