@@ -1,4 +1,4 @@
-// @(#) $Id: Object.cpp 80577 2008-02-06 10:24:05Z johnnyw $
+// @(#) $Id: Object.cpp 88308 2009-12-23 09:13:09Z johnnyw $
 //
 // Copyright 1994-1995 by Sun Microsystems Inc.
 // Copyright 1997-2002 by Washington University
@@ -31,7 +31,7 @@
 
 ACE_RCSID (tao,
            Object,
-           "$Id: Object.cpp 80577 2008-02-06 10:24:05Z johnnyw $")
+           "$Id: Object.cpp 88308 2009-12-23 09:13:09Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -113,19 +113,22 @@ if (!this->is_evaluated_) \
 void
 CORBA::Object::_add_ref (void)
 {
-  if (this->is_local_)
-    return;
-
-  this->_tao_actual_add_ref ();
+  this->refcount_.increment ();
 }
 
 void
 CORBA::Object::_remove_ref (void)
 {
-  if (this->is_local_)
+  if (this->refcount_.decrement () != 0)
     return;
 
-  this->_tao_actual_remove_ref ();
+  delete this;
+}
+
+CORBA::ULong
+CORBA::Object::_refcount_value(void) const
+{
+  return static_cast<CORBA::ULong> (this->refcount_.value ());
 }
 
 void
@@ -303,6 +306,11 @@ CORBA::Object::_hash (CORBA::ULong maximum)
 CORBA::Boolean
 CORBA::Object::_is_equivalent (CORBA::Object_ptr other_obj)
 {
+  if (other_obj == 0)
+    {
+      return false;
+    }
+
   if (other_obj == this)
     {
       return true;
@@ -349,6 +357,7 @@ CORBA::Object::_proxy_broker (TAO::Object_Proxy_Broker *proxy_broker)
 CORBA::Boolean
 CORBA::Object::is_nil_i (CORBA::Object_ptr obj)
 {
+
   // If the profile length is zero for a non-evaluted IOR it is a
   // null-object.
   if ((!obj->is_evaluated ()) && obj->ior ().profiles.length () == 0)
@@ -444,6 +453,7 @@ CORBA::Object::_create_request (CORBA::Context_ptr ctx,
 }
 #endif
 
+#if !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
 CORBA::Request_ptr
 CORBA::Object::_request (const char *operation)
 {
@@ -452,8 +462,7 @@ CORBA::Object::_request (const char *operation)
     {
       TAO_Dynamic_Adapter *dynamic_adapter =
         ACE_Dynamic_Service<TAO_Dynamic_Adapter>::instance (
-            TAO_ORB_Core::dynamic_adapter_name ()
-          );
+            TAO_ORB_Core::dynamic_adapter_name ());
 
       return dynamic_adapter->request (
                                   this,
@@ -465,6 +474,7 @@ CORBA::Object::_request (const char *operation)
       throw ::CORBA::NO_IMPLEMENT ();
     }
 }
+#endif
 
 // NON_EXISTENT ... send a simple call to the object, which will
 // either elicit a false response or a OBJECT_NOT_EXIST exception.  In
@@ -817,7 +827,9 @@ operator>> (TAO_InputCDR& cdr, CORBA::Object*& x)
     {
       if (orb_core->resource_factory ()->resource_usage_strategy () ==
           TAO_Resource_Factory::TAO_LAZY)
-        lazy_strategy = true;
+        {
+          lazy_strategy = true;
+        }
     }
 
   if (!lazy_strategy)
@@ -825,12 +837,12 @@ operator>> (TAO_InputCDR& cdr, CORBA::Object*& x)
       // If the user has set up a eager strategy..
       CORBA::String_var type_hint;
 
-      if ((cdr >> type_hint.inout ()) == 0)
-        return 0;
+      if (!(cdr >> type_hint.inout ()))
+        return false;
 
       CORBA::ULong profile_count;
-      if ((cdr >> profile_count) == 0)
-        return 0;
+      if (!(cdr >> profile_count))
+        return false;
 
       if (profile_count == 0)
         {
@@ -868,7 +880,9 @@ operator>> (TAO_InputCDR& cdr, CORBA::Object*& x)
             {
               TAO_Profile *pfile = connector_registry->create_profile (cdr);
               if (pfile != 0)
-                mp.give_profile (pfile);
+                {
+                  mp.give_profile (pfile);
+                }
             }
 
           // Make sure we got some profiles!
@@ -877,11 +891,12 @@ operator>> (TAO_InputCDR& cdr, CORBA::Object*& x)
               // @@ This occurs when profile creation fails when decoding the
               //    profile from the IOR.
               ACE_ERROR_RETURN ((LM_ERROR,
-                                 ACE_TEXT ("TAO (%P|%t) ERROR: Could not create all ")
-                                 ACE_TEXT ("profiles while extracting object\n")
-                                 ACE_TEXT ("TAO (%P|%t) ERROR: reference from the ")
-                                 ACE_TEXT ("CDR stream.\n")),
-                                0);
+                                 ACE_TEXT ("TAO (%P|%t) - ERROR: Could not create all ")
+                                 ACE_TEXT ("profiles while extracting object [%d, %d]\n")
+                                 ACE_TEXT ("TAO (%P|%t) - ERROR: reference from the ")
+                                 ACE_TEXT ("CDR stream.\n"),
+                                 mp.profile_count (), profile_count),
+                                false);
             }
 
           objdata = orb_core->create_stub (type_hint.in (), mp);
@@ -890,18 +905,20 @@ operator>> (TAO_InputCDR& cdr, CORBA::Object*& x)
         {
           if (TAO_debug_level > 0)
             ex._tao_print_exception (
-              ACE_TEXT ("TAO - ERROR creating stub ")
+              ACE_TEXT ("TAO (%P|%t) - ERROR creating stub ")
               ACE_TEXT ("object when demarshaling object ")
               ACE_TEXT ("reference.\n"));
 
-          return 0;
+          return false;
         }
 
       TAO_Stub_Auto_Ptr safe_objdata (objdata);
 
       x = orb_core->create_object (safe_objdata.get ());
-      if (x == 0)
-        return 0;
+      if (!x)
+        {
+          return false;
+        }
 
       // Transfer ownership to the CORBA::Object
       (void) safe_objdata.release ();
@@ -913,12 +930,16 @@ operator>> (TAO_InputCDR& cdr, CORBA::Object*& x)
 
       ACE_NEW_RETURN (ior,
                       IOP::IOR (),
-                      0);
+                      false);
 
-      cdr >> *ior;
+      if (!(cdr >> *ior))
+        {
+          return false;
+        }
+        
       ACE_NEW_RETURN (x,
                       CORBA::Object (ior, orb_core),
-                      0);
+                      false);
     }
 
   return (CORBA::Boolean) cdr.good_bit ();
@@ -971,7 +992,7 @@ namespace TAO
   Objref_Traits<CORBA::Object>::marshal (const CORBA::Object_ptr p,
                                          TAO_OutputCDR & cdr)
   {
-    return p->marshal (cdr);
+    return ::CORBA::Object::marshal (p, cdr);
   }
 } // close TAO namespace
 
