@@ -1,8 +1,10 @@
+// -*- C++ -*-
+
 // ================================================================
 /**
  *  @file   Object_Loader.h
  *
- *  Object_Loader.h,v 1.15 2005/01/04 09:55:22 jwillemsen Exp
+ *  $Id: Object_Loader.h 76995 2007-02-11 12:51:42Z johnnyw $
  *
  *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
  */
@@ -18,7 +20,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/SystemException.h"
+#include "tao/orbconf.h"
+#include "tao/TAO_Export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace CORBA
 {
@@ -55,10 +60,11 @@ public:
    */
   virtual CORBA::Object_ptr create_object (CORBA::ORB_ptr orb,
                                            int argc,
-                                           ACE_TCHAR* argv []
-                                           ACE_ENV_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException)) = 0;
+                                           ACE_TCHAR* argv []) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
+
 #endif /* TAO_OBJECT_LOADER_H */
