@@ -1,4 +1,4 @@
-// $Id: ClientRequestInfo.cpp 77779 2007-03-23 11:48:02Z johnnyw $
+// $Id: ClientRequestInfo.cpp 82354 2008-07-22 11:34:18Z johnnyw $
 
 #include "tao/PI/ClientRequestInfo.h"
 
@@ -6,7 +6,7 @@
 
 ACE_RCSID (PI,
            ClientRequestInfo,
-           "$Id: ClientRequestInfo.cpp 77779 2007-03-23 11:48:02Z johnnyw $")
+           "$Id: ClientRequestInfo.cpp 82354 2008-07-22 11:34:18Z johnnyw $")
 
 #include "tao/AnyTypeCode/Any.h"
 #include "tao/AnyTypeCode/ExceptionA.h"
@@ -41,7 +41,7 @@ TAO_ClientRequestInfo::setup_picurrent (void)
 {
   // Retrieve the thread scope current (no TSS access incurred yet).
   CORBA::Object_ptr pi_current_obj =
-    this->invocation_->orb_core ()->pi_current ();
+    this->invocation_->stub ()->orb_core ()->pi_current ();
 
   TAO::PICurrent *pi_current =
     dynamic_cast <TAO::PICurrent*> (pi_current_obj);
@@ -138,8 +138,8 @@ TAO_ClientRequestInfo::received_exception (void)
 {
   this->check_validity ();
 
-  if (this->invocation_->reply_status () != PortableInterceptor::SYSTEM_EXCEPTION
-      && this->invocation_->reply_status () != PortableInterceptor::USER_EXCEPTION)
+  if (this->invocation_->pi_reply_status () != PortableInterceptor::SYSTEM_EXCEPTION
+      && this->invocation_->pi_reply_status () != PortableInterceptor::USER_EXCEPTION)
     {
       throw ::CORBA::BAD_INV_ORDER (CORBA::OMGVMCID | 14, CORBA::COMPLETED_NO);
     }
@@ -554,7 +554,7 @@ TAO_ClientRequestInfo::reply_status (void)
   this->check_validity ();
 
   PortableInterceptor::ReplyStatus const status =
-    this->invocation_->reply_status();
+    this->invocation_->pi_reply_status();
   if (status == -1 || status == PortableInterceptor::UNKNOWN)
     {
       // A reply hasn't been received yet.
@@ -569,7 +569,7 @@ TAO_ClientRequestInfo::forward_reference (void)
 {
   this->check_validity ();
 
-  if (this->invocation_->reply_status() != PortableInterceptor::LOCATION_FORWARD)
+  if (this->invocation_->pi_reply_status() != PortableInterceptor::LOCATION_FORWARD)
     {
       throw ::CORBA::BAD_INV_ORDER (CORBA::OMGVMCID | 14, CORBA::COMPLETED_NO);
     }
