@@ -4,7 +4,7 @@
 /**
  * @file ClientRequestInfo.h
  *
- * $Id: ClientRequestInfo.h 79914 2007-11-01 10:51:19Z johnnyw $
+ * $Id: ClientRequestInfo.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  * This is the implementation of the
  * PortableInterceptor::ClientRequestInfo interface.
@@ -70,7 +70,7 @@ namespace Messaging
  */
 class TAO_PI_Export TAO_ClientRequestInfo
   : public virtual PortableInterceptor::ClientRequestInfo,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
   TAO_ClientRequestInfo (TAO::Invocation_Base *invocation);
