@@ -15,7 +15,7 @@
 
 ACE_RCSID (PI,
            ClientRequestInterceptorAdapter_Impl,
-           "$Id: ClientRequestInterceptor_Adapter_Impl.cpp 78457 2007-05-23 12:42:05Z johnnyw $")
+           "$Id: ClientRequestInterceptor_Adapter_Impl.cpp 81632 2008-05-07 09:19:05Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -152,7 +152,7 @@ namespace TAO
         this->receive_exception (invocation);
 
         PortableInterceptor::ReplyStatus status =
-          this->reply_status (invocation);
+          this->pi_reply_status (invocation);
 
         // Only re-throw the exception if it hasn't been transformed by
         // the receive_exception() interception point (e.g. to a
@@ -221,7 +221,7 @@ namespace TAO
         this->receive_exception (invocation);
 
         PortableInterceptor::ReplyStatus status =
-          this->reply_status (invocation);
+          this->pi_reply_status (invocation);
 
         // Only re-throw the exception if it hasn't been transformed by
         // the receive_exception() interception point (e.g. to a
@@ -265,7 +265,7 @@ namespace TAO
   }
 
   PortableInterceptor::ReplyStatus
-  ClientRequestInterceptor_Adapter_Impl::reply_status (
+  ClientRequestInterceptor_Adapter_Impl::pi_reply_status (
     TAO::Invocation_Base const &invocation_base)
   {
     PortableInterceptor::ReplyStatus reply_status;
@@ -276,7 +276,8 @@ namespace TAO
         reply_status = PortableInterceptor::SUCCESSFUL;
         break;
       case TAO::TAO_INVOKE_RESTART:
-        if (invocation_base.is_forwarded ())
+        if (invocation_base.reply_status () == GIOP::LOCATION_FORWARD ||
+            invocation_base.reply_status () == GIOP::LOCATION_FORWARD_PERM)
           reply_status = PortableInterceptor::LOCATION_FORWARD;
         else
           reply_status = PortableInterceptor::TRANSPORT_RETRY;
