@@ -4,7 +4,7 @@
 /**
  *  @file    ClientRequestInterceptor_Adapter_Impl.h
  *
- *  $Id: ClientRequestInterceptor_Adapter_Impl.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: ClientRequestInterceptor_Adapter_Impl.h 85371 2009-05-18 13:39:38Z sma $
  *
  *   This file an adapter class to simplify the support of
  *   interceptors.
@@ -33,6 +33,7 @@
 #include "tao/PI/Interceptor_List_T.h"
 #include "tao/PI/PI_includeC.h"
 #include "tao/PI/ClientRequestDetails.h"
+#include "tao/PI/RequestInterceptor_Adapter_Impl.h"
 #include "tao/ClientRequestInterceptor_Adapter.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -62,9 +63,9 @@ namespace TAO
    */
   class ClientRequestInterceptor_Adapter_Impl
     : public ClientRequestInterceptor_Adapter
+    , public TAO_RequestInterceptor_Adapter_Impl
   {
   public:
-
     ClientRequestInterceptor_Adapter_Impl (void);
 
     /**
@@ -104,11 +105,15 @@ namespace TAO
 
     virtual void destroy_interceptors (void);
 
-    virtual PortableInterceptor::ReplyStatus reply_status (
+    virtual PortableInterceptor::ReplyStatus pi_reply_status (
       TAO::Invocation_Base const &invocation_base);
 
-  protected:
+    void popTSC (TAO_ORB_Core *orb_core)
+      {TAO_RequestInterceptor_Adapter_Impl::popTSC (orb_core);}
+    void pushTSC (TAO_ORB_Core *orb_core)
+      {TAO_RequestInterceptor_Adapter_Impl::pushTSC (orb_core);}
 
+  protected:
     /// Process the given PortableInterceptor::ForwardRequest exception,
     /// i.e. invoke the receive_other() interception point, in addition
     /// to notifying the Invocation object of the LOCATION_FORWARD.
@@ -116,7 +121,6 @@ namespace TAO
                                   const PortableInterceptor::ForwardRequest &exc);
 
   private:
-
     /// List of registered interceptors.
     ClientRequestInterceptor_List interceptor_list_;
   };
