@@ -1,4 +1,4 @@
-// $Id: Interceptor_List_T.cpp 79914 2007-11-01 10:51:19Z johnnyw $
+// $Id: Interceptor_List_T.cpp 84443 2009-02-12 20:26:35Z johnnyw $
 
 #include "tao/PI/PI_includeC.h"
 #include "tao/ORB_Constants.h"
@@ -34,7 +34,7 @@ namespace TAO
 
   template <typename InterceptorType, typename DetailsType>
   size_t
-  Interceptor_List<InterceptorType,DetailsType>::size (void)
+  Interceptor_List<InterceptorType,DetailsType>::size (void) const
   {
     return this->interceptors_.size ();
   }
@@ -166,7 +166,7 @@ namespace TAO
         details.apply_policies(policies);
 
         /// Increase the length of the Interceptor sequence by one.
-        const size_t new_len = old_len + 1;
+        size_t const new_len = old_len + 1;
         this->interceptors_.size (new_len);
 
         // Add the interceptor
@@ -224,7 +224,7 @@ namespace TAO
             ACE_DEBUG ((LM_DEBUG,
                         ACE_TEXT ("TAO (%P|%t) - Exception in ")
                         ACE_TEXT ("Interceptor_List")
-                        ACE_TEXT ("::destroy_interceptors () \n")));
+                        ACE_TEXT ("::destroy_interceptors ()\n")));
           }
       }
   }
