@@ -4,7 +4,7 @@
 /**
  *  @file   Interceptor_List_T.h
  *
- *  $Id: Interceptor_List_T.h 77151 2007-02-15 13:24:41Z johnnyw $
+ *  $Id: Interceptor_List_T.h 80823 2008-03-04 10:11:35Z johnnyw $
  *
  *  @author Ossama Othman <ossama@uci.edu>
  *  @author Johnny Willemsen  <jwillemsen@remedy.nl>
@@ -78,10 +78,9 @@ namespace TAO
     /// Return the interceptor in sequence element @a index.
     InterceptorType_ptr_type interceptor (size_t index);
 
-    size_t size (void);
+    size_t size (void) const;
 
   private:
-
     typedef ACE_Array_Base<RegisteredInterceptor > RegisteredArray;
 
     /// Dynamic array of registered interceptors.
