@@ -4,7 +4,7 @@
 /**
  *  @file   ORBInitInfo.h
  *
- *  $Id: ORBInitInfo.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: ORBInitInfo.h 83309 2008-10-17 13:57:39Z johnnyw $
  *
  *  @author Ossama Othman <ossama@dre.vanderbilt.edu>
  */
@@ -31,10 +31,6 @@
 #pragma warning(disable:4250)
 #endif /* _MSC_VER */
 
-#if defined (__BORLANDC__)
-#pragma option push -w-rvl -w-rch -w-ccc -w-inl
-#endif /* __BORLANDC__ */
-
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_ORB_Core;
@@ -58,7 +54,7 @@ typedef TAO_Objref_Out_T<TAO_ORBInitInfo>
  */
 class TAO_PI_Export TAO_ORBInitInfo
   : public virtual PortableInterceptor::ORBInitInfo_3_1,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
 
@@ -279,10 +275,6 @@ TAO_END_VERSIONED_NAMESPACE_DECL
 #pragma warning(pop)
 #endif /* _MSC_VER */
 
-#if defined (__BORLANDC__)
-#pragma option pop
-#endif /* __BORLANDC__ */
-
 #include /**/ "ace/post.h"
 
 #endif /* TAO_ORB_INIT_INFO_H */
