@@ -16,7 +16,7 @@
 
 ACE_RCSID (PI,
            ORBInitializer_Registry,
-           "$Id: ORBInitializer_Registry_Impl.cpp 78935 2007-07-18 12:40:46Z johnnyw $")
+           "$Id: ORBInitializer_Registry_Impl.cpp 84281 2009-01-30 15:01:17Z wotte $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -80,8 +80,15 @@ TAO::ORBInitializer_Registry::fini (void)
 
   // Release all initializers in the array
   size_t const initializer_count (this->initializers_.size ());
-  for (size_t i = 0; i < initializer_count; ++i)
+  for (size_t i = initializer_count; i > 0;)
     {
+      --i;
+      if (TAO_debug_level > 8)
+        {
+          ACE_DEBUG((LM_DEBUG, ACE_TEXT("TAO (%P|%t) - ORBInitializer_Registry::fini clearing %d @%@\n"),
+            i, this->initializers_[i].operator->()
+            ));
+        }
       this->initializers_[i] = PortableInterceptor::ORBInitializer::_nil();
     }
 
@@ -105,6 +112,13 @@ TAO::ORBInitializer_Registry::register_orb_initializer (
         throw ::CORBA::INTERNAL ();
 
       // Add the given ORBInitializer to the sequence.
+      if (TAO_debug_level > 8)
+        {
+          ACE_DEBUG((LM_DEBUG, ACE_TEXT("TAO (%P|%t) - ORBInitializer_Registry::register_orb_initializer %d @%@\n"),
+            cur_len, init
+            ));
+        }
+
       this->initializers_[cur_len] =
         PortableInterceptor::ORBInitializer::_duplicate (init);
     }
@@ -227,8 +241,6 @@ TAO::ORBInitializer_Registry::post_init (
     }
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 ACE_STATIC_SVC_DEFINE (ORBInitializer_Registry,
                        ACE_TEXT ("ORBInitializer_Registry"),
                        ACE_SVC_OBJ_T,
@@ -237,3 +249,6 @@ ACE_STATIC_SVC_DEFINE (ORBInitializer_Registry,
                        0)
 
 ACE_FACTORY_NAMESPACE_DEFINE (TAO_PI, ORBInitializer_Registry, TAO::ORBInitializer_Registry)
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
