@@ -4,7 +4,7 @@
 /**
  *  @file   PI.h
  *
- *  $Id: PI.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: PI.h 81670 2008-05-09 18:14:09Z johnnyw $
  *
  *  @author Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -37,7 +37,7 @@ public:
   static int Initializer (void);
 };
 
-#if defined (TAO_AS_STATIC_LIBS)
+#if defined (TAO_AS_STATIC_LIBS) || (defined (ACE_VXWORKS) && !defined (__RTP__))
 // only do this for static builds, it causes a circular
 // dependency for dynamic builds.
 static int
