@@ -4,7 +4,7 @@
 /**
  * @file PICurrent_Loader.cpp
  *
- * $Id: PICurrent_Loader.cpp 77409 2007-02-26 23:48:49Z ossama $
+ * $Id: PICurrent_Loader.cpp 84281 2009-01-30 15:01:17Z wotte $
  *
  * @author Johnny Willemsen  <jwillemsen@remedy.nl>
  *
@@ -23,21 +23,20 @@
 
 ACE_RCSID (PI,
            PICurrent_Loader,
-           "$Id: PICurrent_Loader.cpp 77409 2007-02-26 23:48:49Z ossama $")
+           "$Id: PICurrent_Loader.cpp 84281 2009-01-30 15:01:17Z wotte $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 CORBA::Object_ptr
 TAO_PICurrent_Loader::create_object (CORBA::ORB_ptr orb,  int, ACE_TCHAR *[])
 {
-  CORBA::Object_ptr obj = CORBA::Object_ptr ();
+  CORBA::Object_ptr obj = CORBA::Object::_nil ();
   ACE_NEW_RETURN (obj,
                   TAO::PICurrent (*orb->orb_core ()),
                   CORBA::Object::_nil ());
   return obj;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 ACE_STATIC_SVC_DEFINE (TAO_PICurrent_Loader,
                        ACE_TEXT ("PICurrent_Loader"),
@@ -47,4 +46,6 @@ ACE_STATIC_SVC_DEFINE (TAO_PICurrent_Loader,
                        0)
 ACE_FACTORY_DEFINE (TAO_PI, TAO_PICurrent_Loader)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif  /* TAO_HAS_INTERCEPTORS == 1 */
