@@ -4,7 +4,7 @@
 /**
  * @file PI_PolicyFactory.h
  *
- * $Id: PI_PolicyFactory.h 79914 2007-11-01 10:51:19Z johnnyw $
+ * $Id: PI_PolicyFactory.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  * @author Tim Bradley <bradley_t@ociweb.com>
  */
@@ -33,7 +33,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// Policy factory for all PortableInterceptor related policies.
 class TAO_PI_Export TAO_PI_PolicyFactory
   : public virtual PortableInterceptor::PolicyFactory,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
   CORBA::Policy_ptr create_policy (CORBA::PolicyType type,
