@@ -1,5 +1,5 @@
 
-// $Id: PI_Server_Loader.cpp 79209 2007-08-05 18:58:56Z johnnyw $
+// $Id: PI_Server_Loader.cpp 87582 2009-11-16 16:04:12Z vzykov $
 
 #include "tao/PI_Server/PI_Server_Loader.h"
 #include "tao/PI_Server/PortableServer_ORBInitializer.h"
@@ -10,11 +10,12 @@
 
 ACE_RCSID (PI_Server,
            PI_Server_Loader,
-           "$Id: PI_Server_Loader.cpp 79209 2007-08-05 18:58:56Z johnnyw $")
+           "$Id: PI_Server_Loader.cpp 87582 2009-11-16 16:04:12Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_PI_Server_Loader::TAO_PI_Server_Loader (void)
+  : initialized_ (false)
 {
 }
 
@@ -27,13 +28,11 @@ TAO_PI_Server_Loader::init (int, ACE_TCHAR* [])
 {
   ACE_TRACE ("TAO_PI_Server_Loader::init");
 
-  static bool initialized = false;
-
   // Only allow initialization once.
-  if (initialized)
+  if (this->initialized_)
     return 0;
 
-  initialized = true;
+  this->initialized_ = true;
 
   // Register the ORB initializer.
   try
@@ -64,7 +63,6 @@ TAO_PI_Server_Loader::init (int, ACE_TCHAR* [])
   return 0;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 /////////////////////////////////////////////////////////////////////
 
@@ -76,3 +74,4 @@ ACE_STATIC_SVC_DEFINE (TAO_PI_Server_Loader,
                        ACE_Service_Type::DELETE_THIS
                        | ACE_Service_Type::DELETE_OBJ,
                        0)
+TAO_END_VERSIONED_NAMESPACE_DECL
