@@ -4,7 +4,7 @@
 /**
  *  @file    PI_Server_Loader.h
  *
- *  $Id: PI_Server_Loader.h 79209 2007-08-05 18:58:56Z johnnyw $
+ *  $Id: PI_Server_Loader.h 87582 2009-11-16 16:04:12Z vzykov $
  */
 //=============================================================================
 
@@ -36,12 +36,17 @@ public:
 
   /// Initialize the PI_Server loader hooks.
   virtual int init (int argc, ACE_TCHAR* []);
+
+private:
+  /// Set to true after init is called.
+  bool initialized_;
 };
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 ACE_STATIC_SVC_DECLARE_EXPORT (TAO_PI_Server, TAO_PI_Server_Loader)
 ACE_FACTORY_DECLARE (TAO_PI_Server, TAO_PI_Server_Loader)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_PI_SERVER_LOADER_H */
