@@ -4,7 +4,7 @@
 /**
  *  @file PortableServer_ORBInitializer.h
  *
- *  $Id: PortableServer_ORBInitializer.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: PortableServer_ORBInitializer.h 81455 2008-04-28 10:26:37Z johnnyw $
  *
  *  @author Irfan Pyarali <irfan@oomworks.com>
  */
@@ -28,7 +28,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// PortableServer ORB initializer.
 class TAO_PortableServer_ORBInitializer
   : public virtual PortableInterceptor::ORBInitializer,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
 
@@ -42,7 +42,6 @@ public:
   void pre_init (PortableInterceptor::ORBInitInfo_ptr info);
 
   void post_init (PortableInterceptor::ORBInitInfo_ptr info);
-
   //@}
 
 private:
