@@ -4,7 +4,7 @@
 /**
  * @file PortableServer_PolicyFactory.h
  *
- * $Id: PortableServer_PolicyFactory.h 76995 2007-02-11 12:51:42Z johnnyw $
+ * $Id: PortableServer_PolicyFactory.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  * @author Irfan Pyarali <irfan@oomworks.com>
  */
@@ -28,7 +28,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 /// Policy factory for all PortableServer related policies.
 class TAO_PortableServer_PolicyFactory
   : public virtual PortableInterceptor::PolicyFactory,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
   CORBA::Policy_ptr create_policy (CORBA::PolicyType type,
