@@ -4,7 +4,7 @@
 /**
  *  @file    ServerInterceptorAdapter.h
  *
- *  $Id: ServerInterceptorAdapter.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: ServerInterceptorAdapter.h 85371 2009-05-18 13:39:38Z sma $
  *
  *   This file contains a helper class to simplify the support of
  *   interceptors in TAO_IDL generated skeletons.
@@ -26,17 +26,16 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-
 #if TAO_HAS_INTERCEPTORS == 1
 
 #include "tao/PI_Server/PI_Server_includeC.h"
 
 #include "tao/PI/Interceptor_List_T.h"
 #include "tao/ServerRequestInterceptor_Adapter.h"
+#include "tao/PI/RequestInterceptor_Adapter_Impl.h"
 #include "tao/Basic_Types.h"
 #include "tao/PI_Server/ServerRequestDetails.h"
 
-
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
@@ -67,9 +66,9 @@ namespace TAO
    */
   class ServerRequestInterceptor_Adapter_Impl
     : public ServerRequestInterceptor_Adapter
+    , public TAO_RequestInterceptor_Adapter_Impl
   {
   public:
-
     /// Constructor.
     ServerRequestInterceptor_Adapter_Impl (void);
 
@@ -84,7 +83,6 @@ namespace TAO
     /// This method implements the "starting" server side interception
     /// point. It will be used as the first interception point and it is
     /// proprietary to TAO.
-    /// @@ Will go away once Bug 1369 is fixed
     void tao_ft_interception_point (
         TAO_ServerRequest &server_request,
         TAO::Argument * const args[],
@@ -169,12 +167,15 @@ namespace TAO
         TAO_ServerRequest &server_request,
         TAO::Upcall_Command &command);
 
-  private:
+    void popTSC (TAO_ORB_Core *orb_core)
+      {TAO_RequestInterceptor_Adapter_Impl::popTSC (orb_core);}
+    void pushTSC (TAO_ORB_Core *orb_core)
+      {TAO_RequestInterceptor_Adapter_Impl::pushTSC (orb_core);}
 
+  private:
     /// List of registered interceptors.
     ServerRequestInterceptor_List interceptor_list_;
   };
-
 }  // End namespace TAO
 
 TAO_END_VERSIONED_NAMESPACE_DECL
