@@ -4,7 +4,7 @@
 /**
  * @file ServerRequestInfo.h
  *
- * $Id: ServerRequestInfo.h 79914 2007-11-01 10:51:19Z johnnyw $
+ * $Id: ServerRequestInfo.h 81663 2008-05-09 12:43:47Z johnnyw $
  *
  * This is the implementation of the
  * @c PortableInterceptor::ServerRequestInfo interface.
@@ -69,7 +69,7 @@ namespace TAO
    */
   class ServerRequestInfo
     : public virtual PortableInterceptor::ServerRequestInfo
-    , public virtual CORBA::LocalObject
+    , public virtual ::CORBA::LocalObject
   {
   public:
 
@@ -220,8 +220,7 @@ namespace TAO
     /// contexts.
     IOP::ServiceContext * get_service_context_i (
         TAO_Service_Context & service_context_list,
-        IOP::ServiceId id
-        );
+        IOP::ServiceId id);
 
   protected:
 
