@@ -1,33 +1,31 @@
-// Policy_Validator.cpp,v 1.11 2004/12/06 22:19:02 jeliazkov_i Exp
+// $Id: Policy_Validator.cpp 76687 2007-01-29 19:18:13Z johnnyw $
 
-#include "Policy_Validator.h"
-#include "Environment.h"
-#include "debug.h"
+#include "tao/Policy_Validator.h"
+#include "tao/debug.h"
 
 #include "ace/Log_Msg.h"
 
 ACE_RCSID (tao,
            Policy_Validator,
-           "Policy_Validator.cpp,v 1.11 2004/12/06 22:19:02 jeliazkov_i Exp")
+           "$Id: Policy_Validator.cpp 76687 2007-01-29 19:18:13Z johnnyw $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Policy_Validator::TAO_Policy_Validator (TAO_ORB_Core &orb_core)
   : orb_core_ (orb_core),
     next_ (0)
 {
-  // No-Op.
 }
 
 TAO_Policy_Validator::~TAO_Policy_Validator (void)
 {
-  if (this->next_)
-    {
-      delete this->next_;
-    }
+  delete this->next_;
 }
 
-TAO_ORB_Core & 
+TAO_ORB_Core &
 TAO_Policy_Validator::orb_core() const
-{ 
+{
   return this->orb_core_;
 }
 
@@ -67,30 +65,24 @@ TAO_Policy_Validator::add_validator (TAO_Policy_Validator *validator)
 
 
 void
-TAO_Policy_Validator::validate (TAO_Policy_Set &policies
-                                ACE_ENV_ARG_DECL)
+TAO_Policy_Validator::validate (TAO_Policy_Set &policies)
 {
-  this->validate_impl (policies ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->validate_impl (policies);
 
   if (this->next_ != 0)
     {
-      this->next_->validate (policies ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->next_->validate (policies);
     }
 }
 
 void
-TAO_Policy_Validator::merge_policies (TAO_Policy_Set &policies
-                                      ACE_ENV_ARG_DECL)
+TAO_Policy_Validator::merge_policies (TAO_Policy_Set &policies)
 {
-  this->merge_policies_impl (policies ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->merge_policies_impl (policies);
 
-  if (this->next_ != 0)
+  if (this->next_)
     {
-      this->next_->merge_policies (policies ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+      this->next_->merge_policies (policies);
     }
 }
 
@@ -101,3 +93,5 @@ TAO_Policy_Validator::legal_policy (CORBA::PolicyType type)
           || ((this->next_ != 0)
               && this->next_->legal_policy_impl (type)));
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
