@@ -1,10 +1,10 @@
-// $Id: Adapter_Activator.cpp 77357 2007-02-24 06:58:14Z johnnyw $
+// $Id: Adapter_Activator.cpp 81410 2008-04-24 09:22:08Z johnnyw $
 
 #include "tao/PortableServer/Adapter_Activator.h"
 
 ACE_RCSID (PortableServer,
            Adapter_Activator,
-           "$Id: Adapter_Activator.cpp 77357 2007-02-24 06:58:14Z johnnyw $")
+           "$Id: Adapter_Activator.cpp 81410 2008-04-24 09:22:08Z johnnyw $")
 
 #if (TAO_HAS_MINIMUM_POA == 0)
 #if !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
@@ -34,9 +34,7 @@ namespace TAO
 
       // This assumes that the lock on the parent is recursive
       PortableServer::POA_var child =
-        parent->create_POA (name,
-                            this->poa_manager_.in (),
-                            default_policies);
+        parent->create_POA (name, this->poa_manager_.in (), default_policies);
 
       try
         {
