@@ -1,11 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Adapter_Activator.h
  *
- *  Adapter_Activator.h,v 1.2 2005/02/18 09:07:11 jwillemsen Exp
- *
+ *  $Id: Adapter_Activator.h 79124 2007-07-31 12:39:37Z johnnyw $
  */
 //=============================================================================
 
@@ -13,15 +12,18 @@
 #define TAO_ADAPTER_ACTIVATOR_H
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "AdapterActivatorC.h"
+#include "tao/PortableServer/AdapterActivatorC.h"
 
 #if (TAO_HAS_MINIMUM_POA == 0)
+#if !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace PortableServer
 {
@@ -39,13 +41,10 @@ namespace TAO
       : public PortableServer::AdapterActivator
     {
     public:
-
       Adapter_Activator (PortableServer::POAManager_ptr poa_manager);
 
       CORBA::Boolean unknown_adapter (PortableServer::POA_ptr parent,
-                                      const char *name
-                                      ACE_ENV_ARG_DECL)
-        ACE_THROW_SPEC ((CORBA::SystemException));
+                                      const char *name);
 
     protected:
 
@@ -55,6 +54,9 @@ namespace TAO
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#endif
 #endif /* TAO_HAS_MINIMUM_POA == 0 */
 
 #include /**/ "ace/post.h"
