@@ -4,7 +4,7 @@
 /**
  *  @file    Collocated_Object_Proxy_Broker.h
  *
- *  Collocated_Object_Proxy_Broker.h,v 1.5 2005/07/25 18:13:01 jwillemsen Exp
+ *  $Id: Collocated_Object_Proxy_Broker.h 79610 2007-09-07 18:17:34Z johnnyw $
  *
  *  This files contains the Collocated Proxy Broker implementation
  *  for the CORBA Object.
@@ -18,7 +18,7 @@
 #define TAO_COLLOCATED_OBJECT_PROXY_BROKER_H
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -26,6 +26,8 @@
 
 #include "tao/Object_Proxy_Broker.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   /**
@@ -43,24 +45,19 @@ namespace TAO
     /// Please see the documentation in Object_Proxy_Broker.h for
     /// details.
     virtual CORBA::Boolean _is_a (CORBA::Object_ptr target,
-                                  const char *logical_type_id
-                                  ACE_ENV_ARG_DECL);
+                                  const char *logical_type_id);
 
 #if (TAO_HAS_MINIMUM_CORBA == 0)
 
-  virtual CORBA::Boolean _non_existent (CORBA::Object_ptr target
-                                        ACE_ENV_ARG_DECL);
+  virtual CORBA::Boolean _non_existent (CORBA::Object_ptr target);
 
-  virtual CORBA::InterfaceDef * _get_interface (
-      CORBA::Object_ptr target
-      ACE_ENV_ARG_DECL
-    );
+#if !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
+  virtual CORBA::InterfaceDef * _get_interface (CORBA::Object_ptr target);
 
-  virtual CORBA::Object_ptr _get_component (CORBA::Object_ptr target
-                                            ACE_ENV_ARG_DECL);
+  virtual CORBA::Object_ptr _get_component (CORBA::Object_ptr target);
+#endif
 
-  virtual char * _repository_id (CORBA::Object_ptr target
-                                 ACE_ENV_ARG_DECL);
+  virtual char * _repository_id (CORBA::Object_ptr target);
 
 #endif /* TAO_HAS_MINIMUM_CORBA == 0 */
 
@@ -73,6 +70,8 @@ namespace TAO
 /// proxy broker. All the CORBA::Object share the proxy broker.
 TAO::Collocated_Object_Proxy_Broker *the_tao_collocated_object_proxy_broker (void);
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_COLLOCATED_OBJECT_PROXY_BROKER_H*/
