@@ -4,10 +4,9 @@
 /**
  *  @file    Default_Acceptor_Filter.h
  *
- *  Default_Acceptor_Filter.h,v 1.8 2005/01/09 10:37:42 jwillemsen Exp
- *
- *   Default strategy for populating mprofile
+ *  $Id: Default_Acceptor_Filter.h 72358 2006-04-26 13:22:59Z mesnier_p $
  *
+ *  Default strategy for populating mprofile
  *
  *  @author  Marina Spivak <marina@cs.wustl.edu>
  *  @author  Carlos O'Ryan <coryan@uci.edu>
@@ -17,9 +16,10 @@
 
 #ifndef TAO_DEFAULT_ACCEPTOR_FILTER_H
 #define TAO_DEFAULT_ACCEPTOR_FILTER_H
+
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -27,6 +27,8 @@
 
 #include "tao/Acceptor_Filter.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_Acceptor;
 
 /**
@@ -44,7 +46,7 @@ public:
   TAO_Default_Acceptor_Filter (void);
 
   /// Populate @a mprofile with all available endpoints.
-  int fill_profile (const TAO::ObjectKey &object_key,
+  virtual int fill_profile (const TAO::ObjectKey &object_key,
                     TAO_MProfile &mprofile,
                     TAO_Acceptor **acceptors_begin,
                     TAO_Acceptor **acceptors_end,
@@ -55,5 +57,8 @@ public:
   int encode_endpoints (TAO_MProfile &mprofile);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
+
 #endif /* TAO_DEFAULT_ACCEPTOR_FILTER_H */
