@@ -1,11 +1,16 @@
-// @(#) Default_Servant_Dispatcher.cpp,v 1.10 2005/03/07 13:27:18 jwillemsen Exp
+// $Id: Default_Servant_Dispatcher.cpp 77248 2007-02-20 16:06:37Z jai $
 
-#include "Default_Servant_Dispatcher.h"
-#include "Root_POA.h"
+#include "tao/PortableServer/Default_Servant_Dispatcher.h"
+#include "tao/PortableServer/Root_POA.h"
+#include "tao/PortableServer/Network_Priority_Hook.h"
 
 ACE_RCSID(PortableServer,
           Default_Servant_Dispatcher,
-          "Default_Servant_Dispatcher.cpp,v 1.10 2005/03/07 13:27:18 jwillemsen Exp")
+          "$Id: Default_Servant_Dispatcher.cpp 77248 2007-02-20 16:06:37Z jai $")
+
+#include "ace/CORBA_macros.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Default_Servant_Dispatcher::~TAO_Default_Servant_Dispatcher (void)
 {
@@ -13,48 +18,44 @@ TAO_Default_Servant_Dispatcher::~TAO_Default_Servant_Dispatcher (void)
 
 TAO_Root_POA *
 TAO_Default_Servant_Dispatcher::create_Root_POA (const ACE_CString &name,
-                                                 TAO_POA_Manager &poa_manager,
+                                                 PortableServer::POAManager_ptr poa_manager,
                                                  const TAO_POA_Policy_Set &policies,
                                                  ACE_Lock &lock,
                                                  TAO_SYNCH_MUTEX &thread_lock,
                                                  TAO_ORB_Core &orb_core,
-                                                 TAO_Object_Adapter *object_adapter
-                                                 ACE_ENV_ARG_DECL)
+                                                 TAO_Object_Adapter *object_adapter)
 {
   TAO_Root_POA *poa = 0;
 
   ACE_NEW_THROW_EX (poa,
                     TAO_Root_POA (name,
-                             poa_manager,
-                             policies,
-                             0,
-                             lock,
-                             thread_lock,
-                             orb_core,
-                             object_adapter
-                             ACE_ENV_ARG_PARAMETER),
+                                  poa_manager,
+                                  policies,
+                                  0,
+                                  lock,
+                                  thread_lock,
+                                  orb_core,
+                                  object_adapter),
                     CORBA::NO_MEMORY ());
-  ACE_CHECK_RETURN (0);
 
   return poa;
 }
 
 void
 TAO_Default_Servant_Dispatcher::pre_invoke_remote_request (
-  TAO_Root_POA &,
+  TAO_Root_POA &poa,
   CORBA::Short,
-  TAO_ServerRequest &,
-  TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &
-  ACE_ENV_ARG_DECL_NOT_USED)
+  TAO_ServerRequest &req,
+  TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &)
 {
+  poa.network_priority_hook ()-> set_dscp_codepoint (req, poa);
 }
 
 void
 TAO_Default_Servant_Dispatcher::pre_invoke_collocated_request (
   TAO_Root_POA &,
   CORBA::Short,
-  TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &
-  ACE_ENV_ARG_DECL_NOT_USED)
+  TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &)
 {
 }
 
@@ -64,3 +65,5 @@ TAO_Default_Servant_Dispatcher::post_invoke (
   TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &)
 {
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
