@@ -1,4 +1,4 @@
-// $Id: Direct_Collocation_Upcall_Wrapper.cpp 76995 2007-02-11 12:51:42Z johnnyw $
+// $Id: Direct_Collocation_Upcall_Wrapper.cpp 81211 2008-04-02 11:36:47Z vzykov $
 
 #include "tao/PortableServer/Direct_Collocation_Upcall_Wrapper.h"
 
@@ -13,7 +13,7 @@
 
 ACE_RCSID (PortableServer,
            Direct_Collocation_Upcall_Wrapper,
-           "$Id: Direct_Collocation_Upcall_Wrapper.cpp 76995 2007-02-11 12:51:42Z johnnyw $")
+           "$Id: Direct_Collocation_Upcall_Wrapper.cpp 81211 2008-04-02 11:36:47Z vzykov $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -21,6 +21,7 @@ void
 TAO::Direct_Collocation_Upcall_Wrapper::upcall (
   CORBA::Object_ptr obj,
   CORBA::Object_out forward_obj,
+  bool & is_forwarded,
   TAO::Argument ** args,
   int num_args,
   const char * op,
@@ -47,9 +48,11 @@ TAO::Direct_Collocation_Upcall_Wrapper::upcall (
     {
       forward_obj =
         CORBA::Object::_duplicate (forward_request.forward_reference.in ());
+      is_forwarded = true;
     }
 #else
   ACE_UNUSED_ARG (forward_obj);
+  ACE_UNUSED_ARG (is_forwarded);
 #endif /* TAO_HAS_MINIMUM_CORBA && !CORBA_E_COMPACT && !CORBA_E_MICRO*/
 }
 
