@@ -4,7 +4,7 @@
 /**
  *  @file    Direct_Collocation_Upcall_Wrapper.h
  *
- *  $Id: Direct_Collocation_Upcall_Wrapper.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: Direct_Collocation_Upcall_Wrapper.h 88803 2010-02-02 11:13:27Z vzykov $
  *
  *  @author Johnny Willemsen
  */
@@ -17,7 +17,7 @@
 
 #include "tao/PortableServer/portableserver_export.h"
 
-#ifndef ACE_LACKS_PRAGMA_ONCE
+#if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* !ACE_LACKS_PRAGMA_ONCE */
 
@@ -56,6 +56,7 @@ namespace TAO
     void upcall (
       CORBA::Object_ptr obj,
       CORBA::Object_out forward_obj,
+      bool & is_forwarded,
       TAO::Argument ** args,
       int num_args,
       const char * op,
