@@ -4,7 +4,7 @@
 /**
  *  @file IdAssignmentStrategyFactory.h
  *
- *  IdAssignmentStrategyFactory.h,v 1.3 2005/02/21 18:13:50 jwillemsen Exp
+ *  $Id: IdAssignmentStrategyFactory.h 76551 2007-01-24 13:42:44Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -14,14 +14,16 @@
 #define TAO_PORTABLESERVER_IDASSIGNMENTSTRATEGYFACTORY_H
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "StrategyFactory.h"
-#include "IdAssignmentPolicyC.h"
+#include "tao/PortableServer/StrategyFactory.h"
+#include "tao/PortableServer/IdAssignmentPolicyC.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -39,10 +41,12 @@ namespace TAO
 
       virtual void destroy (
         IdAssignmentStrategy *strategy
-        ACE_ENV_ARG_DECL) = 0;
+        ) = 0;
     };
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_PORTABLESERVER_IDASSIGNMENTSTRATEGYFACTORY_H */
