@@ -1,9 +1,15 @@
-#include "IdUniquenessPolicy.h"
-#include "PortableServer.h"
+#include "tao/PortableServer/IdUniquenessPolicy.h"
+#include "tao/PortableServer/PortableServer.h"
 
 ACE_RCSID (PortableServer,
            IdUniquenessPolicy,
-           "IdUniquenessPolicy.cpp,v 1.2 2005/02/18 09:07:11 jwillemsen Exp")
+           "$Id: IdUniquenessPolicy.cpp 76995 2007-02-11 12:51:42Z johnnyw $")
+
+#include "ace/CORBA_macros.h"
+
+#if !defined (CORBA_E_MICRO)
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -16,34 +22,29 @@ namespace TAO
     }
 
     CORBA::Policy_ptr
-    IdUniquenessPolicy::copy (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    IdUniquenessPolicy::copy (void)
     {
       IdUniquenessPolicy *copy = 0;
       ACE_NEW_THROW_EX (copy,
                         IdUniquenessPolicy (this->value_),
                         CORBA::NO_MEMORY ());
-      ACE_CHECK_RETURN (CORBA::Policy::_nil ());
 
       return copy;
     }
 
     void
-    IdUniquenessPolicy::destroy (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    IdUniquenessPolicy::destroy (void)
     {
     }
 
     ::PortableServer::IdUniquenessPolicyValue
-    IdUniquenessPolicy::value (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    IdUniquenessPolicy::value (void)
     {
       return value_;
     }
 
     CORBA::PolicyType
-    IdUniquenessPolicy::policy_type (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    IdUniquenessPolicy::policy_type (void)
     {
       return ::PortableServer::ID_UNIQUENESS_POLICY_ID;
     }
@@ -62,3 +63,6 @@ namespace TAO
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#endif
