@@ -4,7 +4,7 @@
 /**
  *  @file ImplicitActivationPolicy.h
  *
- *  $Id: ImplicitActivationPolicy.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: ImplicitActivationPolicy.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -40,7 +40,7 @@ namespace TAO
   {
     class TAO_PortableServer_Export ImplicitActivationPolicy
       : public virtual ::PortableServer::ImplicitActivationPolicy,
-        public virtual TAO_Local_RefCounted_Object
+        public virtual ::CORBA::LocalObject
     {
     public:
       ImplicitActivationPolicy (::PortableServer::ImplicitActivationPolicyValue value);
