@@ -4,7 +4,7 @@
 /**
  *  @file ImplicitActivationStrategy.h
  *
- *  ImplicitActivationStrategy.h,v 1.4 2005/07/26 07:45:11 jwillemsen Exp
+ *  $Id: ImplicitActivationStrategy.h 76551 2007-01-24 13:42:44Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -14,12 +14,14 @@
 #define TAO_ACTIVATION_STRATEGY_H
 #include /**/ "ace/pre.h"
 
-#include "Policy_Strategy.h"
+#include "tao/PortableServer/Policy_Strategy.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   namespace Portable_Server
@@ -28,14 +30,16 @@ namespace TAO
       : public Policy_Strategy
     {
     public:
-      virtual void strategy_init(TAO_Root_POA *poa ACE_ENV_ARG_DECL);
+      virtual void strategy_init(TAO_Root_POA *poa);
 
-      virtual void strategy_cleanup(ACE_ENV_SINGLE_ARG_DECL);
+      virtual void strategy_cleanup(void);
 
       virtual bool allow_implicit_activation (void) const = 0;
     };
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_ACTIVATION_STRATEGY_H */
