@@ -1,9 +1,15 @@
-#include "LifespanPolicy.h"
-#include "PortableServer.h"
+#include "tao/PortableServer/LifespanPolicy.h"
+#include "tao/PortableServer/PortableServer.h"
 
 ACE_RCSID (PortableServer,
            LifespanPolicy,
-           "LifespanPolicy.cpp,v 1.2 2005/02/18 09:07:12 jwillemsen Exp")
+           "$Id: LifespanPolicy.cpp 76995 2007-02-11 12:51:42Z johnnyw $")
+
+#include "ace/CORBA_macros.h"
+
+#if !defined (CORBA_E_MICRO)
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -16,34 +22,29 @@ namespace TAO
     }
 
     CORBA::Policy_ptr
-    LifespanPolicy::copy (ACE_ENV_SINGLE_ARG_DECL)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    LifespanPolicy::copy (void)
     {
       LifespanPolicy *copy = 0;
       ACE_NEW_THROW_EX (copy,
                         LifespanPolicy (this->value_),
                         CORBA::NO_MEMORY ());
-      ACE_CHECK_RETURN (CORBA::Policy::_nil ());
 
       return copy;
     }
 
     void
-    LifespanPolicy::destroy (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    LifespanPolicy::destroy (void)
     {
     }
 
     ::PortableServer::LifespanPolicyValue
-    LifespanPolicy::value (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    LifespanPolicy::value (void)
     {
       return value_;
     }
 
     CORBA::PolicyType
-    LifespanPolicy::policy_type (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-      ACE_THROW_SPEC ((CORBA::SystemException))
+    LifespanPolicy::policy_type (void)
     {
       return ::PortableServer::LIFESPAN_POLICY_ID;
     }
@@ -62,3 +63,6 @@ namespace TAO
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#endif
