@@ -1,4 +1,4 @@
-// $Id: Object_Adapter.cpp 79714 2007-09-25 05:09:52Z johnnyw $
+// $Id: Object_Adapter.cpp 84443 2009-02-12 20:26:35Z johnnyw $
 
 // -- PortableServer Include --
 #include "tao/PortableServer/Object_Adapter.h"
@@ -50,7 +50,7 @@
 
 ACE_RCSID (PortableServer,
            Object_Adapter,
-           "$Id: Object_Adapter.cpp 79714 2007-09-25 05:09:52Z johnnyw $")
+           "$Id: Object_Adapter.cpp 84443 2009-02-12 20:26:35Z johnnyw $")
 
 #if (TAO_HAS_MINIMUM_POA == 0) && !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
 namespace PortableServer
@@ -191,7 +191,7 @@ TAO_Object_Adapter::TAO_Object_Adapter (const TAO_Server_Strategy_Factory::Activ
       ACE_ERROR ((LM_ERROR,
                   "linear option for -ORBPersistentidPolicyDemuxStrategy "
                   "not supported with minimum POA maps. "
-                  "Ingoring option to use default... \n"));
+                  "Ingoring option to use default...\n"));
       /* FALL THROUGH */
 #endif /* TAO_HAS_MINIMUM_POA_MAPS == 0 */
     case TAO_DYNAMIC_HASH:
@@ -221,7 +221,7 @@ TAO_Object_Adapter::TAO_Object_Adapter (const TAO_Server_Strategy_Factory::Activ
       ACE_ERROR ((LM_ERROR,
                   "linear and dynamic options for -ORBTransientidPolicyDemuxStrategy "
                   "are not supported with minimum POA maps. "
-                  "Ingoring option to use default... \n"));
+                  "Ingoring option to use default...\n"));
       /* FALL THROUGH */
 #endif /* TAO_HAS_MINIMUM_POA_MAPS == 0 */
     case TAO_ACTIVE_DEMUX:
@@ -382,7 +382,7 @@ TAO_Object_Adapter::dispatch_servant (const TAO::ObjectKey &key,
   // calling operation's mem-space.
   if (req.collocated() && req.pi_reply_status () == PortableInterceptor::LOCATION_FORWARD)
     {
-      forward_to = CORBA::Object::_duplicate (req.forward_location ());
+      forward_to = req.forward_location ();
       result = TAO_Adapter::DS_FORWARD;
     }
 #endif
@@ -757,7 +757,7 @@ TAO_Object_Adapter::dispatch (TAO::ObjectKey &key,
           // thrown, then set the forward_to object reference and return
           // with the appropriate return status.
           forward_to.ptr () = request.forward_location ();
-          if (!CORBA::is_nil (request.forward_location ()))
+          if (request.is_forwarded ())
             {
               return TAO_Adapter::DS_FORWARD;
             }
@@ -777,7 +777,7 @@ TAO_Object_Adapter::dispatch (TAO::ObjectKey &key,
           // thrown, then set the forward_to object reference and return
           // with the appropriate return status.
           forward_to.ptr () = request.forward_location ();
-          if (!CORBA::is_nil (request.forward_location ()))
+          if (request.is_forwarded ())
             {
               return TAO_Adapter::DS_FORWARD;
             }
@@ -790,6 +790,8 @@ TAO_Object_Adapter::dispatch (TAO::ObjectKey &key,
 
       if (result == TAO_Adapter::DS_FORWARD)
         {
+          request.reply_status (GIOP::LOCATION_FORWARD);
+          request.pi_reply_status (PortableInterceptor::LOCATION_FORWARD);
           request.forward_location (forward_to.ptr ());
           if (sri_adapter != 0)
             {
