@@ -1,11 +1,13 @@
-// Operation_Table.cpp,v 1.12 2005/03/04 10:02:50 jwillemsen Exp
+// $Id: Operation_Table.cpp 71473 2006-03-10 07:19:20Z jtc $
 
-#include "Operation_Table.h"
+#include "tao/PortableServer/Operation_Table.h"
 #include "tao/ORB.h"
 
 ACE_RCSID(PortableServer,
           Operation_Table,
-          "Operation_Table.cpp,v 1.12 2005/03/04 10:02:50 jwillemsen Exp")
+          "$Id: Operation_Table.cpp 71473 2006-03-10 07:19:20Z jtc $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // destructor
 TAO_Operation_Table::~TAO_Operation_Table (void)
@@ -15,8 +17,9 @@ TAO_Operation_Table::~TAO_Operation_Table (void)
 /**************************************************************/
 TAO::Operation_Skeletons::Operation_Skeletons (void)
   : skel_ptr (0)
-    , thruPOA_skel_ptr (0)
-    , direct_skel_ptr (0)
+  , thruPOA_skel_ptr (0)
+  , direct_skel_ptr (0)
 {
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
