@@ -1,4 +1,4 @@
-// $Id: Operation_Table_Perfect_Hash.cpp 79209 2007-08-05 18:58:56Z johnnyw $
+// $Id: Operation_Table_Perfect_Hash.cpp 83502 2008-10-30 12:17:36Z johnnyw $
 
 #include "tao/PortableServer/Operation_Table_Perfect_Hash.h"
 #include "tao/Timeprobe.h"
@@ -6,7 +6,7 @@
 
 ACE_RCSID(PortableServer,
           Operation_Table_Perfect_Hash,
-          "$Id: Operation_Table_Perfect_Hash.cpp 79209 2007-08-05 18:58:56Z johnnyw $")
+          "$Id: Operation_Table_Perfect_Hash.cpp 83502 2008-10-30 12:17:36Z johnnyw $")
 
 #if defined (ACE_ENABLE_TIMEPROBES)
 
@@ -50,8 +50,8 @@ TAO_Perfect_Hash_OpTable::find (const char *opname,
       skelfunc = 0; // insure that somebody can't call a wrong function!
       ACE_ERROR_RETURN ((LM_ERROR,
                          ACE_TEXT ("TAO_Perfect_Hash_OpTable:find for ")
-                         ACE_TEXT ("operation '%s' (length=%d) failed\n"),
-                         ACE_TEXT_CHAR_TO_TCHAR (opname ? opname : "<null string>"), length),
+                         ACE_TEXT ("operation '%C' (length=%d) failed\n"),
+                         opname ? opname : "<null string>", length),
                         -1);
     }
 
@@ -76,8 +76,8 @@ TAO_Perfect_Hash_OpTable::find (const char *opname,
       skelfunc = 0; // insure that somebody can't call a wrong function!
       ACE_ERROR_RETURN ((LM_ERROR,
                          ACE_TEXT ("TAO_Perfect_Hash_OpTable:find for ")
-                         ACE_TEXT ("operation '%s' (length=%d) failed\n"),
-                         ACE_TEXT_CHAR_TO_TCHAR (opname ? opname : "<null string>"), length),
+                         ACE_TEXT ("operation '%C' (length=%d) failed\n"),
+                         opname ? opname : "<null string>", length),
                         -1);
     }
 
