@@ -1,27 +1,28 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    POA_Guard.h
  *
- *  POA_Guard.h,v 1.3 2005/02/21 18:13:50 jwillemsen Exp
- *
+ *  $Id: POA_Guard.h 76995 2007-02-11 12:51:42Z johnnyw $
  */
 //=============================================================================
 
 #ifndef TAO_POA_GUARD_H
 #define TAO_POA_GUARD_H
+
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/orbconf.h"
 #include "ace/Guard_T.h"
-#include "ace/CORBA_macros.h"
-#include "tao/Environment.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Root_POA;
 
@@ -39,9 +40,7 @@ namespace TAO
     class TAO_PortableServer_Export POA_Guard
     {
     public:
-      POA_Guard (::TAO_Root_POA &poa
-                 ACE_ENV_ARG_DECL,
-                 int check_for_destruction = 1);
+      POA_Guard (::TAO_Root_POA &poa, bool check_for_destruction = true);
 
     private:
       ACE_Guard<ACE_Lock> guard_;
@@ -49,5 +48,8 @@ namespace TAO
   } /* namespace Portable_Server */
 } /* namespace TAO */
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
+
 #endif /* TAO_POA_GUARD_H */
