@@ -4,7 +4,7 @@
 /**
  *  @file Policy_Strategy.h
  *
- *  Policy_Strategy.h,v 1.4 2005/07/26 07:45:11 jwillemsen Exp
+ *  $Id: Policy_Strategy.h 76995 2007-02-11 12:51:42Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -14,14 +14,15 @@
 #define TAO_POLICY_STRATEGY_H
 #include /**/ "ace/pre.h"
 
-#include "ace/Service_Object.h"
+#include "tao/orbconf.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "ace/CORBA_macros.h"
-#include "tao/Environment.h"
+#include "ace/Service_Object.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Root_POA;
 
@@ -33,14 +34,16 @@ namespace TAO
       : public ACE_Service_Object
     {
     public:
-      virtual void strategy_init(TAO_Root_POA *poa ACE_ENV_ARG_DECL) = 0;
+      virtual void strategy_init(TAO_Root_POA *poa ) = 0;
 
-      virtual void strategy_cleanup(ACE_ENV_SINGLE_ARG_DECL) = 0;
+      virtual void strategy_cleanup(void) = 0;
 
       virtual ~Policy_Strategy (void) {};
     };
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_POLICY_STRATEGY_H */
