@@ -4,7 +4,7 @@
 /**
  *  @file    PortableServer_Functions.h
  *
- *  PortableServer_Functions.h,v 1.2 2005/02/18 09:07:12 jwillemsen Exp
+ *  $Id: PortableServer_Functions.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  PortableServer helper functions
  *
@@ -17,7 +17,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -40,6 +40,8 @@
 #include "tao/PortableServer/PS_ForwardC.h"
 #include "ace/OS_NS_wchar.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace PortableServer
 {
   /// Utility functions for the other
@@ -50,6 +52,8 @@ namespace PortableServer
     const char *id);
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_PORTABLESERVER_FUNCTIONS_H */
