@@ -4,7 +4,7 @@
 /**
  *  @file RequestProcessingPolicy.h
  *
- *  $Id: RequestProcessingPolicy.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: RequestProcessingPolicy.h 81429 2008-04-24 18:49:54Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -40,7 +40,7 @@ namespace TAO
   {
     class TAO_PortableServer_Export RequestProcessingPolicy :
       public virtual ::PortableServer::RequestProcessingPolicy,
-      public virtual TAO_Local_RefCounted_Object
+      public virtual ::CORBA::LocalObject
     {
     public:
       RequestProcessingPolicy (::PortableServer::RequestProcessingPolicyValue value);
