@@ -1,4 +1,4 @@
-// $Id: Root_POA.cpp 80395 2008-01-08 10:16:50Z vzykov $
+// $Id: Root_POA.cpp 88564 2010-01-15 09:56:57Z johnnyw $
 
 #include "tao/PortableServer/Root_POA.h"
 #include "tao/PortableServer/Regular_POA.h"
@@ -63,7 +63,7 @@
 
 ACE_RCSID (PortableServer,
            Root_POA,
-           "$Id: Root_POA.cpp 80395 2008-01-08 10:16:50Z vzykov $")
+           "$Id: Root_POA.cpp 88564 2010-01-15 09:56:57Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -205,28 +205,22 @@ TAO_Root_POA::TAO_Root_POA (const TAO_Root_POA::String &name,
     ort_adapter_ (0),
     adapter_state_ (PortableInterceptor::HOLDING),
     network_priority_hook_ (0),
-
 #if (TAO_HAS_MINIMUM_POA == 0) && !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
-
     adapter_activator_ (),
-
 #endif /* TAO_HAS_MINIMUM_POA == 0 */
-
     children_ (),
     lock_ (lock),
     orb_core_ (orb_core),
     object_adapter_ (object_adapter),
-    cleanup_in_progress_ (0),
+    cleanup_in_progress_ (false),
     outstanding_requests_ (0),
     outstanding_requests_condition_ (thread_lock),
     wait_for_completion_pending_ (0),
-    waiting_destruction_ (0),
+    waiting_destruction_ (false),
     servant_deactivation_condition_ (thread_lock),
-
 #if (TAO_HAS_MINIMUM_POA == 0) && !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
     filter_factory_ (0),
 #endif
-
     caller_key_to_object_ (0),
     servant_for_key_to_object_ (0)
 {
@@ -239,6 +233,12 @@ TAO_Root_POA::TAO_Root_POA (const TAO_Root_POA::String &name,
   // a cache.
   this->cached_policies_.update (this->policies_);
 
+#if (TAO_HAS_MINIMUM_POA == 0) && !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
+  this->filter_factory_
+    = ACE_Dynamic_Service<TAO_Acceptor_Filter_Factory>::instance (
+        "TAO_Acceptor_Filter_Factory");
+#endif
+
   this->network_priority_hook_
     = ACE_Dynamic_Service<TAO_Network_Priority_Hook>::instance (
         "TAO_Network_Priority_Hook");
@@ -327,10 +327,10 @@ void
 TAO_Root_POA::complete_destruction_i (void)
 {
   bool doing_complete_destruction =
-    this->waiting_destruction_ != 0;
+    this->waiting_destruction_ != false;
 
   // No longer awaiting destruction.
-  this->waiting_destruction_ = 0;
+  this->waiting_destruction_ = false;
 
   PortableServer::POA_var poa;
   TAO::ORT_Array my_array_obj_ref_template;
@@ -358,15 +358,13 @@ TAO_Root_POA::complete_destruction_i (void)
     }
 
   // Remove POA from the POAManager.
-  int result = this->poa_manager_.remove_poa (this);
-
-  if (result != 0)
+  if (this->poa_manager_.remove_poa (this) != 0)
     throw ::CORBA::OBJ_ADAPTER ();
 
   // Remove POA from the Object Adapter.
-  result = this->object_adapter ().unbind_poa (this,
-                                               this->folded_name_,
-                                               this->system_name_.in ());
+  int result = this->object_adapter ().unbind_poa (this,
+                                                   this->folded_name_,
+                                                   this->system_name_.in ());
   if (result != 0)
     throw ::CORBA::OBJ_ADAPTER ();
 
@@ -474,8 +472,7 @@ TAO_Root_POA::create_POA_i (const char *adapter_name,
       // The POAManager name will be generated when the POAManager instance
       // is created.
       the_poa_manager
-        = tao_poa_manager_factory->create_POAManager (0,
-                                                      empty_policies);
+        = tao_poa_manager_factory->create_POAManager (0, empty_policies);
 #else
 
       PortableServer::POAManager_ptr the_poa_manager_ptr;
@@ -635,26 +632,21 @@ TAO_Root_POA::find_POA_i (const ACE_CString &child_name,
               this->check_state ();
 
               CORBA::Boolean success = false;
-              try
-                {
-                  // ATTENTION: Trick locking here, see class header for details
-                  TAO::Portable_Server::Non_Servant_Upcall non_servant_upcall (
-                    *this);
-                  ACE_UNUSED_ARG (non_servant_upcall);
 
-                  // When unknown_adapter gives a system exception, the POA
-                  // should raise OBJ_ADAPTER with standard minor code 1.
-                  // See 11.3.9.2 of the Corba spec
-                  success =
-                    this->adapter_activator_->unknown_adapter (
-                      this,
-                      child_name.c_str ());
-                }
-              catch (const ::CORBA::SystemException&)
-                {
-                  throw ::CORBA::OBJ_ADAPTER (CORBA::OMGVMCID | 1,
-                                              CORBA::COMPLETED_NO);
-                }
+              {
+                // ATTENTION: Trick locking here, see class header for details
+                TAO::Portable_Server::Non_Servant_Upcall non_servant_upcall (
+                  *this);
+                ACE_UNUSED_ARG (non_servant_upcall);
+
+                // When unknown_adapter gives a system exception, the POA
+                // should just pass the system exception through
+                // See 15.3.9.2 of the 3.1 CORBA spec
+                success =
+                  this->adapter_activator_->unknown_adapter (
+                    this,
+                    child_name.c_str ());
+              }
 
               if (success)
                 {
@@ -797,8 +789,7 @@ TAO_Root_POA::destroy (CORBA::Boolean etherealize_objects,
   TAO::Portable_Server::POA_Guard poa_guard (*this , 0);
   ACE_UNUSED_ARG (poa_guard);
 
-  this->destroy_i (etherealize_objects,
-                   wait_for_completion);
+  this->destroy_i (etherealize_objects, wait_for_completion);
 }
 
 void
@@ -818,7 +809,7 @@ TAO_Root_POA::destroy_i (CORBA::Boolean etherealize_objects,
   TAO_Root_POA::check_for_valid_wait_for_completions (this->orb_core (),
                                                       wait_for_completion);
 
-  this->cleanup_in_progress_ = 1;
+  this->cleanup_in_progress_ = true;
 
   // Inform the custom servant dispatching strategy to stop the working
   // threads when the poa is destroyed.
@@ -963,7 +954,7 @@ TAO_Root_POA::destroy_i (CORBA::Boolean etherealize_objects,
   else
     {
       // Mark that we are ready for destruction.
-      this->waiting_destruction_ = 1;
+      this->waiting_destruction_ = true;
     }
 }
 
@@ -1025,7 +1016,6 @@ TAO_Root_POA::adapter_name_i (void)
   while (!CORBA::is_nil (poa.in ()))
     {
       poa = poa->the_parent ();
-
       ++len;
     }
 
@@ -1160,7 +1150,6 @@ TAO_Root_POA::activate_object (PortableServer::Servant servant)
     }
 }
 
-#if !defined (CORBA_E_MICRO)
 void
 TAO_Root_POA::activate_object_with_id (const PortableServer::ObjectId &id,
                                        PortableServer::Servant servant)
@@ -1186,9 +1175,7 @@ TAO_Root_POA::activate_object_with_id (const PortableServer::ObjectId &id,
         return;
     }
 }
-#endif
 
-#if !defined (CORBA_E_MICRO)
 void
 TAO_Root_POA::activate_object_with_id_i (const PortableServer::ObjectId &id,
                                          PortableServer::Servant servant,
@@ -1201,7 +1188,6 @@ TAO_Root_POA::activate_object_with_id_i (const PortableServer::ObjectId &id,
                              priority,
                              wait_occurred_restart_call);
 }
-#endif
 
 void
 TAO_Root_POA::deactivate_all_objects_i (CORBA::Boolean etherealize_objects,
@@ -1247,14 +1233,14 @@ TAO_Root_POA::check_for_valid_wait_for_completions (const TAO_ORB_Core &orb_core
           // belonging to the same ORB as this POA, the BAD_INV_ORDER
           // system exception with standard minor code 3 is raised and
           // POA destruction does not occur.
-          if (poa_current_impl != 0)
+          if ((poa_current_impl != 0) && (poa_current_impl->poa () != 0))
             {
               if (&orb_core == &poa_current_impl->orb_core ())
                 {
                   // CORBA 2.3 specifies which minor code corresponds
                   // to this particular problem.
                   throw ::CORBA::BAD_INV_ORDER (CORBA::OMGVMCID | 3,
-                                                   CORBA::COMPLETED_NO);
+                                                CORBA::COMPLETED_NO);
                 }
             }
           else
@@ -1285,7 +1271,6 @@ TAO_Root_POA::deactivate_object (const PortableServer::ObjectId &oid)
   this->deactivate_object_i (oid);
 }
 
-
 void
 TAO_Root_POA::deactivate_object_i (const PortableServer::ObjectId &id)
 {
@@ -1444,26 +1429,24 @@ TAO_Root_POA::is_poa_generated (CORBA::Object_ptr reference,
                                       is_persistent,
                                       is_system_id,
                                       poa_creation_time);
-  if (result != 0 ||
-      !this->root () &&
-      poa_system_name != this->system_name () ||
-      is_root != this->root () ||
-      is_system_id != this->system_id () ||
-      !this->validate_lifespan (is_persistent, poa_creation_time))
+  if (result != 0
+      || (this->root () == 0 && poa_system_name != this->system_name ())
+      || is_root != this->root ()
+      || is_system_id != this->system_id ()
+      || !this->validate_lifespan (is_persistent, poa_creation_time))
     {
-      // The passed reference is NOT generated by this POA
+      // The passed reference is NOT generated by this POA.
       return false;
     }
   else
     {
-      // The passed reference is generated by this POA
+      // The passed reference is generated by this POA.
       return true;
     }
 }
 
 PortableServer::ObjectId *
-TAO_Root_POA::reference_to_id (CORBA::Object_ptr reference
-                               )
+TAO_Root_POA::reference_to_id (CORBA::Object_ptr reference)
 {
   // Make sure that the reference is valid.
   if (CORBA::is_nil (reference))
@@ -1478,9 +1461,7 @@ TAO_Root_POA::reference_to_id (CORBA::Object_ptr reference
   // reference was not created by this POA, the WrongAdapter exception
   // is raised.
   PortableServer::ObjectId system_id;
-  bool const is_generated = this->is_poa_generated (reference,
-                                                    system_id
-                                                   );
+  bool const is_generated = this->is_poa_generated (reference, system_id);
 
   if (!is_generated)
     {
@@ -1495,8 +1476,7 @@ TAO_Root_POA::reference_to_id (CORBA::Object_ptr reference
 }
 
 PortableServer::Servant
-TAO_Root_POA::find_servant (const PortableServer::ObjectId &system_id
-                            )
+TAO_Root_POA::find_servant (const PortableServer::ObjectId &system_id)
 {
   return this->active_policy_strategies_.servant_retention_strategy()->
     find_servant (system_id);
@@ -1512,16 +1492,14 @@ TAO_Root_POA::unbind_using_user_id (const PortableServer::ObjectId &user_id)
 void
 TAO_Root_POA::cleanup_servant (
   PortableServer::Servant servant,
-  const PortableServer::ObjectId &user_id
-  )
+  const PortableServer::ObjectId &user_id)
 {
   this->active_policy_strategies_.request_processing_strategy()->
     cleanup_servant (servant, user_id);
 }
 
 PortableServer::Servant
-TAO_Root_POA::id_to_servant_i (const PortableServer::ObjectId &id
-                               )
+TAO_Root_POA::id_to_servant_i (const PortableServer::ObjectId &id)
 {
 
   PortableServer::Servant servant =
@@ -1548,8 +1526,7 @@ TAO_Root_POA::id_to_servant_i (const PortableServer::ObjectId &id
 }
 
 PortableServer::Servant
-TAO_Root_POA::user_id_to_servant_i (const PortableServer::ObjectId &id
-                                    )
+TAO_Root_POA::user_id_to_servant_i (const PortableServer::ObjectId &id)
 {
   return this->active_policy_strategies_.servant_retention_strategy()->
     user_id_to_servant (id);
@@ -1557,8 +1534,7 @@ TAO_Root_POA::user_id_to_servant_i (const PortableServer::ObjectId &id
 
 CORBA::Object_ptr
 TAO_Root_POA::id_to_reference_i (const PortableServer::ObjectId &id,
-                                 bool indirect
-                                 )
+                                 bool indirect)
 {
   return this->active_policy_strategies_.servant_retention_strategy()->
     id_to_reference (id, indirect);
@@ -1580,16 +1556,14 @@ TAO_Root_POA::locate_servant_i (const char *operation,
                                 const PortableServer::ObjectId &system_id,
                                 TAO::Portable_Server::Servant_Upcall &servant_upcall,
                                 TAO::Portable_Server::POA_Current_Impl &poa_current_impl,
-                                bool &wait_occurred_restart_call
-                                )
+                                bool &wait_occurred_restart_call)
 {
   return this->active_policy_strategies_.request_processing_strategy()->
     locate_servant (operation,
                     system_id,
                     servant_upcall,
                     poa_current_impl,
-                    wait_occurred_restart_call
-                   );
+                    wait_occurred_restart_call);
 }
 
 /* static */
@@ -1999,8 +1973,8 @@ TAO_Root_POA::key_to_object (const TAO::ObjectKey &key,
 
       if (TAO_debug_level > 0)
         ACE_DEBUG ((LM_DEBUG,
-                    "IMR IOR = \n%s\n",
-                    ACE_TEXT_CHAR_TO_TCHAR (imr_str.in ())));
+                    "IMR IOR =\n%C\n",
+                    imr_str.in ()));
 
       // Search for "corbaloc:" alone, without the protocol.  This code
       // should be protocol neutral.
@@ -2032,8 +2006,8 @@ TAO_Root_POA::key_to_object (const TAO::ObjectKey &key,
 
       if (TAO_debug_level > 0)
         ACE_DEBUG ((LM_DEBUG,
-                    "ImR-ified IOR = \n%s\n",
-                    ACE_TEXT_CHAR_TO_TCHAR (ior.c_str ())));
+                    "ImR-ified IOR =\n%C\n",
+                    ior.c_str ()));
 
       obj = this->orb_core_.orb ()->string_to_object (ior.c_str ());
 
@@ -2100,17 +2074,17 @@ TAO_Root_POA::key_to_stub_i (const TAO::ObjectKey &key,
   TAO_Acceptor_Filter* filter = 0;
 
 #if (TAO_HAS_MINIMUM_POA == 0) && !defined (CORBA_E_COMPACT) && !defined (CORBA_E_MICRO)
-  if (this->filter_factory_ == 0)
-    this->filter_factory_
-      = ACE_Dynamic_Service<TAO_Acceptor_Filter_Factory>::instance ("TAO_Acceptor_Filter_Factory");
-
-  filter =
-    this->filter_factory_->create_object (this->poa_manager_);
-#else
-  ACE_NEW_RETURN (filter,
-                  TAO_Default_Acceptor_Filter (),
-                  0);
+  if (this->filter_factory_)
+    {
+      filter = this->filter_factory_->create_object (this->poa_manager_);
+    }
+  else
 #endif
+    {
+      ACE_NEW_RETURN (filter,
+                      TAO_Default_Acceptor_Filter (),
+                      0);
+    }
 
   // Give ownership to the auto pointer.
   auto_ptr<TAO_Acceptor_Filter> new_filter (filter);
@@ -2246,7 +2220,7 @@ TAO_Root_POA::create_stub_object (const TAO::ObjectKey &object_key,
   for (CORBA::ULong i = 0; i != len; ++i)
     {
       this->add_ior_component (mprofile, this->tagged_component_[i]);
-      }
+    }
 
   len = this->tagged_component_id_.length ();
 
@@ -2376,8 +2350,7 @@ TAO_Root_POA::the_activator (void)
 }
 
 void
-TAO_Root_POA::the_activator (PortableServer::AdapterActivator_ptr adapter_activator
-                             )
+TAO_Root_POA::the_activator (PortableServer::AdapterActivator_ptr adapter_activator)
 {
   // Lock access for the duration of this transaction.
   TAO_POA_GUARD;
@@ -2699,6 +2672,13 @@ TAO_POA_Static_Resources* TAO_POA_Static_Resources::instance_ = 0;
 TAO_POA_Static_Resources* TAO_POA_Static_Resources::initialization_reference_ =
   TAO_POA_Static_Resources::instance ();
 
+void
+TAO_POA_Static_Resources::fini (void)
+{
+  delete TAO_POA_Static_Resources::instance_;
+  TAO_POA_Static_Resources::instance_ = 0;
+}
+
 TAO_POA_Static_Resources*
 TAO_POA_Static_Resources::instance (void)
 {
