@@ -4,7 +4,7 @@
 /**
  *  @file    Root_POA.h
  *
- *  $Id: Root_POA.h 79672 2007-09-20 08:39:19Z johnnyw $
+ *  $Id: Root_POA.h 88564 2010-01-15 09:56:57Z johnnyw $
  *
  *  Header file for CORBA's ORB type.
  *
@@ -113,7 +113,7 @@ namespace PortableServer
  */
 class TAO_PortableServer_Export TAO_Root_POA
   : public virtual PortableServer::POA,
-    public virtual TAO_Local_RefCounted_Object
+    public virtual ::CORBA::LocalObject
 {
 public:
 
@@ -217,10 +217,8 @@ public:
 
   PortableServer::ObjectId *activate_object (PortableServer::Servant p_servant);
 
-#if !defined (CORBA_E_MICRO)
   void activate_object_with_id (const PortableServer::ObjectId &id,
                                 PortableServer::Servant p_servant);
-#endif
 
   void deactivate_object (const PortableServer::ObjectId &oid);
 
@@ -418,8 +416,7 @@ public:
 
   void cleanup_servant (
     PortableServer::Servant servant,
-    const PortableServer::ObjectId &user_id
-   );
+    const PortableServer::ObjectId &user_id);
 
   void post_invoke_servant_cleanup(
     const PortableServer::ObjectId &system_id,
@@ -432,9 +429,7 @@ public:
   PortableServer::ObjectId *activate_object_i (
       PortableServer::Servant p_servant,
       CORBA::Short priority,
-      bool &wait_occurred_restart_call
-
-    );
+      bool &wait_occurred_restart_call);
 
   CORBA::Object_ptr id_to_reference_i (const PortableServer::ObjectId &oid,
                                        bool indirect);
@@ -554,12 +549,10 @@ protected:
   PortableServer::Servant get_servant_i (void);
 
 protected:
-#if !defined (CORBA_E_MICRO)
   void activate_object_with_id_i (const PortableServer::ObjectId &id,
                                   PortableServer::Servant p_servant,
                                   CORBA::Short priority,
                                   bool &wait_occurred_restart_call);
-#endif
 
   virtual void remove_from_parent_i (void);
 
@@ -808,6 +801,9 @@ public:
   /// Return the singleton instance.
   static TAO_POA_Static_Resources* instance (void);
 
+  /// Cleanup the static singleton
+  static void fini (void) ACE_GCC_DESTRUCTOR_ATTRIBUTE;
+
 public:
 
   /**
