@@ -4,7 +4,7 @@
 /**
  *  @file    ServantRetentionStrategyNonRetain.cpp
  *
- *  $Id: ServantRetentionStrategyNonRetain.cpp 79672 2007-09-20 08:39:19Z johnnyw $
+ *  $Id: ServantRetentionStrategyNonRetain.cpp 88564 2010-01-15 09:56:57Z johnnyw $
  *
  */
 //=============================================================================
@@ -18,8 +18,8 @@
 #include "tao/debug.h"
 
 ACE_RCSID (PortableServer,
-           Servant_Retention_Strategy,
-           "$Id: ServantRetentionStrategyNonRetain.cpp 79672 2007-09-20 08:39:19Z johnnyw $")
+           ServantRetentionStrategyNonRetain,
+           "$Id: ServantRetentionStrategyNonRetain.cpp 88564 2010-01-15 09:56:57Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -164,7 +164,6 @@ namespace TAO
       throw PortableServer::POA::WrongPolicy ();
     }
 
-#if !defined (CORBA_E_MICRO)
     void
     ServantRetentionStrategyNonRetain::activate_object_with_id (
       const PortableServer::ObjectId &/*id*/,
@@ -174,7 +173,6 @@ namespace TAO
     {
       throw PortableServer::POA::WrongPolicy ();
     }
-#endif
 
     CORBA::Object_ptr
     ServantRetentionStrategyNonRetain::create_reference (
