@@ -4,7 +4,7 @@
 /**
  *  @file    ServantRetentionStrategyRetain.cpp
  *
- *  $Id: ServantRetentionStrategyRetain.cpp 79672 2007-09-20 08:39:19Z johnnyw $
+ *  $Id: ServantRetentionStrategyRetain.cpp 88564 2010-01-15 09:56:57Z johnnyw $
  *
  */
 //=============================================================================
@@ -18,11 +18,14 @@
 #include "tao/PortableServer/Root_POA.h"
 #include "tao/PortableServer/Active_Object_Map.h"
 #include "tao/PortableServer/Active_Object_Map_Entry.h"
-#include "ace/Auto_Ptr.h"
+
+#if defined (TAO_HAS_MONITOR_POINTS) && (TAO_HAS_MONITOR_POINTS == 1)
+#include "ace/Monitor_Size.h"
+#endif /* TAO_HAS_MONITOR_POINTS */
 
 ACE_RCSID (PortableServer,
-           Servant_Retention_Strategy,
-           "$Id: ServantRetentionStrategyRetain.cpp 79672 2007-09-20 08:39:19Z johnnyw $")
+           ServantRetentionStrategyRetain,
+           "$Id: ServantRetentionStrategyRetain.cpp 88564 2010-01-15 09:56:57Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -32,7 +35,7 @@ namespace TAO
   {
     ServantRetentionStrategyRetain::ServantRetentionStrategyRetain (void) :
       ServantRetentionStrategyNonRetain (),
-      active_object_map_ (0),
+      active_object_map_ (),
       waiting_servant_deactivation_ (0)
     {
     }
@@ -51,31 +54,28 @@ namespace TAO
                                                poa->orb_core().server_factory ()->active_object_map_creation_parameters ()
                                               ), CORBA::NO_MEMORY ());
 
-      // Give ownership of the new map to the auto pointer.  Note, that it
-      // is important for the auto pointer to take ownership before
-      // checking for exception since we may need to delete the new map.
-      auto_ptr<TAO_Active_Object_Map> new_active_object_map (active_object_map);
+      ACE_auto_ptr_reset (this->active_object_map_, active_object_map);
 
-      // Check for exception in construction of the active object map.
-
-      // Finally everything is fine.  Make sure to take ownership away
-      // from the auto pointer.
-      this->active_object_map_ = new_active_object_map.release ();
+#if defined (TAO_HAS_MONITOR_POINTS) && (TAO_HAS_MONITOR_POINTS == 1)
+      ACE_CString name_str ("Active_Object_Map_");
+      name_str += poa->orb_core ().orbid ();
+      name_str += '_';
+      name_str += poa->the_name ();
+      
+      active_object_map->monitor_->name (name_str.c_str ());
+      active_object_map->monitor_->add_to_registry ();
+#endif /* TAO_HAS_MONITOR_POINTS */
     }
 
     void
-    ServantRetentionStrategyRetain::strategy_cleanup(void)
+    ServantRetentionStrategyRetain::strategy_cleanup (void)
     {
-      // Delete the active object map.
-      delete this->active_object_map_;
-      active_object_map_ = 0;
     }
 
     void
     ServantRetentionStrategyRetain::deactivate_object (
       const PortableServer::ObjectId &id)
     {
-
       TAO_Active_Object_Map_Entry *active_object_map_entry = 0;
       int const result = this->active_object_map_->
         find_entry_using_user_id (id, active_object_map_entry);
@@ -104,8 +104,7 @@ namespace TAO
         {
           this->poa_->servant_deactivated_hook (
             active_object_map_entry->servant_,
-            active_object_map_entry->user_id_
-           );
+            active_object_map_entry->user_id_);
         }
 
       if (new_count == 0)
@@ -197,10 +196,7 @@ namespace TAO
       // associated with that object in the Active Object Map.
       PortableServer::Servant servant = 0;
 
-      int const result =
-        this->active_object_map_->find_servant_using_user_id (id, servant);
-
-      if (result == -1)
+      if (this->active_object_map_->find_servant_using_user_id (id, servant) == -1)
         {
           throw PortableServer::POA::ObjectNotActive ();
         }
@@ -253,8 +249,7 @@ namespace TAO
       // Find user id from system id.
       PortableServer::ObjectId_var user_id;
       if (this->active_object_map_->
-          find_user_id_using_system_id (system_id,
-                                        user_id.out()) != 0)
+          find_user_id_using_system_id (system_id, user_id.out()) != 0)
         {
           throw ::CORBA::OBJ_ADAPTER ();
         }
@@ -474,9 +469,9 @@ namespace TAO
         = this->active_object_map_->user_id_map_->end ();
 
       for (TAO_Active_Object_Map::user_id_map::iterator iter
-             = this->active_object_map_->user_id_map_->begin ();
-           iter != end;
-           ++iter)
+              = this->active_object_map_->user_id_map_->begin ();
+            iter != end;
+            ++iter)
         {
           TAO_Active_Object_Map::user_id_map::value_type map_pair = *iter;
           TAO_Active_Object_Map_Entry *active_object_map_entry = map_pair.second ();
@@ -489,8 +484,8 @@ namespace TAO
         }
 
       for (size_t i = 0;
-           i < counter;
-           ++i)
+            i < counter;
+            ++i)
         {
           this->deactivate_map_entry (map_entries[i]);
         }
@@ -758,7 +753,6 @@ namespace TAO
       return user_id._retn ();
     }
 
-#if !defined (CORBA_E_MICRO)
     void
     ServantRetentionStrategyRetain::activate_object_with_id (
       const PortableServer::ObjectId &id,
@@ -861,7 +855,6 @@ namespace TAO
       // invoke _remove_ref on it the same number of times.
       servant->_add_ref ();
     }
-#endif
 
     CORBA::Object_ptr
     ServantRetentionStrategyRetain::create_reference (
