@@ -4,7 +4,7 @@
 /**
  *  @file ServantRetentionStrategyRetain.h
  *
- *  $Id: ServantRetentionStrategyRetain.h 79672 2007-09-20 08:39:19Z johnnyw $
+ *  $Id: ServantRetentionStrategyRetain.h 88564 2010-01-15 09:56:57Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -20,6 +20,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "ace/Auto_Ptr.h"
+
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Root_POA;
@@ -49,14 +51,12 @@ namespace TAO
                        CORBA::Short priority,
                        bool &wait_occurred_restart_call);
 
-#if !defined (CORBA_E_MICRO)
       virtual
       void
       activate_object_with_id (const PortableServer::ObjectId &id,
                                PortableServer::Servant servant,
                                CORBA::Short priority,
                                bool &wait_occurred_restart_call);
-#endif
 
       void deactivate_object (const PortableServer::ObjectId &id);
 
@@ -93,8 +93,7 @@ namespace TAO
         PortableServer::Servant servant);
 
       virtual
-      CORBA::Object_ptr
-      servant_to_reference (PortableServer::Servant servant);
+      CORBA::Object_ptr servant_to_reference (PortableServer::Servant servant);
 
       virtual
       CORBA::Object_ptr create_reference (
@@ -140,7 +139,7 @@ namespace TAO
         const PortableServer::ObjectId &user_id);
 
     private:
-      TAO_Active_Object_Map *active_object_map_;
+      auto_ptr<TAO_Active_Object_Map> active_object_map_;
       CORBA::ULong waiting_servant_deactivation_;
     };
   }
