@@ -1,10 +1,10 @@
-/* -*- C++ -*- */
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Servant_Dispatcher.h
  *
- *  Servant_Dispatcher.h,v 1.13 2005/03/07 13:22:14 jwillemsen Exp
+ *  $Id: Servant_Dispatcher.h 79339 2007-08-14 17:49:17Z sowayaa $
  *
  *  @author Frank Hunleth <fhunleth@cs.wustl.edu>
  */
@@ -14,23 +14,34 @@
 #define TAO_SERVANT_DISPATCHER_H
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/PortableServer/Servant_Upcall.h"
 #include "ace/SStringfwd.h"
-#include "Servant_Upcall.h"
+
+ACE_BEGIN_VERSIONED_NAMESPACE_DECL
+class ACE_Lock;
+ACE_END_VERSIONED_NAMESPACE_DECL
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // Forward references.
 class TAO_POA_Manager;
 class TAO_POA_Policy_Set;
 class TAO_Root_POA;
-class ACE_Lock;
 class TAO_ORB_Core;
 class TAO_ServerRequest;
 
+namespace PortableServer
+{
+  class POAManager;
+  typedef POAManager *POAManager_ptr;
+}
+
 /**
  * @class TAO_Servant_Dispatcher
  *
@@ -45,9 +56,8 @@ public:
   virtual void pre_invoke_remote_request (
       TAO_Root_POA &poa,
       CORBA::Short servant_priority,
-			TAO_ServerRequest &req,
+      TAO_ServerRequest &req,
       TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &pre_invoke_state
-      ACE_ENV_ARG_DECL
     ) = 0;
 
   /// Pre_invoke collocated request.
@@ -55,7 +65,7 @@ public:
       TAO_Root_POA &poa,
       CORBA::Short servant_priority,
       TAO::Portable_Server::Servant_Upcall::Pre_Invoke_State &pre_invoke_state
-      ACE_ENV_ARG_DECL) = 0;
+      ) = 0;
 
   /// Post_invoke request.
   virtual void post_invoke (
@@ -65,14 +75,15 @@ public:
   /// Factory method for creating new POA's.
   virtual TAO_Root_POA *create_Root_POA (
       const ACE_CString &name,
-      TAO_POA_Manager &poa_manager,
+      PortableServer::POAManager_ptr poa_manager,
       const TAO_POA_Policy_Set &policies,
       ACE_Lock &lock,
       TAO_SYNCH_MUTEX &thread_lock,
       TAO_ORB_Core &orb_core,
-      TAO_Object_Adapter *object_adapter
-      ACE_ENV_ARG_DECL) = 0;
+      TAO_Object_Adapter *object_adapter) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_SERVANT_DISPATCHER_H */
