@@ -4,7 +4,7 @@
 /**
  *  @file    Servant_Location.h
  *
- *  Servant_Location.h,v 1.2 2005/01/09 11:59:27 jwillemsen Exp
+ *  $Id: Servant_Location.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  @author Irfan Pyarali
  */
@@ -15,12 +15,14 @@
 
 #include /**/ "ace/pre.h"
 
-#include "portableserver_export.h"
+#include "tao/PortableServer/portableserver_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 enum TAO_SERVANT_LOCATION
 {
   TAO_SERVANT_FOUND,
@@ -29,6 +31,8 @@ enum TAO_SERVANT_LOCATION
   TAO_SERVANT_NOT_FOUND
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_SERVANT_LOCATION_H */
