@@ -4,7 +4,7 @@
 /**
  *  @file ThreadStrategyFactory.h
  *
- *  ThreadStrategyFactory.h,v 1.4 2005/07/26 07:45:11 jwillemsen Exp
+ *  $Id: ThreadStrategyFactory.h 76551 2007-01-24 13:42:44Z johnnyw $
  *
  *  @author  Johnny Willemsen  <jwillemsen@remedy.nl>
  */
@@ -12,15 +12,18 @@
 
 #ifndef TAO_PORTABLESERVER_THREADPOLICYSTRATEGYFACTORY_H
 #define TAO_PORTABLESERVER_THREADPOLICYSTRATEGYFACTORY_H
+
 #include /**/ "ace/pre.h"
 
-#include "StrategyFactory.h"
+#include "tao/PortableServer/StrategyFactory.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "ThreadPolicyC.h"
+#include "tao/PortableServer/ThreadPolicyC.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -39,10 +42,13 @@ namespace TAO
       /// Cleanup the given strategy instance
       virtual void destroy (
         ThreadStrategy *strategy
-        ACE_ENV_ARG_DECL) = 0;
+        ) = 0;
     };
   }
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
+
 #endif /* TAO_PORTABLESERVER_THREADPOLICYSTRATEGYFACTORY_H */
