@@ -1,4 +1,4 @@
-// $Id: Upcall_Wrapper.cpp 79713 2007-09-25 05:06:46Z johnnyw $
+// $Id: Upcall_Wrapper.cpp 87951 2009-12-07 07:13:31Z dai_y $
 
 #include "tao/PortableServer/Upcall_Wrapper.h"
 #include "tao/PortableServer/Upcall_Command.h"
@@ -18,10 +18,11 @@
 #include "tao/Argument.h"
 #include "tao/operation_details.h"
 #include "ace/Log_Msg.h"
+#include "tao/debug.h"
 
 ACE_RCSID (PortableServer,
            Upcall_Wrapper,
-           "$Id: Upcall_Wrapper.cpp 79713 2007-09-25 05:06:46Z johnnyw $")
+           "$Id: Upcall_Wrapper.cpp 87951 2009-12-07 07:13:31Z dai_y $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -99,7 +100,7 @@ TAO::Upcall_Wrapper::upcall (TAO_ServerRequest & server_request,
         // Don't bother performing the upcall if an interceptor caused a
         // location forward.
         CORBA::Object_var forward_to = server_request.forward_location ();
-        if (CORBA::is_nil (forward_to.in ()))
+        if (!server_request.is_forwarded ())
           {
             if (interceptor_adapter != 0)
               {
@@ -133,7 +134,7 @@ TAO::Upcall_Wrapper::upcall (TAO_ServerRequest & server_request,
           // we'd still need to avoid resetting the reply status to
           // SUCCESSFUL, however.
           CORBA::Object_var forward_to_after = server_request.forward_location ();
-          if (CORBA::is_nil (forward_to_after.in ()))
+          if (!server_request.is_forwarded ())
             {
               // No location forward by interceptors and successful upcall.
               server_request.pi_reply_status (PortableInterceptor::SUCCESSFUL);
@@ -200,13 +201,12 @@ TAO::Upcall_Wrapper::upcall (TAO_ServerRequest & server_request,
 #if TAO_HAS_INTERCEPTORS == 1
   // Don't bother marshaling inout/out/return values if an interceptor
   // caused a location forward.
- CORBA::Object_var forward_to_end = server_request.forward_location ();
-  if (CORBA::is_nil (forward_to_end.in ()))
+  if (!server_request.is_forwarded ())
 #endif  /* TAO_HAS_INTERCEPTORS == 1 */
     {
       if (server_request.outgoing ())
         {
-          this->post_upcall (*server_request.outgoing (), args, nargs);
+          this->post_upcall (server_request, args, nargs);
         }
     }
 
@@ -229,39 +229,57 @@ TAO::Upcall_Wrapper::pre_upcall (TAO_InputCDR & cdr,
   //        always the first element in the array, regardless of
   //        whether or not the return type is void.
 
-  TAO::Argument * const * const begin = args + 1;  // Skip the return value.
-  TAO::Argument * const * const end   = args + nargs;
+  try {
+    TAO::Argument * const * const begin = args + 1;  // Skip the return value.
+    TAO::Argument * const * const end   = args + nargs;
 
-  for (TAO::Argument * const * i = begin; i != end; ++i)
-    {
-      if (!(*i)->demarshal (cdr))
-        {
-          TAO_InputCDR::throw_skel_exception (errno);
-        }
-    }
+    for (TAO::Argument * const * i = begin; i != end; ++i)
+      {
+        if (!(*i)->demarshal (cdr))
+          {
+            TAO_InputCDR::throw_skel_exception (errno);
+          }
+      }
+
+    cdr.reset_vt_indirect_maps ();
+  }
+  catch (...) {
+    cdr.reset_vt_indirect_maps ();
+    throw;
+  }
 }
 
 void
-TAO::Upcall_Wrapper::post_upcall (TAO_OutputCDR & cdr,
+TAO::Upcall_Wrapper::post_upcall (TAO_ServerRequest& server_request,
                                   TAO::Argument * const * args,
                                   size_t nargs)
 {
-  // Marshal the operation "inout" and "out" arguments and return
-  // value, if any.
-
+  TAO_OutputCDR & cdr = (*server_request.outgoing ());
   TAO::Argument * const * const begin = args;
   TAO::Argument * const * const end   = args + nargs;
 
-  for (TAO::Argument * const * i = begin; i != end; ++i)
-    {
-      if (!(*i)->marshal (cdr))
-        {
-          TAO_OutputCDR::throw_skel_exception (errno);
-        }
-    }
+  try {
+    for (TAO::Argument * const * i = begin; i != end; ++i)
+      {
+        if (!(*i)->marshal (cdr))
+          {
+            TAO_OutputCDR::throw_skel_exception (errno);
+          }
+      }
 
-  // Reply body marshaling completed.  No other fragments to send.
-  cdr.more_fragments (false);
+    // Reply body marshaling completed.  No other fragments to send.
+    cdr.more_fragments (false);
+
+  #ifdef TAO_HAS_VALUETYPE_OUT_INDIRECTION
+    cdr.reset_vt_indirect_maps ();
+  #endif
+  }
+  catch (...) {
+#ifdef TAO_HAS_VALUETYPE_OUT_INDIRECTION
+    cdr.reset_vt_indirect_maps ();
+#endif
+    throw;
+  }
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
