@@ -1,19 +1,22 @@
-// Principal.cpp,v 1.17 2005/07/19 10:10:46 jwillemsen Exp
+// $Id: Principal.cpp 79339 2007-08-14 17:49:17Z sowayaa $
 
 // Copyright 1994-1995 by Sun Microsystems Inc.
 // All Rights Reserved
-// ORB:		Principal identifier pseudo-objref
+// ORB: Principal identifier pseudo-objref
 
-#include "Principal.h"
-#include "CDR.h"
+#include "tao/Principal.h"
+#include "tao/CDR.h"
 
 #if !defined (__ACE_INLINE__)
-#include "tao/Principal.i"
+#include "tao/Principal.inl"
 #endif /* __ACE_INLINE__ */
 
 ACE_RCSID (tao,
            Principal,
-           "Principal.cpp,v 1.17 2005/07/19 10:10:46 jwillemsen Exp")
+           "$Id: Principal.cpp 79339 2007-08-14 17:49:17Z sowayaa $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 CORBA::Principal::Principal (void)
   : refcount_ (1)
@@ -61,3 +64,4 @@ operator>> (TAO_InputCDR & cdr, CORBA::Principal *& x)
   return (CORBA::Boolean) cdr.good_bit ();
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
