@@ -1,4 +1,4 @@
-// $Id: Profile.cpp 79339 2007-08-14 17:49:17Z sowayaa $
+// $Id: Profile.cpp 84909 2009-03-19 15:16:15Z johnnyw $
 
 #include "tao/Profile.h"
 #include "tao/Messaging_PolicyValueC.h"
@@ -23,7 +23,7 @@
 
 ACE_RCSID (tao,
            Profile,
-           "$Id: Profile.cpp 79339 2007-08-14 17:49:17Z sowayaa $")
+           "$Id: Profile.cpp 84909 2009-03-19 15:16:15Z johnnyw $")
 
 // ****************************************************************
 
@@ -80,25 +80,6 @@ TAO_Profile::~TAO_Profile (void)
   //@@ TAO_PROFILE_SPL_DESTRUCTOR_ADD_HOOK
 }
 
-unsigned long
-TAO_Profile::_incr_refcnt (void)
-{
-  return this->refcount_.increment ();
-}
-
-unsigned long
-TAO_Profile::_decr_refcnt (void)
-{
-  unsigned long count = this->refcount_.decrement ();
-  if (count != 0)
-    return count;
-
-  // refcount is 0, so delete us!
-  // delete will call our ~ destructor which in turn deletes stuff.
-  delete this;
-  return 0;
-}
-
 void
 TAO_Profile::add_tagged_component (const IOP::TaggedComponent &component)
 {
@@ -221,8 +202,7 @@ TAO_Profile::decode (TAO_InputCDR& cdr)
   TAO::ObjectKey ok;
 
   // ... and object key.
-  if (TAO::ObjectKey::demarshal_key (ok,
-                                     cdr) == 0)
+  if (TAO::ObjectKey::demarshal_key (ok, cdr) == 0)
     {
       return -1;
     }
@@ -236,8 +216,7 @@ TAO_Profile::decode (TAO_InputCDR& cdr)
 
   // Tagged Components *only* exist after version 1.0!
   // For GIOP 1.2, IIOP and GIOP have same version numbers!
-  if (this->version_.major > 1
-      || this->version_.minor > 0)
+  if (this->version_.major > 1 || this->version_.minor > 0)
     {
       if (this->tagged_components_.decode (cdr) == 0)
         {
@@ -334,8 +313,7 @@ TAO_Profile::set_tagged_components (TAO_OutputCDR &out_cdr)
   IOP::TaggedComponent tagged_component;
   tagged_component.tag = TAO_TAG_ENDPOINTS;
   tagged_component.component_data.length (length);
-  CORBA::Octet *buf =
-    tagged_component.component_data.get_buffer ();
+  CORBA::Octet *buf = tagged_component.component_data.get_buffer ();
 
   for (const ACE_Message_Block *iterator = out_cdr.begin ();
        iterator != 0;
@@ -356,8 +334,6 @@ TAO_Profile::set_tagged_components (TAO_OutputCDR &out_cdr)
 void
 TAO_Profile::policies (CORBA::PolicyList *policy_list)
 {
-#if (TAO_HAS_CORBA_MESSAGING == 1)
-
   if (policy_list == 0)
     {
       if (TAO_debug_level)
@@ -370,26 +346,27 @@ TAO_Profile::policies (CORBA::PolicyList *policy_list)
       return;
     }
 
-  Messaging::PolicyValue pv;
   Messaging::PolicyValueSeq policy_value_seq;
 
-  size_t length;
+  size_t length = 0;
   CORBA::Octet *buf = 0;
 
-  policy_value_seq.length (policy_list->length ());
-
   // This loop iterates through CORBA::PolicyList to convert
   // each CORBA::Policy into a CORBA::PolicyValue
-  const size_t plen = policy_list->length ();
+  CORBA::ULong const plen = policy_list->length ();
+
+  policy_value_seq.length (plen);
 
   for (CORBA::ULong i = 0; i < plen; ++i)
     {
       TAO_OutputCDR out_CDR;
-      policy_value_seq[i].ptype =
-        (*policy_list)[i]->policy_type ();
+      policy_value_seq[i].ptype = (*policy_list)[i]->policy_type ();
 
-      out_CDR << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER);
-      (*policy_list)[i]->_tao_encode (out_CDR);
+      if (!(out_CDR << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER)))
+        return;
+
+      if (!((*policy_list)[i]->_tao_encode (out_CDR)))
+        return;
 
       length = out_CDR.total_length ();
       policy_value_seq[i].pvalue.length (static_cast <CORBA::ULong>(length));
@@ -414,8 +391,11 @@ TAO_Profile::policies (CORBA::PolicyList *policy_list)
   IOP::TaggedComponent tagged_component;
   tagged_component.tag = Messaging::TAG_POLICIES;
 
-  out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER);
-  out_cdr << policy_value_seq;
+  if (!(out_cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER)))
+    return;
+
+  if (!(out_cdr << policy_value_seq))
+    return;
 
   length = out_cdr.total_length ();
 
@@ -436,22 +416,13 @@ TAO_Profile::policies (CORBA::PolicyList *policy_list)
   // member variable.
   tagged_components_.set_component (tagged_component);
   this->are_policies_parsed_ = true;
-
-#else /* TAO_HAS_CORBA_MESSAGING == 1 */
-
-  ACE_UNUSED_ARG (policy_list);
-
-#endif /* TAO_HAS_CORBA_MESSAGING == 1 */
 }
 
-
-
 void
 TAO_Profile::get_policies (CORBA::PolicyList& pl)
 {
-#if (TAO_HAS_CORBA_MESSAGING == 1) && !defined (CORBA_E_MICRO)
-
-  if (!this->are_policies_parsed_)
+#if !defined(CORBA_E_MICRO)
+     if (!this->are_policies_parsed_)
     // None has already parsed the policies.
     {
       IOP::TaggedComponent tagged_component;
@@ -470,9 +441,9 @@ TAO_Profile::get_policies (CORBA::PolicyList& pl)
           // Extract the Byte Order
           CORBA::Boolean byte_order;
 
-          if ((in_cdr >> ACE_InputCDR::to_boolean (byte_order)) == 0)
+          if (!(in_cdr >> ACE_InputCDR::to_boolean (byte_order)))
             {
-              return ;
+              return;
             }
 
           in_cdr.reset_byte_order (static_cast <int> (byte_order));
@@ -488,18 +459,13 @@ TAO_Profile::get_policies (CORBA::PolicyList& pl)
 
           // Here we extract the Messaging::PolicyValue out of the sequence
           // and we convert those into the proper CORBA::Policy
-
-          CORBA::Policy_var policy;
           CORBA::ULong const length = policy_value_seq.length ();
 
-          // Set the policy list length.
-          pl.length (length);
-
           for (CORBA::ULong i = 0; i < length; ++i)
             {
               try
                 {
-                  policy =
+                  CORBA::Policy_var policy =
                     this->orb_core_->orb ()->_create_policy (
                       policy_value_seq[i].ptype);
 
@@ -516,7 +482,13 @@ TAO_Profile::get_policies (CORBA::PolicyList& pl)
 
                       in_cdr.reset_byte_order (static_cast <int> (byte_order));
 
-                      policy->_tao_decode (in_cdr);
+                      if (!policy->_tao_decode (in_cdr))
+                        throw ::CORBA::INV_OBJREF ();
+
+                      // Increase the policy length with 1 when we know we support
+                      // this policy, this way we don't get nil values in the list
+                      pl.length (pl.length () + 1);
+
                       pl[i] = policy._retn ();
                     }
                   else
@@ -526,7 +498,6 @@ TAO_Profile::get_policies (CORBA::PolicyList& pl)
                       // so as specified by the RT-CORBA
                       // spec. ptc/99-05-03 we just ignore these
                       // un-understood policies.
-
                       if (TAO_debug_level >= 5)
                         ACE_DEBUG ((LM_DEBUG,
                                     ACE_TEXT ("The IOR contains unsupported ")
@@ -548,20 +519,17 @@ TAO_Profile::get_policies (CORBA::PolicyList& pl)
             }
         }
     }
-
 #else
-  ACE_UNUSED_ARG (pl);
-#endif /* (TAO_HAS_CORBA_MESSAGING == 1) */
-
+ ACE_UNUSED_ARG (pl);
+#endif
 }
 
-
 void
 TAO_Profile::verify_orb_configuration (void)
 {
   // If the ORB isn't configured to support tagged components, then
   // throw an exception.
-  if (this->orb_core_->orb_params ()->std_profile_components () == 0
+  if (!this->orb_core_->orb_params ()->std_profile_components ()
       || !this->orb_core_->orb ()->_use_omg_ior_format ())
     {
       if (TAO_debug_level > 0)
@@ -851,7 +819,7 @@ TAO_Unknown_Profile::to_string (void)
 int
 TAO_Unknown_Profile::decode (TAO_InputCDR& cdr)
 {
-  if ((cdr >> this->body_) == 0)
+  if (!(cdr >> this->body_))
     {
       return -1;
     }
@@ -909,8 +877,7 @@ TAO_Unknown_Profile::is_equivalent_hook (const TAO_Profile * /* other */)
 }
 
 CORBA::ULong
-TAO_Unknown_Profile::hash (CORBA::ULong max
-                           )
+TAO_Unknown_Profile::hash (CORBA::ULong max)
 {
   return (ACE::hash_pjw (reinterpret_cast <const char*>
                                           (this->body_.get_buffer ()),
