@@ -1,7 +1,7 @@
-// Pseudo_VarOut_T.cpp,v 1.5 2003/09/04 03:27:24 ossama Exp
+// $Id: Pseudo_VarOut_T.cpp 72136 2006-04-19 09:10:19Z jwillemsen $
 
-#ifndef TAO_PSEUDO_VAROUT_T_C
-#define TAO_PSEUDO_VAROUT_T_C
+#ifndef TAO_PSEUDO_VAROUT_T_CPP
+#define TAO_PSEUDO_VAROUT_T_CPP
 
 #include "tao/Pseudo_VarOut_T.h"
 
@@ -9,9 +9,7 @@
 #include "tao/Pseudo_VarOut_T.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (tao,
-           Pseudo_VarOut_T,
-           "Pseudo_VarOut_T.cpp,v 1.5 2003/09/04 03:27:24 ossama Exp")
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 template <typename T>
 TAO_Pseudo_Var_T<T> &
@@ -19,10 +17,13 @@ TAO_Pseudo_Var_T<T>::operator= (const TAO_Pseudo_Var_T<T> & p)
 {
   if (this != &p)
     {
-      CORBA::release (this->ptr_);
+      ::CORBA::release (this->ptr_);
       this->ptr_ = T::_duplicate (p.ptr ());
     }
 
   return *this;
 }
-#endif /* TAO_PSEUDO_VAROUT_T_C */
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#endif /* TAO_PSEUDO_VAROUT_T_CPP */
