@@ -1,16 +1,23 @@
-// -*- C++ -*-
-// Queued_Message.cpp,v 1.11 2005/06/11 11:51:36 jwillemsen Exp
+// $Id: Queued_Message.cpp 80306 2007-12-18 12:10:07Z johnnyw $
 
-#include "Queued_Message.h"
+#include "tao/Queued_Message.h"
+
+#if !defined (__ACE_INLINE__)
+# include "tao/Queued_Message.inl"
+#endif /* __ACE_INLINE__ */
 
 ACE_RCSID (tao,
            Queued_Message,
-           "Queued_Message.cpp,v 1.11 2005/06/11 11:51:36 jwillemsen Exp")
+           "$Id: Queued_Message.cpp 80306 2007-12-18 12:10:07Z johnnyw $")
 
-TAO_Queued_Message::TAO_Queued_Message (ACE_Allocator *alloc,
-                                        int is_heap_allocated)
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+TAO_Queued_Message::TAO_Queued_Message (TAO_ORB_Core *oc,
+                                        ACE_Allocator *alloc,
+                                        bool is_heap_allocated)
   : allocator_ (alloc)
   , is_heap_created_ (is_heap_allocated)
+  , orb_core_ (oc)
   , next_ (0)
   , prev_ (0)
 {
@@ -20,18 +27,6 @@ TAO_Queued_Message::~TAO_Queued_Message (void)
 {
 }
 
-TAO_Queued_Message *
-TAO_Queued_Message::next (void) const
-{
-  return this->next_;
-}
-
-TAO_Queued_Message *
-TAO_Queued_Message::prev (void) const
-{
-  return this->prev_;
-}
-
 void
 TAO_Queued_Message::remove_from_list (TAO_Queued_Message *&head,
                                       TAO_Queued_Message *&tail)
@@ -68,13 +63,14 @@ TAO_Queued_Message::push_back (TAO_Queued_Message *&head,
       head = this;
       this->next_ = 0;
       this->prev_ = 0;
-      return;
     }
-
-  tail->next_ = this;
-  this->prev_ = tail;
-  this->next_ = 0;
-  tail = this;
+  else
+    {
+      tail->next_ = this;
+      this->prev_ = tail;
+      this->next_ = 0;
+      tail = this;
+    }
 }
 
 void
@@ -87,11 +83,20 @@ TAO_Queued_Message::push_front (TAO_Queued_Message *&head,
       head = this;
       this->next_ = 0;
       this->prev_ = 0;
-      return;
     }
-
-  head->prev_ = this;
-  this->next_ = head;
-  this->prev_ = 0;
-  head = this;
+  else
+    {
+      head->prev_ = this;
+      this->next_ = head;
+      this->prev_ = 0;
+      head = this;
+    }
 }
+
+bool
+TAO_Queued_Message::is_expired (const ACE_Time_Value &) const
+{
+  return false;
+}
+
+TAO_END_VERSIONED_NAMESPACE_DECL
