@@ -1,20 +1,19 @@
-// Linear_Network_Priority_Mapping.h,v 1.8 2005/01/05 10:10:09 jwillemsen Exp
+// -*- C++ -*-
+
+
+//=============================================================================
+/**
+ *  @file   Linear_Network_Priority_Mapping.h
+ *
+ *  $Id: Linear_Network_Priority_Mapping.h 78627 2007-06-28 08:50:01Z johnnyw $
+ *
+ * Declares the Linear_Network_Priority_Mapping interface,
+ *
+ *
+ *  @author Yamuna Krishnamurthy (yamuna@oomworks.com)
+ */
+//=============================================================================
 
-// ============================================================================
-//
-// = LIBRARY
-//   TAO
-//
-// = FILENAME
-//   Linear_Network_Priority_Mapping.h
-//
-// = DESCRIPTION
-//   Declares the Linear_Network_Priority_Mapping interface,
-//
-// = AUTHOR
-//   Yamuna Krishnamurthy (yamuna@oomworks.com)
-//
-// ============================================================================
 
 #ifndef TAO_LINEAR_NETWORK_PRIORITY_MAPPING_H
 #define TAO_LINEAR_NETWORK_PRIORITY_MAPPING_H
@@ -22,15 +21,17 @@
 
 #include "tao/orbconf.h"
 
-#include "rtcorba_export.h"
-#include "Network_Priority_Mapping.h"
-
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
+#include "tao/RTCORBA/rtcorba_export.h"
+#include "tao/RTCORBA/Network_Priority_Mapping.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Linear_Network_Priority_Mapping
  *
@@ -42,8 +43,8 @@
 class TAO_RTCORBA_Export TAO_Linear_Network_Priority_Mapping : public TAO_Network_Priority_Mapping
 {
 public:
-  /// Default constructor
-  TAO_Linear_Network_Priority_Mapping (long policy);
+
+  TAO_Linear_Network_Priority_Mapping (long);
 
   CORBA::Boolean to_network (RTCORBA::Priority corba_priority,
                              RTCORBA::NetworkPriority &network_priority);
@@ -52,6 +53,8 @@ public:
                            RTCORBA::Priority &corba_priority);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #include /**/ "ace/post.h"
