@@ -1,21 +1,20 @@
-// Linear_Priority_Mapping.h,v 1.6 2005/01/05 10:10:09 jwillemsen Exp
+// -*- C++ -*-
+
+
+//=============================================================================
+/**
+ *  @file   Linear_Priority_Mapping.h
+ *
+ *  $Id: Linear_Priority_Mapping.h 79339 2007-08-14 17:49:17Z sowayaa $
+ *
+ * Declares the Linear_Priority_Mapping interface, as defined in the
+ * RT-CORBA spec.
+ *
+ *
+ *  @author Carlos O'Ryan (coryan@cs.wustl.edu)
+ */
+//=============================================================================
 
-// ============================================================================
-//
-// = LIBRARY
-//   TAO
-//
-// = FILENAME
-//   Linear_Priority_Mapping.h
-//
-// = DESCRIPTION
-//   Declares the Linear_Priority_Mapping interface, as defined in the
-//   RT-CORBA spec.
-//
-// = AUTHOR
-//   Carlos O'Ryan (coryan@cs.wustl.edu)
-//
-// ============================================================================
 
 #ifndef TAO_LINEAR_PRIORITY_MAPPING_H
 #define TAO_LINEAR_PRIORITY_MAPPING_H
@@ -23,15 +22,17 @@
 
 #include "tao/orbconf.h"
 
-#include "rtcorba_export.h"
-#include "Priority_Mapping.h"
-
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
+#include "tao/RTCORBA/rtcorba_export.h"
+#include "tao/RTCORBA/Priority_Mapping.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Linear_Priority_Mapping
  *
@@ -51,22 +52,22 @@ public:
   /// The destructor
   virtual ~TAO_Linear_Priority_Mapping (void);
 
-  virtual CORBA::Boolean
-      to_native (RTCORBA::Priority corba_priority,
-                 RTCORBA::NativePriority &native_priority);
-  virtual CORBA::Boolean
-      to_CORBA (RTCORBA::NativePriority native_priority,
-                RTCORBA::Priority &corba_priority);
+  virtual CORBA::Boolean to_native (RTCORBA::Priority corba_priority,
+                                    RTCORBA::NativePriority &native_priority);
+  virtual CORBA::Boolean to_CORBA (RTCORBA::NativePriority native_priority,
+                                   RTCORBA::Priority &corba_priority);
 
 private:
   /// The scheduling policy
   long policy_;
 
   // The range
-  int min_;
-  int max_;
+  int const min_;
+  int const max_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #include /**/ "ace/post.h"
