@@ -1,35 +1,35 @@
-// Multi_Priority_Mapping.h,v 1.5 2005/01/05 10:10:09 jwillemsen Exp
-// Multi_Priority_Mapping.h,v 1.0
+// -*- C++ -*-
+
+
+//=============================================================================
+/**
+ *  @file   Multi_Priority_Mapping.h
+ *
+ *  $Id: Multi_Priority_Mapping.h 78627 2007-06-28 08:50:01Z johnnyw $
+ *
+ * Declares a priority mapping to support cross platform communication.
+ *
+ *
+ *  @author Brian Mendel (brian.r.mendel@boeing.com)
+ */
+//=============================================================================
 
-// ============================================================================
-//
-// = LIBRARY
-//   TAO
-//
-// = FILENAME
-//   Multi_Priority_Mapping.h
-//
-// = DESCRIPTION
-//   Declares a priority mapping to support cross platform communication.
-//
-// = AUTHOR
-//   Brian Mendel (brian.r.mendel@boeing.com)
-//
-// ============================================================================
 
 #ifndef TAO_MULTI_PRIORITY_MAPPING_H
 #define TAO_MULTI_PRIORITY_MAPPING_H
 
 #include "tao/orbconf.h"
 
-#include "tao/RTCORBA/Priority_Mapping.h"
-
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
+#include "tao/RTCORBA/Priority_Mapping.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Multi_Priority_Mapping
  *
@@ -41,7 +41,8 @@
  * ACE_SCHED_FIFO, ACE_SCHED_RR) and the valid range of CORBA
  * priorities (0...32767)
  */
-class TAO_RTCORBA_Export TAO_Multi_Priority_Mapping : public TAO_Priority_Mapping
+class TAO_RTCORBA_Export TAO_Multi_Priority_Mapping
+: public TAO_Priority_Mapping
 {
 public:
   /// Default constructor
@@ -72,9 +73,9 @@ public:
 
 private:
 
+  /// The base settings
   int base_native_priority_;
   int base_corba_priority_;
-  // The base settings
 
   const int priority_spacing_;
   const int priorities_contiguous_;
@@ -82,11 +83,13 @@ private:
   /// The scheduling policy
   int policy_;
 
-  int min_;
-  int max_;
-  // The range
+  /// The range
+  int const min_;
+  int const max_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #endif /* TAO_MULTI_PRIORITY_MAPPING_H */
