@@ -1,17 +1,21 @@
-// Network_Priority_Mapping.cpp,v 1.4 2005/01/05 10:10:09 jwillemsen Exp
+// $Id: Network_Priority_Mapping.cpp 71473 2006-03-10 07:19:20Z jtc $
 
 #include "tao/orbconf.h"
 
-#include "Network_Priority_Mapping.h"
+#include "tao/RTCORBA/Network_Priority_Mapping.h"
 
 ACE_RCSID(RTCORBA,
           Network_Priority_Mapping,
-          "Network_Priority_Mapping.cpp,v 1.4 2005/01/05 10:10:09 jwillemsen Exp")
+          "$Id: Network_Priority_Mapping.cpp 71473 2006-03-10 07:19:20Z jtc $")
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_Network_Priority_Mapping::~TAO_Network_Priority_Mapping (void)
 {
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
