@@ -1,32 +1,28 @@
-// Priority_Mapping_Manager.cpp,v 1.6 2003/10/28 18:29:32 bala Exp
+// $Id: Priority_Mapping_Manager.cpp 76593 2007-01-25 19:19:27Z johnnyw $
 
-#include "Priority_Mapping_Manager.h"
+#include "tao/RTCORBA/Priority_Mapping_Manager.h"
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
 #if ! defined (__ACE_INLINE__)
-#include "Priority_Mapping_Manager.i"
+#include "tao/RTCORBA/Priority_Mapping_Manager.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID (RTCORBA, 
-           Priority_Mapping_Manager, 
-           "Priority_Mapping_Manager.cpp,v 1.6 2003/10/28 18:29:32 bala Exp")
+ACE_RCSID (RTCORBA,
+           Priority_Mapping_Manager,
+           "$Id: Priority_Mapping_Manager.cpp 76593 2007-01-25 19:19:27Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Priority_Mapping_Manager::~TAO_Priority_Mapping_Manager (void)
 {
-  delete mapping_;
+  delete this->mapping_;
 }
 
 TAO_Priority_Mapping_Manager_ptr
-TAO_Priority_Mapping_Manager::_narrow (CORBA::Object_ptr obj
-                                       ACE_ENV_ARG_DECL_NOT_USED)
+TAO_Priority_Mapping_Manager::_narrow (CORBA::Object_ptr obj)
 {
-  if (CORBA::is_nil (obj))
-    {
-      return TAO_Priority_Mapping_Manager::_nil ();
-    }
-
-  return 
+  return
     TAO_Priority_Mapping_Manager::_duplicate (
         dynamic_cast<TAO_Priority_Mapping_Manager_ptr> (obj)
       );
@@ -46,5 +42,7 @@ TAO_Priority_Mapping_Manager::_interface_repository_id (void) const
   return "IDL:Priority_Mapping_Manager:1.0";
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
