@@ -4,7 +4,7 @@
 /**
  *  @file   RT_Endpoint_Selector_Factory.h
  *
- *  $Id: RT_Endpoint_Selector_Factory.h 79221 2007-08-06 11:01:22Z johnnyw $
+ *  $Id: RT_Endpoint_Selector_Factory.h 84860 2009-03-17 10:17:38Z johnnyw $
  *
  * Strategies for selecting profile/endpoint from an IOR for making an
  * invocation.
@@ -61,15 +61,20 @@ public:
 
   virtual TAO_Invocation_Endpoint_Selector *get_selector (void);
 
+private:
+  void operator= (const RT_Endpoint_Selector_Factory &);
+  RT_Endpoint_Selector_Factory (const RT_Endpoint_Selector_Factory &);
+
 private:
   TAO_RT_Invocation_Endpoint_Selector *rt_invocation_endpoint_selector_;
 };
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 ACE_STATIC_SVC_DECLARE_EXPORT (TAO_RTCORBA, RT_Endpoint_Selector_Factory)
 ACE_FACTORY_DECLARE (TAO_RTCORBA, RT_Endpoint_Selector_Factory)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #include /**/ "ace/post.h"
