@@ -4,7 +4,7 @@
 /**
  *  @file   RT_Endpoint_Utils.h
  *
- *  $Id: RT_Endpoint_Utils.h 76551 2007-01-24 13:42:44Z johnnyw $
+ *  $Id: RT_Endpoint_Utils.h 82354 2008-07-22 11:34:18Z johnnyw $
  *
  *  Commonly used utility methods used by RT_Endpoint_Selectors.
  *
@@ -44,9 +44,8 @@ class TAO_RTCORBA_Export TAO_RT_Endpoint_Utils
 {
 public:
   static
-  CORBA::Policy *policy (TAO_Cached_Policy_Type type,
-                         TAO::Profile_Transport_Resolver &r
-                        );
+  CORBA::Policy_ptr policy (TAO_Cached_Policy_Type type,
+                            TAO::Profile_Transport_Resolver &r);
 
 private:
   /// ctor.
