@@ -1,32 +1,42 @@
-// RT_ORB.cpp,v 1.16 2005/07/12 11:51:23 jwillemsen Exp
+// $Id: RT_ORB.cpp 80216 2007-12-10 08:15:33Z johnnyw $
 
-#include "RT_ORB.h"
+#include "tao/RTCORBA/RT_ORB.h"
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
-#include "RT_Policy_i.h"
-#include "RT_Mutex.h"
-#include "Priority_Mapping_Manager.h"
+#include "tao/RTCORBA/RT_Policy_i.h"
+#include "tao/RTCORBA/RT_Mutex.h"
+#include "tao/RTCORBA/Priority_Mapping_Manager.h"
 #include "tao/ORB_Core.h"
 #include "tao/ORB.h"
+#include "tao/SystemException.h"
 #include "tao/RTCORBA/Thread_Pool.h"
 #include "tao/RTCORBA/RT_Thread_Lane_Resources_Manager.h"
 #include "ace/Sched_Params.h"
 
 ACE_RCSID(RTCORBA,
           RT_ORB,
-          "RT_ORB.cpp,v 1.16 2005/07/12 11:51:23 jwillemsen Exp")
+          "$Id: RT_ORB.cpp 80216 2007-12-10 08:15:33Z johnnyw $")
 
-TAO_RT_ORB::TAO_RT_ORB (TAO_ORB_Core *orb_core)
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+TAO_RT_ORB::TAO_RT_ORB (TAO_ORB_Core *orb_core,
+                        TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                        ACE_Time_Value const &dynamic_thread_time)
   : orb_core_ (orb_core),
     mutex_mgr_ (),
-    tp_manager_ (0)
+    tp_manager_ (0),
+    lifespan_ (lifespan),
+    dynamic_thread_time_ (dynamic_thread_time)
 {
   TAO_Thread_Lane_Resources_Manager *thread_lane_resources_manager =
     &this->orb_core_->thread_lane_resources_manager ();
 
   TAO_RT_Thread_Lane_Resources_Manager *rt_thread_lane_resources_manager =
-    (TAO_RT_Thread_Lane_Resources_Manager *) thread_lane_resources_manager;
+    dynamic_cast <TAO_RT_Thread_Lane_Resources_Manager *> (thread_lane_resources_manager);
+
+  if (!rt_thread_lane_resources_manager)
+    throw CORBA::INTERNAL ();
 
   this->tp_manager_ =
     &rt_thread_lane_resources_manager->tp_manager ();
@@ -37,41 +47,29 @@ TAO_RT_ORB::~TAO_RT_ORB (void)
 }
 
 RTCORBA::Mutex_ptr
-TAO_RT_ORB::create_mutex (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RT_ORB::create_mutex (void)
 {
-  return this->mutex_mgr_.create_mutex (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return this->mutex_mgr_.create_mutex ();
 }
 
 void
-TAO_RT_ORB::destroy_mutex (RTCORBA::Mutex_ptr mutex
-                           ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RT_ORB::destroy_mutex (RTCORBA::Mutex_ptr mutex)
 {
-  this->mutex_mgr_.destroy_mutex (mutex
-                                  ACE_ENV_ARG_PARAMETER);
+  this->mutex_mgr_.destroy_mutex (mutex);
 }
 
 
 RTCORBA::Mutex_ptr
 TAO_RT_ORB::create_named_mutex (const char *name,
-                                CORBA::Boolean_out created_flag
-                                ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                CORBA::Boolean_out created_flag)
 {
-  return this->mutex_mgr_.create_named_mutex (name,
-                                              created_flag
-                                              ACE_ENV_ARG_PARAMETER);
+  return this->mutex_mgr_.create_named_mutex (name, created_flag);
 }
 
 RTCORBA::Mutex_ptr
-TAO_RT_ORB::open_named_mutex (const char *name
-                              ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTCORBA::RTORB::MutexNotFound))
+TAO_RT_ORB::open_named_mutex (const char *name)
 {
-  return this->mutex_mgr_.open_named_mutex (name
-                                            ACE_ENV_ARG_PARAMETER);
+  return this->mutex_mgr_.open_named_mutex (name);
 }
 
 ////////////////////////////////////////////////////////////////////////////////
@@ -85,8 +83,7 @@ TAO_Named_RT_Mutex_Manager::~TAO_Named_RT_Mutex_Manager (void)
 }
 
 RTCORBA::Mutex_ptr
-TAO_Named_RT_Mutex_Manager::create_mutex (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_Named_RT_Mutex_Manager::create_mutex (void)
 {
   TAO_RT_Mutex *mutex = 0;
   ACE_NEW_THROW_EX (mutex,
@@ -96,7 +93,6 @@ TAO_Named_RT_Mutex_Manager::create_mutex (ACE_ENV_SINGLE_ARG_DECL)
                         TAO::VMCID,
                         ENOMEM),
                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::Mutex::_nil ());
 
   return mutex;
 }
@@ -105,9 +101,7 @@ TAO_Named_RT_Mutex_Manager::create_mutex (ACE_ENV_SINGLE_ARG_DECL)
 // as also indicated by the comment below.
 #if (TAO_HAS_NAMED_RT_MUTEXES == 1)
 void
-TAO_Named_RT_Mutex_Manager::destroy_mutex (RTCORBA::Mutex_ptr mutex
-                                           ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_Named_RT_Mutex_Manager::destroy_mutex (RTCORBA::Mutex_ptr mutex)
 {
   TAO_RT_Mutex *tao_mutex =
     dynamic_cast<TAO_RT_Mutex *> (mutex);
@@ -122,29 +116,24 @@ TAO_Named_RT_Mutex_Manager::destroy_mutex (RTCORBA::Mutex_ptr mutex
                           monitor,
                           this->lock_,
                           CORBA::INTERNAL ());
-      ACE_CHECK;
 
       int result =
         this->map_.unbind (name);
 
       if (result != 0)
-        ACE_THROW (CORBA::INTERNAL ());
+        throw ::CORBA::INTERNAL ();
     }
 }
 #else /* TAO_HAS_NAMED_RT_MUTEXES == 1 */
 void
-TAO_Named_RT_Mutex_Manager::destroy_mutex (RTCORBA::Mutex_ptr
-                                           ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_Named_RT_Mutex_Manager::destroy_mutex (RTCORBA::Mutex_ptr)
 {
 }
 #endif /* TAO_HAS_NAMED_RT_MUTEXES == 1 */
 
 RTCORBA::Mutex_ptr
 TAO_Named_RT_Mutex_Manager::create_named_mutex (const char *name,
-                                                CORBA::Boolean_out created_flag
-                                                ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                                CORBA::Boolean_out created_flag)
 {
 #if (TAO_HAS_NAMED_RT_MUTEXES == 1)
   // The following should be atomic.
@@ -152,18 +141,16 @@ TAO_Named_RT_Mutex_Manager::create_named_mutex (const char *name,
                       monitor,
                       this->lock_,
                       CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (RTCORBA::Mutex::_nil ());
 
   // Optimistic that we'll find it.
-  created_flag = 0;
+  created_flag = false;
 
   // If we find the mutex, simply return it.
   RTCORBA::Mutex_var mutex;
-  if (this->map_.find (name,
-                       mutex) != 0)
+  if (this->map_.find (name, mutex) != 0)
     {
       // Oops, we didn't find it.
-      created_flag = 1;
+      created_flag = true;
 
       RTCORBA::Mutex_ptr tmp_mutex;
 
@@ -175,18 +162,14 @@ TAO_Named_RT_Mutex_Manager::create_named_mutex (const char *name,
                             TAO::VMCID,
                             ENOMEM),
                           CORBA::COMPLETED_NO));
-      ACE_CHECK_RETURN (RTCORBA::Mutex::_nil ());
 
       mutex = tmp_mutex;
 
       // Add it to the map.
-      int result =
-        this->map_.bind (name,
-                         mutex);
+      int const result = this->map_.bind (name, mutex);
 
       if (result != 0)
-        ACE_THROW_RETURN (CORBA::INTERNAL (),
-                          RTCORBA::Mutex::_nil ());
+        throw ::CORBA::INTERNAL ();
     }
 
   // Return the one we found or created.
@@ -194,16 +177,12 @@ TAO_Named_RT_Mutex_Manager::create_named_mutex (const char *name,
 #else /* TAO_HAS_NAMED_RT_MUTEXES */
   ACE_UNUSED_ARG (name);
   ACE_UNUSED_ARG (created_flag);
-  ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (),
-                    RTCORBA::Mutex::_nil ());
+  throw ::CORBA::NO_IMPLEMENT ();
 #endif /* TAO_HAS_NAMED_RT_MUTEXES */
 }
 
 RTCORBA::Mutex_ptr
-TAO_Named_RT_Mutex_Manager::open_named_mutex (const char *name
-                                              ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTCORBA::RTORB::MutexNotFound))
+TAO_Named_RT_Mutex_Manager::open_named_mutex (const char *name)
 {
 #if (TAO_HAS_NAMED_RT_MUTEXES == 1)
   // The following should be atomic.
@@ -211,21 +190,17 @@ TAO_Named_RT_Mutex_Manager::open_named_mutex (const char *name
                       monitor,
                       this->lock_,
                       CORBA::INTERNAL ());
-  ACE_CHECK_RETURN (RTCORBA::Mutex::_nil ());
 
   // If we find the mutex, simply return it.
   RTCORBA::Mutex_var mutex;
-  if (this->map_.find (name,
-                       mutex) != 0)
-    ACE_THROW_RETURN (RTCORBA::RTORB::MutexNotFound (),
-                      RTCORBA::Mutex::_nil ());
+  if (this->map_.find (name, mutex) != 0)
+    throw RTCORBA::RTORB::MutexNotFound ();
 
   // Return the one we found.
   return mutex._retn ();
 #else /* TAO_HAS_NAMED_RT_MUTEXES */
   ACE_UNUSED_ARG (name);
-  ACE_THROW_RETURN (CORBA::NO_IMPLEMENT (),
-                    RTCORBA::Mutex::_nil ());
+  throw ::CORBA::NO_IMPLEMENT ();
 #endif /* TAO_HAS_NAMED_RT_MUTEXES */
 }
 
@@ -238,8 +213,7 @@ TAO_RT_ORB::create_tcp_protocol_properties (CORBA::Long send_buffer_size,
                                             CORBA::Boolean dont_route,
                                             CORBA::Boolean no_delay,
                                             CORBA::Boolean enable_network_priority
-                                            ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException ))
+                                            )
 {
   TAO_TCP_Protocol_Properties *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
@@ -251,7 +225,6 @@ TAO_RT_ORB::create_tcp_protocol_properties (CORBA::Long send_buffer_size,
                                         enable_network_priority),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::TCPProtocolProperties::_nil ());
 
   return tmp;
 }
@@ -259,9 +232,7 @@ TAO_RT_ORB::create_tcp_protocol_properties (CORBA::Long send_buffer_size,
 RTCORBA::UnixDomainProtocolProperties_ptr
 TAO_RT_ORB::create_unix_domain_protocol_properties (
                                                     CORBA::Long send_buffer_size,
-                                                    CORBA::Long recv_buffer_size
-                                                    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                                    CORBA::Long recv_buffer_size)
 {
   TAO_UnixDomain_Protocol_Properties *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
@@ -270,7 +241,6 @@ TAO_RT_ORB::create_unix_domain_protocol_properties (
                                                recv_buffer_size),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::UnixDomainProtocolProperties::_nil ());
 
   return tmp;
 }
@@ -284,9 +254,7 @@ TAO_RT_ORB::create_shared_memory_protocol_properties (
                                                       CORBA::Boolean no_delay,
                                                       CORBA::Long preallocate_buffer_size,
                                                       const char *mmap_filename,
-                                                      const char *mmap_lockname
-                                                      ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                                      const char *mmap_lockname)
 {
   TAO_SharedMemory_Protocol_Properties *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
@@ -300,24 +268,24 @@ TAO_RT_ORB::create_shared_memory_protocol_properties (
                                                           mmap_lockname),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::SharedMemoryProtocolProperties::_nil ());
 
   return tmp;
 }
 
 RTCORBA::UserDatagramProtocolProperties_ptr
 TAO_RT_ORB::create_user_datagram_protocol_properties (
-                                                      CORBA::Boolean enable_network_priority
-                                                      ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                                      CORBA::Long send_buffer_size,
+                                                      CORBA::Long recv_buffer_size,
+                                                      CORBA::Boolean enable_network_priority)
 {
   TAO_UserDatagram_Protocol_Properties *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_UserDatagram_Protocol_Properties (
+                                                 send_buffer_size,
+                                                 recv_buffer_size,
                                                  enable_network_priority),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::UserDatagramProtocolProperties::_nil ());
 
   return tmp;
 }
@@ -330,8 +298,7 @@ TAO_RT_ORB::create_stream_control_protocol_properties (
                                                        CORBA::Boolean dont_route,
                                                        CORBA::Boolean no_delay,
                                                        CORBA::Boolean enable_network_priority
-                                                       ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                                       )
 {
   TAO_StreamControl_Protocol_Properties *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
@@ -344,7 +311,6 @@ TAO_RT_ORB::create_stream_control_protocol_properties (
                                                   enable_network_priority),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::StreamControlProtocolProperties::_nil ());
 
   return tmp;
 }
@@ -357,8 +323,7 @@ TAO_RT_ORB::create_threadpool (CORBA::ULong stacksize,
                                CORBA::Boolean allow_request_buffering,
                                CORBA::ULong max_buffered_requests,
                                CORBA::ULong max_request_buffer_size
-                               ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                               )
 {
   return this->tp_manager_->create_threadpool (stacksize,
                                                static_threads,
@@ -366,8 +331,9 @@ TAO_RT_ORB::create_threadpool (CORBA::ULong stacksize,
                                                default_priority,
                                                allow_request_buffering,
                                                max_buffered_requests,
-                                               max_request_buffer_size
-                                               ACE_ENV_ARG_PARAMETER);
+                                               max_request_buffer_size,
+                                               this->lifespan_,
+                                               this->dynamic_thread_time_);
 }
 
 RTCORBA::ThreadpoolId
@@ -376,116 +342,94 @@ TAO_RT_ORB::create_threadpool_with_lanes (CORBA::ULong stacksize,
                                           CORBA::Boolean allow_borrowing,
                                           CORBA::Boolean allow_request_buffering,
                                           CORBA::ULong max_buffered_requests,
-                                          CORBA::ULong max_request_buffer_size
-                                          ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                          CORBA::ULong max_request_buffer_size)
 {
   return this->tp_manager_->create_threadpool_with_lanes (stacksize,
                                                           lanes,
                                                           allow_borrowing,
                                                           allow_request_buffering,
                                                           max_buffered_requests,
-                                                          max_request_buffer_size
-                                                          ACE_ENV_ARG_PARAMETER);
+                                                          max_request_buffer_size,
+                                                          this->lifespan_,
+                                                          this->dynamic_thread_time_);
 }
 
 void
-TAO_RT_ORB::destroy_threadpool (RTCORBA::ThreadpoolId threadpool
-                                ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTCORBA::RTORB::InvalidThreadpool))
+TAO_RT_ORB::destroy_threadpool (RTCORBA::ThreadpoolId threadpool)
 {
-  this->tp_manager_->destroy_threadpool (threadpool
-                                         ACE_ENV_ARG_PARAMETER);
+  this->tp_manager_->destroy_threadpool (threadpool);
 }
 
 RTCORBA::PriorityModelPolicy_ptr
 TAO_RT_ORB::create_priority_model_policy (RTCORBA::PriorityModel priority_model,
-                                          RTCORBA::Priority server_priority
-                                          ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                          RTCORBA::Priority server_priority)
 {
   TAO_PriorityModelPolicy *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_PriorityModelPolicy (priority_model, server_priority),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::PriorityModelPolicy::_nil ());
 
   return tmp;
 }
 
 RTCORBA::ThreadpoolPolicy_ptr
-TAO_RT_ORB::create_threadpool_policy (RTCORBA::ThreadpoolId threadpool
-                                      ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RT_ORB::create_threadpool_policy (RTCORBA::ThreadpoolId threadpool)
 {
   TAO_ThreadpoolPolicy *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_ThreadpoolPolicy (threadpool),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::ThreadpoolPolicy::_nil ());
 
   return tmp;
 }
 
 RTCORBA::PriorityBandedConnectionPolicy_ptr
 TAO_RT_ORB::create_priority_banded_connection_policy (const
-                                                      RTCORBA::PriorityBands & priority_bands
-                                                      ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                                      RTCORBA::PriorityBands & priority_bands)
 {
   TAO_PriorityBandedConnectionPolicy *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_PriorityBandedConnectionPolicy (priority_bands),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::PriorityBandedConnectionPolicy::_nil ());
 
   return tmp;
 }
 
 RTCORBA::PrivateConnectionPolicy_ptr
-TAO_RT_ORB::create_private_connection_policy (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RT_ORB::create_private_connection_policy (void)
 {
   TAO_PrivateConnectionPolicy *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_PrivateConnectionPolicy (),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::PrivateConnectionPolicy::_nil ());
 
   return tmp;
 }
 
 RTCORBA::ServerProtocolPolicy_ptr
-TAO_RT_ORB::create_server_protocol_policy (const RTCORBA::ProtocolList & protocols
-                                           ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RT_ORB::create_server_protocol_policy (const RTCORBA::ProtocolList & protocols)
 {
   TAO_ServerProtocolPolicy *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_ServerProtocolPolicy (protocols),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::ServerProtocolPolicy::_nil ());
 
   return tmp;
 }
 
 RTCORBA::ClientProtocolPolicy_ptr
-TAO_RT_ORB::create_client_protocol_policy (const RTCORBA::ProtocolList & protocols
-                                           ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RT_ORB::create_client_protocol_policy (const RTCORBA::ProtocolList & protocols)
 {
   TAO_ClientProtocolPolicy *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     TAO_ClientProtocolPolicy (protocols),
                     CORBA::NO_MEMORY (TAO::VMCID,
                                       CORBA::COMPLETED_NO));
-  ACE_CHECK_RETURN (RTCORBA::ClientProtocolPolicy::_nil ());
 
   return tmp;
 }
@@ -524,18 +468,14 @@ TAO_RT_ORB::modify_thread_scheduling_policy (CORBA::ORB_ptr orb)
 
 #if defined (linux)
 
-  int sched_policy =
-    orb->orb_core ()->orb_params ()->ace_sched_policy ();
+  int const sched_policy = orb->orb_core ()->orb_params ()->ace_sched_policy ();
 
-  int minimum_priority =
-    ACE_Sched_Params::priority_min (sched_policy);
+  int const minimum_priority = ACE_Sched_Params::priority_min (sched_policy);
 
   ACE_hthread_t thread_id;
   ACE_Thread::self (thread_id);
 
-  return ACE_Thread::setprio (thread_id,
-                              minimum_priority,
-                              sched_policy);
+  return ACE_Thread::setprio (thread_id, minimum_priority, sched_policy);
 
 #else /* linux */
 
@@ -546,28 +486,8 @@ TAO_RT_ORB::modify_thread_scheduling_policy (CORBA::ORB_ptr orb)
 
 }
 
-////////////////////////////////////////////////////////////////////////////////
+TAO_END_VERSIONED_NAMESPACE_DECL
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-#if (TAO_HAS_NAMED_RT_MUTEXES == 1)
-template class ACE_Hash_Map_Manager_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Base_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Iterator_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Reverse_Iterator_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>;
-template class ACE_Hash_Map_Entry<ACE_CString, RTCORBA::Mutex_var>;
-#endif /* TAO_HAS_NAMED_RT_MUTEXES == 1 */
-
-#elif defined(ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#if (TAO_HAS_NAMED_RT_MUTEXES == 1)
-#pragma instantiate ACE_Hash_Map_Manager_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Iterator_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<ACE_CString, RTCORBA::Mutex_var, ACE_Hash<ACE_CString>, ACE_Equal_To<ACE_CString>, ACE_Null_Mutex>
-#pragma instantiate ACE_Hash_Map_Entry<ACE_CString, RTCORBA::Mutex_var>
-#endif /* TAO_HAS_NAMED_RT_MUTEXES == 1 */
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+///////////////////////////////////////////////////////////////////////////////
 
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
