@@ -4,7 +4,7 @@
 /**
  *  @file    RT_ORB_Loader.h
  *
- *  $Id: RT_ORB_Loader.h 78627 2007-06-28 08:50:01Z johnnyw $
+ *  $Id: RT_ORB_Loader.h 87582 2009-11-16 16:04:12Z vzykov $
  *
  *   Header file for Loading RT_ORB.
  *
@@ -37,18 +37,26 @@ class TAO_RTCORBA_Export TAO_RT_ORB_Loader : public ACE_Service_Object
 {
 public:
 
+  /// Constructor.
+  TAO_RT_ORB_Loader (void);
+
   /// Destructor.
   virtual ~TAO_RT_ORB_Loader (void);
 
   /// Initialize the RT ORB loader hooks.
   virtual int init (int argc, ACE_TCHAR* []);
+
+private:
+  /// Set to true after init is called.
+  bool initialized_;
 };
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 ACE_STATIC_SVC_DECLARE_EXPORT (TAO_RTCORBA, TAO_RT_ORB_Loader)
 ACE_FACTORY_DECLARE (TAO_RTCORBA, TAO_RT_ORB_Loader)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #include /**/ "ace/post.h"
