@@ -1,4 +1,4 @@
-// $Id: RT_Policy_i.cpp 78627 2007-06-28 08:50:01Z johnnyw $
+// $Id: RT_Policy_i.cpp 83337 2008-10-21 09:10:54Z johnnyw $
 
 #include "tao/RTCORBA/RT_Policy_i.h"
 
@@ -15,7 +15,7 @@
 
 ACE_RCSID (RTCORBA,
            RT_Policy_i,
-           "$Id: RT_Policy_i.cpp 78627 2007-06-28 08:50:01Z johnnyw $")
+           "$Id: RT_Policy_i.cpp 83337 2008-10-21 09:10:54Z johnnyw $")
 
 // ****************************************************************
 
@@ -26,9 +26,8 @@ TAO_PriorityModelPolicy::TAO_PriorityModelPolicy (
   RTCORBA::Priority server_priority)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::PriorityModelPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , priority_model_ (priority_model)
   , server_priority_ (server_priority)
 {
@@ -37,9 +36,8 @@ TAO_PriorityModelPolicy::TAO_PriorityModelPolicy (
 TAO_PriorityModelPolicy::TAO_PriorityModelPolicy (const TAO_PriorityModelPolicy &rhs)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::PriorityModelPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , priority_model_ (rhs.priority_model_)
   , server_priority_ (rhs.server_priority_)
 {
@@ -146,9 +144,8 @@ TAO_PriorityModelPolicy::_tao_scope (void) const
 TAO_ThreadpoolPolicy::TAO_ThreadpoolPolicy (RTCORBA::ThreadpoolId id)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::ThreadpoolPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , id_ (id)
 {
 }
@@ -156,9 +153,8 @@ TAO_ThreadpoolPolicy::TAO_ThreadpoolPolicy (RTCORBA::ThreadpoolId id)
 TAO_ThreadpoolPolicy::TAO_ThreadpoolPolicy (const TAO_ThreadpoolPolicy &rhs)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::ThreadpoolPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , id_ (rhs.id_)
 {
 }
@@ -168,11 +164,10 @@ TAO_ThreadpoolPolicy::~TAO_ThreadpoolPolicy (void)
 }
 
 CORBA::Policy_ptr
-TAO_ThreadpoolPolicy::create (const CORBA::Any &val
-                              )
+TAO_ThreadpoolPolicy::create (const CORBA::Any &val)
 {
   RTCORBA::ThreadpoolId value;
-  if ((val >>= value) == 0)
+  if (!(val >>= value))
     throw ::CORBA::PolicyError (CORBA::BAD_POLICY_VALUE);
 
   TAO_ThreadpoolPolicy *tmp = 0;
@@ -231,18 +226,16 @@ TAO_ThreadpoolPolicy::_tao_scope (void) const
 TAO_PrivateConnectionPolicy::TAO_PrivateConnectionPolicy (void)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::PrivateConnectionPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
 {
 }
 
 TAO_PrivateConnectionPolicy::TAO_PrivateConnectionPolicy (const TAO_PrivateConnectionPolicy &)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::PrivateConnectionPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
 {
 }
 
@@ -304,9 +297,8 @@ TAO_PrivateConnectionPolicy::_tao_scope (void) const
 TAO_PriorityBandedConnectionPolicy::TAO_PriorityBandedConnectionPolicy (const RTCORBA::PriorityBands &bands)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::PriorityBandedConnectionPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , priority_bands_ (bands)
 {
 }
@@ -314,9 +306,8 @@ TAO_PriorityBandedConnectionPolicy::TAO_PriorityBandedConnectionPolicy (const RT
 TAO_PriorityBandedConnectionPolicy::TAO_PriorityBandedConnectionPolicy (const TAO_PriorityBandedConnectionPolicy &rhs)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::PriorityBandedConnectionPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , priority_bands_ (rhs.priority_bands_)
 {
 }
@@ -333,7 +324,7 @@ CORBA::Policy_ptr
 TAO_PriorityBandedConnectionPolicy::create (const CORBA::Any &val)
 {
   RTCORBA::PriorityBands *value = 0;
-  if ((val >>= value) == 0)
+  if (!(val >>= value))
     throw ::CORBA::PolicyError (CORBA::BAD_POLICY_VALUE);
 
   TAO_PriorityBandedConnectionPolicy *tmp = 0;
@@ -348,7 +339,7 @@ TAO_PriorityBandedConnectionPolicy::create (const CORBA::Any &val)
 RTCORBA::PriorityBands *
 TAO_PriorityBandedConnectionPolicy::priority_bands (void)
 {
-  RTCORBA::PriorityBands *tmp;
+  RTCORBA::PriorityBands *tmp = 0;
   ACE_NEW_THROW_EX (tmp,
                     RTCORBA::PriorityBands (this->priority_bands_),
                     CORBA::NO_MEMORY (TAO::VMCID,
@@ -383,13 +374,13 @@ TAO_PriorityBandedConnectionPolicy::destroy (void)
 CORBA::Boolean
 TAO_PriorityBandedConnectionPolicy::_tao_encode (TAO_OutputCDR &out_cdr)
 {
-  return out_cdr << priority_bands_;
+  return out_cdr << this->priority_bands_;
 }
 
 CORBA::Boolean
 TAO_PriorityBandedConnectionPolicy::_tao_decode (TAO_InputCDR &in_cdr)
 {
-  return in_cdr >> priority_bands_;
+  return in_cdr >> this->priority_bands_;
 }
 
 TAO_Cached_Policy_Type
@@ -408,7 +399,7 @@ TAO_PriorityBandedConnectionPolicy::_tao_scope (void) const
 RTCORBA::PriorityBands &
 TAO_PriorityBandedConnectionPolicy::priority_bands_rep (void)
 {
-  return priority_bands_;
+  return this->priority_bands_;
 }
 
 // ****************************************************************
@@ -416,9 +407,8 @@ TAO_PriorityBandedConnectionPolicy::priority_bands_rep (void)
 TAO_ServerProtocolPolicy::TAO_ServerProtocolPolicy (const RTCORBA::ProtocolList &protocols)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::ServerProtocolPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , protocols_ (protocols)
 {
 }
@@ -426,9 +416,8 @@ TAO_ServerProtocolPolicy::TAO_ServerProtocolPolicy (const RTCORBA::ProtocolList
 TAO_ServerProtocolPolicy::TAO_ServerProtocolPolicy (const TAO_ServerProtocolPolicy &rhs)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::ServerProtocolPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , protocols_ (rhs.protocols_)
 {
 }
@@ -441,7 +430,7 @@ CORBA::Policy_ptr
 TAO_ServerProtocolPolicy::create (const CORBA::Any &val)
 {
   RTCORBA::ProtocolList *value = 0;
-  if ((val >>= value) == 0)
+  if (!(val >>= value))
     throw ::CORBA::PolicyError (CORBA::BAD_POLICY_VALUE);
 
   TAO_ServerProtocolPolicy *tmp = 0;
@@ -517,9 +506,8 @@ TAO_ClientProtocolPolicy::TAO_ClientProtocolPolicy (void)
 TAO_ClientProtocolPolicy::TAO_ClientProtocolPolicy (const RTCORBA::ProtocolList &protocols)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::ClientProtocolPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , protocols_ (protocols)
 {
 }
@@ -527,9 +515,8 @@ TAO_ClientProtocolPolicy::TAO_ClientProtocolPolicy (const RTCORBA::ProtocolList
 TAO_ClientProtocolPolicy::TAO_ClientProtocolPolicy (const TAO_ClientProtocolPolicy &rhs)
   : ::CORBA::Object ()
   , ::CORBA::Policy ()
-  , ::CORBA::LocalObject ()
   , RTCORBA::ClientProtocolPolicy ()
-  , TAO_Local_RefCounted_Object ()
+  , ::CORBA::LocalObject ()
   , protocols_ (rhs.protocols_)
 {
 }
@@ -539,11 +526,10 @@ TAO_ClientProtocolPolicy::~TAO_ClientProtocolPolicy ()
 }
 
 CORBA::Policy_ptr
-TAO_ClientProtocolPolicy::create (const CORBA::Any &val
-                                  )
+TAO_ClientProtocolPolicy::create (const CORBA::Any &val)
 {
   RTCORBA::ProtocolList *value = 0;
-  if ((val >>= value) == 0)
+  if (!(val >>= value))
     throw ::CORBA::PolicyError (CORBA::BAD_POLICY_VALUE);
 
   TAO_ClientProtocolPolicy *tmp = 0;
@@ -728,8 +714,7 @@ TAO_TCP_Protocol_Properties::dont_route (void)
 }
 
 void
-TAO_TCP_Protocol_Properties::dont_route (CORBA::Boolean dont_route
-                                         )
+TAO_TCP_Protocol_Properties::dont_route (CORBA::Boolean dont_route)
 {
   this->dont_route_ = dont_route;
 }
@@ -740,8 +725,7 @@ CORBA::Boolean TAO_TCP_Protocol_Properties::no_delay (void)
 }
 
 void
-TAO_TCP_Protocol_Properties::no_delay (CORBA::Boolean no_delay
-                                       )
+TAO_TCP_Protocol_Properties::no_delay (CORBA::Boolean no_delay)
 {
   this->no_delay_ = no_delay;
 }
@@ -753,8 +737,7 @@ TAO_TCP_Protocol_Properties::enable_network_priority (void)
 }
 
 void
-TAO_TCP_Protocol_Properties::enable_network_priority (CORBA::Boolean enable
-                                                      )
+TAO_TCP_Protocol_Properties::enable_network_priority (CORBA::Boolean enable)
 {
   this->enable_network_priority_ = enable;
 }
@@ -808,8 +791,7 @@ TAO_UnixDomain_Protocol_Properties::send_buffer_size (void)
 }
 
 void
-TAO_UnixDomain_Protocol_Properties::send_buffer_size (CORBA::Long send_buffer_size
-                                                      )
+TAO_UnixDomain_Protocol_Properties::send_buffer_size (CORBA::Long send_buffer_size)
 {
   this->send_buffer_size_ = send_buffer_size;
 }
@@ -821,8 +803,7 @@ TAO_UnixDomain_Protocol_Properties::recv_buffer_size (void)
 }
 
 void
-TAO_UnixDomain_Protocol_Properties::recv_buffer_size (CORBA::Long recv_buffer_size
-                                                      )
+TAO_UnixDomain_Protocol_Properties::recv_buffer_size (CORBA::Long recv_buffer_size)
 {
   this->recv_buffer_size_ = recv_buffer_size;
 }
@@ -874,8 +855,7 @@ TAO_SharedMemory_Protocol_Properties::send_buffer_size (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::send_buffer_size (CORBA::Long send_buffer_size
-                                                        )
+TAO_SharedMemory_Protocol_Properties::send_buffer_size (CORBA::Long send_buffer_size)
 {
   this->send_buffer_size_ = send_buffer_size;
 }
@@ -887,8 +867,7 @@ TAO_SharedMemory_Protocol_Properties::recv_buffer_size (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::recv_buffer_size (CORBA::Long recv_buffer_size
-                                                        )
+TAO_SharedMemory_Protocol_Properties::recv_buffer_size (CORBA::Long recv_buffer_size)
 {
   this->recv_buffer_size_ = recv_buffer_size;
 }
@@ -900,8 +879,7 @@ TAO_SharedMemory_Protocol_Properties::keep_alive (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::keep_alive (CORBA::Boolean keep_alive
-                                                  )
+TAO_SharedMemory_Protocol_Properties::keep_alive (CORBA::Boolean keep_alive)
 {
   this->keep_alive_ = keep_alive;
 }
@@ -913,8 +891,7 @@ TAO_SharedMemory_Protocol_Properties::dont_route (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::dont_route (CORBA::Boolean dont_route
-                                                  )
+TAO_SharedMemory_Protocol_Properties::dont_route (CORBA::Boolean dont_route)
 {
   this->dont_route_ = dont_route;
 }
@@ -926,8 +903,7 @@ TAO_SharedMemory_Protocol_Properties::no_delay (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::no_delay (CORBA::Boolean no_delay
-                                                )
+TAO_SharedMemory_Protocol_Properties::no_delay (CORBA::Boolean no_delay)
 {
   this->no_delay_ = no_delay;
 }
@@ -939,8 +915,7 @@ TAO_SharedMemory_Protocol_Properties::preallocate_buffer_size (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::preallocate_buffer_size (CORBA::Long preallocate_buffer_size
-                                                               )
+TAO_SharedMemory_Protocol_Properties::preallocate_buffer_size (CORBA::Long preallocate_buffer_size)
 {
   this->preallocate_buffer_size_ = preallocate_buffer_size;
 }
@@ -952,8 +927,7 @@ TAO_SharedMemory_Protocol_Properties::mmap_filename (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::mmap_filename (const char * mmap_filename
-                                                     )
+TAO_SharedMemory_Protocol_Properties::mmap_filename (const char * mmap_filename)
 {
   this->mmap_filename_.set (mmap_filename);
 }
@@ -965,8 +939,7 @@ TAO_SharedMemory_Protocol_Properties::mmap_lockname (void)
 }
 
 void
-TAO_SharedMemory_Protocol_Properties::mmap_lockname (const char * mmap_lockname
-                                                     )
+TAO_SharedMemory_Protocol_Properties::mmap_lockname (const char * mmap_lockname)
 {
   this->mmap_lockname_.set (mmap_lockname);
 }
@@ -1115,8 +1088,7 @@ TAO_StreamControl_Protocol_Properties::recv_buffer_size (void)
 }
 
 void
-TAO_StreamControl_Protocol_Properties::recv_buffer_size (CORBA::Long recv_buffer_size
-                                                         )
+TAO_StreamControl_Protocol_Properties::recv_buffer_size (CORBA::Long recv_buffer_size)
 {
   this->recv_buffer_size_ = recv_buffer_size;
 }
@@ -1128,8 +1100,7 @@ TAO_StreamControl_Protocol_Properties::keep_alive (void)
 }
 
 void
-TAO_StreamControl_Protocol_Properties::keep_alive (CORBA::Boolean keep_alive
-                                                   )
+TAO_StreamControl_Protocol_Properties::keep_alive (CORBA::Boolean keep_alive)
 {
   this->keep_alive_ = keep_alive;
 }
@@ -1141,8 +1112,7 @@ TAO_StreamControl_Protocol_Properties::dont_route (void)
 }
 
 void
-TAO_StreamControl_Protocol_Properties::dont_route (CORBA::Boolean dont_route
-                                                   )
+TAO_StreamControl_Protocol_Properties::dont_route (CORBA::Boolean dont_route)
 {
   this->dont_route_ = dont_route;
 }
@@ -1153,8 +1123,7 @@ CORBA::Boolean TAO_StreamControl_Protocol_Properties::no_delay (void)
 }
 
 void
-TAO_StreamControl_Protocol_Properties::no_delay (CORBA::Boolean no_delay
-                                                 )
+TAO_StreamControl_Protocol_Properties::no_delay (CORBA::Boolean no_delay)
 {
   this->no_delay_ = no_delay;
 }
@@ -1166,8 +1135,7 @@ TAO_StreamControl_Protocol_Properties::enable_network_priority (void)
 }
 
 void
-TAO_StreamControl_Protocol_Properties::enable_network_priority (CORBA::Boolean enable
-                                                                )
+TAO_StreamControl_Protocol_Properties::enable_network_priority (CORBA::Boolean enable)
 {
   this->enable_network_priority_ = enable;
 }
@@ -1213,13 +1181,13 @@ TAO_GIOP_Protocol_Properties::~TAO_GIOP_Protocol_Properties (void)
 CORBA::Boolean
 TAO_GIOP_Protocol_Properties::_tao_encode (TAO_OutputCDR &)
 {
-  return 1;
+  return true;
 }
 
 CORBA::Boolean
 TAO_GIOP_Protocol_Properties::_tao_decode (TAO_InputCDR &)
 {
-  return 1;
+  return true;
 }
 
 // ****************************************************************
@@ -1235,8 +1203,8 @@ TAO_Protocol_Properties_Factory::create_transport_protocol_property (IOP::Profil
       int send_buffer_size = orb_core ? orb_core->orb_params ()->sock_sndbuf_size () : 0;
       int recv_buffer_size = orb_core ? orb_core->orb_params ()->sock_rcvbuf_size () : 0;
       int no_delay = orb_core ? orb_core->orb_params ()->nodelay () : 0;
-      CORBA::Boolean keep_alive = true;
-      CORBA::Boolean dont_route = false;
+      CORBA::Boolean keep_alive = orb_core ? orb_core->orb_params ()->sock_keepalive () : true;
+      CORBA::Boolean dont_route = orb_core ? orb_core->orb_params ()->sock_dontroute () : false;
       CORBA::Boolean enable_network_priority = false;
 
       ACE_NEW_RETURN (property,
@@ -1274,8 +1242,8 @@ TAO_Protocol_Properties_Factory::create_transport_protocol_property (IOP::Profil
 
   else if (id == TAO_TAG_UIOP_PROFILE)
     {
-      int send_buffer_size = orb_core ? orb_core->orb_params ()->sock_sndbuf_size () : 0;
-      int recv_buffer_size = orb_core ? orb_core->orb_params ()->sock_rcvbuf_size () : 0;
+      int const send_buffer_size = orb_core ? orb_core->orb_params ()->sock_sndbuf_size () : 0;
+      int const recv_buffer_size = orb_core ? orb_core->orb_params ()->sock_rcvbuf_size () : 0;
 
       ACE_NEW_RETURN (property,
                       TAO_UnixDomain_Protocol_Properties (send_buffer_size,
@@ -1285,8 +1253,8 @@ TAO_Protocol_Properties_Factory::create_transport_protocol_property (IOP::Profil
 
   else if (id == TAO_TAG_DIOP_PROFILE)
     {
-      int send_buffer_size = orb_core ? orb_core->orb_params ()->sock_sndbuf_size () : 0;
-      int recv_buffer_size = orb_core ? orb_core->orb_params ()->sock_rcvbuf_size () : 0;
+      int const send_buffer_size = orb_core ? orb_core->orb_params ()->sock_sndbuf_size () : 0;
+      int const recv_buffer_size = orb_core ? orb_core->orb_params ()->sock_rcvbuf_size () : 0;
       CORBA::Boolean enable_network_priority = false;
 
       ACE_NEW_RETURN (property,
