@@ -3,7 +3,7 @@
 /**
  *  @file   RT_Policy_i.h
  *
- *  $Id: RT_Policy_i.h 78627 2007-06-28 08:50:01Z johnnyw $
+ *  $Id: RT_Policy_i.h 82354 2008-07-22 11:34:18Z johnnyw $
  *
  *  @author Marina Spivak (marina@cs.wustl.edu)
  */
@@ -47,7 +47,7 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
  */
 class TAO_RTCORBA_Export TAO_PriorityModelPolicy
   : public RTCORBA::PriorityModelPolicy,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -120,7 +120,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_ThreadpoolPolicy
   : public RTCORBA::ThreadpoolPolicy,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -172,7 +172,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_PrivateConnectionPolicy
   : public RTCORBA::PrivateConnectionPolicy,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -220,7 +220,7 @@ protected:
  */
 class TAO_RTCORBA_Export TAO_PriorityBandedConnectionPolicy
   : public RTCORBA::PriorityBandedConnectionPolicy,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -289,7 +289,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_ServerProtocolPolicy
   : public RTCORBA::ServerProtocolPolicy,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -305,8 +305,7 @@ public:
    */
   RTCORBA::ProtocolList & protocols_rep (void);
 
-  RTCORBA::ProtocolList *protocols
-  (void);
+  RTCORBA::ProtocolList *protocols (void);
 
   CORBA::PolicyType policy_type (void);
 
@@ -348,7 +347,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_ClientProtocolPolicy
   : public RTCORBA::ClientProtocolPolicy,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -364,8 +363,7 @@ public:
    */
   RTCORBA::ProtocolList & protocols_rep (void);
 
-  RTCORBA::ProtocolList *protocols
-  (void);
+  RTCORBA::ProtocolList *protocols (void);
 
   CORBA::PolicyType policy_type (void);
 
@@ -419,7 +417,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_TCP_Protocol_Properties
   : public RTCORBA::TCPProtocolProperties,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -489,7 +487,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_UnixDomain_Protocol_Properties
   : public RTCORBA::UnixDomainProtocolProperties,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
 
@@ -549,7 +547,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_SharedMemory_Protocol_Properties
   : public RTCORBA::SharedMemoryProtocolProperties,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -646,7 +644,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_UserDatagram_Protocol_Properties
   : public RTCORBA::UserDatagramProtocolProperties,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -697,7 +695,7 @@ private:
  */
 class TAO_RTCORBA_Export TAO_StreamControl_Protocol_Properties
   : public RTCORBA::StreamControlProtocolProperties,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
   /// Constructor.
@@ -759,7 +757,7 @@ private:
 
 class TAO_RTCORBA_Export TAO_GIOP_Protocol_Properties
   : public RTCORBA::GIOPProtocolProperties,
-    public TAO_Local_RefCounted_Object
+    public ::CORBA::LocalObject
 {
 public:
 
