@@ -15,6 +15,7 @@
 #include "tao/Protocol_Factory.h"
 #include "tao/Transport_Acceptor.h"
 #include "tao/Transport_Connector.h"
+#include "tao/TSS_Resources.h"
 #include "tao/Policy_Set.h"
 #include "tao/debug.h"
 #include "tao/CDR.h"
@@ -25,7 +26,7 @@
 
 ACE_RCSID (RTCORBA,
            RT_Protocols_Hooks,
-           "$Id: RT_Protocols_Hooks.cpp 78627 2007-06-28 08:50:01Z johnnyw $")
+           "$Id: RT_Protocols_Hooks.cpp 85406 2009-05-20 09:07:56Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -74,19 +75,19 @@ TAO_RT_Protocols_Hooks::server_protocol_properties (IOP::ProfileId protocol_tag,
                                                     CORBA::Policy_ptr policy)
 {
   if (CORBA::is_nil (policy))
-    return 0;
+    return RTCORBA::ProtocolProperties::_nil ();
 
   RTCORBA::ServerProtocolPolicy_var server_protocol_policy =
     RTCORBA::ServerProtocolPolicy::_narrow (policy);
 
   if (CORBA::is_nil (server_protocol_policy.in ()))
-    return 0;
+    return RTCORBA::ProtocolProperties::_nil ();
 
   TAO_ServerProtocolPolicy *server_protocols =
     dynamic_cast<TAO_ServerProtocolPolicy *> (server_protocol_policy.in ());
 
   if (server_protocols == 0)
-    return 0;
+    return RTCORBA::ProtocolProperties::_nil ();
 
   // TAO_ServerProtocolPolicy
   RTCORBA::ProtocolList &protocols =
@@ -101,7 +102,7 @@ TAO_RT_Protocols_Hooks::server_protocol_properties (IOP::ProfileId protocol_tag,
         }
     }
 
-  return 0;
+  return RTCORBA::ProtocolProperties::_nil ();
 }
 
 RTCORBA::ProtocolProperties_ptr
@@ -109,19 +110,19 @@ TAO_RT_Protocols_Hooks::client_protocol_properties (IOP::ProfileId protocol_tag,
                                                     CORBA::Policy_ptr policy)
 {
   if (CORBA::is_nil (policy))
-    return 0;
+    return RTCORBA::ProtocolProperties::_nil ();
 
   RTCORBA::ClientProtocolPolicy_var client_protocol_policy =
     RTCORBA::ClientProtocolPolicy::_narrow (policy);
 
   if (CORBA::is_nil (client_protocol_policy.in ()))
-    return 0;
+    return RTCORBA::ProtocolProperties::_nil ();
 
   TAO_ClientProtocolPolicy *client_protocols =
     dynamic_cast<TAO_ClientProtocolPolicy *> (client_protocol_policy.in ());
 
   if (client_protocols == 0)
-    return 0;
+    return RTCORBA::ProtocolProperties::_nil ();
 
   // TAO_ClientProtocolPolicy
   RTCORBA::ProtocolList &protocols =
@@ -136,7 +137,7 @@ TAO_RT_Protocols_Hooks::client_protocol_properties (IOP::ProfileId protocol_tag,
         }
     }
 
-  return 0;
+  return RTCORBA::ProtocolProperties::_nil ();
 }
 
 RTCORBA::ProtocolProperties_ptr
@@ -458,77 +459,6 @@ TAO_RT_Protocols_Hooks::get_dscp_codepoint (void)
   return codepoint;
 }
 
-void
-TAO_RT_Protocols_Hooks::rt_service_context (
-    TAO_Stub *stub,
-    TAO_Service_Context &service_context,
-    CORBA::Boolean restart)
-{
-  // If the restart flag is true, then this call for a
-  // reinvocation. We need not prepare the Service Context List once
-  // again. We can use the already existing one.
-  if (!restart)
-    {
-      TAO_RT_Stub *rt_stub =
-        dynamic_cast<TAO_RT_Stub *> (stub);
-
-      if (!rt_stub)
-        throw CORBA::INTERNAL ();
-
-      CORBA::Policy_var priority_model_policy =
-        rt_stub->get_cached_policy (TAO_CACHED_POLICY_PRIORITY_MODEL);
-
-      if (!CORBA::is_nil (priority_model_policy.in ()))
-        {
-          CORBA::Short client_priority;
-
-          int const status =
-            this->get_thread_CORBA_priority (client_priority);
-
-          if (status == -1)
-            throw ::CORBA::DATA_CONVERSION (1, CORBA::COMPLETED_NO);
-
-          this->add_rt_service_context_hook (service_context,
-                                             priority_model_policy.in (),
-                                             client_priority);
-        }
-      else
-        {
-          // The Object does not contain PriorityModel policy in its IOR.
-          // We must be talking to a non-RT ORB.  Do nothing.
-        }
-    }
-}
-
-void
-TAO_RT_Protocols_Hooks::add_rt_service_context_hook (
-    TAO_Service_Context &service_context,
-    CORBA::Policy *model_policy,
-    CORBA::Short &client_priority
-
-  )
-{
-  RTCORBA::PriorityModelPolicy_var model_policy_ptr =
-    RTCORBA::PriorityModelPolicy::_narrow (model_policy);
-
-  TAO_PriorityModelPolicy *priority_model =
-    static_cast<TAO_PriorityModelPolicy *> (model_policy_ptr.in ());
-
-  if (priority_model->get_priority_model () == RTCORBA::CLIENT_PROPAGATED)
-    {
-      // Encapsulate the priority of the current thread into
-      // a service context.
-      TAO_OutputCDR cdr;
-      if ((cdr << ACE_OutputCDR::from_boolean (TAO_ENCAP_BYTE_ORDER) == 0)
-          || (cdr << client_priority) == 0)
-        {
-          throw ::CORBA::MARSHAL ();
-        }
-
-      service_context.set_context (IOP::RTCorbaPriority, cdr);
-    }
-}
-
 void
 TAO_RT_Protocols_Hooks::get_selector_hook (
     CORBA::Policy *model_policy,
@@ -589,14 +519,9 @@ TAO_RT_Protocols_Hooks::get_selector_bands_policy_hook (
 int
 TAO_RT_Protocols_Hooks::get_thread_CORBA_priority (CORBA::Short &priority)
 {
-  CORBA::Short native_priority = 0;
+  priority = TAO_TSS_Resources::instance ()->rtcorba_current_priority_;
 
-  if (this->get_thread_CORBA_and_native_priority (priority, native_priority) == -1)
-    {
-      return -1;
-    }
-
-  return 0;
+  return (priority == -1 ? -1 : 0);
 }
 
 int
@@ -612,8 +537,8 @@ TAO_RT_Protocols_Hooks::get_thread_native_priority (
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - ")
-                  ACE_TEXT ("RT_Protocols_Hooks::get_thread_priority: ")
-                  ACE_TEXT (" ACE_Thread::get_prio\n")));
+                  ACE_TEXT ("RT_Protocols_Hooks::get_thread_native_priority: ")
+                  ACE_TEXT (" ACE_Thread::get_prio failed\n")));
 
       return -1;
     }
@@ -632,21 +557,49 @@ TAO_RT_Protocols_Hooks::get_thread_CORBA_and_native_priority (
       return -1;
     }
 
-  TAO_Priority_Mapping *priority_mapping =
-    this->mapping_manager_.in ()->mapping ();
-
-  if (priority_mapping->to_CORBA (native_priority, priority) == 0)
+  if (this->get_thread_CORBA_priority (priority) == -1)
     {
-      ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("TAO (%P|%t) - ")
-                  ACE_TEXT ("RT_Protocols_Hooks::get_thread_priority: ")
-                  ACE_TEXT ("Priority_Mapping::to_CORBA\n")));
-      return -1;
+      // This thread had an unset CORBA priority - as this method
+      // should only be used to get and restore the state of play before and
+      // after invocations that might be OK for all I know. Or care frankly.
+      priority = -1;
     }
 
   return 0;
 }
 
+int
+TAO_RT_Protocols_Hooks::get_thread_implicit_CORBA_priority (CORBA::Short &priority)
+{
+  TAO_Priority_Mapping *pm =
+    this->mapping_manager_.in ()->mapping ();
+
+  CORBA::Short native_priority = 0;
+  if (this->get_thread_native_priority (native_priority) == 0 &&
+      pm->to_CORBA (native_priority, priority))
+    {
+      return 0;
+    }
+
+  return -1;
+}
+
+int
+TAO_RT_Protocols_Hooks::restore_thread_CORBA_and_native_priority (
+    CORBA::Short priority,
+    CORBA::Short native_priority
+  )
+{
+  // Only used for restoration of values that were previously set /
+  // checked when so no need to re-apply the mapping.
+  int result = this->set_thread_native_priority (native_priority);
+
+  if (result == 0)
+    TAO_TSS_Resources::instance ()->rtcorba_current_priority_ = priority;
+
+  return result;
+}
+
 int
 TAO_RT_Protocols_Hooks::set_thread_CORBA_priority (CORBA::Short priority)
 {
@@ -660,7 +613,8 @@ TAO_RT_Protocols_Hooks::set_thread_CORBA_priority (CORBA::Short priority)
       return -1;
     }
 
-  return this->set_thread_native_priority (native_priority);
+  return this->restore_thread_CORBA_and_native_priority (priority,
+                                                         native_priority);
 }
 
 int
@@ -676,14 +630,13 @@ TAO_RT_Protocols_Hooks::set_thread_native_priority (
                          ACE_TEXT ("(%N,%l) Error setting thread ")
                          ACE_TEXT ("priority to %d, errno %d %m\n"),
                          native_priority,
-                         errno ),
+                         ACE_ERRNO_GET),
                        -1);
     }
 
   return 0;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 ACE_STATIC_SVC_DEFINE (TAO_RT_Protocols_Hooks,
                        ACE_TEXT ("RT_Protocols_Hooks"),
@@ -694,4 +647,6 @@ ACE_STATIC_SVC_DEFINE (TAO_RT_Protocols_Hooks,
                        0)
 ACE_FACTORY_DEFINE (TAO_RTCORBA, TAO_RT_Protocols_Hooks)
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
