@@ -4,9 +4,10 @@
 /**
  *  @file    Thread_Pool.h
  *
- *  Thread_Pool.h,v 1.10 2005/01/05 10:10:09 jwillemsen Exp
+ *  $Id: Thread_Pool.h 80216 2007-12-10 08:15:33Z johnnyw $
  *
  *  @author Irfan Pyarali
+ *  @author Johnny Willemsen
  */
 // ===================================================================
 
@@ -22,16 +23,16 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#define TAO_RTCORBA_SAFE_INCLUDE
-#include "RTCORBAC.h"
-#undef TAO_RTCORBA_SAFE_INCLUDE
-
+#include "tao/RTCORBA/RTCORBA_includeC.h"
+#include "tao/RTCORBA/RT_ORBInitializer.h"
 #include "ace/Hash_Map_Manager.h"
 #include "tao/Thread_Lane_Resources.h"
 #include "tao/New_Leader_Generator.h"
 #include "ace/Task.h"
 #include "ace/Null_Mutex.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_Thread_Lane;
 
 /**
@@ -63,12 +64,12 @@ private:
 /**
  * @class TAO_Thread_Pool_Threads
  *
- * @brief Class representing a thread running in a thread lane.
+ * @brief Class representing a static thread running in a thread lane.
  *
  * \nosubgrouping
  *
  **/
-class TAO_RTCORBA_Export TAO_Thread_Pool_Threads : public ACE_Task_Base
+class TAO_Thread_Pool_Threads : public ACE_Task_Base
 {
 public:
 
@@ -85,12 +86,33 @@ public:
   static void set_tss_resources (TAO_ORB_Core &orb_core,
                                  TAO_Thread_Lane &thread_lane);
 
-private:
+protected:
+  /// Do the real work
+  virtual int run (TAO_ORB_Core &orb_core);
 
   /// Lane to which this thread belongs to.
   TAO_Thread_Lane &lane_;
 };
 
+/**
+ * @class TAO_Dynamic_Thread_Pool_Threads
+ *
+ * @brief Class representing a dynamic thread running in a thread lane.
+ *
+ * \nosubgrouping
+ *
+ **/
+class TAO_Dynamic_Thread_Pool_Threads : public TAO_Thread_Pool_Threads
+{
+public:
+  /// Constructor.
+  TAO_Dynamic_Thread_Pool_Threads (TAO_Thread_Lane &lane);
+
+protected:
+  /// Do the real work
+  virtual int run (TAO_ORB_Core &orb_core);
+};
+
 class TAO_Thread_Pool;
 
 /**
@@ -104,20 +126,20 @@ class TAO_Thread_Pool;
 class TAO_RTCORBA_Export TAO_Thread_Lane
 {
 public:
-
   /// Constructor.
   TAO_Thread_Lane (TAO_Thread_Pool &pool,
                    CORBA::ULong id,
                    CORBA::Short lane_priority,
                    CORBA::ULong static_threads,
-                   CORBA::ULong dynamic_threads
-                   ACE_ENV_ARG_DECL);
+                   CORBA::ULong dynamic_threads,
+                   TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                   ACE_Time_Value const &dynamic_thread_time);
 
   /// Destructor.
   ~TAO_Thread_Lane (void);
 
   /// Open the lane.
-  void open (ACE_ENV_SINGLE_ARG_DECL);
+  void open (void);
 
   /// Finalize the resources.
   void finalize (void);
@@ -134,13 +156,25 @@ public:
   /// Create the static threads - only called once.
   int create_static_threads (void);
 
-  /// Create @a number_of_threads of dynamic threads.  Can be called
-  /// multiple times.
-  int create_dynamic_threads (CORBA::ULong number_of_threads);
+  /// Mark that this lane is shutting down, we then don't create any
+  /// dynamic threads anymore. When the pool is shutting down the leader
+  /// follower loop is called which can cause a request to create a
+  /// new dynamic thread but we shouldn't create a new one.
+  void shutting_down (void);
+
+  /// Called by the TAO_RT_New_Leader_Generator to request a new dynamic
+  /// thread.
+  /**
+   * It can be that no thread can be created because the number of
+   * threads is equal to the maximum we can have or the Thread Lane
+   * is shutting down.
+   * @retval true A new thread is created
+   * @retval false No thread could be created
+   */
+  bool new_dynamic_thread (void);
 
   /// @name Accessors
   // @{
-
   TAO_Thread_Pool &pool (void) const;
   CORBA::ULong id (void) const;
 
@@ -149,37 +183,65 @@ public:
   CORBA::ULong dynamic_threads (void) const;
 
   CORBA::ULong current_threads (void) const;
-  void current_threads (CORBA::ULong);
 
   CORBA::Short native_priority (void) const;
 
-  TAO_Thread_Pool_Threads &threads (void);
-
   TAO_Thread_Lane_Resources &resources (void);
 
+  TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan (void) const;
+
+  ACE_Time_Value const &dynamic_thread_time (void) const;
   // @}
 
 private:
 
   /// Validate lane's priority and map it to a native value.
-  void validate_and_map_priority (ACE_ENV_SINGLE_ARG_DECL);
+  void validate_and_map_priority (void);
 
+  int create_threads_i (TAO_Thread_Pool_Threads &thread_pool,
+                        CORBA::ULong number_of_threads,
+                        long thread_flags);
+
+  /// Create @a number_of_threads of dynamic threads.  Can be called
+  /// multiple times.
+  int create_dynamic_threads (CORBA::ULong number_of_threads);
+
+  /// The Thread Pool to which this lane belongs.
   TAO_Thread_Pool &pool_;
-  CORBA::ULong id_;
+
+  /// The id of this lane
+  CORBA::ULong const id_;
 
   CORBA::Short lane_priority_;
-  CORBA::ULong static_threads_;
-  CORBA::ULong dynamic_threads_;
 
-  CORBA::ULong current_threads_;
+  /// This boolean is set when we are shutting down, then we will not create
+  /// any new dynamic threads
+  bool shutdown_;
 
-  TAO_Thread_Pool_Threads threads_;
+  /// Number of static threads
+  CORBA::ULong const static_threads_number_;
+
+  /// Maximum number of threads we are allowed to create
+  CORBA::ULong const dynamic_threads_number_;
+
+  /// Array with all static threads
+  TAO_Thread_Pool_Threads static_threads_;
+
+  /// Array with all dynamic threads
+  TAO_Dynamic_Thread_Pool_Threads dynamic_threads_;
 
   TAO_RT_New_Leader_Generator new_thread_generator_;
 
   TAO_Thread_Lane_Resources resources_;
 
   CORBA::Short native_priority_;
+
+  TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan const lifespan_;
+
+  ACE_Time_Value const dynamic_thread_time_;
+
+  /// Lock to guard all members of the lane
+  mutable TAO_SYNCH_MUTEX lock_;
 };
 
 class TAO_Thread_Pool_Manager;
@@ -195,8 +257,6 @@ class TAO_Thread_Pool_Manager;
  **/
 class TAO_RTCORBA_Export TAO_Thread_Pool
 {
-  friend class TAO_Thread_Lane;
-
 public:
 
   /// Constructor (for pools without lanes).
@@ -208,8 +268,9 @@ public:
                    CORBA::Short default_priority,
                    CORBA::Boolean allow_request_buffering,
                    CORBA::ULong max_buffered_requests,
-                   CORBA::ULong max_request_buffer_size
-                   ACE_ENV_ARG_DECL);
+                   CORBA::ULong max_request_buffer_size,
+                   TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                   ACE_Time_Value const &dynamic_thread_time);
 
   /// Constructor (for pools with lanes).
   TAO_Thread_Pool (TAO_Thread_Pool_Manager &manager,
@@ -219,14 +280,15 @@ public:
                    CORBA::Boolean allow_borrowing,
                    CORBA::Boolean allow_request_buffering,
                    CORBA::ULong max_buffered_requests,
-                   CORBA::ULong max_request_buffer_size
-                   ACE_ENV_ARG_DECL);
+                   CORBA::ULong max_request_buffer_size,
+                   TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                   ACE_Time_Value const &dynamic_thread_time);
 
   /// Destructor.
   ~TAO_Thread_Pool (void);
 
   /// Open the pool.
-  void open (ACE_ENV_SINGLE_ARG_DECL);
+  void open (void);
 
   /// Finalize the resources.
   void finalize (void);
@@ -237,6 +299,9 @@ public:
   /// Wait for threads to exit.
   void wait (void);
 
+  /// Mark this thread pool that we are shutting down.
+  void shutting_down (void);
+
   /// Does @a mprofile belong to us?
   int is_collocated (const TAO_MProfile &mprofile);
 
@@ -244,7 +309,7 @@ public:
   int create_static_threads (void);
 
   /// Check if this thread pool has (explicit) lanes.
-  int with_lanes (void) const;
+  bool with_lanes (void) const;
 
   /// @name Accessors
   // @{
@@ -260,7 +325,6 @@ public:
 
   TAO_Thread_Lane **lanes (void);
   CORBA::ULong number_of_lanes (void) const;
-
   // @}
 
 private:
@@ -273,10 +337,12 @@ private:
   CORBA::Boolean allow_request_buffering_;
   CORBA::ULong max_buffered_requests_;
   CORBA::ULong max_request_buffer_size_;
+  TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan const lifespan_;
+  ACE_Time_Value const dynamic_thread_time_;
 
   TAO_Thread_Lane **lanes_;
   CORBA::ULong number_of_lanes_;
-  int with_lanes_;
+  bool with_lanes_;
 };
 
 class TAO_ORB_Core;
@@ -319,9 +385,9 @@ public:
                      RTCORBA::Priority default_priority,
                      CORBA::Boolean allow_request_buffering,
                      CORBA::ULong max_buffered_requests,
-                     CORBA::ULong max_request_buffer_size
-                     ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                     CORBA::ULong max_request_buffer_size,
+                     TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                     ACE_Time_Value const &dynamic_thread_time);
 
   /// Create a threadpool with lanes.
   RTCORBA::ThreadpoolId
@@ -330,28 +396,21 @@ public:
                                 CORBA::Boolean allow_borrowing,
                                 CORBA::Boolean allow_request_buffering,
                                 CORBA::ULong max_buffered_requests,
-                                CORBA::ULong max_request_buffer_size
-                                ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                                CORBA::ULong max_request_buffer_size,
+                                TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                                ACE_Time_Value const &dynamic_thread_time);
 
   /// Destroy a threadpool.
-  void destroy_threadpool (RTCORBA::ThreadpoolId threadpool
-                           ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     RTCORBA::RTORB::InvalidThreadpool));
+  void destroy_threadpool (RTCORBA::ThreadpoolId threadpool);
+
+  TAO_Thread_Pool *get_threadpool (RTCORBA::ThreadpoolId thread_pool_id);
 
   /// Collection of thread pools.
   typedef ACE_Hash_Map_Manager<RTCORBA::ThreadpoolId, TAO_Thread_Pool *, ACE_Null_Mutex> THREAD_POOLS;
 
   /// @name Accessors
   // @{
-
-  ACE_SYNCH_MUTEX &lock (void);
-
   TAO_ORB_Core &orb_core (void) const;
-
-  THREAD_POOLS &thread_pools (void);
-
   // @}
 
 private:
@@ -366,9 +425,9 @@ private:
                        RTCORBA::Priority default_priority,
                        CORBA::Boolean allow_request_buffering,
                        CORBA::ULong max_buffered_requests,
-                       CORBA::ULong max_request_buffer_size
-                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                       CORBA::ULong max_request_buffer_size,
+                       TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                       ACE_Time_Value const &dynamic_thread_time);
 
   RTCORBA::ThreadpoolId
   create_threadpool_with_lanes_i (CORBA::ULong stacksize,
@@ -376,29 +435,29 @@ private:
                                   CORBA::Boolean allow_borrowing,
                                   CORBA::Boolean allow_request_buffering,
                                   CORBA::ULong max_buffered_requests,
-                                  CORBA::ULong max_request_buffer_size
-                                  ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-
-  void destroy_threadpool_i (RTCORBA::ThreadpoolId threadpool
-                             ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     RTCORBA::RTORB::InvalidThreadpool));
+                                  CORBA::ULong max_request_buffer_size,
+                                  TAO_RT_ORBInitializer::TAO_RTCORBA_DT_LifeSpan lifespan,
+                                  ACE_Time_Value const &dynamic_thread_time);
 
   RTCORBA::ThreadpoolId
-  create_threadpool_helper (TAO_Thread_Pool *thread_pool
-                            ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-
+  create_threadpool_helper (TAO_Thread_Pool *thread_pool);
   // @}
 
+private:
+
   TAO_ORB_Core &orb_core_;
 
   THREAD_POOLS thread_pools_;
   RTCORBA::ThreadpoolId thread_pool_id_counter_;
-  ACE_SYNCH_MUTEX lock_;
+  TAO_SYNCH_MUTEX lock_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
+#if defined (__ACE_INLINE__)
+#include "tao/RTCORBA/Thread_Pool.inl"
+#endif /* __ACE_INLINE__ */
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #include /**/ "ace/post.h"
