@@ -1,9 +1,10 @@
 // -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file    RT_Acceptor_Filters.h
  *
- *  RT_Acceptor_Filters.h,v 1.11 2005/01/05 10:49:48 jwillemsen Exp
+ *  $Id: RT_Acceptor_Filters.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *  RTCORBA strategies for populating mprofile.
  *
@@ -24,13 +25,15 @@
 
 #if defined (TAO_HAS_CORBA_MESSAGING) && TAO_HAS_CORBA_MESSAGING != 0
 
-#include "rtportableserver_export.h"
+#include "tao/RTPortableServer/rtportableserver_export.h"
 #include "tao/Acceptor_Filter.h"
 
 #define TAO_RTCORBA_SAFE_INCLUDE
 #include "tao/RTCORBA/RTCORBAC.h"
 #undef TAO_RTCORBA_SAFE_INCLUDE
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_Acceptor;
 
 /**
@@ -63,6 +66,8 @@ private:
   RTCORBA::ProtocolList &protocols_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_CORBA_MESSAGING && TAO_HAS_CORBA_MESSAGING != 0 */
 
 #include /**/ "ace/post.h"
