@@ -1,5 +1,5 @@
-#include "Current.h"
-#include "Distributable_Thread.h"
+#include "tao/RTScheduling/Current.h"
+#include "tao/RTScheduling/Distributable_Thread.h"
 #include "tao/RTCORBA/Priority_Mapping_Manager.h"
 #include "tao/RTCORBA/RT_Current.h"
 #include "tao/ORB_Core.h"
@@ -11,8 +11,9 @@
 
 ACE_RCSID (RTScheduling,
            Current,
-           "Current.cpp,v 1.29 2005/07/22 12:04:40 jwillemsen Exp")
+           "$Id: Current.cpp 76995 2007-02-11 12:51:42Z johnnyw $")
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 ACE_Atomic_Op<TAO_SYNCH_MUTEX, long> TAO_RTScheduler_Current::guid_counter;
 
@@ -25,13 +26,14 @@ TAO_DTId_Hash::operator () (const IdType &id) const
 
 TAO_RTScheduler_Current::TAO_RTScheduler_Current (void)
 {
-
 }
 
+TAO_RTScheduler_Current::~TAO_RTScheduler_Current (void)
+{
+}
 
 void
-TAO_RTScheduler_Current::init (TAO_ORB_Core* orb
-                               ACE_ENV_ARG_DECL)
+TAO_RTScheduler_Current::init (TAO_ORB_Core* orb)
 {
   this->orb_ = orb;
 
@@ -69,10 +71,7 @@ void
 TAO_RTScheduler_Current::begin_scheduling_segment (
     const char * name,
     CORBA::Policy_ptr sched_param,
-    CORBA::Policy_ptr implicit_sched_param
-    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTScheduling::Current::UNSUPPORTED_SCHEDULING_DISCIPLINE))
+    CORBA::Policy_ptr implicit_sched_param)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
@@ -86,7 +85,6 @@ TAO_RTScheduler_Current::begin_scheduling_segment (
                                           TAO::VMCID,
                                           ENOMEM),
                                           CORBA::COMPLETED_NO));
-      ACE_CHECK;
 
       this->implementation (impl);
     }
@@ -94,8 +92,7 @@ TAO_RTScheduler_Current::begin_scheduling_segment (
   impl->begin_scheduling_segment (name,
                                   sched_param,
                                   implicit_sched_param
-                                  ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                 );
 }
 
 
@@ -103,26 +100,21 @@ void
 TAO_RTScheduler_Current::update_scheduling_segment (const char * name,
                                                     CORBA::Policy_ptr sched_param,
                                                     CORBA::Policy_ptr implicit_sched_param
-                                                    ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTScheduling::Current::UNSUPPORTED_SCHEDULING_DISCIPLINE))
+                                                    )
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
   if (impl == 0)
-    ACE_THROW (CORBA::BAD_INV_ORDER ());
+    throw ::CORBA::BAD_INV_ORDER ();
 
   impl->update_scheduling_segment (name,
                                    sched_param,
                                    implicit_sched_param
-                                   ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                  );
 }
 
 void
-TAO_RTScheduler_Current::end_scheduling_segment (const char * name
-                                                 ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::end_scheduling_segment (const char * name)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
@@ -130,19 +122,16 @@ TAO_RTScheduler_Current::end_scheduling_segment (const char * name
     {
       ACE_ERROR ((LM_ERROR,
                   "Missing scheduling context OR DT cancelled\n"));
-      ACE_THROW (CORBA::BAD_INV_ORDER ());
+      throw ::CORBA::BAD_INV_ORDER ();
       return;
     }
 
   impl->end_scheduling_segment (name
-                                ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                               );
 }
 
 RTScheduling::DistributableThread_ptr
-TAO_RTScheduler_Current::lookup(const RTScheduling::Current::IdType & id
-                                ACE_ENV_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::lookup(const RTScheduling::Current::IdType & id)
 {
   RTScheduling::DistributableThread_var DT;
   int result = this->dt_hash_.find (id,
@@ -163,14 +152,12 @@ TAO_RTScheduler_Current::spawn (RTScheduling::ThreadAction_ptr start,
                                 CORBA::Policy_ptr sched_param,
                                 CORBA::Policy_ptr implicit_sched_param,
                                 CORBA::ULong stack_size,
-                                RTCORBA::Priority base_priority
-                                ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                RTCORBA::Priority base_priority)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
   if (impl == 0)
-    ACE_THROW_RETURN (CORBA::BAD_INV_ORDER (), 0);
+    throw ::CORBA::BAD_INV_ORDER ();
 
   return impl->spawn (start,
                       data,
@@ -179,79 +166,71 @@ TAO_RTScheduler_Current::spawn (RTScheduling::ThreadAction_ptr start,
                       implicit_sched_param,
                       stack_size,
                       base_priority
-                      ACE_ENV_ARG_PARAMETER);
+                     );
 }
 
 RTScheduling::Current::IdType *
-TAO_RTScheduler_Current::id (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::id (void)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
   if (impl == 0)
-    ACE_THROW_RETURN (CORBA::BAD_INV_ORDER (), 0);
+    throw ::CORBA::BAD_INV_ORDER ();
 
-  return impl->id (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return impl->id ();
 }
 
 CORBA::Policy_ptr
-TAO_RTScheduler_Current::scheduling_parameter (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::scheduling_parameter (void)
 {
 
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
   if (impl == 0)
-    ACE_THROW_RETURN (CORBA::BAD_INV_ORDER (), 0);
+    throw ::CORBA::BAD_INV_ORDER ();
 
-  return impl->scheduling_parameter (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return impl->scheduling_parameter ();
 }
 
 CORBA::Policy_ptr
-TAO_RTScheduler_Current::implicit_scheduling_parameter (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::implicit_scheduling_parameter (void)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
   if (impl == 0)
-    ACE_THROW_RETURN (CORBA::BAD_INV_ORDER (), 0);
+    throw ::CORBA::BAD_INV_ORDER ();
 
-  return impl->implicit_scheduling_parameter (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return impl->implicit_scheduling_parameter ();
 }
 
 RTScheduling::Current::NameList *
-TAO_RTScheduler_Current::current_scheduling_segment_names (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::current_scheduling_segment_names (void)
 {
   TAO_RTScheduler_Current_i *impl = this->implementation ();
 
   if (impl == 0)
-    ACE_THROW_RETURN (CORBA::BAD_INV_ORDER (), 0);
+    throw ::CORBA::BAD_INV_ORDER ();
 
-  return impl->current_scheduling_segment_names (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return impl->current_scheduling_segment_names ();
 }
 
 RTCORBA::Priority
-TAO_RTScheduler_Current::the_priority (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::the_priority (void)
 {
-  return this->rt_current_->the_priority (ACE_ENV_SINGLE_ARG_PARAMETER);
+  return this->rt_current_->the_priority ();
 }
 
 void
-TAO_RTScheduler_Current::the_priority (RTCORBA::Priority the_priority
-                                       ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current::the_priority (RTCORBA::Priority the_priority)
 {
-  this->rt_current_->the_priority(the_priority
-                                  ACE_ENV_ARG_PARAMETER);
+  this->rt_current_->the_priority(the_priority);
 }
 
 TAO_RTScheduler_Current_i*
 TAO_RTScheduler_Current::implementation (TAO_RTScheduler_Current_i* new_current)
 {
   TAO_TSS_Resources *tss =
-    TAO_TSS_RESOURCES::instance ();
+    TAO_TSS_Resources::instance ();
 
   TAO_RTScheduler_Current_i *old =
     static_cast<TAO_RTScheduler_Current_i *> (tss->rtscheduler_current_impl_);
@@ -264,7 +243,7 @@ TAO_RTScheduler_Current_i*
 TAO_RTScheduler_Current::implementation (void)
 {
   TAO_TSS_Resources *tss =
-    TAO_TSS_RESOURCES::instance ();
+    TAO_TSS_Resources::instance ();
 
   TAO_RTScheduler_Current_i* impl =
     static_cast<TAO_RTScheduler_Current_i *> (tss->rtscheduler_current_impl_);
@@ -290,8 +269,7 @@ TAO_RTScheduler_Current_i::scheduler (void)
 }
 
 TAO_RTScheduler_Current_i::TAO_RTScheduler_Current_i (TAO_ORB_Core* orb,
-                                                      DT_Hash_Map* dt_hash
-                                                      ACE_ENV_ARG_DECL)
+                                                      DT_Hash_Map* dt_hash)
   :orb_ (orb),
    dt_ (RTScheduling::DistributableThread::_nil ()),
    previous_current_ (0),
@@ -301,9 +279,7 @@ TAO_RTScheduler_Current_i::TAO_RTScheduler_Current_i (TAO_ORB_Core* orb,
     this->orb_->object_ref_table ().resolve_initial_reference (
       "RTScheduler");
 
-  this->scheduler_ = RTScheduling::Scheduler::_narrow (scheduler_obj.in ()
-                                                       ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->scheduler_ = RTScheduling::Scheduler::_narrow (scheduler_obj.in ());
 }
 
 TAO_RTScheduler_Current_i::TAO_RTScheduler_Current_i (
@@ -314,8 +290,7 @@ TAO_RTScheduler_Current_i::TAO_RTScheduler_Current_i (
   CORBA::Policy_ptr sched_param,
   CORBA::Policy_ptr implicit_sched_param,
   RTScheduling::DistributableThread_ptr dt,
-  TAO_RTScheduler_Current_i* prev_current
-  ACE_ENV_ARG_DECL)
+  TAO_RTScheduler_Current_i* prev_current)
   : orb_ (orb),
     guid_ (guid),
     name_ (CORBA::string_dup (name)),
@@ -325,23 +300,23 @@ TAO_RTScheduler_Current_i::TAO_RTScheduler_Current_i (
     previous_current_ (prev_current),
     dt_hash_ (dt_hash)
 {
-  CORBA::Object_ptr scheduler_obj =
+  CORBA::Object_var scheduler_obj =
     orb->object_ref_table ().resolve_initial_reference (
       "RTScheduler");
 
-  this->scheduler_ = RTScheduling::Scheduler::_narrow (scheduler_obj
-                                                       ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+  this->scheduler_ = RTScheduling::Scheduler::_narrow (scheduler_obj.in ()
+                                                      );
+}
+
+TAO_RTScheduler_Current_i::~TAO_RTScheduler_Current_i (void)
+{
 }
 
 void
 TAO_RTScheduler_Current_i::begin_scheduling_segment(
   const char * name,
   CORBA::Policy_ptr sched_param,
-  CORBA::Policy_ptr implicit_sched_param
-  ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTScheduling::Current::UNSUPPORTED_SCHEDULING_DISCIPLINE))
+  CORBA::Policy_ptr implicit_sched_param)
 {
   // Check if it is a new Scheduling Segmnet
   if (this->guid_.length () == 0)
@@ -364,8 +339,7 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
                                                       name,
                                                       sched_param,
                                                       implicit_sched_param
-                                                      ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                                     );
 
       if (CORBA::is_nil (this->dt_.in ()))
         //Create new DT.
@@ -378,8 +352,7 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
       // Error in binding to the map - cancel thread.
       if (result != 0)
         {
-          this->cancel_thread (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_CHECK;
+          this->cancel_thread ();
         }
 
       // Remember parameters for the scheduling segment.
@@ -393,8 +366,7 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
       // Check current DT state.
       if (this->dt_->state () == RTScheduling::DistributableThread::CANCELLED)
         {
-          this->cancel_thread (ACE_ENV_SINGLE_ARG_PARAMETER);
-          ACE_CHECK;
+          this->cancel_thread ();
         }
 
       // Inform scheduler of start of nested scheduling segment.
@@ -403,13 +375,12 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
          name,
          sched_param,
          implicit_sched_param
-         ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+        );
 
       TAO_TSS_Resources *tss =
-        TAO_TSS_RESOURCES::instance ();
+        TAO_TSS_Resources::instance ();
 
-      TAO_RTScheduler_Current_i* new_current;
+      TAO_RTScheduler_Current_i* new_current = 0;
         ACE_NEW_THROW_EX (new_current,
                           TAO_RTScheduler_Current_i (this->orb_,
                                                      this->dt_hash_,
@@ -424,7 +395,6 @@ TAO_RTScheduler_Current_i::begin_scheduling_segment(
                                           TAO::VMCID,
                                           ENOMEM),
                                           CORBA::COMPLETED_NO));
-        ACE_CHECK;
 
       tss->rtscheduler_current_impl_ = new_current;
     }
@@ -434,15 +404,12 @@ void
 TAO_RTScheduler_Current_i::update_scheduling_segment (const char * name,
                                                       CORBA::Policy_ptr sched_param,
                                                       CORBA::Policy_ptr implicit_sched_param
-                                                      ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException,
-                   RTScheduling::Current::UNSUPPORTED_SCHEDULING_DISCIPLINE))
+                                                      )
 {
   // Check if DT has been cancelled
   if (this->dt_->state () == RTScheduling::DistributableThread::CANCELLED)
     {
-      this->cancel_thread (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
+      this->cancel_thread ();
     }
 
   // Let scheduler know of the updates.
@@ -450,8 +417,7 @@ TAO_RTScheduler_Current_i::update_scheduling_segment (const char * name,
                                                name,
                                                sched_param,
                                                implicit_sched_param
-                                               ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                                              );
 
   // Remember the new values.
   this->name_ = CORBA::string_dup (name);
@@ -460,15 +426,12 @@ TAO_RTScheduler_Current_i::update_scheduling_segment (const char * name,
 }
 
 void
-TAO_RTScheduler_Current_i::end_scheduling_segment (const char * name
-                                                   ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current_i::end_scheduling_segment (const char * name)
 {
   // Check if DT has been cancelled
   if (this->dt_->state () == RTScheduling::DistributableThread::CANCELLED)
     {
-      this->cancel_thread (ACE_ENV_SINGLE_ARG_PARAMETER);
-      ACE_CHECK;
+      this->cancel_thread ();
     }
 
   if (this->previous_current_ == 0)
@@ -477,8 +440,7 @@ TAO_RTScheduler_Current_i::end_scheduling_segment (const char * name
       // terminating.
       this->scheduler_->end_scheduling_segment(this->guid_,
                                                name
-                                               ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                              );
 
       // Cleanup DT.
       this->cleanup_DT ();
@@ -494,8 +456,7 @@ TAO_RTScheduler_Current_i::end_scheduling_segment (const char * name
       this->scheduler_->end_nested_scheduling_segment (this->guid_,
                                                        name,
                                                        this->previous_current_->sched_param_
-                                                       ACE_ENV_ARG_PARAMETER);
-      ACE_CHECK;
+                                                      );
 
       // Cleanup current.
       this->cleanup_current ();
@@ -514,15 +475,16 @@ TAO_RTScheduler_Current_i::spawn (RTScheduling::ThreadAction_ptr start,
                                   CORBA::Policy_ptr implicit_sched_param,
                                   CORBA::ULong stack_size,
                                   RTCORBA::Priority base_priority
-                                  ACE_ENV_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+                                  )
 {
   // Check if DT has been cancelled.
   if (this->dt_->state () == RTScheduling::DistributableThread::CANCELLED)
-    this->cancel_thread (ACE_ENV_SINGLE_ARG_PARAMETER);
+    {
+      this->cancel_thread ();
+    }
 
   // Create new task for new DT.
-  DTTask *dttask;
+  DTTask *dttask = 0;
 
   // If no scheduling parameter is specified then use the current
   // implicit scheduling parameter as the scheduling parameter
@@ -530,7 +492,7 @@ TAO_RTScheduler_Current_i::spawn (RTScheduling::ThreadAction_ptr start,
     sched_param = this->implicit_sched_param_;
 
   RTScheduling::DistributableThread_var dt = TAO_DistributableThread_Factory::create_DT ();
-  TAO_RTScheduler_Current_i *new_current;
+  TAO_RTScheduler_Current_i *new_current = 0;
 
   ACE_NEW_RETURN (new_current,
                   TAO_RTScheduler_Current_i (this->orb_,
@@ -566,7 +528,7 @@ TAO_RTScheduler_Current_i::spawn (RTScheduling::ThreadAction_ptr start,
 int
 DTTask::activate_task (RTCORBA::Priority base_priority,
                        CORBA::ULong stack_size
-                       ACE_ENV_ARG_DECL)
+                       )
 {
   // Activate thread.
   long default_flags = THR_NEW_LWP | THR_JOINABLE;
@@ -581,8 +543,7 @@ DTTask::activate_task (RTCORBA::Priority base_priority,
 
   RTCORBA::PriorityMappingManager_var mapping_manager =
     RTCORBA::PriorityMappingManager::_narrow (object.in ()
-                                              ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK_RETURN (-1);
+                                             );
 
   RTCORBA::PriorityMapping *pm =
     mapping_manager->mapping ();
@@ -612,8 +573,7 @@ DTTask::activate_task (RTCORBA::Priority base_priority,
   return 0;
 }
 
-DTTask::DTTask (//ACE_Thread_Manager *manager,
-                TAO_ORB_Core *orb,
+DTTask::DTTask (TAO_ORB_Core *orb,
                 DT_Hash_Map *dt_hash,
                 TAO_RTScheduler_Current_i* new_current,
                 RTScheduling::ThreadAction_ptr start,
@@ -621,8 +581,7 @@ DTTask::DTTask (//ACE_Thread_Manager *manager,
                 const char *name,
                 CORBA::Policy_ptr sched_param,
                 CORBA::Policy_ptr implicit_sched_param)
-  ://manager_ (manager),
-   orb_ (orb),
+  :orb_ (orb),
    dt_hash_ (dt_hash),
    current_ (new_current),
    start_ (RTScheduling::ThreadAction::_duplicate (start)),
@@ -633,47 +592,45 @@ DTTask::DTTask (//ACE_Thread_Manager *manager,
 {
 }
 
+DTTask::~DTTask (void)
+{
+  delete this->current_;
+}
+
 int
 DTTask::svc (void)
 {
-  ACE_TRY_NEW_ENV
+  try
     {
 
       TAO_TSS_Resources *tss =
-        TAO_TSS_RESOURCES::instance ();
+        TAO_TSS_Resources::instance ();
 
       tss->rtscheduler_current_impl_ = this->current_;
 
       this->current_->begin_scheduling_segment (this->name_.in (),
                                                 this->sched_param_.in (),
                                                 this->implicit_sched_param_.in ()
-                                                ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                               );
 
       // Invoke entry point into new DT.
       this->start_->_cxx_do (this->data_
-                             ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                            );
 
       this->current_->end_scheduling_segment (this->name_.in ()
-                                             ACE_ENV_ARG_PARAMETER);
-      ACE_TRY_CHECK;
+                                            );
     }
-  ACE_CATCHANY
+  catch (const ::CORBA::Exception& ex)
     {
-      ACE_PRINT_EXCEPTION (ACE_ANY_EXCEPTION,
-                           "Caught exception:");
+      ex._tao_print_exception ("Caught exception:");
       return -1;
     }
-  ACE_ENDTRY;
 
   return 0;
 }
 
-
 RTScheduling::Current::IdType *
-TAO_RTScheduler_Current_i::id (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current_i::id (void)
 {
 
   RTScheduling::Current::IdType_var guid = this->guid_;
@@ -682,22 +639,19 @@ TAO_RTScheduler_Current_i::id (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
 
 
 CORBA::Policy_ptr
-TAO_RTScheduler_Current_i::scheduling_parameter (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current_i::scheduling_parameter (void)
 {
   return CORBA::Policy::_duplicate (this->sched_param_);
 }
 
 CORBA::Policy_ptr
-TAO_RTScheduler_Current_i::implicit_scheduling_parameter (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current_i::implicit_scheduling_parameter (void)
 {
   return CORBA::Policy::_duplicate (this->implicit_sched_param_);
 }
 
 RTScheduling::Current::NameList *
-TAO_RTScheduler_Current_i::current_scheduling_segment_names (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current_i::current_scheduling_segment_names (void)
 {
   RTScheduling::Current::NameList* name_list;
   ACE_NEW_RETURN (name_list,
@@ -722,13 +676,12 @@ TAO_RTScheduler_Current_i::name (void)
   return CORBA::string_dup (this->name_.in ());
 }
 
-#if defined (ACE_HAS_PREDEFINED_THREAD_CANCELLED_MACRO)
+#if defined (THREAD_CANCELLED)
 #undef THREAD_CANCELLED
-#endif /* ACE_HAS_PREDEFINED_THREAD_CANCELLED_MACRO */
+#endif /* THREAD_CANCELLED */
 
 void
-TAO_RTScheduler_Current_i::cancel_thread (ACE_ENV_SINGLE_ARG_DECL)
-  ACE_THROW_SPEC ((CORBA::SystemException))
+TAO_RTScheduler_Current_i::cancel_thread (void)
 {
   size_t guid;
   ACE_OS::memcpy (&guid,
@@ -742,8 +695,7 @@ TAO_RTScheduler_Current_i::cancel_thread (ACE_ENV_SINGLE_ARG_DECL)
   // Let the scheduler know that the thread has
   // been cancelled.
   this->scheduler_->cancel (this->guid_
-                            ACE_ENV_ARG_PARAMETER);
-  ACE_CHECK;
+                           );
 
   this->cleanup_DT ();
 
@@ -751,7 +703,7 @@ TAO_RTScheduler_Current_i::cancel_thread (ACE_ENV_SINGLE_ARG_DECL)
   this->delete_all_currents ();
 
   // Throw exception.
-  ACE_THROW (CORBA::THREAD_CANCELLED ());
+  throw ::CORBA::THREAD_CANCELLED ();
 }
 
 void
@@ -765,7 +717,7 @@ void
 TAO_RTScheduler_Current_i::cleanup_current (void)
 {
   TAO_TSS_Resources *tss =
-    TAO_TSS_RESOURCES::instance ();
+    TAO_TSS_Resources::instance ();
 
   tss->rtscheduler_current_impl_ = this->previous_current_;
 
@@ -786,7 +738,7 @@ TAO_RTScheduler_Current_i::delete_all_currents (void)
     }
 
   TAO_TSS_Resources *tss =
-    TAO_TSS_RESOURCES::instance ();
+    TAO_TSS_Resources::instance ();
 
   tss->rtscheduler_current_impl_ = tss->rtscheduler_previous_current_impl_;
 }
@@ -798,7 +750,7 @@ TAO_RTScheduler_Current_i::id (RTScheduling::Current::IdType guid)
 }
 
 void
-TAO_RTScheduler_Current_i::name (char * name)
+TAO_RTScheduler_Current_i::name (const char * name)
 {
   this->name_ = CORBA::string_dup (name);
 }
@@ -851,13 +803,13 @@ TAO_RTScheduler_Current_var::TAO_RTScheduler_Current_var (const ::TAO_RTSchedule
 
 TAO_RTScheduler_Current_var::~TAO_RTScheduler_Current_var (void) // destructor
 {
-  CORBA::release (this->ptr_);
+  ::CORBA::release (this->ptr_);
 }
 
 TAO_RTScheduler_Current_var &
 TAO_RTScheduler_Current_var::operator= (TAO_RTScheduler_Current_ptr p)
 {
-  CORBA::release (this->ptr_);
+  ::CORBA::release (this->ptr_);
   this->ptr_ = p;
   return *this;
 }
@@ -867,7 +819,7 @@ TAO_RTScheduler_Current_var::operator= (const ::TAO_RTScheduler_Current_var &p)
 {
   if (this != &p)
   {
-    CORBA::release (this->ptr_);
+    ::CORBA::release (this->ptr_);
     this->ptr_ = ::TAO_RTScheduler_Current::_duplicate (p.ptr ());
   }
   return *this;
@@ -904,7 +856,7 @@ TAO_RTScheduler_Current_var::inout (void)
 TAO_RTScheduler_Current_ptr &
 TAO_RTScheduler_Current_var::out (void)
 {
-  CORBA::release (this->ptr_);
+  ::CORBA::release (this->ptr_);
   this->ptr_ = ::TAO_RTScheduler_Current::_nil ();
   return this->ptr_;
 }
@@ -927,7 +879,7 @@ TAO_RTScheduler_Current_var::duplicate (TAO_RTScheduler_Current_ptr p)
 void
 TAO_RTScheduler_Current_var::release (TAO_RTScheduler_Current_ptr p)
 {
-  CORBA::release (p);
+  ::CORBA::release (p);
 }
 
 TAO_RTScheduler_Current_ptr
@@ -939,10 +891,10 @@ TAO_RTScheduler_Current_var::nil (void)
 TAO_RTScheduler_Current_ptr
 TAO_RTScheduler_Current_var::narrow (
     CORBA::Object *p
-    ACE_ENV_ARG_DECL
+
   )
 {
-  return ::TAO_RTScheduler_Current::_narrow (p ACE_ENV_ARG_PARAMETER);
+  return ::TAO_RTScheduler_Current::_narrow (p);
 }
 
 CORBA::Object *
@@ -955,7 +907,7 @@ TAO_RTScheduler_Current_var::upcast (void *src)
 
 TAO_RTScheduler_Current_ptr TAO_RTScheduler_Current::_narrow (
     CORBA::Object_ptr obj
-    ACE_ENV_ARG_DECL_NOT_USED
+
   )
 {
   return
@@ -977,22 +929,4 @@ const char* TAO_RTScheduler_Current::_interface_repository_id (void) const
   return "IDL:TAO_RTScheduler_Current:1.0";
 }
 
-
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_Equal_To<IdType>;
-template class ACE_Hash_Map_Manager_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-template class ACE_Hash_Map_Iterator_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-template class ACE_Hash_Map_Entry<IdType, RTScheduling::DistributableThread_var>;
-template class ACE_Hash_Map_Reverse_Iterator_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-template class ACE_Hash_Map_Iterator_Base_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-#pragma instantiate ACE_Equal_To<IdType>;
-#pragma instantiate ACE_Hash_Map_Manager_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-#pragma instantiate ACE_Hash_Map_Iterator_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-#pragma instantiate ACE_Hash_Map_Entry<IdType, RTScheduling::DistributableThread_var>;
-#pragma instantiate ACE_Hash_Map_Reverse_Iterator_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-#pragma instantiate ACE_Hash_Map_Iterator_Base_Ex<IdType, RTScheduling::DistributableThread_var, TAO_DTId_Hash, ACE_Equal_To<IdType>, TAO_SYNCH_MUTEX>;
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
