@@ -1,10 +1,12 @@
-// RTScheduler.h,v 1.5 2003/10/28 18:29:33 bala Exp
+// -*- C++ -*-
+
+// $Id: RTScheduler.h 71473 2006-03-10 07:19:20Z jtc $
 
 //=============================================================================
 /**
  *  @file RTScheduler.h
  *
- *  RTScheduler.h,v 1.5 2003/10/28 18:29:33 bala Exp
+ *  $Id: RTScheduler.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *   Takes care of the RT Scheduler loading on static build.
  *
@@ -17,13 +19,16 @@
 #define TAO_RTSCHEDULER_H_
 #include /**/ "ace/pre.h"
 
-#include "rtscheduler_export.h"
-
+#include "tao/RTScheduling/rtscheduler_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#include "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_RTScheduler_Export TAO_RTScheduler_Initializer
 {
 public:
@@ -33,8 +38,10 @@ public:
 
 static TAO_RTScheduler_Initializer TAO_RTScheduler_initializer;
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #define TAO_RTSCHEDULER_SAFE_INCLUDE
-#include "RTSchedulerC.h"
+#include "tao/RTScheduling/RTSchedulerC.h"
 #undef TAO_RTSCHEDULER_SAFE_INCLUDE
 
 #include /**/ "ace/post.h"
