@@ -4,7 +4,7 @@
 /**
  *  @file RTScheduler_Initializer.h
  *
- *  $Id: RTScheduler_Initializer.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: RTScheduler_Initializer.h 81455 2008-04-28 10:26:37Z johnnyw $
  *
  *  @author Yamuna Krishnamurthy <yamuna@oomworks.com>
  */
@@ -40,16 +40,15 @@ class TAO_RTScheduler_Current;
 /// RTCORBA ORB initializer.
 class TAO_RTScheduler_ORB_Initializer
   : public virtual PortableInterceptor::ORBInitializer
-  , public virtual TAO_Local_RefCounted_Object
+  , public virtual ::CORBA::LocalObject
 {
 public:
   virtual void pre_init (PortableInterceptor::ORBInitInfo_ptr info);
 
   virtual void post_init (PortableInterceptor::ORBInitInfo_ptr info);
+
 private:
-
   TAO_RTScheduler_Current* current_;
-
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
