@@ -4,7 +4,7 @@
 /**
  *  @file    RTScheduler_Loader.h
  *
- *  $Id: RTScheduler_Loader.h 79914 2007-11-01 10:51:19Z johnnyw $
+ *  $Id: RTScheduler_Loader.h 87582 2009-11-16 16:04:12Z vzykov $
  *
  *   Header file for Loading RTScheduler.
  *
@@ -33,11 +33,18 @@ TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 class TAO_RTScheduler_Export TAO_RTScheduler_Loader : public ACE_Service_Object
 {
 public:
+  /// Constructor.
+  TAO_RTScheduler_Loader (void);
+
   /// Destructor.
   virtual ~TAO_RTScheduler_Loader (void);
 
   /// Initialize the RTScheduler loader hooks.
   virtual int init (int argc, ACE_TCHAR* []);
+
+private:
+  /// Set to true after init is called.
+  bool initialized_;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
