@@ -1,6 +1,6 @@
 // -*- C++ -*-
 
-//$Id: ThreadAction.h 76995 2007-02-11 12:51:42Z johnnyw $
+//$Id: ThreadAction.h 88803 2010-02-02 11:13:27Z vzykov $
 #ifndef TAO_ThreadAction_H
 #define TAO_ThreadAction_H
 
@@ -8,19 +8,16 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/RTScheduling/RTSchedulerC.h"
+#include "tao/RTScheduling/RTScheduler.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_RTScheduler_Export TAO_ThreadAction:
-public RTScheduling::ThreadAction,
-  public TAO_Local_RefCounted_Object
+  public RTScheduling::ThreadAction,
+  public ::CORBA::LocalObject
 {
- public:
-
-  virtual void do (CORBA::VoidData data
-       )
-      = 0;
+public:
+  virtual void _cxx_do (CORBA::VoidData data) = 0;
 };
 
 TAO_END_VERSIONED_NAMESPACE_DECL
