@@ -4,7 +4,7 @@
 /**
  *  @file Reactive_Flushing_Strategy.h
  *
- *  Reactive_Flushing_Strategy.h,v 1.6 2003/10/28 18:29:19 bala Exp
+ *  $Id: Reactive_Flushing_Strategy.h 80603 2008-02-11 22:14:39Z johnc $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -15,18 +15,20 @@
 
 #include /**/ "ace/pre.h"
 
-#include "Flushing_Strategy.h"
+#include "tao/Flushing_Strategy.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Reactive_Flushing_Strategy
  *
  * @brief Implement a flushing strategy that uses the reactor.
  */
-class TAO_Export TAO_Reactive_Flushing_Strategy : public TAO_Flushing_Strategy
+class TAO_Reactive_Flushing_Strategy : public TAO_Flushing_Strategy
 {
 public:
   virtual int schedule_output (TAO_Transport *transport);
@@ -34,9 +36,12 @@ public:
   virtual int flush_message (TAO_Transport *transport,
                              TAO_Queued_Message *msg,
                              ACE_Time_Value *max_wait_time);
-  virtual int flush_transport (TAO_Transport *transport);
+  virtual int flush_transport (TAO_Transport *transport
+                               , ACE_Time_Value *max_wait_time);
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_REACTIVE_FLUSHING_STRATEGY_H */
