@@ -4,7 +4,7 @@
 /**
  *  @file    Remote_Invocation.h
  *
- *  $Id: Remote_Invocation.h 80292 2007-12-17 20:38:32Z johnnyw $
+ *  $Id: Remote_Invocation.h 84860 2009-03-17 10:17:38Z johnnyw $
  *
  *
  *  @author Balachandran Natarajan <bala@dre.vanderbilt.edu>
@@ -66,7 +66,7 @@ namespace TAO
   protected:
 
     /// Initialize the @a spec.
-    void init_target_spec (TAO_Target_Specification &spec);
+    void init_target_spec (TAO_Target_Specification &spec, TAO_OutputCDR& output);
 
     /// Write the GIOP header into the stream.
     void write_header (TAO_OutputCDR &out_stream);
@@ -76,7 +76,7 @@ namespace TAO
 
     /// Write the message onto the socket
     Invocation_Status send_message (TAO_OutputCDR &cdr,
-                                    TAO_Transport::TAO_Message_Semantics message_semantics,
+                                    TAO_Message_Semantics message_semantics,
                                     ACE_Time_Value *max_wait_time);
 
   protected:
