@@ -4,7 +4,7 @@
 /**
  *  @file    Remote_Object_Proxy_Broker.h
  *
- *  Remote_Object_Proxy_Broker.h,v 1.9 2005/07/25 18:02:50 jwillemsen Exp
+ *  $Id: Remote_Object_Proxy_Broker.h 76551 2007-01-24 13:42:44Z johnnyw $
  *
  *  This files contains the Remote Proxy Broker implementation
  *  for the CORBA Object.
@@ -26,6 +26,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   /**
@@ -44,24 +46,17 @@ namespace TAO
     /// details.
 
     virtual CORBA::Boolean _is_a (CORBA::Object_ptr target,
-                                  const char *logical_type_id
-                                  ACE_ENV_ARG_DECL);
+                                  const char *logical_type_id);
 
 #if (TAO_HAS_MINIMUM_CORBA == 0)
 
-  virtual CORBA::Boolean _non_existent (CORBA::Object_ptr target
-                                        ACE_ENV_ARG_DECL);
+  virtual CORBA::Boolean _non_existent (CORBA::Object_ptr target);
 
-  virtual CORBA::InterfaceDef * _get_interface (
-      CORBA::Object_ptr target
-      ACE_ENV_ARG_DECL
-    );
+  virtual CORBA::InterfaceDef * _get_interface (CORBA::Object_ptr target);
 
-  virtual CORBA::Object_ptr _get_component (CORBA::Object_ptr target
-                                            ACE_ENV_ARG_DECL);
+  virtual CORBA::Object_ptr _get_component (CORBA::Object_ptr target);
 
-  virtual char * _repository_id (CORBA::Object_ptr target
-                                 ACE_ENV_ARG_DECL);
+  virtual char * _repository_id (CORBA::Object_ptr target);
 #endif /* TAO_HAS_MINIMUM_CORBA == 0 */
 
   };
@@ -71,6 +66,8 @@ namespace TAO
 
 TAO::Remote_Object_Proxy_Broker *the_tao_remote_object_proxy_broker (void);
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_REMOTE_OBJECT_PROXY_BROKER_H */
