@@ -1,4 +1,4 @@
-// $Id: Request_Dispatcher.cpp 76551 2007-01-24 13:42:44Z johnnyw $
+// $Id: Request_Dispatcher.cpp 84215 2009-01-22 18:31:17Z johnnyw $
 
 #include "tao/Request_Dispatcher.h"
 #include "tao/TAO_Server_Request.h"
@@ -6,7 +6,7 @@
 
 ACE_RCSID (tao,
            Request_Dispatcher,
-           "$Id: Request_Dispatcher.cpp 76551 2007-01-24 13:42:44Z johnnyw $")
+           "$Id: Request_Dispatcher.cpp 84215 2009-01-22 18:31:17Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -20,9 +20,9 @@ TAO_Request_Dispatcher::dispatch (TAO_ORB_Core *orb_core,
                                   CORBA::Object_out forward_to)
 {
   // Dispatch based on object key
-  orb_core->adapter_registry ()->dispatch (request.object_key (),
-                                           request,
-                                           forward_to);
+  orb_core->adapter_registry ().dispatch (request.object_key (),
+                                          request,
+                                          forward_to);
 }
 
 TAO_END_VERSIONED_NAMESPACE_DECL
