@@ -1,20 +1,20 @@
-// Resource_Factory.cpp,v 1.42 2005/07/17 21:50:46 mesnier_p Exp
+// $Id: Resource_Factory.cpp 77840 2007-03-29 11:24:54Z johnnyw $
 
-#include "Resource_Factory.h"
-#include "Protocol_Factory.h"
-#include "orbconf.h"
+#include "tao/Resource_Factory.h"
+#include "tao/Protocol_Factory.h"
+#include "tao/orbconf.h"
 
-#include "ace/Dynamic_Service.h"
 #include "ace/ACE.h"
 
-
 ACE_RCSID (tao,
            Resource_Factory,
-           "Resource_Factory.cpp,v 1.42 2005/07/17 21:50:46 mesnier_p Exp")
+           "$Id: Resource_Factory.cpp 77840 2007-03-29 11:24:54Z johnnyw $")
 
 
 // ****************************************************************
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 TAO_Protocol_Item::TAO_Protocol_Item (const ACE_CString &name)
   : name_ (name),
     factory_ (0),
@@ -60,15 +60,6 @@ TAO_Resource_Factory::~TAO_Resource_Factory (void)
 {
 }
 
-#if 0
-// @@todo: Need to go at a later date!
-int
-TAO_Resource_Factory::use_tss_resources (void) const
-{
-  return 0;
-}
-#endif /*if 0*/
-
 int
 TAO_Resource_Factory::use_locked_data_blocks (void) const
 {
@@ -99,6 +90,11 @@ TAO_Resource_Factory::get_acceptor_registry (void)
   return 0;
 }
 
+void
+TAO_Resource_Factory::use_local_memory_pool (bool)
+{
+}
+
 ACE_Allocator *
 TAO_Resource_Factory::input_cdr_dblock_allocator (void)
 {
@@ -191,8 +187,7 @@ TAO_Resource_Factory::max_muxed_connections (void) const
 
 
 int
-TAO_Resource_Factory::get_parser_names (char **&,
-                                        int &)
+TAO_Resource_Factory::get_parser_names (char **&, int &)
 {
   return 0;
 }
@@ -221,26 +216,17 @@ TAO_Resource_Factory::create_corba_object_lock (void)
   return 0;
 }
 
+TAO_Configurable_Refcount
+TAO_Resource_Factory::create_corba_object_refcount (void)
+{
+  return TAO_Configurable_Refcount (
+                    TAO_Configurable_Refcount::TAO_NULL_LOCK);
+}
+
 int
 TAO_Resource_Factory::load_default_protocols (void)
 {
   return 0;
 }
 
-#if defined (ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION)
-
-template class ACE_Dynamic_Service<TAO_Resource_Factory>;
-template class ACE_Node<TAO_Protocol_Item*>;
-///
-template class ACE_Unbounded_Set<TAO_Protocol_Item*>;
-template class ACE_Unbounded_Set_Iterator<TAO_Protocol_Item*>;
-///
-#elif defined (ACE_HAS_TEMPLATE_INSTANTIATION_PRAGMA)
-
-#pragma instantiate ACE_Dynamic_Service<TAO_Resource_Factory>
-#pragma instantiate ACE_Node<TAO_Protocol_Item*>
-///
-#pragma instantiate ACE_Unbounded_Set<TAO_Protocol_Item*>
-#pragma instantiate ACE_Unbounded_Set_Iterator<TAO_Protocol_Item*>
-
-#endif /* ACE_HAS_EXPLICIT_TEMPLATE_INSTANTIATION */
+TAO_END_VERSIONED_NAMESPACE_DECL
