@@ -1,13 +1,15 @@
-// $Id: Sequence_T.h 75544 2006-11-24 09:33:33Z johnnyw $
+// $Id: Sequence_T.h 84191 2009-01-19 16:32:41Z vzykov $
 
 #include "tao/Unbounded_Octet_Sequence_T.h"
 #include "tao/Unbounded_Value_Sequence_T.h"
 #include "tao/Unbounded_Basic_String_Sequence_T.h"
+#include "tao/Unbounded_BD_String_Sequence_T.h"
 #include "tao/Unbounded_Object_Reference_Sequence_T.h"
 #include "tao/Unbounded_Array_Sequence_T.h"
 #include "tao/Unbounded_Sequence_CDR_T.h"
 #include "tao/Bounded_Value_Sequence_T.h"
 #include "tao/Bounded_Basic_String_Sequence_T.h"
+#include "tao/Bounded_BD_String_Sequence_T.h"
 #include "tao/Bounded_Object_Reference_Sequence_T.h"
 #include "tao/Bounded_Array_Sequence_T.h"
 #include "tao/Bounded_Sequence_CDR_T.h"
