@@ -4,7 +4,7 @@
 /**
  *  @file    ServerRequestInterceptor_Adapter.h
  *
- *  $Id: ServerRequestInterceptor_Adapter.h 76995 2007-02-11 12:51:42Z johnnyw $
+ *  $Id: ServerRequestInterceptor_Adapter.h 85371 2009-05-18 13:39:38Z sma $
  *
  *   This file an adapter class to simplify the support of
  *   interceptors.
@@ -19,6 +19,7 @@
 #include /**/ "ace/pre.h"
 
 #include /**/ "tao/TAO_Export.h"
+#include "tao/RequestInterceptor_Adapter.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -59,6 +60,7 @@ namespace TAO
    * @class ServerRequestInterceptor_Adapter
    */
   class TAO_Export ServerRequestInterceptor_Adapter
+    : public RequestInterceptor_Adapter
   {
   public:
     virtual ~ServerRequestInterceptor_Adapter (void);
@@ -74,7 +76,6 @@ namespace TAO
     /// This method implements the "starting" server side interception
     /// point. It will be used as the first interception point and it is
     /// proprietary to TAO.
-    /// @@ Will go away once Bug 1369 is fixed
     virtual void tao_ft_interception_point (
         TAO_ServerRequest &server_request,
         TAO::Argument * const args[],
@@ -150,8 +151,6 @@ namespace TAO
       const CORBA::PolicyList& policies
       ) = 0;
 
-    virtual void destroy_interceptors (void) = 0;
-
     virtual TAO::PICurrent_Impl *allocate_pi_current (void) = 0;
 
     virtual void deallocate_pi_current (TAO::PICurrent_Impl *picurrent) = 0;
