@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file     Server_Strategy_Factory.h
  *
- *  Server_Strategy_Factory.h,v 1.29 2005/07/04 14:12:12 jwillemsen Exp
+ *  $Id: Server_Strategy_Factory.h 74014 2006-08-14 13:52:22Z johnnyw $
  *
  *  @author  Chris Cleeland
  */
@@ -21,8 +21,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "TAO_Export.h"
-#include "Basic_Types.h"
+#include /**/ "tao/TAO_Export.h"
+#include "tao/Basic_Types.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_ORB_Core;
 
@@ -128,6 +130,8 @@ protected:
   Active_Object_Map_Creation_Parameters active_object_map_creation_parameters_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_SERVER_STRATEGY_FACTORY_H */
