@@ -1,4 +1,4 @@
-// $Id: Service_Context.cpp 76593 2007-01-25 19:19:27Z johnnyw $
+// $Id: Service_Context.cpp 82034 2008-06-18 11:59:23Z johnnyw $
 
 #include "tao/Service_Context.h"
 #include "tao/CDR.h"
@@ -11,7 +11,7 @@
 
 ACE_RCSID (tao,
            Service_Context,
-           "$Id: Service_Context.cpp 76593 2007-01-25 19:19:27Z johnnyw $")
+           "$Id: Service_Context.cpp 82034 2008-06-18 11:59:23Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -86,12 +86,6 @@ TAO_Service_Context::set_context (const IOP::ServiceContext &context,
   return 1;
 }
 
-void
-TAO_Service_Context::set_context (IOP::ServiceContext &context)
-{
-  this->add_context_i (context);
-}
-
 void
 TAO_Service_Context::set_context_i (const IOP::ServiceContext& context)
 {
@@ -212,7 +206,7 @@ TAO_Service_Context::encode (TAO_OutputCDR& cdr) const
 int
 TAO_Service_Context::decode (TAO_InputCDR& cdr)
 {
-  if ((cdr >> this->service_context_) == 0)
+  if (!(cdr >> this->service_context_))
     {
       return 0;
     }
