@@ -1,12 +1,13 @@
 #include "tao/Services_Activate.h"
-#include "ace/Dynamic_Service.h"
 
 ACE_RCSID (tao,
            Services_Activate,
-           "Services_Activate.cpp,v 1.3 2005/06/10 10:22:40 jwillemsen Exp")
+           "$Id: Services_Activate.cpp 69153 2005-11-02 11:03:27Z ossama $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Services_Activate::~TAO_Services_Activate (void)
 {
-  //no-op
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
