@@ -1,13 +1,14 @@
+// -*- C++ -*-
+
 //=============================================================================
 /**
  *  @file    Services_Activate.h
  *
- *  Services_Activate.h,v 1.7 2004/09/03 06:00:39 ossama Exp
+ *  $Id: Services_Activate.h 76995 2007-02-11 12:51:42Z johnnyw $
  *
  * This is a generic interface that would be used to activate
  * the services that are loaded through the svc.conf file
  *
- *
  *  @author Bala Natarajan <bala@cs.wustl.edu>
  */
 //=============================================================================
@@ -22,7 +23,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "tao/SystemException.h"
+#include "tao/orbconf.h"
+#include /**/ "tao/TAO_Export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_ORB_Core;
 class TAO_Service_Callbacks;
@@ -50,10 +54,11 @@ public:
    * This method cannot throw any exception, but it can return a nil
    * object to indicate an error condition.
    */
-  virtual TAO_Service_Callbacks* activate_services (TAO_ORB_Core *orb)
-    ACE_THROW_SPEC ((CORBA::SystemException)) = 0;
+  virtual TAO_Service_Callbacks* activate_services (TAO_ORB_Core *orb) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /*TAO_SERVICES_ACTIVATE_H*/
