@@ -4,7 +4,7 @@
 /**
  *  @file    Special_Basic_Argument_T.h
  *
- *  Special_Basic_Argument_T.h,v 1.7 2005/04/27 18:46:27 jwillemsen Exp
+ *  $Id: Special_Basic_Argument_T.h 74007 2006-08-14 12:50:21Z elliott_c $
  *
  *  @authors Jeff Parsons and Carlos O'Ryan
  */
@@ -23,6 +23,8 @@
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   /**
@@ -31,38 +33,67 @@ namespace TAO
    * @brief Template class for IN stub argument of (w)char/boolean/octet.
    *
    */
-  template<typename S, typename to_S, typename from_S>
-  class In_Special_Basic_Argument_T : public Argument
+  template<typename S,
+           typename to_S,
+           typename from_S,
+           class Insert_Policy>
+  class In_Special_Basic_Argument_T : public InArgument
   {
   public:
     In_Special_Basic_Argument_T (S const &);
 
-    virtual CORBA::Boolean marshal (TAO_OutputCDR &);
+    virtual CORBA::Boolean marshal (TAO_OutputCDR &cdr);
 #if TAO_HAS_INTERCEPTORS == 1
-    virtual void interceptor_param (Dynamic::Parameter &);
+    virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
     S const & arg (void) const;
 
-  private:
+  protected:
     S const & x_;
   };
 
+  /**
+   * @class In_Special_Basic_Clonable_Argument_T
+   *
+   * @brief Template class for IN stub argument of (w)char/boolean/octet.
+   *
+   */
+  template<typename S,
+           typename to_S,
+           typename from_S,
+           class Insert_Policy>
+  class In_Special_Basic_Clonable_Argument_T :
+        public In_Special_Basic_Argument_T<S, to_S, from_S, Insert_Policy>
+  {
+  public:
+    In_Special_Basic_Clonable_Argument_T (S const &);
+    virtual ~In_Special_Basic_Clonable_Argument_T (void);
+
+    virtual Argument* clone (void);
+
+  private:
+    bool is_clone_;
+  };
+
   /**
    * @class Inout_Special_Basic_Argument_T
    *
    * @brief Template class for INOUT stub argument of (w)char/boolean/octet.
    *
    */
-  template<typename S, typename to_S, typename from_S>
-  class Inout_Special_Basic_Argument_T : public Argument
+  template<typename S,
+           typename to_S,
+           typename from_S,
+           class Insert_Policy>
+  class Inout_Special_Basic_Argument_T : public InoutArgument
   {
   public:
     Inout_Special_Basic_Argument_T (S & x);
 
-    virtual CORBA::Boolean marshal (TAO_OutputCDR &);
+    virtual CORBA::Boolean marshal (TAO_OutputCDR &cdr);
     virtual CORBA::Boolean demarshal (TAO_InputCDR &);
 #if TAO_HAS_INTERCEPTORS == 1
-    virtual void interceptor_param (Dynamic::Parameter &);
+    virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
     S & arg (void);
 
@@ -76,15 +107,18 @@ namespace TAO
    * @brief Template class for OUT stub argument of (w)char/boolean/octet.
    *
    */
-  template<typename S, typename to_S, typename from_S>
-  class Out_Special_Basic_Argument_T : public Argument
+  template<typename S,
+           typename to_S,
+           typename from_S,
+           class Insert_Policy>
+  class Out_Special_Basic_Argument_T : public OutArgument
   {
   public:
     Out_Special_Basic_Argument_T (S & x);
 
     virtual CORBA::Boolean demarshal (TAO_InputCDR &);
 #if TAO_HAS_INTERCEPTORS == 1
-    virtual void interceptor_param (Dynamic::Parameter &);
+    virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
     S & arg (void);
 
@@ -98,15 +132,18 @@ namespace TAO
    * @brief Template class for return stub value of (w)char/boolean/octet.
    *
    */
-  template<typename S, typename to_S, typename from_S>
-  class Ret_Special_Basic_Argument_T : public Argument
+  template<typename S,
+           typename to_S,
+           typename from_S,
+           class Insert_Policy>
+  class Ret_Special_Basic_Argument_T : public RetArgument
   {
   public:
     Ret_Special_Basic_Argument_T (void);
 
     virtual CORBA::Boolean demarshal (TAO_InputCDR &);
 #if TAO_HAS_INTERCEPTORS == 1
-    virtual void interceptor_result (CORBA::Any *);
+    virtual void interceptor_value (CORBA::Any *any) const;
 #endif /* TAO_HAS_INTERCEPTORS == 1 */
     S & arg (void);
 
@@ -126,12 +163,15 @@ namespace TAO
   struct TAO_Export Special_Basic_Tag {};
 
   /**
-   * @struct Special_Basic_Traits_T
+   * @struct Special_Basic_Arg_Traits_T
    *
    * @brief Template class for stub argument traits of (w)char/boolean/octet.
    *
    */
-  template<typename T, typename to_T, typename from_T>
+  template<typename T,
+           typename to_T,
+           typename from_T,
+           class Insert_Policy>
   struct Special_Basic_Arg_Traits_T
   {
     typedef T                                               ret_type;
@@ -139,15 +179,19 @@ namespace TAO
     typedef T &                                             inout_type;
     typedef T &                                             out_type;
 
-    typedef In_Special_Basic_Argument_T<T,to_T,from_T>      in_arg_val;
-    typedef Inout_Special_Basic_Argument_T<T,to_T,from_T>   inout_arg_val;
-    typedef Out_Special_Basic_Argument_T<T,to_T,from_T>     out_arg_val;
-    typedef Ret_Special_Basic_Argument_T<T,to_T,from_T>     ret_val;
+    typedef In_Special_Basic_Argument_T<T,to_T,from_T,Insert_Policy>      in_arg_val;
+    typedef In_Special_Basic_Clonable_Argument_T<T,to_T,from_T,Insert_Policy>
+                                                                          in_clonable_arg_val;
+    typedef Inout_Special_Basic_Argument_T<T,to_T,from_T,Insert_Policy>   inout_arg_val;
+    typedef Out_Special_Basic_Argument_T<T,to_T,from_T,Insert_Policy>     out_arg_val;
+    typedef Ret_Special_Basic_Argument_T<T,to_T,from_T,Insert_Policy>     ret_val;
 
     typedef Special_Basic_Tag                               idl_tag;
   };
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
 #include "tao/Special_Basic_Argument_T.inl"
 #endif /* __ACE_INLINE__ */
