@@ -1,5 +1,5 @@
 // This may look like C, but it's really -*- C++ -*-
-// $Id: DIOP_Acceptor.cpp 79033 2007-07-26 09:26:46Z vridosh $
+// $Id: DIOP_Acceptor.cpp 85329 2009-05-13 19:46:11Z mitza $
 
 #include "tao/Strategies/DIOP_Acceptor.h"
 
@@ -24,7 +24,7 @@
 
 ACE_RCSID (Strategies,
            DIOP_Acceptor,
-           "$Id: DIOP_Acceptor.cpp 79033 2007-07-26 09:26:46Z vridosh $")
+           "$Id: DIOP_Acceptor.cpp 85329 2009-05-13 19:46:11Z mitza $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -140,13 +140,12 @@ TAO_DIOP_Acceptor::create_shared_profile (const TAO::ObjectKey &object_key,
                                           CORBA::Short priority)
 {
   CORBA::ULong index = 0;
-  TAO_Profile *pfile = 0;
   TAO_DIOP_Profile *diop_profile = 0;
 
   // First see if <mprofile> already contains a DIOP profile.
   for (TAO_PHandle i = 0; i != mprofile.profile_count (); ++i)
     {
-      pfile = mprofile.get_profile (i);
+      TAO_Profile *pfile = mprofile.get_profile (i);
       if (pfile->tag () == TAO_TAG_DIOP_PROFILE)
       {
         diop_profile = dynamic_cast<TAO_DIOP_Profile *> (pfile);
@@ -181,7 +180,7 @@ TAO_DIOP_Acceptor::create_shared_profile (const TAO::ObjectKey &object_key,
           diop_profile->tagged_components ().set_orb_type (TAO_ORB_TYPE);
           TAO_Codeset_Manager *csm = this->orb_core_->codeset_manager ();
           if (csm)
-            csm->set_codeset (pfile->tagged_components ());
+            csm->set_codeset (diop_profile->tagged_components ());
         }
 
       index = 1;
@@ -321,7 +320,7 @@ TAO_DIOP_Acceptor::open (TAO_ORB_Core *orb_core,
     {
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - ")
-                  ACE_TEXT ("DIOP_Acceptor::open, specified host=%s:%d\n"),
+                  ACE_TEXT ("DIOP_Acceptor::open, specified host=%C:%d\n"),
                   (specified_hostname.length () == 0 ? "<null>" : specified_hostname.c_str ()),
                   addr.get_port_number ()));
     }
@@ -456,8 +455,8 @@ TAO_DIOP_Acceptor::open_i (const ACE_INET_Addr& addr,
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("TAO (%P|%t) - DIOP_Acceptor::open_i, ")
-                      ACE_TEXT ("listening on: <%s:%u>\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR (this->hosts_[i]),
+                      ACE_TEXT ("listening on: <%C:%u>\n"),
+                      this->hosts_[i],
                       this->addrs_[i].get_port_number ()));
         }
     }
@@ -1022,9 +1021,9 @@ TAO_DIOP_Acceptor::parse_options (const char *str)
           if (slot == len - 1
               || slot == ACE_CString::npos)
             ACE_ERROR_RETURN ((LM_ERROR,
-                               ACE_TEXT ("TAO (%P|%t) - DIOP option <%s> is ")
+                               ACE_TEXT ("TAO (%P|%t) - DIOP option <%C> is ")
                                ACE_TEXT ("missing a value.\n"),
-                               ACE_TEXT_CHAR_TO_TCHAR (opt.c_str ())),
+                               opt.c_str ()),
                               -1);
 
           ACE_CString name = opt.substring (0, slot);
@@ -1042,14 +1041,14 @@ TAO_DIOP_Acceptor::parse_options (const char *str)
             {
               ACE_ERROR_RETURN ((LM_ERROR,
                                  ACE_TEXT ("TAO (%P|%t) - Invalid DIOP endpoint format: ")
-                                 ACE_TEXT ("endpoint priorities no longer supported. \n")),
+                                 ACE_TEXT ("endpoint priorities no longer supported.\n")),
                                 -1);
             }
           else
             {
               ACE_ERROR_RETURN ((LM_ERROR,
-                                 ACE_TEXT ("TAO (%P|%t) - Invalid DIOP option: <%s>\n"),
-                                 ACE_TEXT_CHAR_TO_TCHAR (name.c_str ())),
+                                 ACE_TEXT ("TAO (%P|%t) - Invalid DIOP option: <%C>\n"),
+                                 name.c_str ()),
                                 -1);
             }
         }
