@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    DIOP_Acceptor.h
  *
- *  DIOP_Acceptor.h,v 1.10 2004/09/29 21:51:48 irfan Exp
+ *  $Id: DIOP_Acceptor.h 78931 2007-07-18 09:59:36Z johnnyw $
  *
  *  DIOP specific acceptor processing
  *
@@ -20,18 +20,20 @@
 
 #include "tao/orbconf.h"
 
-#if defined (TAO_HAS_DIOP) && (TAO_HAS_DIOP != 0)
-
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+#if defined (TAO_HAS_DIOP) && (TAO_HAS_DIOP != 0)
+
 #include "tao/Transport_Acceptor.h"
-#include "DIOP_Connection_Handler.h"
+#include "tao/Strategies/DIOP_Connection_Handler.h"
 #include "tao/Acceptor_Impl.h"
 
 #include "tao/GIOP_Message_Version.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 // TAO DIOP_Acceptor concrete call defination
 
 /**
@@ -45,7 +47,7 @@ class TAO_Strategies_Export TAO_DIOP_Acceptor : public TAO_Acceptor
 {
 public:
   /// Constructor.
-  TAO_DIOP_Acceptor (CORBA::Boolean flag = 0);
+  TAO_DIOP_Acceptor (void);
 
   /// Destructor.
   ~TAO_DIOP_Acceptor (void);
@@ -57,6 +59,12 @@ public:
   /// Returns the array of endpoints in this acceptor
   const ACE_INET_Addr *endpoints (void);
 
+  /// Returns address for default endpoint
+  const ACE_INET_Addr& default_address (void) const;
+
+  /// Set address for default endpoint
+  void set_default_address (const ACE_INET_Addr& addr);
+
   /**
    * @name The TAO_Acceptor Methods
    *
@@ -93,10 +101,10 @@ public:
    * hostname and the desired one cannot be determined in any
    * other way.
    */
-  int hostname (TAO_ORB_Core *orb_core,
-                ACE_INET_Addr &addr,
-                char *&host,
-                const char *specified_hostname = 0);
+  virtual int hostname (TAO_ORB_Core *orb_core,
+                        ACE_INET_Addr &addr,
+                        char *&host,
+                        const char *specified_hostname = 0);
 
   /**
    * Set the host name for the given address using the dotted decimal
@@ -107,6 +115,20 @@ public:
 
 protected:
 
+  /**
+   * Helper method
+   * Clear out 'addr' & 'specified_hostname' and initialize them based
+   * upon 'address'. If a non-zero pointer is passed in for def_type,
+   * this will be set to AF_INET6 if IPv6 support is enabled and
+   * supplied hostname is either [] or [::]. It will be set to AF_INET
+   * if the hostname is 0.0.0.0, otherwise it is set to
+   * AF_UNSPEC. This value is then passed to probe_interfaces by open.
+   */
+  int parse_address (const char *address,
+                     ACE_INET_Addr &addr,
+                     ACE_CString &specified_hostname,
+                     int *def_type = 0);
+
   /**
    * Implement the common part of the open*() methods.  This method is
    * virtual to allow a derived class implementation to be invoked
@@ -121,8 +143,13 @@ protected:
    * interface.  The port for each initialized ACE_INET_Addr will be
    * set in the open_i() method.  This method only gets invoked when
    * no explicit hostname is provided in the specified endpoint.
+   *
+   * The optional argument def_type is used to constrain the resulting
+   * list of interfaces to be either only IPv6 or IPv4, or both, when
+   * ACE_HAS_IPV6 is enabled and the source endpoint was an explicitly
+   * declared wildcard.
    */
-  int probe_interfaces (TAO_ORB_Core *orb_core);
+  int probe_interfaces (TAO_ORB_Core *orb_core, int def_type = AF_UNSPEC);
 
   /// Parse protocol specific options.
   virtual int parse_options (const char *options);
@@ -167,8 +194,8 @@ protected:
   /// ORB Core.
   TAO_ORB_Core *orb_core_;
 
-  /// Should we use GIOP lite??
-  CORBA::Boolean lite_flag_;
+  /// Address for default endpoint
+  ACE_INET_Addr default_address_;
 
 private:
   // @@ Frank: From DIOP_Acceptor.h
@@ -176,8 +203,10 @@ private:
 
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined(__ACE_INLINE__)
-#include "DIOP_Acceptor.i"
+#include "tao/Strategies/DIOP_Acceptor.inl"
 #endif /* __ACE_INLINE__ */
 
 #endif /* TAO_HAS_DIOP && TAO_HAS_DIOP != 0 */
