@@ -1,11 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file     DIOP_Profile.h
  *
- *  DIOP_Profile.h,v 1.14 2005/01/04 20:16:38 jwillemsen Exp
+ *  $Id: DIOP_Profile.h 76551 2007-01-24 13:42:44Z johnnyw $
  *
  *   DIOP profile specific processing
  *
@@ -22,14 +21,16 @@
 
 #include "tao/orbconf.h"
 
-#if defined (TAO_HAS_DIOP) && (TAO_HAS_DIOP != 0)
-
-#include "tao/Profile.h"
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
-#include "DIOP_Endpoint.h"
 
+#if defined (TAO_HAS_DIOP) && (TAO_HAS_DIOP != 0)
+
+#include "tao/Strategies/DIOP_Endpoint.h"
+#include "tao/Profile.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 // TAO DIOP_Profile concrete Profile definitions
 /**
@@ -76,12 +77,11 @@ public:
 
 
   /// Template methods. Please tao/Profile.h for documentation.
-  virtual char * to_string (ACE_ENV_SINGLE_ARG_DECL);
+  virtual char * to_string (void);
   virtual int encode_endpoints (void);
   virtual TAO_Endpoint *endpoint (void);
   virtual CORBA::ULong endpoint_count (void) const;
-  virtual CORBA::ULong hash (CORBA::ULong max
-                             ACE_ENV_ARG_DECL);
+  virtual CORBA::ULong hash (CORBA::ULong max);
   /**
    * Add <endp> to this profile's list of endpoints (it is inserted
    * next to the head of the list).  This profiles takes ownership of
@@ -93,8 +93,7 @@ protected:
 
   /// Template methods. Please see tao/Profile.h for documentation.
   virtual int decode_profile (TAO_InputCDR& cdr);
-  virtual void parse_string_i (const char *string
-                               ACE_ENV_ARG_DECL);
+  virtual void parse_string_i (const char *string);
   virtual void create_profile_body (TAO_OutputCDR &cdr) const;
   virtual int decode_endpoints (void);
   virtual CORBA::Boolean do_is_equivalent (const TAO_Profile *other_profile);
@@ -122,6 +121,8 @@ protected:
   CORBA::ULong count_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_DIOP && TAO_HAS_DIOP != 0 */
 
 #include /**/ "ace/post.h"
