@@ -1,9 +1,12 @@
-// FIFO_Connection_Purging_Strategy.cpp,v 1.4 2001/05/23 14:06:37 oci Exp
+// $Id: FIFO_Connection_Purging_Strategy.cpp 73152 2006-06-20 07:33:02Z jwillemsen $
 
-#include "FIFO_Connection_Purging_Strategy.h"
+#include "tao/Strategies/FIFO_Connection_Purging_Strategy.h"
 #include "tao/Transport.h"
 
-ACE_RCSID(tao, FIFO_Connection_Purging_Strategy, "FIFO_Connection_Purging_Strategy.cpp,v 1.4 2001/05/23 14:06:37 oci Exp")
+ACE_RCSID(tao, FIFO_Connection_Purging_Strategy, "$Id: FIFO_Connection_Purging_Strategy.cpp 73152 2006-06-20 07:33:02Z jwillemsen $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_FIFO_Connection_Purging_Strategy::TAO_FIFO_Connection_Purging_Strategy (
                                                             int cache_maximum)
@@ -14,12 +17,6 @@ TAO_FIFO_Connection_Purging_Strategy::TAO_FIFO_Connection_Purging_Strategy (
 {
 }
 
-
-TAO_FIFO_Connection_Purging_Strategy::~TAO_FIFO_Connection_Purging_Strategy (void)
-{
-}
-
-
 void
 TAO_FIFO_Connection_Purging_Strategy::update_item (TAO_Transport* transport)
 {
@@ -31,4 +28,4 @@ TAO_FIFO_Connection_Purging_Strategy::update_item (TAO_Transport* transport)
     }
 }
 
-
+TAO_END_VERSIONED_NAMESPACE_DECL
