@@ -1,9 +1,12 @@
-// LFU_Connection_Purging_Strategy.cpp,v 1.4 2001/05/23 14:06:37 oci Exp
+// $Id: LFU_Connection_Purging_Strategy.cpp 73152 2006-06-20 07:33:02Z jwillemsen $
 
-#include "LFU_Connection_Purging_Strategy.h"
+#include "tao/Strategies/LFU_Connection_Purging_Strategy.h"
 #include "tao/Transport.h"
 
-ACE_RCSID(tao, LFU_Connection_Purging_Strategy, "LFU_Connection_Purging_Strategy.cpp,v 1.4 2001/05/23 14:06:37 oci Exp")
+ACE_RCSID(tao, LFU_Connection_Purging_Strategy, "$Id: LFU_Connection_Purging_Strategy.cpp 73152 2006-06-20 07:33:02Z jwillemsen $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_LFU_Connection_Purging_Strategy::TAO_LFU_Connection_Purging_Strategy (
                                                            int cache_maximum)
@@ -11,15 +14,10 @@ TAO_LFU_Connection_Purging_Strategy::TAO_LFU_Connection_Purging_Strategy (
 {
 }
 
-
-TAO_LFU_Connection_Purging_Strategy::~TAO_LFU_Connection_Purging_Strategy (void)
-{
-}
-
-
 void
 TAO_LFU_Connection_Purging_Strategy::update_item (TAO_Transport* transport)
 {
   transport->purging_order (transport->purging_order () + 1);
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
