@@ -1,13 +1,15 @@
-// -*- C++ -*-
-// LF_Strategy_Null.cpp,v 1.2 2001/08/01 23:39:57 coryan Exp
+// $Id: LF_Strategy_Null.cpp 71473 2006-03-10 07:19:20Z jtc $
 
-#include "LF_Strategy_Null.h"
+#include "tao/Strategies/LF_Strategy_Null.h"
 
 #if !defined (__ACE_INLINE__)
-# include "LF_Strategy_Null.inl"
+# include "tao/Strategies/LF_Strategy_Null.inl"
 #endif /* __ACE_INLINE__ */
 
-ACE_RCSID(tao, LF_Strategy_Null, "LF_Strategy_Null.cpp,v 1.2 2001/08/01 23:39:57 coryan Exp")
+ACE_RCSID(tao, LF_Strategy_Null, "$Id: LF_Strategy_Null.cpp 71473 2006-03-10 07:19:20Z jtc $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_LF_Strategy_Null::~TAO_LF_Strategy_Null (void)
 {
@@ -30,3 +32,5 @@ TAO_LF_Strategy_Null::reset_event_loop_thread (int,
                                                TAO_Leader_Follower &)
 {
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
