@@ -1,8 +1,10 @@
+// -*- C++ -*-
+
 // ================================================================
 /**
  *  @file   NULL_Connection_Purging_Strategy.h
  *
- *  NULL_Connection_Purging_Strategy.h,v 1.6 2003/07/21 23:51:39 dhinton Exp
+ *  $Id: NULL_Connection_Purging_Strategy.h 73152 2006-06-20 07:33:02Z jwillemsen $
  *
  *  @author Chad Elliott (elliott_c@ociweb.com)
  */
@@ -12,7 +14,7 @@
 #define TAO_NULL_PURGING_STRATEGY_H
 #include /**/ "ace/pre.h"
 
-#include "strategies_export.h"
+#include "tao/Strategies/strategies_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -21,6 +23,8 @@
 #include "tao/Connection_Purging_Strategy.h"
 
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_NULL_Connection_Purging_Strategy
  *
@@ -35,9 +39,6 @@ public:
   /// The constructor
   TAO_NULL_Connection_Purging_Strategy (int cache_maximum);
 
-  /// The destructor
-  virtual ~TAO_NULL_Connection_Purging_Strategy (void);
-
   /// Does nothing.
   virtual void update_item (TAO_Transport* transport);
 
@@ -45,5 +46,7 @@ public:
   virtual int cache_maximum (void) const;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /* TAO_NULL_PURGING_STRATEGY_H */
