@@ -9,6 +9,7 @@
 #include "tao/Codeset_Manager.h"
 #include "tao/Transport.h"
 #include "tao/CDR.h"
+#include "ace/os_include/os_netdb.h"
 
 #if !defined(__ACE_INLINE__)
 #include "tao/Strategies/SCIOP_Acceptor.inl"
@@ -16,8 +17,7 @@
 
 ACE_RCSID(tao,
           SCIOP_Acceptor,
-          "$Id: SCIOP_Acceptor.cpp 78931 2007-07-18 09:59:36Z johnnyw $")
-
+          "$Id: SCIOP_Acceptor.cpp 84695 2009-03-03 12:31:26Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -30,7 +30,7 @@ TAO_SCIOP_Acceptor::TAO_SCIOP_Acceptor (void)
     hostname_in_ior_ (0),
     version_ (TAO_DEF_SCIOP_MAJOR, TAO_DEF_SCIOP_MINOR),
     orb_core_ (0),
-    base_acceptor_ (),
+    base_acceptor_ (this),
     creation_strategy_ (0),
     concurrency_strategy_ (0),
     accept_strategy_ (0)
@@ -213,8 +213,8 @@ TAO_SCIOP_Acceptor::close (void)
 int
 TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
                          ACE_Reactor *reactor,
-                         int major,
-                         int minor,
+                         int,
+                         int,
                          const char *address,
                          const char *options)
 {
@@ -235,9 +235,6 @@ TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
   if (address == 0)
     return -1;
 
-  ACE_UNUSED_ARG (major);
-  ACE_UNUSED_ARG (minor);
-
   // Parse options
   if (this->parse_options (options) == -1)
     return -1;
@@ -290,7 +287,7 @@ TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
                          ACE_TEXT ("TAO (%P|%t) ")
                          ACE_TEXT ("SCIOP_Acceptor::open - ")
                          ACE_TEXT ("no port number after the ")
-                         ACE_TEXT ("colon in \"%s\"\n"),
+                         ACE_TEXT ("colon in \"%C\"\n"),
                          address),
                         -1);
     }
@@ -329,7 +326,7 @@ TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
     ACE_ERROR_RETURN ((LM_ERROR,
                        ACE_TEXT ("TAO (%P|%t) ")
                        ACE_TEXT ("SCIOP_Acceptor::open - ")
-                       ACE_TEXT ("no hostnames in string \"%s\"\n"),
+                       ACE_TEXT ("no hostnames in string \"%C\"\n"),
                        tmp_host),
                       -1);
   }
@@ -385,7 +382,10 @@ TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
                primary_ip_addr,
                1,
                secondary_ip_addrs,
-               num_secondary_ip_addrs));
+               num_secondary_ip_addrs) != 0)
+    {
+      return -1;
+    }
 
   // Number of endpoints equals the size of the hostname array.
   this->endpoint_count_ = hostnames.size();
@@ -418,7 +418,7 @@ TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
       if (TAO_debug_level > 2)
       {
         ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("Overriding address in IOR with %s\n"),
+                    ACE_TEXT ("Overriding address in IOR with %C\n"),
                     this->hostname_in_ior_));
       }
       if (this->hostname (orb_core,
@@ -452,8 +452,8 @@ TAO_SCIOP_Acceptor::open (TAO_ORB_Core *orb_core,
 int
 TAO_SCIOP_Acceptor::open_default (TAO_ORB_Core *orb_core,
                                  ACE_Reactor *reactor,
-                                 int major,
-                                 int minor,
+                                 int,
+                                 int,
                                  const char *options)
 {
   this->orb_core_ = orb_core;
@@ -469,10 +469,6 @@ TAO_SCIOP_Acceptor::open_default (TAO_ORB_Core *orb_core,
                         -1);
     }
 
-
-  ACE_UNUSED_ARG (major);
-  ACE_UNUSED_ARG (minor);
-
   // Parse options
   if (this->parse_options (options) == -1)
     return -1;
@@ -607,12 +603,19 @@ TAO_SCIOP_Acceptor::open_i (const ACE_Multihomed_INET_Addr& addr,
         {
           ACE_DEBUG ((LM_DEBUG,
                       ACE_TEXT ("\nTAO (%P|%t) SCIOP_Acceptor::open_i - ")
-                      ACE_TEXT ("listening on: <%s:%u>\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR(this->hosts_[i]),
+                      ACE_TEXT ("listening on: <%C:%u>\n"),
+                      this->hosts_[i],
                       this->addrs_[i].get_port_number ()));
         }
     }
 
+  // In the event that an accept() fails, we can examine the reason.  If
+  // the reason warrants it, we can try accepting again at a later time.
+  // The amount of time we wait to accept again is governed by this orb
+  // parameter.
+  this->set_error_retry_delay (
+    this->orb_core_->orb_params ()->accept_error_delay());
+
   return 0;
 }
 
@@ -773,7 +776,7 @@ TAO_SCIOP_Acceptor::probe_interfaces (TAO_ORB_Core *orb_core)
           if (TAO_debug_level > 2)
             {
               ACE_DEBUG ((LM_DEBUG,
-                          ACE_TEXT ("Overriding address in IOR with %s\n"),
+                          ACE_TEXT ("Overriding address in IOR with %C\n"),
                           this->hostname_in_ior_));
             }
           if (this->hostname (orb_core,
@@ -885,7 +888,7 @@ TAO_SCIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
     {
       if (TAO_debug_level > 0)
         {
-          ACE_DEBUG ((LM_DEBUG,
+          ACE_ERROR ((LM_ERROR,
                       ACE_TEXT ("TAO (%P|%t) SCIOP_Profile::decode - v%d.%d\n"),
                       major,
                       minor));
@@ -910,7 +913,7 @@ TAO_SCIOP_Acceptor::object_key (IOP::TaggedProfile &profile,
     }
 
   // ... and object key.
-  if ((cdr >> object_key) == 0)
+  if (!(cdr >> object_key))
     return -1;
 
   // We are NOT bothered about the rest.
@@ -977,7 +980,7 @@ TAO_SCIOP_Acceptor::parse_options (const char *str)
           if (slot == len - 1
               || slot == ACE_CString::npos)
             ACE_ERROR_RETURN ((LM_ERROR,
-                               ACE_TEXT ("TAO (%P|%t) SCIOP option <%s> is ")
+                               ACE_TEXT ("TAO (%P|%t) SCIOP option <%C> is ")
                                ACE_TEXT ("missing a value.\n"),
                                opt.c_str ()),
                               -1);
@@ -995,7 +998,7 @@ TAO_SCIOP_Acceptor::parse_options (const char *str)
             {
               ACE_ERROR_RETURN ((LM_ERROR,
                                  ACE_TEXT ("TAO (%P|%t) Invalid SCIOP endpoint format: ")
-                                 ACE_TEXT ("endpoint priorities no longer supported. \n")),
+                                 ACE_TEXT ("endpoint priorities no longer supported.\n")),
                                 -1);
             }
           else if (name == "portspan")
@@ -1005,7 +1008,7 @@ TAO_SCIOP_Acceptor::parse_options (const char *str)
               if (range < 1 || range > ACE_MAX_DEFAULT_PORT)
                 ACE_ERROR_RETURN ((LM_ERROR,
                                    ACE_TEXT ("TAO (%P|%t) Invalid SCIOP endpoint ")
-                                   ACE_TEXT ("portspan: <%s>\n")
+                                   ACE_TEXT ("portspan: <%C>\n")
                                    ACE_TEXT ("Valid range 1 -- %d\n"),
                                    value.c_str (), ACE_MAX_DEFAULT_PORT),
                                   -1);
@@ -1018,7 +1021,7 @@ TAO_SCIOP_Acceptor::parse_options (const char *str)
             }
           else
             ACE_ERROR_RETURN ((LM_ERROR,
-                               ACE_TEXT ("TAO (%P|%t) Invalid SCIOP option: <%s>\n"),
+                               ACE_TEXT ("TAO (%P|%t) Invalid SCIOP option: <%C>\n"),
                                name.c_str ()),
                               -1);
 
