@@ -4,11 +4,10 @@
 /**
  *  @file    SHMIOP_Connector.h
  *
- *  SHMIOP_Connector.h,v 1.21 2004/08/09 12:04:49 jwillemsen Exp
+ *  $Id: SHMIOP_Connector.h 78931 2007-07-18 09:59:36Z johnnyw $
  *
  *  SHMIOP specific connector processing
  *
- *
  *  @author Nanbor Wang <nanbor@cs.wustl.edu>
  */
 //=============================================================================
@@ -30,10 +29,12 @@
 #include "ace/MEM_Connector.h"
 #include "ace/Connector.h"
 #include "tao/Transport_Connector.h"
-#include "SHMIOP_Connection_Handler.h"
+#include "tao/Strategies/SHMIOP_Connection_Handler.h"
 #include "tao/Resource_Factory.h"
 #include "tao/Connector_Impl.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 class TAO_SHMIOP_Endpoint;
 
 // ****************************************************************
@@ -51,7 +52,7 @@ class TAO_Strategies_Export TAO_SHMIOP_Connector : public TAO_Connector
 {
 public:
   /// Constructor.
-  TAO_SHMIOP_Connector (CORBA::Boolean flag = 0);
+  TAO_SHMIOP_Connector (void);
 
   /// Default destructor
   ~TAO_SHMIOP_Connector (void);
@@ -101,7 +102,7 @@ protected:
                                   TAO_Transport_Descriptor_Interface &desc,
                                   ACE_Time_Value *timeout = 0);
 
-  virtual TAO_Profile *make_profile (ACE_ENV_SINGLE_ARG_DECL);
+  virtual TAO_Profile *make_profile (void);
 
   /// Cancel the passed cvs handler from the connector
   int cancel_svc_handler (TAO_Connection_Handler * svc_handler);
@@ -122,11 +123,10 @@ private:
 
   /// The connector initiating connection requests for SHMIOP.
   TAO_SHMIOP_BASE_CONNECTOR base_connector_;
-
-  /// Are we using GIOP lite?
-  CORBA::Boolean lite_flag_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif /* TAO_HAS_SHMIOP && TAO_HAS_SHMIOP != 0 */
 
 #include /**/ "ace/post.h"
