@@ -1,5 +1,5 @@
-#include "UIOP_Endpoint.h"
-#include "UIOP_Connection_Handler.h"
+#include "tao/Strategies/UIOP_Endpoint.h"
+#include "tao/Strategies/UIOP_Connection_Handler.h"
 
 #include "tao/ORB_Constants.h"
 
@@ -11,13 +11,14 @@
 
 ACE_RCSID (Strategies,
            UIOP_Endpoint,
-           "UIOP_Endpoint.cpp,v 1.9 2005/02/25 06:23:35 ossama Exp")
+           "$Id: UIOP_Endpoint.cpp 73791 2006-07-27 20:54:56Z wotte $")
 
 
 #if !defined (__ACE_INLINE__)
-# include "UIOP_Endpoint.i"
+# include "tao/Strategies/UIOP_Endpoint.inl"
 #endif /* __ACE_INLINE__ */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_UIOP_Endpoint::TAO_UIOP_Endpoint (const ACE_UNIX_Addr &addr,
                                       CORBA::Short priority)
@@ -102,4 +103,7 @@ TAO_UIOP_Endpoint::hash (void)
 
   return this->hash_val_;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #endif  /* TAO_HAS_UIOP == 1 */
