@@ -1,4 +1,4 @@
-// $Id: advanced_resource.cpp 80577 2008-02-06 10:24:05Z johnnyw $
+// $Id: advanced_resource.cpp 84281 2009-01-30 15:01:17Z wotte $
 #include "ace/Service_Config.h"
 #include "tao/Strategies/advanced_resource.h"
 
@@ -35,7 +35,7 @@
 #include "ace/Null_Mutex.h"
 #include "ace/OS_NS_strings.h"
 
-ACE_RCSID(Strategies, advanced_resource, "$Id: advanced_resource.cpp 80577 2008-02-06 10:24:05Z johnnyw $")
+ACE_RCSID(Strategies, advanced_resource, "$Id: advanced_resource.cpp 84281 2009-01-30 15:01:17Z wotte $")
 
 #if !defined (TAO_DEFAULT_REACTOR_TYPE)
 #define TAO_DEFAULT_REACTOR_TYPE TAO_REACTOR_TP
@@ -392,16 +392,16 @@ TAO_Advanced_Resource_Factory::init_protocol_factories (void)
         {
           ACE_ERROR_RETURN ((LM_ERROR,
                              ACE_TEXT("TAO (%P|%t) Unable to load ")
-                             ACE_TEXT("protocol <%s>, %m\n"),
-                             ACE_TEXT_CHAR_TO_TCHAR(name.c_str ())),
+                             ACE_TEXT("protocol <%C>, %m\n"),
+                             name.c_str ()),
                             -1);
         }
 
       if (TAO_debug_level > 0)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT("TAO (%P|%t) Loaded protocol <%s>\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR(name.c_str ())));
+                      ACE_TEXT("TAO (%P|%t) Loaded protocol <%C>\n"),
+                      name.c_str ()));
         }
     }
  return 0;
@@ -682,7 +682,6 @@ TAO_Advanced_Resource_Factory::report_unsupported_error (
              option_name));
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
 
 // ****************************************************************
 
@@ -695,3 +694,4 @@ ACE_STATIC_SVC_DEFINE (TAO_Advanced_Resource_Factory,
 ACE_FACTORY_DEFINE (TAO_Strategies, TAO_Advanced_Resource_Factory)
 
 // ****************************************************************
+TAO_END_VERSIONED_NAMESPACE_DECL
