@@ -1,4 +1,4 @@
-// $Id: Synch_Invocation.cpp 80108 2007-11-27 11:22:38Z johnnyw $
+// $Id: Synch_Invocation.cpp 88333 2009-12-24 10:21:16Z johnnyw $
 
 #include "tao/Synch_Invocation.h"
 #include "tao/Profile_Transport_Resolver.h"
@@ -15,6 +15,7 @@
 #include "tao/ORB_Core.h"
 #include "tao/Service_Context.h"
 #include "tao/SystemException.h"
+#include "ace/Intrusive_Auto_Ptr.h"
 
 #if TAO_HAS_INTERCEPTORS == 1
 # include "tao/PortableInterceptorC.h"
@@ -31,7 +32,7 @@
 
 ACE_RCSID (tao,
            Synch_Invocation,
-           "$Id: Synch_Invocation.cpp 80108 2007-11-27 11:22:38Z johnnyw $")
+           "$Id: Synch_Invocation.cpp 88333 2009-12-24 10:21:16Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -55,8 +56,15 @@ namespace TAO
   {
     ACE_Countdown_Time countdown (max_wait_time);
 
-    TAO_Synch_Reply_Dispatcher rd (this->resolver_.stub ()->orb_core (),
-                                   this->details_.reply_service_info ());
+    TAO_Synch_Reply_Dispatcher *rd_p = 0;
+    ACE_NEW_NORETURN (rd_p, TAO_Synch_Reply_Dispatcher (this->resolver_.stub ()->orb_core (),
+                                          this->details_.reply_service_info ()));
+    if (!rd_p)
+      {
+        throw ::CORBA::NO_MEMORY ();
+      }
+
+    ACE_Intrusive_Auto_Ptr<TAO_Synch_Reply_Dispatcher> rd(rd_p, false);
 
     Invocation_Status s = TAO_INVOKE_FAILURE;
 
@@ -83,11 +91,14 @@ namespace TAO
             throw CORBA::TRANSIENT (CORBA::OMGVMCID | 2, CORBA::COMPLETED_NO);
           }
 
+        ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon,
+                          transport->output_cdr_lock (), TAO_INVOKE_FAILURE);
+
         TAO_OutputCDR &cdr = transport->out_stream ();
 
         cdr.message_attributes (this->details_.request_id (),
                                 this->resolver_.stub (),
-                                TAO_Transport::TAO_TWOWAY_REQUEST,
+                                TAO_TWOWAY_REQUEST,
                                 max_wait_time);
 
         this->write_header (cdr);
@@ -98,7 +109,7 @@ namespace TAO
         // preallocated reply dispatcher.
         TAO_Bind_Dispatcher_Guard dispatch_guard (
           this->details_.request_id (),
-          &rd,
+          rd.get (),
           transport->tms ());
 
         if (dispatch_guard.status () != 0)
@@ -113,9 +124,11 @@ namespace TAO
         countdown.update ();
 
         s = this->send_message (cdr,
-                                TAO_Transport::TAO_TWOWAY_REQUEST,
+                                TAO_TWOWAY_REQUEST,
                                 max_wait_time);
 
+        ace_mon.release();
+
 #if TAO_HAS_INTERCEPTORS == 1
         // @@NOTE: Too much code repetition.
         // If the above call returns a restart due to connection
@@ -158,7 +171,7 @@ namespace TAO
         // (explicitly coded) handlers called.  We assume a POSIX.1c/C/C++
         // environment.
 
-        s = this->wait_for_reply (max_wait_time, rd, dispatch_guard);
+        s = this->wait_for_reply (max_wait_time, *rd.get (), dispatch_guard);
 
 #if TAO_HAS_INTERCEPTORS == 1
         if (s == TAO_INVOKE_RESTART)
@@ -177,7 +190,7 @@ namespace TAO
         // What happens when the above call returns an error through
         // the return value? That would be bogus as per the contract
         // in the interface. The call violated the contract
-        s = this->check_reply_status (rd);
+        s = this->check_reply_status (*rd.get ());
 
         // For some strategies one may want to release the transport
         // back to  cache after receiving the reply.
@@ -241,17 +254,20 @@ namespace TAO
      * exception. Success alone is returned through the return value.
      */
 
-    int const reply_error =
-      this->resolver_.transport ()->wait_strategy ()->wait (max_wait_time, rd);
+    bool const
+      expired= (max_wait_time && ACE_Time_Value::zero == *max_wait_time);
+    if (expired)
+      errno= ETIME;
+    int const
+      reply_error = expired ? -1 :
+        this->resolver_.transport ()->wait_strategy ()->wait (max_wait_time, rd);
 
     if (TAO_debug_level > 0 && max_wait_time)
       {
-        CORBA::ULong const msecs = max_wait_time->msec ();
-
         ACE_DEBUG ((LM_DEBUG,
                     "TAO (%P|%t) - Synch_Twoway_Invocation::wait_for_reply, "
                     "timeout after recv is <%u> status <%d>\n",
-                    msecs,
+                    max_wait_time->msec (),
                     reply_error));
       }
 
@@ -264,7 +280,7 @@ namespace TAO
           {
             ACE_DEBUG ((LM_DEBUG,
                         "TAO (%P|%t) - Synch_Twoway_Invocation::wait_for_reply, "
-                        "recovering after an error \n"));
+                        "recovering after an error\n"));
           }
 
         // You the smarty, don't try to moving the unbind_dispatcher
@@ -305,7 +321,7 @@ namespace TAO
             try
               {
                 return
-                  this->orb_core ()->service_raise_comm_failure (
+                  this->stub()->orb_core ()->service_raise_comm_failure (
                     this->details_.request_service_context ().service_info (),
                     this->resolver_.profile ());
 
@@ -367,7 +383,7 @@ namespace TAO
             {
               // de-marshalling of permanent object reference was successfull
               CORBA::Boolean const permanent_forward_condition =
-                this->orb_core ()->is_permanent_forward_condition
+                this->stub ()->orb_core ()->is_permanent_forward_condition
                   (this->forwarded_to_.in (),
                    this->request_service_context ());
 
@@ -381,6 +397,9 @@ namespace TAO
 
                    throw ::CORBA::INTERNAL (0, CORBA::COMPLETED_NO);
                 }
+
+              // This is the only place where we set in permanent forward state.
+              this->reply_status (GIOP::LOCATION_FORWARD_PERM);
             }
 
           return s;
@@ -427,12 +446,12 @@ namespace TAO
       {
         ACE_DEBUG ((LM_DEBUG,
                     ACE_TEXT ("TAO (%P|%t) - Synch_Twoway_Invocation::location_forward ")
-                    ACE_TEXT ("being handled \n")));
+                    ACE_TEXT ("being handled\n")));
       }
 
     CORBA::Object_var fwd;
 
-    if ((inp_stream >> fwd) == 0)
+    if (!(inp_stream >> fwd))
       {
         throw ::CORBA::MARSHAL (
           CORBA::SystemException::_tao_minor_code (
@@ -457,12 +476,12 @@ namespace TAO
     if (TAO_debug_level > 3)
       ACE_DEBUG ((LM_DEBUG,
                   "TAO (%P|%t) - Synch_Twoway_Invocation::"
-                  "handle_user_exception \n"));
+                  "handle_user_exception\n"));
 
     // Pull the exception from the stream.
     CORBA::String_var buf;
 
-    if ((cdr >> buf.inout ()) == 0)
+    if (!(cdr >> buf.inout ()))
       {
         // Could not demarshal the exception id, raise an local
         // CORBA::MARSHAL
@@ -478,18 +497,16 @@ namespace TAO
         ACE_DEBUG ((LM_DEBUG,
                     ACE_TEXT ("TAO (%P|%t) - Synch_Twoway_Invocation::")
                     ACE_TEXT ("handle_user_exception - ")
-                    ACE_TEXT ("raising exception %s\n"),
-                    ACE_TEXT_CHAR_TO_TCHAR (buf.in ())));
+                    ACE_TEXT ("raising exception %C\n"),
+                    buf.in ()));
       }
 
     mon.set_status (TAO_INVOKE_USER_EXCEPTION);
 
-    // If we have native exceptions, we must manage the memory allocated
-    // by the call above to alloc(). Otherwise the Environment class
-    // manages the memory.
+    // We must manage the memory allocated
+    // by the call above to alloc(). 
     auto_ptr<CORBA::Exception> safety (exception);
 
-    // Direct throw because we don't have the try_ENV.
     exception->_raise ();
 
     return TAO_INVOKE_USER_EXCEPTION;
@@ -503,11 +520,11 @@ namespace TAO
     if (TAO_debug_level > 3)
       ACE_DEBUG ((LM_DEBUG,
                   "TAO (%P|%t) - Synch_Twoway_Invocation::"
-                  "handle_system_exception \n"));
+                  "handle_system_exception\n"));
 
     CORBA::String_var type_id;
 
-    if ((cdr >> type_id.inout ()) == 0)
+    if (!(cdr >> type_id.inout ()))
       {
         // Could not demarshal the exception id, raise an local
         // CORBA::MARSHAL
@@ -517,39 +534,58 @@ namespace TAO
     CORBA::ULong minor = 0;
     CORBA::ULong completion = 0;
 
-    if ((cdr >> minor) == 0 || (cdr >> completion) == 0)
+    if (!(cdr >> minor) || !(cdr >> completion))
       {
         throw ::CORBA::MARSHAL (0, CORBA::COMPLETED_MAYBE);
       }
 
-    // Special handling for non-fatal system exceptions.
-    //
-    // Note that we are careful to retain "at most once" semantics.
-    if ((ACE_OS_String::strcmp (type_id.in (),
-                                "IDL:omg.org/CORBA/TRANSIENT:1.0") == 0 ||
-         ACE_OS_String::strcmp (type_id.in (),
-                                "IDL:omg.org/CORBA/OBJ_ADAPTER:1.0") == 0 ||
-         ACE_OS_String::strcmp (type_id.in (),
-                                "IDL:omg.org/CORBA/NO_RESPONSE:1.0") == 0 ||
-         ACE_OS_String::strcmp (type_id.in (),
-                                "IDL:omg.org/CORBA/COMM_FAILURE:1.0") == 0) &&
-        (CORBA::CompletionStatus) completion != CORBA::COMPLETED_YES)
-      {
-        {
-          // Start the special case for FTCORBA.
-          /**
-           * There has been a unanimous view that this is not the
-           * right way to do things. But a need to be compliant is
-           * forcing us into this.
-           */
-          Invocation_Status const s =
-            this->orb_core ()->service_raise_transient_failure (
-              this->details_.request_service_context ().service_info (),
-              this->resolver_.profile ());
+    bool do_forward = false;
+    int foe_kind = this->stub ()->orb_core ()->orb_params ()->forward_once_exception();
 
-          if (s == TAO_INVOKE_RESTART)
-            return s;
-        }
+    if ((CORBA::CompletionStatus) completion != CORBA::COMPLETED_YES
+        && (((foe_kind & TAO::FOE_TRANSIENT) == 0
+              && ACE_OS_String::strcmp (type_id.in (),
+                                "IDL:omg.org/CORBA/TRANSIENT:1.0") == 0) ||
+            ACE_OS_String::strcmp (type_id.in (),
+                              "IDL:omg.org/CORBA/OBJ_ADAPTER:1.0") == 0 ||
+            ACE_OS_String::strcmp (type_id.in (),
+                              "IDL:omg.org/CORBA/NO_RESPONSE:1.0") == 0 ||
+            ((foe_kind & TAO::FOE_COMM_FAILURE) == 0
+              && ACE_OS_String::strcmp (type_id.in (),
+                              "IDL:omg.org/CORBA/COMM_FAILURE:1.0") == 0) ||
+            (this->stub ()->orb_core ()->orb_params ()->forward_invocation_on_object_not_exist ()
+             && ACE_OS_String::strcmp (type_id.in (),
+                              "IDL:omg.org/CORBA/OBJECT_NOT_EXIST:1.0") == 0) ||
+            (do_forward = ! this->stub ()->forwarded_on_exception ()
+             && ((((foe_kind & TAO::FOE_OBJECT_NOT_EXIST) == TAO::FOE_OBJECT_NOT_EXIST)
+                        && (ACE_OS_String::strcmp (type_id.in (),
+                                "IDL:omg.org/CORBA/OBJECT_NOT_EXIST:1.0") == 0)) ||
+                 (((foe_kind & TAO::FOE_COMM_FAILURE) == TAO::FOE_COMM_FAILURE)
+                        && (ACE_OS_String::strcmp (type_id.in (),
+                                "IDL:omg.org/CORBA/COMM_FAILURE:1.0") == 0)) ||
+                 (((foe_kind & TAO::FOE_TRANSIENT) == TAO::FOE_TRANSIENT)
+                        && (ACE_OS_String::strcmp (type_id.in (),
+                                "IDL:omg.org/CORBA/TRANSIENT:1.0") == 0)) ||
+                 (((foe_kind & TAO::FOE_INV_OBJREF) == TAO::FOE_INV_OBJREF)
+                        && (ACE_OS_String::strcmp (type_id.in (),
+                                "IDL:omg.org/CORBA/INV_OBJREF:1.0") == 0))))))
+      {
+        if (do_forward)
+          this->stub ()->forwarded_on_exception (true);
+
+        // Start the special case for FTCORBA.
+        /**
+          * There has been a unanimous view that this is not the
+          * right way to do things. But a need to be compliant is
+          * forcing us into this.
+          */
+        Invocation_Status const s =
+          this->stub ()->orb_core ()->service_raise_transient_failure (
+            this->details_.request_service_context ().service_info (),
+            this->resolver_.profile ());
+
+        if (s == TAO_INVOKE_RESTART)
+          return s;
 
         // Attempt profile retry.
         /**
@@ -560,7 +596,8 @@ namespace TAO
          *       be able to help in this case but it ultimately ends
          *       up being an application issue.
          */
-        if (this->resolver_.stub ()->next_profile_retry ())
+        if (completion != CORBA::COMPLETED_MAYBE &&
+            this->resolver_.stub ()->next_profile_retry ())
           {
             return TAO_INVOKE_RESTART;
           }
@@ -647,36 +684,45 @@ namespace TAO
             throw CORBA::TRANSIENT (CORBA::OMGVMCID | 2, CORBA::COMPLETED_NO);
           }
 
-        TAO_OutputCDR &cdr = transport->out_stream ();
+  {
+    ACE_GUARD_RETURN (TAO_SYNCH_MUTEX, ace_mon, transport->output_cdr_lock (),
+                      TAO_INVOKE_FAILURE);
 
-        cdr.message_attributes (this->details_.request_id (),
-                                this->resolver_.stub (),
-                                TAO_Transport::TAO_ONEWAY_REQUEST,
-                                max_wait_time);
+    TAO_OutputCDR &cdr = transport->out_stream ();
 
-        this->write_header (cdr);
+    cdr.message_attributes (this->details_.request_id (),
+          this->resolver_.stub (),
+          TAO_ONEWAY_REQUEST,
+          max_wait_time);
 
-        this->marshal_data (cdr);
+    this->write_header (cdr);
 
-        countdown.update ();
+    this->marshal_data (cdr);
 
-        if (transport->is_connected ())
+    countdown.update ();
+
+    if (transport->is_connected ())
+      {
+        // We have a connected transport so we can send the message
+        s = this->send_message (cdr,
+              TAO_ONEWAY_REQUEST,
+              max_wait_time);
+      }
+    else
+      {
+        if (TAO_debug_level > 4)
+          ACE_DEBUG ((LM_DEBUG,
+                      "TAO (%P|%t) - Synch_Oneway_Invocation::"
+                      "remote_oneway, queueing message\n"));
+
+        if (transport->format_queue_message (cdr,
+                                             max_wait_time,
+                                             this->resolver_.stub()) != 0)
           {
-            // We have a connected transport so we can send the message
-            s = this->send_message (cdr,
-                                    TAO_Transport::TAO_ONEWAY_REQUEST,
-                                    max_wait_time);
-          }
-        else
-          {
-            if (TAO_debug_level > 4)
-              ACE_DEBUG ((LM_DEBUG,
-                          "TAO (%P|%t) - Synch_Oneway_Invocation::"
-                          "remote_oneway, queueing message\n"));
-
-            if (transport->format_queue_message (cdr, max_wait_time) != 0)
-              s = TAO_INVOKE_FAILURE;
+            s = TAO_INVOKE_FAILURE;
           }
+      }
+  }
 
 #if TAO_HAS_INTERCEPTORS == 1
         s = this->receive_other_interception ();
