@@ -1,4 +1,4 @@
-// $Id: Synch_Reply_Dispatcher.cpp 79705 2007-09-24 07:45:37Z johnnyw $
+// $Id: Synch_Reply_Dispatcher.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "tao/Synch_Reply_Dispatcher.h"
 #include "tao/ORB_Core.h"
@@ -8,7 +8,7 @@
 
 ACE_RCSID (tao,
            Synch_Reply_Dispatcher,
-           "$Id: Synch_Reply_Dispatcher.cpp 79705 2007-09-24 07:45:37Z johnnyw $")
+           "$Id: Synch_Reply_Dispatcher.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -48,6 +48,12 @@ TAO_Synch_Reply_Dispatcher::reply_cdr (void)
   return this->reply_cdr_;
 }
 
+void
+TAO_Synch_Reply_Dispatcher::reply_timed_out (void)
+{
+  // noop
+}
+
 int
 TAO_Synch_Reply_Dispatcher::dispatch_reply (
     TAO_Pluggable_Reply_Params &params)
@@ -62,12 +68,18 @@ TAO_Synch_Reply_Dispatcher::dispatch_reply (
   // this data.
   CORBA::ULong const max = params.svc_ctx_.maximum ();
   CORBA::ULong const len = params.svc_ctx_.length ();
-  IOP::ServiceContext* context_list = params.svc_ctx_.get_buffer (1);
-  this->reply_service_info_.replace (max, len, context_list, 1);
+  IOP::ServiceContext* context_list = params.svc_ctx_.get_buffer (true);
+  this->reply_service_info_.replace (max, len, context_list, true);
+
+  if (this->reply_service_info_.length() > 0)
+    {
+      orb_core_->service_context_registry ().
+        process_service_contexts (this->reply_service_info_, *(params.transport_));
+    }
 
   // Must reset the message state, it is possible that the same reply
   // dispatcher is used because the request must be re-sent.
-  //this->message_state_.reset (0);
+  // this->message_state_.reset (0);
 
   // Transfer the <params.input_cdr_>'s content to this->reply_cdr_
   if (ACE_BIT_DISABLED ((*params.input_cdr_).start()->data_block()->flags(),
@@ -75,7 +87,7 @@ TAO_Synch_Reply_Dispatcher::dispatch_reply (
   {
     // Data block is on the heap, so just duplicate it.
     this->reply_cdr_ = *params.input_cdr_;
-    this->reply_cdr_.clr_mb_flags( ACE_Message_Block::DONT_DELETE );
+    this->reply_cdr_.clr_mb_flags (ACE_Message_Block::DONT_DELETE);
   }
   else
   {
@@ -87,7 +99,7 @@ TAO_Synch_Reply_Dispatcher::dispatch_reply (
           {
             ACE_ERROR ((LM_ERROR,
                         "TAO (%P|%t) - Synch_Reply_Dispatcher::dispatch_reply "
-                        "clone_from failed \n"));
+                        "clone_from failed\n"));
           }
         return -1;
       }
