@@ -1,4 +1,4 @@
-// $Id: SystemException.cpp 80082 2007-11-23 19:34:27Z johnnyw $
+// $Id: SystemException.cpp 85406 2009-05-20 09:07:56Z johnnyw $
 
 #include "tao/SystemException.h"
 #include "tao/ORB_Constants.h"
@@ -26,7 +26,7 @@
 
 ACE_RCSID (tao,
            SystemException,
-           "$Id: SystemException.cpp 80082 2007-11-23 19:34:27Z johnnyw $")
+           "$Id: SystemException.cpp 85406 2009-05-20 09:07:56Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -101,10 +101,13 @@ CORBA::SystemException::~SystemException (void)
 CORBA::SystemException &
 CORBA::SystemException::operator= (const CORBA::SystemException &src)
 {
-  this->Exception::operator= (src);
+  if (this != &src)
+    {
+      this->Exception::operator= (src);
 
-  this->minor_ = src.minor_;
-  this->completed_ = src.completed_;
+      this->minor_ = src.minor_;
+      this->completed_ = src.completed_;
+    }
 
   return *this;
 }
@@ -220,8 +223,8 @@ void
 CORBA::SystemException::_tao_print_system_exception (FILE *) const
 {
   ACE_ERROR ((LM_ERROR,
-              ACE_TEXT("(%P|%t) system exception, ID '%s'\n"),
-              ACE_TEXT_CHAR_TO_TCHAR (this->_info ().c_str ())));
+              ACE_TEXT("(%P|%t) system exception, ID '%C'\n"),
+              this->_info ().c_str ()));
 }
 
 ACE_CString
@@ -309,7 +312,7 @@ CORBA::SystemException::_info (void) const
           location = "unknown location";
         }
 
-      const char *errno_indication;
+      const char *errno_indication = 0;
       char unknown_errno [255];
       CORBA::ULong minor_code = this->minor () & 0x7FU;
       switch (minor_code)
@@ -673,6 +676,13 @@ CORBA::SystemException::_tao_get_omg_exception_description (
       "No entry for requested interface in Interface Repository." // 2
     };
 
+  static const char *TIMEOUT_TABLE[] =
+    {
+      "Reply is not available in the Poller by the timeout set for it.", // 1
+      "End time specified in RequestEndTimePolicy or RelativeRequestTimeoutPolicy has expired.", // 2
+      "End time specified in ReplyEndTimePolicy or RelativeReplyTimeoutPolicy has expired." // 3
+    };
+
   if (minor_code == 0)
     return "*unknown description*";
 
@@ -804,6 +814,12 @@ CORBA::SystemException::_tao_get_omg_exception_description (
       && minor_code < sizeof INTF_REPOS_TABLE / sizeof (char *))
     return INTF_REPOS_TABLE[minor_code];
 
+  CORBA::TIMEOUT const * timeout_exception =
+    dynamic_cast <const CORBA::TIMEOUT *> (&exc);
+  if (timeout_exception != 0
+      && minor_code < sizeof TIMEOUT_TABLE / sizeof (char *))
+    return TIMEOUT_TABLE[minor_code];
+
 #else
   ACE_UNUSED_ARG (exc);
   ACE_UNUSED_ARG (minor_code);
