@@ -1,4 +1,4 @@
-// $Id: TAO_Internal.cpp 80572 2008-02-05 20:02:46Z johnnyw $
+// $Id: TAO_Internal.cpp 89206 2010-02-24 16:37:42Z vzykov $
 
 #include "tao/TAO_Internal.h"
 #include "tao/TAO_Singleton.h"
@@ -21,19 +21,20 @@
 #include "tao/Codeset_Manager_Factory_Base.h"
 #include "tao/Codeset_Manager.h"
 #include "tao/debug.h"
-#include "tao/StringSeqC.h"
 
 #include "ace/Dynamic_Service.h"
 #include "ace/Arg_Shifter.h"
 #include "ace/Argv_Type_Converter.h"
+#include "ace/ARGV.h"
 #include "ace/Env_Value_T.h"
 #include "ace/ACE.h"
 #include "ace/OS_NS_stdio.h"
 #include "ace/Static_Object_Lock.h"
+#include "ace/OS_NS_sys_stat.h"
 
 ACE_RCSID (tao,
            TAO_Internal,
-           "$Id: TAO_Internal.cpp 80572 2008-02-05 20:02:46Z johnnyw $")
+           "$Id: TAO_Internal.cpp 89206 2010-02-24 16:37:42Z vzykov $")
 
 #ifndef TAO_DEFAULT_RESOURCE_FACTORY_ARGS
 #  define TAO_DEFAULT_RESOURCE_FACTORY_ARGS 0
@@ -47,7 +48,6 @@ ACE_RCSID (tao,
 #  define TAO_DEFAULT_CLIENT_STRATEGY_FACTORY_ARGS 0
 #endif  /* !TAO_DEFAULT_RESOURCE_FACTORY_ARGS */
 
-
 namespace
 {
   /**
@@ -68,7 +68,7 @@ namespace
   int
   parse_global_args_i (int &argc,
                        ACE_TCHAR **argv,
-                       CORBA::StringSeq &svc_config_argv,
+                       ACE_ARGV &svc_config_argv,
                        bool apply_values);
 
   /**
@@ -83,8 +83,24 @@ namespace
    */
   int
   parse_svcconf_args_i (int &argc,
-                       ACE_TCHAR **argv,
-                       CORBA::StringSeq &svc_config_argv);
+                        ACE_TCHAR **argv,
+                        ACE_ARGV &svc_config_argv);
+
+  /**
+   * Checks if there is -ORBGestalt option with non-GLOBAL value.
+   *
+   * @brief Modifies the argc to reflect any arguments it has
+   * "consumed"
+   *
+   * If the first ORB has some special configuration and uses non
+   * GLOBAL gestalt then it's expected the this configuration will
+   * not become default for other ORBs created after it. This function
+   * allows to avoid the above situation.
+   */
+  bool
+  using_global_gestalt_i (int &argc,
+                          ACE_TCHAR **argv,
+                          bool &skip_service_config_open);
 
   /**
    * Initialize the ACE Service Configurator with the process-global
@@ -103,8 +119,10 @@ namespace
    *       reentrant meaning that it is really no longer necessary to
    *       do so.
    */
-  void register_global_services_i (ACE_Service_Gestalt * pcfg);
-  void register_additional_services_i (ACE_Service_Gestalt * pcfg);
+  void
+  register_global_services_i (ACE_Service_Gestalt * pcfg);
+  void
+  register_additional_services_i (ACE_Service_Gestalt * pcfg);
 
   /**
    * Parses the supplied command-line arguments to extract any
@@ -116,7 +134,7 @@ namespace
   int
   parse_private_args_i (int &argc,
                         ACE_TCHAR **argv,
-                        CORBA::StringSeq & svc_config_argv,
+                        ACE_ARGV & svc_config_argv,
                         bool & skip_service_config_open);
 
   /**
@@ -126,11 +144,12 @@ namespace
    * @return @c 0 if successful, @c -1 with @c errno set if failure.
    *
    */
-  int open_private_services_i (ACE_Service_Gestalt* pcfg,
-                               int & argc,
-                               char ** argv,
-                               bool skip_service_config_open = false,
-                               bool ignore_default_svc_conf_file = false);
+  int
+  open_private_services_i (ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> pcfg,
+                           int & argc,
+                           ACE_TCHAR **argv,
+                           bool skip_service_config_open = false,
+                           bool ignore_default_svc_conf_file = false);
 
   /**
    * Number of times open_services() has been called.  Incremented by
@@ -185,16 +204,163 @@ public:
   {
   }
 
+
 private:
   /// The mutex, associated with the condition. Do not use the ACE
-  /// global mutex, because it causes deadlocks with other thrads that
+  /// global mutex, because it causes deadlocks with other threads that
   /// may be in DLL_Manager::open()
   ACE_Recursive_Thread_Mutex mutex_;
 };
 #endif // ACE_HAS_THREADS
 
+
+
+
+// ****************************************************************
+/// Note that the argument vector will be corrupted upon return
 int
-TAO::ORB::open_services (ACE_Service_Gestalt* pcfg,
+TAO::ORB::open_global_services (int argc, ACE_TCHAR **argv)
+{
+  {
+    // Count of the number of (times we did this for all) ORBs.
+    static int orb_init_count = 0;
+
+    // Using ACE_Static_Object_Lock::instance() precludes ORB_init()
+    // from being called within a static object CTOR.
+    ACE_MT (ACE_GUARD_RETURN (TAO_SYNCH_RECURSIVE_MUTEX,
+            guard,
+            *ACE_Static_Object_Lock::instance (),
+            -1));
+
+    // Make sure TAO's singleton manager is initialized.
+    // We need to initialize before TAO_default_environment() is called
+    // since that call instantiates a TAO_TSS_Singleton.
+    if (TAO_Singleton_Manager::instance ()->init () == -1)
+      return -1;
+
+    // Prevent multiple initializations.
+    if (++orb_init_count > 1)
+      return 0;
+  }
+
+  // Prevent any other thread from going through ORB initialization before the
+  // uber-gestalt is initialized.
+  ACE_MT (ACE_GUARD_RETURN (TAO_SYNCH_RECURSIVE_MUTEX,
+          guard,
+          TAO_Ubergestalt_Ready_Condition::instance ()->mutex (),
+          -1));
+
+  if (TAO_debug_level > 2)
+    {
+      ACE_DEBUG ((LM_DEBUG,
+      ACE_TEXT ("TAO (%P|%t) Initializing the ")
+      ACE_TEXT ("process-wide service context\n")));
+    }
+
+  ACE_Service_Gestalt* theone = ACE_Service_Config::global ();
+  ACE_Service_Config_Guard auto_config_guard (theone);
+
+  // Construct an argument vector specific to the process-wide
+  // (global) Service Configurator instance.
+  // Be certain to copy the program name so that service configurator
+  // has something to skip!
+  ACE_ARGV global_svc_config_argv (true); // only this ctor allows
+  // subsequent use of add()!
+  global_svc_config_argv.add ((argc <= 0 || argv == 0) ?
+            ACE_TEXT ("") : argv[0], true);
+
+  // Will expand the environment variables, if any were used.
+  // Is this a good thing? I guess it provides greater flexibility
+  // for deployment,so let's leave it. Will also quote arguments.
+  ACE_ARGV copyargv (argc, argv, true, true);
+
+  // Adjust to proper type
+  int tmpargc = argc;
+  ACE_Argv_Type_Converter cvtargv (tmpargc, copyargv.argv());
+
+  tmpargc = cvtargv.get_argc ();
+  ACE_TCHAR **tmpargv = cvtargv.get_TCHAR_argv ();
+
+  // Collect global SC parameters. True means "immediately
+  // apply global setting" like debug flag, etc.
+  if (parse_global_args_i (tmpargc,
+         tmpargv,
+         global_svc_config_argv,
+         true) == -1)
+    return -1;
+
+  bool skip_service_config_open = false; // by default we shouldn't
+
+  if (using_global_gestalt_i (tmpargc,
+                              tmpargv,
+                              skip_service_config_open))
+    {
+      if (parse_svcconf_args_i (tmpargc,
+              tmpargv,
+              global_svc_config_argv) == -1)
+        return -1;
+    }
+
+  if (parse_private_args_i (tmpargc,
+          tmpargv,
+          global_svc_config_argv,
+          skip_service_config_open) == -1)
+    return -1;
+
+  // register_global_services_i depends on the parsing of at least the
+  // -ORBNegotiateCodesets option, and must be invoked after all the
+  // parsing methods, but still must preceed the opening of other services.
+
+  register_global_services_i (theone);
+
+  // Perform the open magic (unless SC::open() has been called already)
+  int global_svc_config_argc = global_svc_config_argv.argc ();
+  int status = open_private_services_i (theone,
+                                        global_svc_config_argc,
+                                        global_svc_config_argv.argv (),
+                                        skip_service_config_open);
+
+  // okay?
+  if (status == -1)
+    {
+      if (TAO_debug_level > 0)
+        {
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) - Failed to open process-")
+                      ACE_TEXT ("wide service configuration context\n")));
+        }
+
+      return -1;
+    }
+
+  if (TAO_debug_level > 2)
+    ACE_DEBUG ((LM_DEBUG,
+                ACE_TEXT ("TAO (%P|%t) - Completed initializing the ")
+                ACE_TEXT ("process-wide service context\n")));
+
+  if (TAO_debug_level > 4)
+    ACE_DEBUG ((LM_DEBUG,
+                ACE_TEXT ("TAO (%P|%t) - Default ORB services initialization begins\n")));
+
+  // Load more ORB-related services
+  register_additional_services_i (theone);
+
+  if (TAO_debug_level > 4)
+    ACE_DEBUG ((LM_DEBUG,
+                ACE_TEXT ("TAO (%P|%t) - Default ORB services initialization completed\n")));
+
+  // Notify all other threads that may be waiting, that the global
+  // gestalt has been initialized.
+  is_ubergestalt_ready = true;
+  ACE_MT (if (TAO_Ubergestalt_Ready_Condition::instance ()->
+              broadcast () == -1)
+            return -1);
+
+  return 0;
+}
+
+int
+TAO::ORB::open_services (ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> pcfg,
                          int &argc,
                          ACE_TCHAR **argv)
 {
@@ -210,16 +376,16 @@ TAO::ORB::open_services (ACE_Service_Gestalt* pcfg,
       {
         if (TAO_debug_level > 4)
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("TAO (%P|%t) Waiting for the default ")
+                      ACE_TEXT ("TAO (%P|%t) - Waiting for the default ")
                       ACE_TEXT ("ORB to complete the global ")
                       ACE_TEXT ("initialization\n")));
 
-        ACE_MT (while (!is_ubergestalt_ready)
-                TAO_Ubergestalt_Ready_Condition::instance ()->wait ());
+      ACE_MT (while (!is_ubergestalt_ready)
+      TAO_Ubergestalt_Ready_Condition::instance ()->wait ());
 
         if (TAO_debug_level > 4)
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("TAO (%P|%t) The default ")
+                      ACE_TEXT ("TAO (%P|%t) - The default ")
                       ACE_TEXT ("ORB must have completed the global ")
                       ACE_TEXT ("initialization...\n")));
 
@@ -228,37 +394,24 @@ TAO::ORB::open_services (ACE_Service_Gestalt* pcfg,
       {
         if (TAO_debug_level > 4)
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("TAO (%P|%t) We are %sthe default ")
+                      ACE_TEXT ("TAO (%P|%t) - We are%Cthe default ")
                       ACE_TEXT ("ORB ...\n"),
-                      (service_open_count == 0) ? "" : "not "));
+                      (service_open_count == 0) ? " " : " not "));
       }
 
     ++service_open_count;
   }
 
-  // Construct an argument vector specific to the Service
-  // Configurator.
-  CORBA::StringSeq svc_config_argv;
-
+  // Construct an argument vector specific to the Service Configurator.
   // Be certain to copy the program name so that service configurator
   // has something to skip!
-  ACE_CString argv0 ("");
+  ACE_ARGV svc_config_argv (true);  // only this ctor allows subsequent
+                                    // use of add()!
+  svc_config_argv.add ((argc <= 0 || argv == 0) ? ACE_TEXT ("") : argv[0],
+                       true);
 
-  if (argc > 0 && argv != 0)
-    {
-      argv0 = ACE_TEXT_ALWAYS_CHAR (argv[0]);
-    }
-
-  svc_config_argv.length (1);
-  svc_config_argv[0] = argv0.c_str ();
-
-  // Should we skip the ACE_Service_Config::open() method, e.g., if we
-  // already being configured by the ACE Service Configurator.
-  //
-  // @@ This is no longer needed since the Service Configurator is now
-  // reentrant.(-Ossama)
-  // @@ Leaving it in, since the -ORBSkipServiceConfigOpen is still
-  // available. (-Iliyan)
+  // Should we skip the ACE_Service_Config::open() method?,
+  // e.g., because of -ORBSkipServiceConfigOpen
   bool skip_service_config_open = false;
 
   // Extract any ORB options from the argument vector.
@@ -272,152 +425,54 @@ TAO::ORB::open_services (ACE_Service_Gestalt* pcfg,
 
   // Construct an argument vector specific to the process-wide
   // (global) Service Configurator instance.
-  CORBA::StringSeq global_svc_config_argv;
+  ACE_ARGV global_svc_config_argv;
 
-  ACE_Service_Gestalt * theone = ACE_Service_Config::global ();
+  // Parse any globally applicable arguments, but do not make them effective.
+  // We are effectively purging the command line from them without affecting
+  // the global state - after all, it may be a private (local) configuration
+  // context.
+  int status = parse_global_args_i(argc, argv, global_svc_config_argv, false);
 
-  if (service_open_count == 1)
-    {
-      ACE_Service_Config_Guard config_guard (theone);
-
-      if (TAO_debug_level > 2)
-        {
-          ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("TAO (%P|%t) Initializing the ")
-                      ACE_TEXT ("process-wide services\n")));
-        }
-
-      register_global_services_i (theone);
-
-      // Be certain to copy the program name so that service configurator
-      // has something to skip!
-      ACE_CString gargv0 ("");
-
-      if (argc > 0 && argv != 0)
-        {
-          gargv0 = ACE_TEXT_ALWAYS_CHAR (argv[0]);
-        }
-
-      global_svc_config_argv.length (1);
-      global_svc_config_argv[0] = gargv0.c_str ();
-
-      if (parse_global_args_i (argc, argv, global_svc_config_argv, true) == -1)
-        {
-          return -1;
-        }
-
-      if (parse_svcconf_args_i (argc, argv, global_svc_config_argv) == -1)
-        {
-          return -1;
-        }
-
-      // If the target configuration happens to be the global context,
-      // add any 'private' arguments here.
-      if (pcfg == theone && svc_config_argv.length() > 1)
-        {
-          CORBA::ULong glen = global_svc_config_argv.length();
-          global_svc_config_argv.length(glen + svc_config_argv.length() - 1);
-          for (CORBA::ULong i = 1; i < svc_config_argv.length(); i++)
-            global_svc_config_argv[glen++] = svc_config_argv[i];
-          svc_config_argv.length(1);
-        }
-
-      int global_svc_config_argc = global_svc_config_argv.length ();
-      int status =
-        open_private_services_i (theone,
-                                 global_svc_config_argc,
-                                 global_svc_config_argv.get_buffer (),
-                                 skip_service_config_open);
-
-      if (status == -1)
-        {
-          if (TAO_debug_level > 0)
-            {
-              ACE_ERROR ((LM_DEBUG,
-                          ACE_TEXT ("TAO (%P|%t) Failed to open process-")
-                          ACE_TEXT ("wide service configuration\n")));
-            }
-
-          return -1;
-        }
-
-      register_additional_services_i (theone);
-
-      if (TAO_debug_level > 4)
-        ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("TAO (%P|%t) Default ORB - global ")
-                    ACE_TEXT ("initialization completed.\n")));
-
-      // Notify all other threads that may be waiting, that the global
-      // gestalt has been initialized.
-      {
-        ACE_MT (ACE_GUARD_RETURN (TAO_SYNCH_RECURSIVE_MUTEX,
-                                  guard,
-                                  TAO_Ubergestalt_Ready_Condition::instance ()->mutex (),
-                                  -1));
-
-        is_ubergestalt_ready = true;
-        ACE_MT (if (TAO_Ubergestalt_Ready_Condition::instance ()->
-                    broadcast () == -1)
-                return -1);
-      }
-
-    }
-  else
-    {
-      int status =
-        parse_global_args_i(argc, argv,global_svc_config_argv, false);
-      if (status == -1 && TAO_debug_level > 0)
-        ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("TAO (%P|%t) Skipping the process-wide ")
-                    ACE_TEXT ("service configuration, service_open_count ")
-                    ACE_TEXT ("= %d, status = %d\n"),
-                    service_open_count,
-                    status));
-    }
+  if (status == -1 && TAO_debug_level > 0)
+    ACE_DEBUG ((LM_DEBUG,
+    ACE_TEXT ("TAO (%P|%t) - Skipping the process-wide ")
+    ACE_TEXT ("service configuration, service_open_count ")
+    ACE_TEXT ("= %d, status = %d\n"),
+    service_open_count,
+    status));
 
   if (TAO_debug_level > 2)
-    {
-      ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("TAO (%P|%t) Initializing the ")
-                  ACE_TEXT ("orb-specific services\n")));
-    }
+    ACE_DEBUG ((LM_DEBUG,
+    ACE_TEXT ("TAO (%P|%t) - Initializing the ")
+    ACE_TEXT ("orb-specific services\n")));
 
   if (parse_svcconf_args_i (argc, argv, svc_config_argv) == -1)
-    {
-      return -1;
-    }
-
-  int status = 0;
+    return -1;
+  // Not a big deal to call open_private_services_i() again (if it was the global one). The SG::open() would not run if it has already been executed.
   // only open the private context if it is not also the global context
   if (pcfg != ACE_Service_Config::global())
     {
-      int svc_config_argc = svc_config_argv.length ();
+      int svc_config_argc = svc_config_argv.argc ();
       status =
         open_private_services_i (pcfg,
                                  svc_config_argc,
-                                 svc_config_argv.get_buffer (),
+                                 svc_config_argv.argv (),
                                  skip_service_config_open);
     }
 
-  if (status >= 0)
+  if (status < 0 && TAO_debug_level > 0)
     {
-      return 0;
-    }
-
-  if (TAO_debug_level > 0)
-    {
-      ACE_ERROR_RETURN ((LM_DEBUG,
-                         ACE_TEXT ("TAO (%P|%t) Failed to ")
+      ACE_ERROR_RETURN ((LM_ERROR,
+                         ACE_TEXT ("TAO (%P|%t) - Failed to ")
                          ACE_TEXT ("open orb service configuration\n")),
                         -1);
     }
 
-  return -1;
+  return status;
 }
 
 int
-TAO::ORB::close_services (ACE_Service_Gestalt* pcfg)
+TAO::ORB::close_services (ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> pcfg)
 {
   ACE_MT (ACE_GUARD_RETURN (TAO_SYNCH_RECURSIVE_MUTEX,
                             guard,
@@ -425,9 +480,14 @@ TAO::ORB::close_services (ACE_Service_Gestalt* pcfg)
                             -1));
   --service_open_count;
 
-  if (pcfg == ACE_Service_Config::global())
-    return 0;
-  return pcfg->close ();
+  int result = 0;
+
+  if (pcfg != ACE_Service_Config::global())
+    {
+      result = pcfg->close ();
+    }
+
+  return result;
 }
 
 void
@@ -448,9 +508,9 @@ namespace
   /// Open services, belonging to the gestalt instance.
 
   int
-  open_private_services_i (ACE_Service_Gestalt * pcfg,
+  open_private_services_i (ACE_Intrusive_Auto_Ptr<ACE_Service_Gestalt> pcfg,
                            int & argc,
-                           char ** argv,
+                           ACE_TCHAR ** argv,
                            bool skip_service_config_open,
                            bool ignore_default_svc_conf_file)
   {
@@ -469,7 +529,7 @@ namespace
 
     return pcfg->open (command_line.get_argc (),
                        command_line.get_TCHAR_argv (),
-                       ACE_DEFAULT_LOGGER_KEY,
+                       0,
                        0, // Don't ignore static services.
                        ignore_default_svc_conf_file);
   }
@@ -490,7 +550,7 @@ namespace
 
         if (factory == 0 || factory->is_default ())
           {
-#if !defined (TAO_AS_STATIC_LIBS)
+#if !defined (TAO_AS_STATIC_LIBS) && !(defined (ACE_VXWORKS) && !defined (__RTP__))
             // only for dynamic libs, check to see if default factory
             // and if so, remove it
             ACE_Service_Config::process_directive (
@@ -506,8 +566,8 @@ namespace
             factory =
               ACE_Dynamic_Service<
                   TAO_Codeset_Manager_Factory_Base
-                >::instance ("TAO_Codeset");
-#endif
+                 >::instance ("TAO_Codeset");
+#endif /* !TAO_AS_STATIC_LIBS && !(ACE_VXWORKS && !__RTP__) */
           }
 
         if (factory == 0)
@@ -515,7 +575,7 @@ namespace
             if (TAO_debug_level > 0)
               {
                 ACE_ERROR ((LM_ERROR,
-                            ACE_TEXT ("(%P|%t) ORB_Core: ")
+                            ACE_TEXT ("TAO (%P|%t) ORB_Core: ")
                             ACE_TEXT ("Unable to initialize ")
                             ACE_TEXT ("Codeset Manager\n")));
               }
@@ -617,6 +677,18 @@ namespace
         bidir_loader->init (0, 0);
       }
 
+#if defined (TAO_HAS_ZIOP) && TAO_HAS_ZIOP == 1
+    ACE_Service_Object * const ziop_loader =
+      ACE_Dynamic_Service<ACE_Service_Object>::instance (
+        pcfg,
+        "ZIOP_Loader");
+
+    if (ziop_loader != 0)
+      {
+        ziop_loader->init (0, 0);
+      }
+#endif
+
     ACE_Service_Object * const messaging_loader =
       ACE_Dynamic_Service<ACE_Service_Object>::instance (
         pcfg,
@@ -684,26 +756,24 @@ namespace
   int
   parse_svcconf_args_i (int &argc,
                         ACE_TCHAR **argv,
-                        CORBA::StringSeq &svc_config_argv)
+                        ACE_ARGV &svc_config_argv)
   {
     // Extract the Service Configurator ORB options from the argument
     // vector.
     ACE_Arg_Shifter arg_shifter (argc, argv);
-    CORBA::ULong len = 0;
 
     while (arg_shifter.is_anything_left ())
       {
-        const ACE_TCHAR *current_arg =
-          arg_shifter.get_the_parameter (ACE_TEXT ("-ORBSvcConf"));
-
-        if (0 != current_arg)
+        // Can't interpret this argument.  Move on to the next argument.
+        if (arg_shifter.cur_arg_strncasecmp (ACE_TEXT ("-ORBSvcConf")) == 0)
           {
-            // Specify the name of the svc.conf file to be used.
+            const ACE_TCHAR *current_arg =
+                        arg_shifter.get_the_parameter (ACE_TEXT ("-ORBSvcConf"));
+            arg_shifter.consume_arg ();
 
             // Proceeds only if the configuration file exists.
             FILE * const conf_file =
               ACE_OS::fopen (current_arg, ACE_TEXT ("r"));
-
             if (0 == conf_file)
               {
                 // Assigning EINVAL to errno to make an exception
@@ -712,9 +782,8 @@ namespace
                 errno = EINVAL;
 
                 ACE_ERROR_RETURN ((LM_ERROR,
-                                   ACE_TEXT ("TAO (%P|%t) Service ")
-                                   ACE_TEXT ("Configurator ")
-                                   ACE_TEXT ("unable to open file %s\n"),
+                                   ACE_TEXT ("TAO (%P|%t) - Unable to open file <%s>")
+                                   ACE_TEXT (", referenced by -ORBSvcConf option\n"),
                                    current_arg),
                                   -1);
               }
@@ -723,16 +792,24 @@ namespace
                 ACE_OS::fclose (conf_file);
               }
 
-            len = svc_config_argv.length ();
-            svc_config_argv.length (len + 2);  // 2 arguments to add
+            svc_config_argv.add (ACE_TEXT ("-f"));
+            svc_config_argv.add (current_arg, true);
+          }
+        else if (arg_shifter.cur_arg_strncasecmp
+                 (ACE_TEXT ("-ORBSvcConfDirective")) == 0)
+          {
+            const ACE_TCHAR *current_arg =
+              arg_shifter.get_the_parameter (ACE_TEXT ("-ORBSvcConfDirective"));
 
-            svc_config_argv[len] = CORBA::string_dup ("-f");
-            svc_config_argv[len + 1] =
-              CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR (current_arg));
+            // This is used to pass arguments to the Service
+            // Configurator using the "command line" to provide
+            // configuration information rather than using a svc.conf
+            // file.  Pass the "-S" to the service configurator.
+            svc_config_argv.add (ACE_TEXT ("-S"));
+            svc_config_argv.add (current_arg, true); // quote args!
 
             arg_shifter.consume_arg ();
           }
-        // Can't interpret this argument.  Move on to the next argument.
         else
           {
             // Any arguments that don't match are ignored so that the
@@ -747,13 +824,12 @@ namespace
   int
   parse_private_args_i (int &argc,
                         ACE_TCHAR **argv,
-                        CORBA::StringSeq &svc_config_argv,
+                        ACE_ARGV &svc_config_argv,
                         bool & skip_service_config_open)
   {
     // Extract the Service Configurator ORB options from the argument
     // vector.
     ACE_Arg_Shifter arg_shifter (argc, argv);
-    CORBA::ULong len = 0;
 
     while (arg_shifter.is_anything_left ())
       {
@@ -763,33 +839,13 @@ namespace
           {
             skip_service_config_open = true;
 
-            arg_shifter.consume_arg ();
-          }
-        else if (0 != (current_arg = arg_shifter.get_the_parameter
-                       (ACE_TEXT ("-ORBSvcConfDirective"))))
-          {
-            len = svc_config_argv.length ();
-            svc_config_argv.length (len + 2);  // 2 arguments to add
-
-            // This is used to pass arguments to the Service
-            // Configurator using the "command line" to provide
-            // configuration information rather than using a svc.conf
-            // file.  Pass the "-S" to the service configurator.
-            svc_config_argv[len] = CORBA::string_dup ("-S");
-            svc_config_argv[len + 1] =
-              CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR (current_arg));
-
             arg_shifter.consume_arg ();
           }
         else if (0 != (current_arg = arg_shifter.get_the_parameter
                        (ACE_TEXT ("-ORBServiceConfigLoggerKey"))))
           {
-            len = svc_config_argv.length ();
-            svc_config_argv.length (len + 2);  // 2 arguments to add
-
-            svc_config_argv[len] = CORBA::string_dup ("-k");
-            svc_config_argv[len + 1] =
-              CORBA::string_dup (ACE_TEXT_ALWAYS_CHAR (current_arg));
+            svc_config_argv.add (ACE_TEXT ("-k"));
+            svc_config_argv.add (current_arg, true); // quote args!
 
             arg_shifter.consume_arg ();
           }
@@ -804,6 +860,7 @@ namespace
 
             if (0 != (current_arg = arg_shifter.get_current()))
               negotiate_codesets = (ACE_OS::atoi (current_arg));
+
             arg_shifter.ignore_arg();
           }
         else if (0 != (current_arg =
@@ -831,7 +888,7 @@ namespace
   int
   parse_global_args_i (int &argc,
                        ACE_TCHAR **argv,
-                       CORBA::StringSeq &svc_config_argv,
+                       ACE_ARGV &svc_config_argv,
                        bool apply_values)
   {
     // NOTE: When adding new global arguments, ensure they are only
@@ -864,7 +921,6 @@ namespace
     // Extract the Service Configurator ORB options from the argument
     // vector.
     ACE_Arg_Shifter arg_shifter (argc, argv);
-    CORBA::ULong len = 0;
 
     while (arg_shifter.is_anything_left ())
       {
@@ -879,17 +935,12 @@ namespace
 
             arg_shifter.consume_arg ();
           }
-        else if (0 == arg_shifter.cur_arg_strncasecmp
-                 (ACE_TEXT ("-ORBDaemon")))
+        else if (0 == arg_shifter.cur_arg_strncasecmp (ACE_TEXT ("-ORBDaemon")))
           {
             // Be a daemon.
             if (apply_values)
               {
-                len = svc_config_argv.length ();
-                svc_config_argv.length (len + 1);
-
-                svc_config_argv[len] =
-                  CORBA::string_dup ("-b");
+                svc_config_argv.add (ACE_TEXT("-b"));
               }
 
             arg_shifter.consume_arg ();
@@ -905,4 +956,55 @@ namespace
       }
     return 0;
   } /* parse_global_args_i */
+
+  bool
+  using_global_gestalt_i (int &argc,
+                          ACE_TCHAR **argv,
+                          bool &skip_service_config_open)
+  {
+    bool with_global_gestalt = true;
+
+    ACE_Arg_Shifter arg_shifter (argc, argv);
+
+    while (arg_shifter.is_anything_left ())
+      {
+        if (0 == arg_shifter.cur_arg_strncasecmp (ACE_TEXT ("-ORBGestalt")))
+          {
+            // Skip -ORBGestalt. This option is necessary in later stages.
+            arg_shifter.ignore_arg ();
+
+            // This should set current_arg to the value of ORBGestalt option.
+            const ACE_TCHAR *current_arg = arg_shifter.get_current ();
+
+            if (0 != current_arg &&
+                ACE_OS::strcasecmp (current_arg, ACE_TEXT("GLOBAL")) != 0)
+              {
+                with_global_gestalt = false;
+
+                ACE_stat exists;
+                if (ACE_OS::stat (ACE_DEFAULT_SVC_CONF, &exists) == 0)
+                  {
+                    // In case svc.conf exists and we are asked for a local
+                    // gestalt then no matter whether -ORBSvcConf or
+                    // -ORBSvcConfDirective are provided or not we ignore them
+                    // while setting up a global gestalt. They will be
+                    // processed later in a local gestalt.
+                    skip_service_config_open = true;
+                  }
+              }
+
+            // Skip anything that goes after -ORBGestalt.
+            arg_shifter.ignore_arg ();
+          }
+        // Can't interpret this argument.
+        // Move on to the next argument.
+        else
+          {
+            // Any arguments that don't match are ignored so
+            // that the caller can still use them.
+            arg_shifter.ignore_arg ();
+          }
+      }
+    return with_global_gestalt;
+  } /* using_global_gestalt_i */
 } // anonymous namespace.
