@@ -1,4 +1,4 @@
-// $Id: TAO_Server_Request.cpp 79705 2007-09-24 07:45:37Z johnnyw $
+// $Id: TAO_Server_Request.cpp 85203 2009-04-28 20:34:16Z mitza $
 
 #include "tao/TAO_Server_Request.h"
 #include "tao/ORB_Core.h"
@@ -23,7 +23,7 @@
 
 ACE_RCSID (tao,
            TAO_Server_Request,
-           "$Id: TAO_Server_Request.cpp 79705 2007-09-24 07:45:37Z johnnyw $")
+           "$Id: TAO_Server_Request.cpp 85203 2009-04-28 20:34:16Z mitza $")
 
 #if defined (ACE_ENABLE_TIMEPROBES)
 
@@ -57,6 +57,7 @@ TAO_ServerRequest::TAO_ServerRequest (TAO_GIOP_Message_Base *mesg_base,
     operation_ (0),
     operation_len_ (0),
     release_operation_ (false),
+    is_forwarded_ (false),
     incoming_ (&input),
     outgoing_ (&output),
     response_expected_ (false),
@@ -99,6 +100,7 @@ TAO_ServerRequest::TAO_ServerRequest (TAO_GIOP_Message_Base *mesg_base,
     operation_ (CORBA::string_dup (operation)),
     operation_len_ (operation == 0 ? 0 : ACE_OS::strlen (operation)),
     release_operation_ (true),
+    is_forwarded_ (false),
     incoming_ (0),
     outgoing_ (&output),
     response_expected_ (response_expected),
@@ -133,6 +135,7 @@ TAO_ServerRequest::TAO_ServerRequest (TAO_ORB_Core * orb_core,
     operation_ (details.opname ()),
     operation_len_ (details.opname_len ()),
     release_operation_ (false),
+    is_forwarded_ (false),
     incoming_ (0),
     outgoing_ (0),
     response_expected_ (details.response_flags () == TAO_TWOWAY_RESPONSE_FLAG
@@ -208,14 +211,14 @@ TAO_Service_Context &
 TAO_ServerRequest::reply_service_context (void)
 {
   if (!operation_details_)
-  {
-    return this->reply_service_context_;
-  }
+    {
+      return this->reply_service_context_;
+    }
   else
-  {
-    return const_cast <TAO_Operation_Details*> (
-      this->operation_details_)->reply_service_context ();
-  }
+    {
+      return const_cast <TAO_Operation_Details*> (
+        this->operation_details_)->reply_service_context ();
+    }
 }
 
 
@@ -247,7 +250,7 @@ TAO_ServerRequest::init_reply (void)
   reply_params.argument_flag_ = this->argument_flag_;
 
   // Forward exception only.
-  if (!CORBA::is_nil (this->forward_location_.in ()))
+  if (this->is_forwarded_)
     {
       CORBA::Boolean const permanent_forward_condition =
         this->orb_core_->is_permanent_forward_condition (this->forward_location_.in (),
@@ -266,7 +269,7 @@ TAO_ServerRequest::init_reply (void)
 
   this->outgoing_->message_attributes (this->request_id_,
                                        0,
-                                       TAO_Transport::TAO_REPLY,
+                                       TAO_REPLY,
                                        0);
 
   // Construct a REPLY header.
@@ -313,7 +316,7 @@ TAO_ServerRequest::send_no_exception_reply (void)
 
   this->outgoing_->message_attributes (this->request_id_,
                                        0,
-                                       TAO_Transport::TAO_REPLY,
+                                       TAO_REPLY,
                                        0);
 
   // Construct a REPLY header.
@@ -324,7 +327,7 @@ TAO_ServerRequest::send_no_exception_reply (void)
   // Send the message.
   int result = this->transport_->send_message (*this->outgoing_,
                                                0,
-                                               TAO_Transport::TAO_REPLY);
+                                               TAO_REPLY);
 
   if (result == -1)
     {
@@ -349,9 +352,9 @@ TAO_ServerRequest::tao_send_reply (void)
 
   this->outgoing_->more_fragments (false);
 
-  int result = this->transport_->send_message (*this->outgoing_,
-                                               0,
-                                               TAO_Transport::TAO_REPLY);
+  int const result = this->transport_->send_message (*this->outgoing_,
+                                                     0,
+                                                     TAO_REPLY);
   if (result == -1)
     {
       if (TAO_debug_level > 0)
@@ -420,27 +423,40 @@ TAO_ServerRequest::tao_send_reply_exception (const CORBA::Exception &ex)
                             gv.minor);
 
       this->transport_->assign_translators (0, &output);
-      // Make the reply message
-      if (this->mesg_base_->generate_exception_reply (*this->outgoing_,
-                                                      reply_params,
-                                                      ex) == -1)
-        {
-          ACE_ERROR ((LM_ERROR,
-                      ACE_TEXT ("TAO (%P|%t) - ServerRequest::tao_send_reply_exception, ")
-                      ACE_TEXT ("could not make exception reply\n")));
 
+      try
+        {
+          // Make the reply message
+          if (this->mesg_base_->generate_exception_reply (*this->outgoing_,
+                                                          reply_params,
+                                                          ex) == -1)
+            {
+              ACE_ERROR ((LM_ERROR,
+                          ACE_TEXT ("TAO (%P|%t) - ServerRequest::")
+                          ACE_TEXT ("tao_send_reply_exception, ")
+                          ACE_TEXT ("could not make exception reply\n")));
+            }
+
+          this->outgoing_->more_fragments (false);
+
+          // Send the message
+          if (this->transport_->send_message (*this->outgoing_,
+                                              0,
+                                              TAO_REPLY) == -1)
+            {
+              ACE_ERROR ((LM_ERROR,
+                          ACE_TEXT ("TAO (%P|%t) - ServerRequest::")
+                          ACE_TEXT ("tao_send_reply_exception, ")
+                          ACE_TEXT ("could not send exception reply\n")));
+            }
         }
-
-      this->outgoing_->more_fragments (false);
-
-      // Send the message
-      if (this->transport_->send_message (*this->outgoing_,
-                                          0,
-                                          TAO_Transport::TAO_REPLY) == -1)
+      catch (const ::CORBA::BAD_PARAM &bp_ex)
         {
           ACE_ERROR ((LM_ERROR,
-                      ACE_TEXT ("TAO (%P|%t) - ServerRequest::tao_send_reply_exception, ")
-                      ACE_TEXT ("could not send exception reply\n")));
+                      ACE_TEXT ("TAO (%P|%t) - ServerRequest::")
+                      ACE_TEXT ("tao_send_reply_exception, ")
+                      ACE_TEXT ("could not marshal exception reply\n")));
+          this->tao_send_reply_exception (bp_ex);
         }
     }
   else if (TAO_debug_level > 0)
@@ -462,7 +478,7 @@ TAO_ServerRequest::tao_send_reply_exception (const CORBA::Exception &ex)
 void
 TAO_ServerRequest::send_cached_reply (CORBA::OctetSeq &s)
 {
-#if defined(ACE_HAS_PURIFY)
+#if defined(ACE_INITIALIZE_MEMORY_BEFORE_USE)
   // Only inititialize the buffer if we're compiling with Purify.
   // Otherwise, there is no real need to do so, especially since
   // we can avoid the initialization overhead at runtime if we
@@ -473,7 +489,9 @@ TAO_ServerRequest::send_cached_reply (CORBA::OctetSeq &s)
 #endif /* ACE_HAS_PURIFY */
   TAO_GIOP_Message_Version gv;
   if (this->outgoing_)
-    this->outgoing_->get_version (gv);
+    {
+      this->outgoing_->get_version (gv);
+    }
   TAO_OutputCDR output (repbuf,
                         sizeof repbuf,
                         TAO_ENCAP_BYTE_ORDER,
@@ -505,7 +523,7 @@ TAO_ServerRequest::send_cached_reply (CORBA::OctetSeq &s)
 
   this->outgoing_->message_attributes (this->request_id_,
                                        0,
-                                       TAO_Transport::TAO_REPLY,
+                                       TAO_REPLY,
                                        0);
 
   // Make the reply message
@@ -524,16 +542,18 @@ TAO_ServerRequest::send_cached_reply (CORBA::OctetSeq &s)
     s.length ());
 
   if (!this->outgoing_->good_bit ())
-    ACE_ERROR ((LM_ERROR,
-                ACE_TEXT ("TAO (%P|%t) - ServerRequest::send_cached_reply, ")
-                ACE_TEXT ("could not marshal reply\n")));
+    {
+      ACE_ERROR ((LM_ERROR,
+                  ACE_TEXT ("TAO (%P|%t) - ServerRequest::send_cached_reply, ")
+                  ACE_TEXT ("could not marshal reply\n")));
+    }
 
   this->outgoing_->more_fragments (false);
 
   // Send the message
   if (this->transport_->send_message (*this->outgoing_,
                                       0,
-                                      TAO_Transport::TAO_REPLY) == -1)
+                                      TAO_REPLY) == -1)
     {
       ACE_ERROR ((LM_ERROR,
                   ACE_TEXT ("TAO (%P|%t) - ServerRequest::send_cached_reply, ")
@@ -569,6 +589,6 @@ TAO_ServerRequest::rs_pi_current (void)
   return this->rs_pi_current_;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 #endif /* TAO_HAS_INTERCEPTORS */
+
+TAO_END_VERSIONED_NAMESPACE_DECL
