@@ -1,4 +1,4 @@
-// Thread_Lane_Resources_Manager.cpp,v 1.7 2005/07/13 18:53:07 jwillemsen Exp
+// $Id: Thread_Lane_Resources_Manager.cpp 69153 2005-11-02 11:03:27Z ossama $
 
 #include "tao/Thread_Lane_Resources_Manager.h"
 #include "tao/ORB_Core.h"
@@ -8,7 +8,9 @@
 
 ACE_RCSID (tao,
            Thread_Lane_Resources_Manager,
-           "Thread_Lane_Resources_Manager.cpp,v 1.7 2005/07/13 18:53:07 jwillemsen Exp")
+           "$Id: Thread_Lane_Resources_Manager.cpp 69153 2005-11-02 11:03:27Z ossama $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Thread_Lane_Resources_Manager::TAO_Thread_Lane_Resources_Manager (TAO_ORB_Core &orb_core)
   : orb_core_ (&orb_core),
@@ -33,3 +35,4 @@ TAO_Thread_Lane_Resources_Manager_Factory::~TAO_Thread_Lane_Resources_Manager_Fa
 {
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
