@@ -1,4 +1,4 @@
-// $Id: Transport.cpp 80654 2008-02-19 00:24:36Z johnc $
+// $Id: Transport.cpp 88803 2010-02-02 11:13:27Z vzykov $
 
 #include "tao/Transport.h"
 
@@ -23,6 +23,8 @@
 #include "tao/ORB_Core.h"
 #include "tao/MMAP_Allocator.h"
 #include "tao/SystemException.h"
+#include "tao/operation_details.h"
+#include "tao/Transport_Descriptor_Interface.h"
 
 #include "ace/OS_NS_sys_time.h"
 #include "ace/OS_NS_stdio.h"
@@ -45,7 +47,7 @@
 
 ACE_RCSID (tao,
            Transport,
-           "$Id: Transport.cpp 80654 2008-02-19 00:24:36Z johnc $")
+           "$Id: Transport.cpp 88803 2010-02-02 11:13:27Z vzykov $")
 
 /*
  * Static function in file scope
@@ -53,14 +55,14 @@ ACE_RCSID (tao,
 static void
 dump_iov (iovec *iov, int iovcnt, size_t id,
           size_t current_transfer,
-          const char *location)
+          const ACE_TCHAR *location)
 {
   ACE_Guard <ACE_Log_Msg> log_guard (*ACE_Log_Msg::instance ());
 
   ACE_DEBUG ((LM_DEBUG,
               ACE_TEXT ("TAO (%P|%t) - Transport[%d]::%s, ")
               ACE_TEXT ("sending %d buffers\n"),
-              id, ACE_TEXT_CHAR_TO_TCHAR (location), iovcnt));
+              id, location, iovcnt));
 
   for (int i = 0; i != iovcnt && 0 < current_transfer; ++i)
     {
@@ -75,7 +77,7 @@ dump_iov (iovec *iov, int iovcnt, size_t id,
       ACE_DEBUG ((LM_DEBUG,
                   ACE_TEXT ("TAO (%P|%t) - Transport[%d]::%s, ")
                   ACE_TEXT ("buffer %d/%d has %d bytes\n"),
-                  id, ACE_TEXT_CHAR_TO_TCHAR(location),
+                  id, location,
                   i, iovcnt,
                   iov_len));
 
@@ -112,7 +114,7 @@ dump_iov (iovec *iov, int iovcnt, size_t id,
   ACE_DEBUG ((LM_DEBUG,
               ACE_TEXT ("TAO (%P|%t) - Transport[%d]::%s, ")
               ACE_TEXT ("end of data\n"),
-              id, ACE_TEXT_CHAR_TO_TCHAR(location)));
+              id, location));
 }
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -130,6 +132,8 @@ TAO_Transport::TAO_Transport (CORBA::ULong tag,
   : tag_ (tag)
   , orb_core_ (orb_core)
   , cache_map_entry_ (0)
+  , tms_ (0)
+  , ws_ (0)
   , bidirectional_flag_ (-1)
   , opening_connection_role_ (TAO::TAO_UNSPECIFIED_ROLE)
   , head_ (0)
@@ -148,7 +152,7 @@ TAO_Transport::TAO_Transport (CORBA::ULong tag,
   , char_translator_ (0)
   , wchar_translator_ (0)
   , tcs_set_ (0)
-  , first_request_ (1)
+  , first_request_ (true)
   , partial_message_ (0)
 #if TAO_HAS_SENDFILE == 1
     // The ORB has been configured to use the MMAP allocator, meaning
@@ -163,6 +167,7 @@ TAO_Transport::TAO_Transport (CORBA::ULong tag,
 #if TAO_HAS_TRANSPORT_CURRENT == 1
   , stats_ (0)
 #endif /* TAO_HAS_TRANSPORT_CURRENT == 1 */
+  , flush_in_post_open_ (false)
 {
   ACE_NEW (this->messaging_object_,
             TAO_GIOP_Message_Base (orb_core,
@@ -209,9 +214,6 @@ TAO_Transport::~TAO_Transport (void)
       // When we have a not connected transport we could have buffered
       // messages on this transport which we have to cleanup now.
       this->cleanup_queue_i();
-
-      // Cleanup our cache entry
-      this->purge_entry();
     }
 
   // Release the partial message block, however we may
@@ -223,7 +225,7 @@ TAO_Transport::~TAO_Transport (void)
 
   // The following assert is needed for the test "Bug_2494_Regression".
   // See the bugzilla bug #2494 for details.
-  ACE_ASSERT (this->head_ == 0);
+  ACE_ASSERT (this->queue_is_empty_i ());
   ACE_ASSERT (this->cache_map_entry_ == 0);
 
 #if TAO_HAS_TRANSPORT_CURRENT == 1
@@ -325,6 +327,34 @@ TAO_Transport::post_connect_hook (void)
   return true;
 }
 
+bool
+TAO_Transport::register_if_necessary (void)
+{
+  if (this->is_connected_ &&
+      this->wait_strategy ()->register_handler () == -1)
+    {
+      // Registration failures.
+      if (TAO_debug_level > 0)
+        {
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) - Transport[%d]::register_if_necessary, ")
+                      ACE_TEXT ("could not register the transport ")
+                      ACE_TEXT ("in the reactor.\n"),
+                      this->id ()));
+        }
+
+      // Purge from the connection cache, if we are not in the cache, this
+      // just does nothing.
+      (void) this->purge_entry ();
+
+      // Close the handler.
+      (void) this->close_connection ();
+
+      return false;
+    }
+  return true;
+}
+
 void
 TAO_Transport::close_connection (void)
 {
@@ -371,7 +401,7 @@ TAO_Transport::sendfile (TAO_MMAP_Allocator * /* allocator */,
                          iovec * iov,
                          int iovcnt,
                          size_t &bytes_transferred,
-                         ACE_Time_Value const * timeout)
+                         TAO::Transport::Drain_Constraints const & dc)
 {
   // Concrete pluggable transport doesn't implement sendfile().
   // Fallback on TAO_Transport::send().
@@ -380,7 +410,8 @@ TAO_Transport::sendfile (TAO_MMAP_Allocator * /* allocator */,
   //    implementation to this base class method, and leave any TCP
   //    specific configuration out of this base class method.
   //      -Ossama
-  return this->send (iov, iovcnt, bytes_transferred, timeout);
+  return this->send (iov, iovcnt, bytes_transferred,
+                     this->io_timeout (dc));
 }
 #endif  /* TAO_HAS_SENDFILE==1 */
 
@@ -396,7 +427,7 @@ TAO_Transport::generate_locate_request (
     {
       if (TAO_debug_level > 0)
         {
-          ACE_DEBUG ((LM_DEBUG,
+          ACE_ERROR ((LM_ERROR,
                       ACE_TEXT ("TAO (%P|%t) - Transport[%d]::generate_locate_request, ")
                       ACE_TEXT ("error while marshalling the LocateRequest header\n"),
                       this->id ()));
@@ -414,24 +445,15 @@ TAO_Transport::generate_request_header (
     TAO_Target_Specification &spec,
     TAO_OutputCDR &output)
 {
-  // codeset service context is only supposed to be sent in the first request
-  // on a particular connection.
-  if (this->first_request_)
-    {
-      TAO_Codeset_Manager * const csm = this->orb_core ()->codeset_manager ();
-      if (csm)
-        csm->generate_service_context (opdetails,*this);
-    }
-
   if (this->messaging_object ()->generate_request_header (opdetails,
                                                           spec,
                                                           output) == -1)
     {
       if (TAO_debug_level > 0)
         {
-        ACE_DEBUG ((LM_DEBUG,
-                   ACE_TEXT ("(%P|%t) - Transport[%d]::generate_request_header, ")
-                   ACE_TEXT ("error while marshalling the Request header\n"),
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) - Transport[%d]::generate_request_header, ")
+                      ACE_TEXT ("error while marshalling the Request header\n"),
                       this->id()));
         }
 
@@ -450,14 +472,29 @@ TAO_Transport::recache_transport (TAO_Transport_Descriptor_Interface *desc)
   this->purge_entry ();
 
   // Then add ourselves to the cache
-  return this->transport_cache_manager ().cache_transport (desc,
-                                                           this);
+  return this->transport_cache_manager ().cache_transport (desc, this);
 }
 
 int
 TAO_Transport::purge_entry (void)
 {
-  return this->transport_cache_manager ().purge_entry (this->cache_map_entry_);
+  // We must store our entry in a temporary and zero out the data member.
+  // If there is only one reference count on us, we will end up causing
+  // our own destruction.  And we can not be holding a cache map entry if
+  // that happens.
+  TAO::Transport_Cache_Manager::HASH_MAP_ENTRY* entry = 0;
+  {
+    ACE_GUARD_RETURN (ACE_Lock, ace_mon, *this->handler_lock_, -1);
+    entry = this->cache_map_entry_;
+    this->cache_map_entry_ = 0;
+  }
+  return this->transport_cache_manager ().purge_entry (entry);
+}
+
+bool
+TAO_Transport::can_be_purged (void)
+{
+  return !this->tms_->has_request ();
 }
 
 int
@@ -484,20 +521,24 @@ TAO_Transport::update_transport (void)
  *  Methods called and used in the output path of the ORB.
  *
  */
-int
-TAO_Transport::handle_output (ACE_Time_Value *max_wait_time)
+TAO_Transport::Drain_Result
+TAO_Transport::handle_output (TAO::Transport::Drain_Constraints const & dc)
 {
   if (TAO_debug_level > 3)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  ACE_TEXT ("TAO (%P|%t) - Transport[%d]::handle_output\n"),
-                  this->id ()));
+                  ACE_TEXT ("TAO (%P|%t) - Transport[%d]::handle_output")
+                  ACE_TEXT (" - block_on_io=%d, timeout=%d.%06d\n"),
+                  this->id (),
+              dc.block_on_io(),
+              dc.timeout() ? dc.timeout()->sec() : -1,
+              dc.timeout() ? dc.timeout()->usec() : -1 ));
     }
 
   // The flushing strategy (potentially via the Reactor) wants to send
   // more data, first check if there is a current message that needs
   // more sending...
-  int const retval = this->drain_queue (max_wait_time);
+  Drain_Result const retval = this->drain_queue (dc);
 
   if (TAO_debug_level > 3)
     {
@@ -505,7 +546,7 @@ TAO_Transport::handle_output (ACE_Time_Value *max_wait_time)
                   ACE_TEXT ("TAO (%P|%t) - Transport[%d]::handle_output, ")
                   ACE_TEXT ("drain_queue returns %d/%d\n"),
                   this->id (),
-                  retval, errno));
+                  static_cast<int> (retval.dre_), ACE_ERRNO_GET));
     }
 
   // Any errors are returned directly to the Reactor
@@ -514,9 +555,10 @@ TAO_Transport::handle_output (ACE_Time_Value *max_wait_time)
 
 int
 TAO_Transport::format_queue_message (TAO_OutputCDR &stream,
-                                     ACE_Time_Value *max_wait_time)
+                                     ACE_Time_Value *max_wait_time,
+                                     TAO_Stub* stub)
 {
-  if (this->messaging_object ()->format_message (stream) != 0)
+  if (this->messaging_object ()->format_message (stream, stub) != 0)
     return -1;
 
   return this->queue_message_i (stream.begin (), max_wait_time);
@@ -529,15 +571,18 @@ TAO_Transport::send_message_block_chain (const ACE_Message_Block *mb,
 {
   ACE_GUARD_RETURN (ACE_Lock, ace_mon, *this->handler_lock_, -1);
 
+  TAO::Transport::Drain_Constraints dc(
+      max_wait_time, true);
+
   return this->send_message_block_chain_i (mb,
                                            bytes_transferred,
-                                           max_wait_time);
+                                           dc);
 }
 
 int
 TAO_Transport::send_message_block_chain_i (const ACE_Message_Block *mb,
                                            size_t &bytes_transferred,
-                                           ACE_Time_Value *max_wait_time)
+                                           TAO::Transport::Drain_Constraints const & dc)
 {
   size_t const total_length = mb->total_length ();
 
@@ -547,14 +592,14 @@ TAO_Transport::send_message_block_chain_i (const ACE_Message_Block *mb,
 
   synch_message.push_back (this->head_, this->tail_);
 
-  int const n = this->drain_queue_i (max_wait_time);
+  Drain_Result const n = this->drain_queue_i (dc);
 
-  if (n == -1)
+  if (n == DR_ERROR)
     {
       synch_message.remove_from_list (this->head_, this->tail_);
       return -1; // Error while sending...
     }
-  else if (n == 1)
+  else if (n == DR_QUEUE_EMPTY)
     {
       bytes_transferred = total_length;
       return 1;  // Empty queue, message was sent..
@@ -722,7 +767,7 @@ TAO_Transport::send_reply_message_i (const ACE_Message_Block *mb,
       typedef ACE_Reverse_Lock<ACE_Lock> TAO_REVERSE_LOCK;
       TAO_REVERSE_LOCK reverse (*this->handler_lock_);
       ACE_GUARD_RETURN (TAO_REVERSE_LOCK, ace_mon, reverse, -1);
-      (void) flushing_strategy->flush_message (this, msg, 0);
+      (void) flushing_strategy->flush_transport (this, 0);
     }
 
   return 1;
@@ -732,14 +777,17 @@ int
 TAO_Transport::send_synch_message_helper_i (TAO_Synch_Queued_Message &synch_message,
                                             ACE_Time_Value * max_wait_time)
 {
-  int const n = this->drain_queue_i (max_wait_time);
+  TAO::Transport::Drain_Constraints dc(
+      max_wait_time, this->using_blocking_io_for_synch_messages());
 
-  if (n == -1)
+  Drain_Result const n = this->drain_queue_i (dc);
+
+  if (n == DR_ERROR)
     {
       synch_message.remove_from_list (this->head_, this->tail_);
       return -1; // Error while sending...
     }
-  else if (n == 1)
+  else if (n == DR_QUEUE_EMPTY)
     {
       return 1;  // Empty queue, message was sent..
     }
@@ -752,13 +800,6 @@ TAO_Transport::send_synch_message_helper_i (TAO_Synch_Queued_Message &synch_mess
   return 0;
 }
 
-bool
-TAO_Transport::queue_is_empty_i (void)
-{
-  return (this->head_ == 0);
-}
-
-
 int
 TAO_Transport::schedule_output_i (void)
 {
@@ -766,7 +807,18 @@ TAO_Transport::schedule_output_i (void)
   ACE_Reactor * const reactor = eh->reactor ();
 
   if (reactor == 0)
-     return -1;
+    {
+      if (TAO_debug_level > 1)
+        {
+          ACE_ERROR ((LM_ERROR,
+                      ACE_TEXT ("TAO (%P|%t) - ")
+                      ACE_TEXT ("Transport[%d]::schedule_output_i, ")
+                      ACE_TEXT ("no reactor,")
+                      ACE_TEXT ("returning -1\n"),
+                      this->id ()));
+        }
+      return -1;
+    }
 
   // Check to see if our event handler is still registered with the
   // reactor.  It's possible for another thread to have run close_connection()
@@ -780,7 +832,7 @@ TAO_Transport::schedule_output_i (void)
         {
           if (TAO_debug_level > 3)
             {
-              ACE_DEBUG ((LM_DEBUG,
+              ACE_ERROR ((LM_ERROR,
                           ACE_TEXT ("TAO (%P|%t) - ")
                           ACE_TEXT ("Transport[%d]::schedule_output_i ")
                           ACE_TEXT ("event handler not found in reactor,")
@@ -825,7 +877,7 @@ TAO_Transport::handle_timeout (const ACE_Time_Value & /* current_time */,
   if (TAO_debug_level > 6)
     {
       ACE_DEBUG ((LM_DEBUG,
-         ACE_TEXT ("TAO (%P|%t) - TAO_Transport[%d]::handle_timeout, ")
+         ACE_TEXT ("TAO (%P|%t) - Transport[%d]::handle_timeout, ")
          ACE_TEXT ("timer expired\n"),
          this->id ()));
     }
@@ -859,13 +911,13 @@ TAO_Transport::handle_timeout (const ACE_Time_Value & /* current_time */,
   return 0;
 }
 
-int
-TAO_Transport::drain_queue (ACE_Time_Value *max_wait_time)
+TAO_Transport::Drain_Result
+TAO_Transport::drain_queue (TAO::Transport::Drain_Constraints const & dc)
 {
-  ACE_GUARD_RETURN (ACE_Lock, ace_mon, *this->handler_lock_, -1);
-  int const retval = this->drain_queue_i (max_wait_time);
+  ACE_GUARD_RETURN (ACE_Lock, ace_mon, *this->handler_lock_, DR_ERROR);
+  Drain_Result const retval = this->drain_queue_i (dc);
 
-  if (retval == 1)
+  if (retval == DR_QUEUE_EMPTY)
     {
       // ... there is no current message or it was completely
       // sent, cancel output...
@@ -874,17 +926,22 @@ TAO_Transport::drain_queue (ACE_Time_Value *max_wait_time)
 
       flushing_strategy->cancel_output (this);
 
-      return 0;
+      return DR_OK;
     }
 
   return retval;
 }
 
-int
-TAO_Transport::drain_queue_helper (int &iovcnt, iovec iov[], ACE_Time_Value *max_wait_time)
+TAO_Transport::Drain_Result
+TAO_Transport::drain_queue_helper (int &iovcnt, iovec iov[],
+    TAO::Transport::Drain_Constraints const & dc)
 {
+  // As a side-effect, this decrements the timeout() pointed-to value by
+  // the time used in this function.  That might be important as there are
+  // potentially long running system calls invoked from here.
+  ACE_Countdown_Time countdown(dc.timeout());
+
   size_t byte_count = 0;
-  ACE_Countdown_Time countdown (max_wait_time);
 
   // ... send the message ...
   ssize_t retval = -1;
@@ -894,23 +951,19 @@ TAO_Transport::drain_queue_helper (int &iovcnt, iovec iov[], ACE_Time_Value *max
     retval = this->sendfile (this->mmap_allocator_,
                              iov,
                              iovcnt,
-                             byte_count);
+                             byte_count,
+                             dc);
   else
 #endif  /* TAO_HAS_SENDFILE==1 */
-    retval = this->send (iov, iovcnt, byte_count, max_wait_time);
+    retval = this->send (iov, iovcnt, byte_count,
+                         this->io_timeout (dc));
 
   if (TAO_debug_level == 5)
     {
       dump_iov (iov, iovcnt, this->id (),
-                byte_count, "drain_queue_helper");
+                byte_count, ACE_TEXT("drain_queue_helper"));
     }
 
-  // ... now we need to update the queue, removing elements
-  // that have been sent, and updating the last element if it
-  // was only partially sent ...
-  this->cleanup_queue (byte_count);
-  iovcnt = 0;
-
   if (retval == 0)
     {
       if (TAO_debug_level > 4)
@@ -920,7 +973,7 @@ TAO_Transport::drain_queue_helper (int &iovcnt, iovec iov[], ACE_Time_Value *max
              ACE_TEXT ("send() returns 0\n"),
              this->id ()));
         }
-      return -1;
+      return DR_ERROR;
     }
   else if (retval == -1)
     {
@@ -928,18 +981,24 @@ TAO_Transport::drain_queue_helper (int &iovcnt, iovec iov[], ACE_Time_Value *max
         {
           ACE_DEBUG ((LM_DEBUG,
              ACE_TEXT ("TAO (%P|%t) - Transport[%d]::drain_queue_helper, ")
-             ACE_TEXT ("error during send (errno: %d) - %m\n"),
-             this->id (), errno));
+             ACE_TEXT ("error during send() (errno: %d) - %m\n"),
+             this->id (), ACE_ERRNO_GET));
         }
 
       if (errno == EWOULDBLOCK || errno == EAGAIN)
         {
-          return 0;
+          return DR_WOULDBLOCK;
         }
 
-      return -1;
+      return DR_ERROR;
     }
 
+  // ... now we need to update the queue, removing elements
+  // that have been sent, and updating the last element if it
+  // was only partially sent ...
+  this->cleanup_queue (byte_count);
+  iovcnt = 0;
+
   // ... start over, how do we guarantee progress?  Because if
   // no bytes are sent send() can only return 0 or -1
 
@@ -951,14 +1010,15 @@ TAO_Transport::drain_queue_helper (int &iovcnt, iovec iov[], ACE_Time_Value *max
       ACE_DEBUG ((LM_DEBUG,
          ACE_TEXT ("TAO (%P|%t) - Transport[%d]::drain_queue_helper, ")
          ACE_TEXT ("byte_count = %d, head_is_empty = %d\n"),
-         this->id(), byte_count, (this->head_ == 0)));
+         this->id(), byte_count, this->queue_is_empty_i ()));
     }
 
-  return 1;
+  return DR_QUEUE_EMPTY;
+  // drain_queue_i will check if the queue is actually empty
 }
 
-int
-TAO_Transport::drain_queue_i (ACE_Time_Value *max_wait_time)
+TAO_Transport::Drain_Result
+TAO_Transport::drain_queue_i (TAO::Transport::Drain_Constraints const & dc)
 {
   // This is the vector used to send data, it must be declared outside
   // the loop because after the loop there may still be data to be
@@ -989,7 +1049,7 @@ TAO_Transport::drain_queue_i (ACE_Time_Value *max_wait_time)
           if (TAO_debug_level > 3)
           {
             ACE_DEBUG ((LM_DEBUG,
-              ACE_TEXT ("TAO (%P|%t - Transport[%d]::drain_queue_i, ")
+              ACE_TEXT ("TAO (%P|%t) - Transport[%d]::drain_queue_i, ")
               ACE_TEXT ("Discarding expired queued message.\n"),
               this->id ()));
           }
@@ -1009,24 +1069,24 @@ TAO_Transport::drain_queue_i (ACE_Time_Value *max_wait_time)
       // IOV_MAX elements ...
       if (iovcnt == ACE_IOV_MAX)
         {
-          int const retval = this->drain_queue_helper (iovcnt, iov,
-                                                       max_wait_time);
-
-          now = ACE_High_Res_Timer::gettimeofday_hr ();
+          Drain_Result const retval =
+            this->drain_queue_helper (iovcnt, iov, dc);
 
           if (TAO_debug_level > 4)
             {
               ACE_DEBUG ((LM_DEBUG,
                  ACE_TEXT ("TAO (%P|%t) - Transport[%d]::drain_queue_i, ")
                  ACE_TEXT ("helper retval = %d\n"),
-                 this->id (), retval));
+                 this->id (), static_cast<int> (retval.dre_)));
             }
 
-          if (retval != 1)
+          if (retval != DR_QUEUE_EMPTY)
             {
               return retval;
             }
 
+          now = ACE_High_Res_Timer::gettimeofday_hr ();
+
           i = this->head_;
           continue;
         }
@@ -1037,23 +1097,23 @@ TAO_Transport::drain_queue_i (ACE_Time_Value *max_wait_time)
 
   if (iovcnt != 0)
     {
-      int const retval = this->drain_queue_helper (iovcnt, iov, max_wait_time);
+      Drain_Result const retval = this->drain_queue_helper (iovcnt, iov, dc);
 
       if (TAO_debug_level > 4)
         {
           ACE_DEBUG ((LM_DEBUG,
               ACE_TEXT ("TAO (%P|%t) - Transport[%d]::drain_queue_i, ")
               ACE_TEXT ("helper retval = %d\n"),
-              this->id (), retval));
+              this->id (), static_cast<int> (retval.dre_)));
         }
 
-      if (retval != 1)
+      if (retval != DR_QUEUE_EMPTY)
         {
           return retval;
         }
     }
 
-  if (this->head_ == 0)
+  if (this->queue_is_empty_i ())
     {
       if (this->flush_timer_pending ())
         {
@@ -1063,10 +1123,10 @@ TAO_Transport::drain_queue_i (ACE_Time_Value *max_wait_time)
           this->reset_flush_timer ();
         }
 
-      return 1;
+      return DR_QUEUE_EMPTY;
     }
 
-  return 0;
+  return DR_OK;
 }
 
 void
@@ -1084,7 +1144,7 @@ TAO_Transport::cleanup_queue_i ()
   int msg_count = 0;
 
   // Cleanup all messages
-  while (this->head_ != 0)
+  while (!this->queue_is_empty_i ())
     {
       TAO_Queued_Message *i = this->head_;
 
@@ -1115,7 +1175,7 @@ TAO_Transport::cleanup_queue_i ()
 void
 TAO_Transport::cleanup_queue (size_t byte_count)
 {
-  while (this->head_ != 0 && byte_count > 0)
+  while (!this->queue_is_empty_i () && byte_count > 0)
     {
       TAO_Queued_Message *i = this->head_;
 
@@ -1146,6 +1206,16 @@ TAO_Transport::cleanup_queue (size_t byte_count)
           i->remove_from_list (this->head_, this->tail_);
           i->destroy ();
         }
+      else if (byte_count == 0)
+        {
+          // If we have sent out a full message block, but we are not
+          // finished with this message, we need to do something with the
+          // message block chain held by our output stream.  If we don't,
+          // another thread can attempt to service this transport and end
+          // up resetting the output stream which will release the
+          // message that we haven't finished sending.
+          i->copy_if_necessary (this->out_stream ().begin ());
+        }
     }
 }
 
@@ -1215,8 +1285,8 @@ TAO_Transport::report_invalid_event_handler (const char *caller)
     {
       ACE_DEBUG ((LM_DEBUG,
          ACE_TEXT ("TAO (%P|%t) - Transport[%d]::report_invalid_event_handler")
-         ACE_TEXT ("(%s) no longer associated with handler [tag=%d]\n"),
-         this->id (), ACE_TEXT_CHAR_TO_TCHAR (caller), this->tag_));
+         ACE_TEXT ("(%C) no longer associated with handler [tag=%d]\n"),
+         this->id (), caller, this->tag_));
     }
 }
 
@@ -1252,15 +1322,15 @@ TAO_Transport::send_message_shared_i (TAO_Stub *stub,
 
   switch (message_semantics)
     {
-      case TAO_Transport::TAO_TWOWAY_REQUEST:
+      case TAO_TWOWAY_REQUEST:
         ret = this->send_synchronous_message_i (message_block, max_wait_time);
         break;
 
-      case TAO_Transport::TAO_REPLY:
+      case TAO_REPLY:
         ret = this->send_reply_message_i (message_block, max_wait_time);
         break;
 
-      case TAO_Transport::TAO_ONEWAY_REQUEST:
+      case TAO_ONEWAY_REQUEST:
         ret = this->send_asynchronous_message_i (stub,
                                                  message_block,
                                                  max_wait_time);
@@ -1285,7 +1355,7 @@ TAO_Transport::send_asynchronous_message_i (TAO_Stub *stub,
   // to send first:
   bool try_sending_first = true;
 
-  bool const queue_empty = (this->head_ == 0);
+  bool const queue_empty = this->queue_is_empty_i ();
 
   TAO::Transport_Queueing_Strategy *queue_strategy =
     stub->transport_queueing_strategy ();
@@ -1305,6 +1375,9 @@ TAO_Transport::send_asynchronous_message_i (TAO_Stub *stub,
   bool partially_sent = false;
   bool timeout_encountered = false;
 
+  TAO::Transport::Drain_Constraints dc(
+      max_wait_time, this->using_blocking_io_for_asynch_messages());
+
   if (try_sending_first)
     {
       ssize_t n = 0;
@@ -1327,7 +1400,7 @@ TAO_Transport::send_asynchronous_message_i (TAO_Stub *stub,
       // code I will re-visit this decision
       n = this->send_message_block_chain_i (message_block,
                                             byte_count,
-                                            max_wait_time);
+                                            dc);
 
       if (n == -1)
         {
@@ -1572,7 +1645,7 @@ TAO_Transport::handle_input (TAO_Resume_Handle &rh,
         {
           if (TAO_debug_level > 2)
             {
-              ACE_DEBUG ((LM_DEBUG,
+              ACE_ERROR ((LM_ERROR,
                  ACE_TEXT ("TAO (%P|%t) - Transport[%d]::handle_input, ")
                  ACE_TEXT ("error while parsing the head of the queue\n"),
                  this->id()));
@@ -1849,9 +1922,9 @@ TAO_Transport::handle_input_missing_data (TAO_Resume_Handle &rh,
 
 
 int
-TAO_Transport::handle_input_parse_extra_messages (ACE_Message_Block &message_block)
+TAO_Transport::handle_input_parse_extra_messages (
+  ACE_Message_Block &message_block)
 {
-
   // store buffer status of last extraction: -1 parse error, 0
   // incomplete message header in buffer, 1 complete messages header
   // parsed
@@ -1895,7 +1968,6 @@ int
 TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
                                          ACE_Time_Value * max_wait_time)
 {
-
   if (TAO_debug_level > 3)
     {
       ACE_DEBUG ((LM_DEBUG,
@@ -1904,7 +1976,6 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
          this->id ()));
     }
 
-
   // The buffer on the stack which will be used to hold the input
   // messages, ACE_CDR::MAX_ALIGNMENT compensates the
   // memory-alignment. This improves performance with SUN-Java-ORB-1.4
@@ -1931,7 +2002,6 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
                                    ACE_Message_Block::DONT_DELETE,
                                    this->orb_core_->input_cdr_msgblock_allocator ());
 
-
   // Align the message block
   ACE_CDR::mb_align (&message_block);
 
@@ -1940,10 +2010,10 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
   // Pointer to newly parsed message
   TAO_Queued_Data *q_data = 0;
 
-  // optimizing access of constants
+  // Optimizing access of constants
   size_t const header_length = this->messaging_object ()->header_length ();
 
-  // paranoid check
+  // Paranoid check
   if (header_length > message_block.space ())
     {
       return -1;
@@ -2027,7 +2097,7 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
   // invocation context to get meaningful information.
   this->recv_buffer_size_ = recv_size;
 
-  // Read the message into the  message block that we have created on
+  // Read the message into the message block that we have created on
   // the stack.
   ssize_t const n = this->recv (message_block.wr_ptr (),
                                 recv_size,
@@ -2124,8 +2194,7 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
 
       size_t mesg_length  = 0;
 
-      if (this->messaging_object ()->parse_next_message (qd,
-                                                         mesg_length) == -1
+      if (this->messaging_object ()->parse_next_message (qd, mesg_length) == -1
           || (qd.missing_data () == 0
               && mesg_length > message_block.length ()) )
         {
@@ -2136,14 +2205,13 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
       // This prevents seeking rd_ptr behind the wr_ptr
 
       if (qd.missing_data () != 0 ||
-          qd.more_fragments ()   ||
+          qd.more_fragments () ||
           qd.msg_type () == GIOP::Fragment)
         {
           if (qd.missing_data () == 0)
             {
               // Dealing with a fragment
-              TAO_Queued_Data *nqd =
-                TAO_Queued_Data::duplicate (qd);
+              TAO_Queued_Data *nqd = TAO_Queued_Data::duplicate (qd);
 
               if (nqd == 0)
                 {
@@ -2192,8 +2260,7 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
                     }
                 }
 
-              TAO_Queued_Data *nqd =
-                TAO_Queued_Data::duplicate (qd);
+              TAO_Queued_Data *nqd = TAO_Queued_Data::duplicate (qd);
 
               if (nqd == 0)
                 {
@@ -2217,7 +2284,6 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
           // putting them into queue.  When this is done we can return
           // to process this message, and notifying other threads to
           // process the messages in queue.
-
           char * end_marker = message_block.rd_ptr ()
                             + mesg_length;
 
@@ -2238,8 +2304,10 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
                   return -1;
                 }
 
-              // correct the end_marker
-              end_marker = message_block.rd_ptr ();
+              // correct the wr_ptr using the end_marker to point to the
+              // end of the first message else the code after this will
+              // see the full stream with all the messages
+              message_block.wr_ptr (end_marker);
 
               // Restore rd_ptr
               message_block.rd_ptr (rd_ptr_stack_mesg);
@@ -2260,10 +2328,9 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
                      ACE_TEXT ("TAO (%P|%t) - Transport[%d]::handle_input_parse_data, ")
                      ACE_TEXT ("notify reactor\n"),
                      this->id ()));
-
                 }
 
-              const int retval = this->notify_reactor ();
+              int const retval = this->notify_reactor ();
 
               if (retval == 1)
                 {
@@ -2282,12 +2349,10 @@ TAO_Transport::handle_input_parse_data  (TAO_Resume_Handle &rh,
             }
 
           // PRE: incoming_message_queue is empty
-          if (this->process_parsed_messages (&qd,
-                                             rh) == -1)
+          if (this->process_parsed_messages (&qd, rh) == -1)
             {
               return -1;
             }
-
           // move the rd_ptr tp position of end_marker
           message_block.rd_ptr (end_marker);
         }
@@ -2341,10 +2406,12 @@ TAO_Transport::process_parsed_messages (TAO_Queued_Data *qd,
     case GIOP::CloseConnection:
     {
       if (TAO_debug_level > 0)
-        ACE_DEBUG ((LM_DEBUG,
-           ACE_TEXT ("TAO (%P|%t) - Transport[%d]::process_parsed_messages, ")
-           ACE_TEXT ("received CloseConnection message - %m\n"),
-           this->id()));
+        {
+          ACE_DEBUG ((LM_DEBUG,
+             ACE_TEXT ("TAO (%P|%t) - Transport[%d]::process_parsed_messages, ")
+             ACE_TEXT ("received CloseConnection message - %m\n"),
+             this->id()));
+        }
 
       // Return a "-1" so that the next stage can take care of
       // closing connection and the necessary memory management.
@@ -2358,9 +2425,7 @@ TAO_Transport::process_parsed_messages (TAO_Queued_Data *qd,
       // request. This will open up the handle for other threads.
       rh.resume_handle ();
 
-      if (this->messaging_object ()->process_request_message (
-            this,
-            qd) == -1)
+      if (this->messaging_object ()->process_request_message (this, qd) == -1)
         {
           // Return a "-1" so that the next stage can take care of
           // closing connection and the necessary memory management.
@@ -2378,10 +2443,12 @@ TAO_Transport::process_parsed_messages (TAO_Queued_Data *qd,
       if (this->messaging_object ()->process_reply_message (params, qd) == -1)
         {
           if (TAO_debug_level > 0)
-            ACE_DEBUG ((LM_DEBUG,
-               ACE_TEXT ("TAO (%P|%t) - Transport[%d]::process_parsed_messages, ")
-               ACE_TEXT ("error in process_reply_message - %m\n"),
-               this->id ()));
+            {
+              ACE_ERROR ((LM_ERROR,
+                 ACE_TEXT ("TAO (%P|%t) - Transport[%d]::process_parsed_messages, ")
+                 ACE_TEXT ("error in process_reply_message - %m\n"),
+                 this->id ()));
+            }
 
           return -1;
         }
@@ -2491,15 +2558,12 @@ TAO_Transport::process_queue_head (TAO_Resume_Handle &rh)
         }
 
       // Process the message...
-      if (this->process_parsed_messages (qd, rh) == -1)
-        {
-          return -1;
-        }
+      int const retval = this->process_parsed_messages (qd, rh);
 
       // Delete the Queued_Data..
       TAO_Queued_Data::release (qd);
 
-      return 0;
+      return retval;
     }
 
   return 1;
@@ -2526,7 +2590,6 @@ TAO_Transport::notify_reactor (void)
          this->id ()));
     }
 
-
   // Send a notification to the reactor...
   int const retval = reactor->notify (eh, ACE_Event_Handler::READ_MASK);
 
@@ -2534,7 +2597,7 @@ TAO_Transport::notify_reactor (void)
     {
       // @todo: need to think about what is the action that
       // we can take when we get here.
-      ACE_DEBUG ((LM_DEBUG,
+      ACE_ERROR ((LM_ERROR,
          ACE_TEXT ("TAO (%P|%t) - Transport[%d]::notify_reactor, ")
          ACE_TEXT ("notify to the reactor failed..\n"),
          this->id ()));
@@ -2597,6 +2660,12 @@ TAO_Transport::out_stream (void)
   return this->messaging_object ()->out_stream ();
 }
 
+TAO_SYNCH_MUTEX &
+TAO_Transport::output_cdr_lock (void)
+{
+  return this->output_cdr_mutex_;
+}
+
 void
 TAO_Transport::messaging_init (TAO_GIOP_Message_Version const &version)
 {
@@ -2606,7 +2675,14 @@ TAO_Transport::messaging_init (TAO_GIOP_Message_Version const &version)
 void
 TAO_Transport::pre_close (void)
 {
+  // @TODO: something needs to be done with is_connected_. Checking it is
+  // guarded by a mutex, but setting it is not. Until the need for mutexed
+  // protection is required, the transport cache is holding its own copy
+  // of the is_connected_ flag, so that during cache lookups the cache
+  // manager doesn't need to be burdened by the lock in is_connected().
   this->is_connected_ = false;
+  this->transport_cache_manager ().mark_connected (this->cache_map_entry_,
+                                                   false);
   this->purge_entry ();
   {
     ACE_MT (ACE_GUARD (ACE_Lock, guard, *this->handler_lock_));
@@ -2617,45 +2693,75 @@ TAO_Transport::pre_close (void)
 bool
 TAO_Transport::post_open (size_t id)
 {
+  if (TAO_debug_level > 9)
+    ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("TAO (%P|%t) - Transport::post_open, ")
+                ACE_TEXT ("tport id changed from %d to %d\n"), this->id_, id));
   this->id_ = id;
 
-  {
-    ACE_GUARD_RETURN (ACE_Lock,
-                      ace_mon,
-                      *this->handler_lock_,
-                      false);
-    this->is_connected_ = true;
-  }
-
   // When we have data in our outgoing queue schedule ourselves
   // for output
-  if (this->queue_is_empty_i ())
-    return true;
-
-  // If the wait strategy wants us to be registered with the reactor
-  // then we do so. If registeration is required and it succeeds,
-  // #REFCOUNT# becomes two.
-  if (this->wait_strategy ()->register_handler () != 0)
+  if (!this->queue_is_empty_i ())
     {
-      // Registration failures.
+      // If the wait strategy wants us to be registered with the reactor
+      // then we do so. If registeration is required and it succeeds,
+      // #REFCOUNT# becomes two.
+      if (this->wait_strategy ()->register_handler () == 0)
+        {
+          if (this->flush_in_post_open_)
+            {
+              TAO_Flushing_Strategy *flushing_strategy =
+                this->orb_core ()->flushing_strategy ();
 
-      // Purge from the connection cache, if we are not in the cache, this
-      // just does nothing.
-      (void) this->purge_entry ();
+              if (flushing_strategy == 0)
+                throw CORBA::INTERNAL ();
 
-      // Close the handler.
-      (void) this->close_connection ();
+              this->flush_in_post_open_ = false;
+              (void) flushing_strategy->schedule_output (this);
+            }
+        }
+      else
+        {
+          // Registration failures.
 
-      if (TAO_debug_level > 0)
-        ACE_ERROR ((LM_ERROR,
-           ACE_TEXT ("TAO (%P|%t) - Transport[%d]::post_connect , ")
-           ACE_TEXT ("could not register the transport ")
-           ACE_TEXT ("in the reactor.\n"),
-           this->id ()));
+          // Purge from the connection cache, if we are not in the cache, this
+          // just does nothing.
+          (void) this->purge_entry ();
 
-      return false;
+          // Close the handler.
+          (void) this->close_connection ();
+
+          if (TAO_debug_level > 0)
+            {
+              ACE_ERROR ((LM_ERROR,
+                     ACE_TEXT ("TAO (%P|%t) - Transport[%d]::post_open , ")
+                     ACE_TEXT ("could not register the transport ")
+                     ACE_TEXT ("in the reactor.\n"),
+                     this->id ()));
+            }
+
+          return false;
+        }
     }
 
+  {
+    ACE_GUARD_RETURN (ACE_Lock, ace_mon, *this->handler_lock_, false);
+    this->is_connected_ = true;
+  }
+
+  if (TAO_debug_level > 9 && !this->cache_map_entry_)
+    {
+      ACE_DEBUG ((LM_DEBUG, ACE_TEXT ("TAO (%P|%t) - Transport[%d]::post_open")
+                            ACE_TEXT (", cache_map_entry_ is 0\n"), this->id_));
+    }
+
+  this->transport_cache_manager ().mark_connected (this->cache_map_entry_,
+                                                   true);
+
+  // update transport cache to make this entry available
+  this->transport_cache_manager ().set_entry_state (
+    this->cache_map_entry_,
+    TAO::ENTRY_IDLE_AND_PURGABLE);
+
   return true;
 }
 
@@ -2676,6 +2782,42 @@ TAO_Transport::allocate_partial_message_block (void)
     }
 }
 
+void
+TAO_Transport::set_bidir_context_info (TAO_Operation_Details &)
+{
+}
+
+ACE_Time_Value const *
+TAO_Transport::io_timeout(
+    TAO::Transport::Drain_Constraints const & dc) const
+{
+  if (dc.block_on_io())
+  {
+    return dc.timeout();
+  }
+  if (this->wait_strategy()->can_process_upcalls())
+  {
+    return 0;
+  }
+  return dc.timeout();
+}
+
+bool
+TAO_Transport::using_blocking_io_for_synch_messages() const
+{
+  if (this->wait_strategy()->can_process_upcalls())
+  {
+    return false;
+  }
+  return true;
+}
+
+bool
+TAO_Transport::using_blocking_io_for_asynch_messages() const
+{
+  return false;
+}
+
 /*
  * Hook to add concrete implementations from the derived class onto
  * TAO's transport.
