@@ -1,18 +1,22 @@
-// Transport_Mux_Strategy.cpp,v 1.25 2003/10/28 18:29:21 bala Exp
+// $Id: Transport_Mux_Strategy.cpp 78997 2007-07-23 12:21:34Z johnnyw $
 
 #include "tao/Transport_Mux_Strategy.h"
 
 ACE_RCSID (tao,
            Transport_Mux_Strategy,
-           "Transport_Mux_Strategy.cpp,v 1.25 2003/10/28 18:29:21 bala Exp")
+           "$Id: Transport_Mux_Strategy.cpp 78997 2007-07-23 12:21:34Z johnnyw $")
+
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Transport_Mux_Strategy::TAO_Transport_Mux_Strategy (
   TAO_Transport *transport)
   : transport_ (transport)
-  , lock_ (0)
 {
 }
 
 TAO_Transport_Mux_Strategy::~TAO_Transport_Mux_Strategy (void)
 {
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
