@@ -4,7 +4,7 @@
 /**
  *  @file    Transport_Mux_Strategy.h
  *
- *  $Id: Transport_Mux_Strategy.h 78997 2007-07-23 12:21:34Z johnnyw $
+ *  $Id: Transport_Mux_Strategy.h 85001 2009-03-31 10:06:45Z msmit $
  *
  *  @author  Alexander Babu Arulanthu <alex@cs.wustl.edu>
  */
@@ -22,6 +22,7 @@
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
 #include "tao/Basic_Types.h"
+#include "tao/Reply_Dispatcher.h"
 
 ACE_BEGIN_VERSIONED_NAMESPACE_DECL
 class ACE_Lock;
@@ -29,7 +30,6 @@ ACE_END_VERSIONED_NAMESPACE_DECL
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
-class TAO_Reply_Dispatcher;
 class TAO_Transport;
 class TAO_Pluggable_Reply_Params;
 
@@ -55,13 +55,10 @@ public:
   /// invocation.
   virtual CORBA::ULong request_id (void) = 0;
 
-  // = Bind and Find methods for the <Request ID, ReplyDispatcher>
-  //   pairs.
-
   /// Bind the dispatcher with the request id. Commonalities in the
   /// derived class implementations is kept here.
   virtual int bind_dispatcher (CORBA::ULong request_id,
-                               TAO_Reply_Dispatcher *rd) = 0;
+                               ACE_Intrusive_Auto_Ptr<TAO_Reply_Dispatcher> rd) = 0;
 
   /**
    * Unbind the dispatcher, the client is no longer waiting for the
@@ -72,7 +69,12 @@ public:
    */
   virtual int unbind_dispatcher (CORBA::ULong request_id) = 0;
 
-  /// Dispatch the reply for <request_id>, cleanup any resources
+  /**
+   * Dispatch a reply timeout for request @a request_id
+   **/
+  virtual int reply_timed_out (CORBA::ULong request_id) = 0;
+
+  /// Dispatch the reply for request_id, cleanup any resources
   /// allocated for that request.
   virtual int dispatch_reply (TAO_Pluggable_Reply_Params &params) = 0;
 
@@ -90,6 +92,9 @@ public:
   /// dispatchers and waiting strategies.
   virtual void connection_closed (void) = 0;
 
+  /// Do we have a request pending
+  virtual bool has_request (void) = 0;
+
 protected:
   /// Cache the transport reference.
   TAO_Transport *transport_;
