@@ -4,7 +4,7 @@
 /**
  *  @file Transport_Timer.h
  *
- *  Transport_Timer.h,v 1.5 2003/10/28 18:29:21 bala Exp
+ *  $Id: Transport_Timer.h 74014 2006-08-14 13:52:22Z johnnyw $
  *
  *  @author Carlos O'Ryan <coryan@uci.edu>
  */
@@ -20,7 +20,10 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "TAO_Export.h"
+#include /**/ "tao/TAO_Export.h"
+#include /**/ "tao/Versioned_Namespace.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_Transport;
 
@@ -33,7 +36,7 @@ class TAO_Transport;
  *        is a TAO_Transport and the client is the Reactor.
  *
  */
-class TAO_Export TAO_Transport_Timer : public ACE_Event_Handler
+class TAO_Transport_Timer : public ACE_Event_Handler
 {
 public:
   /// Constructor
@@ -51,6 +54,8 @@ private:
   TAO_Transport *transport_;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_TRANSPORT_TIMER_H */
