@@ -6,7 +6,7 @@
  * @brief Details can be found in the documentation for
  * TAO::details::generic_sequence
  *
- * $Id: Unbounded_Reference_Allocation_Traits_T.h 72136 2006-04-19 09:10:19Z jwillemsen $
+ * $Id: Unbounded_Reference_Allocation_Traits_T.h 84506 2009-02-18 11:15:38Z vzykov $
  *
  * @author Carlos O'Ryan
  */
@@ -41,6 +41,17 @@ struct unbounded_reference_allocation_traits
     value_type * buffer = new value_type[maximum + 1];
     reinterpret_cast<value_type**>(buffer)[0] = buffer + maximum + 1;
 
+    // no throw
+    reference_traits::initialize_range(buffer + 1, buffer + maximum + 1);
+
+    return buffer + 1;
+  }
+
+  inline static value_type * allocbuf_noinit(CORBA::ULong maximum)
+  {
+    value_type * buffer = new value_type[maximum + 1];
+    reinterpret_cast<value_type**>(buffer)[0] = buffer + maximum + 1;
+
     // no throw
     reference_traits::zero_range(buffer + 1, buffer + maximum + 1);
 
