@@ -5,7 +5,7 @@
  *
  * @brief Extract the sequence
  *
- * $Id: Unbounded_Sequence_CDR_T.h 77525 2007-03-05 11:02:51Z johnnyw $
+ * $Id: Unbounded_Sequence_CDR_T.h 84506 2009-02-18 11:15:38Z vzykov $
  *
  * @author Carlos O'Ryan
  * @author Johnny Willemsen
@@ -13,6 +13,7 @@
 
 #include "tao/orbconf.h"
 #include "tao/CORBA_String.h"
+#include "tao/SystemException.h"
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -234,6 +235,26 @@ namespace TAO {
     return true;
   }
 
+  template <typename stream>
+  bool demarshal_sequence(stream & strm, TAO::unbounded_value_sequence <CORBA::LongLong> & target) {
+    typedef TAO::unbounded_value_sequence <CORBA::LongLong> sequence;
+    ::CORBA::ULong new_length = 0;
+    if (!(strm >> new_length)) {
+      return false;
+    }
+    if (new_length > strm.length()) {
+      return false;
+    }
+    sequence tmp(new_length);
+    tmp.length(new_length);
+    typename sequence::value_type * buffer = tmp.get_buffer();
+    if (!strm.read_longlong_array (buffer, new_length)) {
+      return false;
+    }
+    tmp.swap(target);
+    return true;
+  }
+
   template <typename stream>
   bool demarshal_sequence(stream & strm, TAO::unbounded_value_sequence <CORBA::ULongLong> & target) {
     typedef TAO::unbounded_value_sequence <CORBA::ULongLong> sequence;
@@ -320,6 +341,7 @@ namespace TAO {
   bool demarshal_sequence(stream & strm, TAO::unbounded_basic_string_sequence <charT> & target) {
     typedef TAO::unbounded_basic_string_sequence <charT> sequence;
     typedef typename sequence::element_traits::string_var string_var;
+    typedef typename sequence::allocation_traits sequence_allocation_traits;
     ::CORBA::ULong new_length = 0;
     if (!(strm >> new_length)) {
       return false;
@@ -327,8 +349,9 @@ namespace TAO {
     if (new_length > strm.length()) {
       return false;
     }
-    sequence tmp(new_length);
-    tmp.length(new_length);
+    sequence tmp(new_length, new_length,
+                 sequence_allocation_traits::allocbuf_noinit(new_length),
+                 true);
     for(CORBA::ULong i = 0; i < new_length; ++i) {
       string_var string;
       if (!(strm >> string.inout ())) {
@@ -342,9 +365,11 @@ namespace TAO {
     return true;
   }
 
-  template <typename stream, typename object_t, typename object_t_var>
-  bool demarshal_sequence(stream & strm, TAO::unbounded_object_reference_sequence<object_t, object_t_var> & target) {
-    typedef TAO::unbounded_object_reference_sequence<object_t, object_t_var> sequence;
+  template <typename stream, typename charT, CORBA::ULong BD_STR_MAX>
+  bool demarshal_sequence(stream & strm, TAO::unbounded_bd_string_sequence <charT, BD_STR_MAX> & target) {
+    typedef TAO::unbounded_bd_string_sequence <charT, BD_STR_MAX> sequence;
+    typedef typename sequence::element_traits::string_var string_var;
+    typedef typename sequence::allocation_traits sequence_allocation_traits;
     ::CORBA::ULong new_length = 0;
     if (!(strm >> new_length)) {
       return false;
@@ -352,8 +377,40 @@ namespace TAO {
     if (new_length > strm.length()) {
       return false;
     }
-    sequence tmp(new_length);
-    tmp.length(new_length);
+    sequence tmp(new_length, new_length,
+                 sequence_allocation_traits::allocbuf_noinit(new_length),
+                 true);
+    for(CORBA::ULong i = 0; i < new_length; ++i) {
+      string_var string;
+      if (!(strm >> string.inout ())) {
+        return false;
+      }
+      else {
+        if (string.in () != 0 &&
+            ACE_OS::strlen (string.in ()) > tmp.bd_string_maximum ()) {
+          throw ::CORBA::BAD_PARAM ();
+        }
+        tmp[i] = string._retn ();
+      }
+    }
+    tmp.swap(target);
+    return true;
+  }
+
+  template <typename stream, typename object_t, typename object_t_var>
+  bool demarshal_sequence(stream & strm, TAO::unbounded_object_reference_sequence<object_t, object_t_var> & target) {
+    typedef TAO::unbounded_object_reference_sequence<object_t, object_t_var> sequence;
+    typedef typename sequence::allocation_traits sequence_allocation_traits;
+    ::CORBA::ULong new_length = 0;
+    if (!(strm >> new_length)) {
+      return false;
+    }
+    if (new_length > strm.length()) {
+      return false;
+    }
+    sequence tmp(new_length, new_length,
+                 sequence_allocation_traits::allocbuf_noinit(new_length),
+                 true);
     typename sequence::value_type * buffer = tmp.get_buffer();
     for(CORBA::ULong i = 0; i < new_length; ++i) {
       if (!(strm >> buffer[i])) {
@@ -463,6 +520,15 @@ namespace TAO {
     return strm.write_double_array (source.get_buffer (), length);
   }
 
+  template <typename stream>
+  bool marshal_sequence(stream & strm, const TAO::unbounded_value_sequence <CORBA::LongLong> & source) {
+    ::CORBA::ULong const length = source.length ();
+    if (!(strm << length)) {
+      return false;
+    }
+    return strm.write_longlong_array (source.get_buffer (), length);
+  }
+
   template <typename stream>
   bool marshal_sequence(stream & strm, const TAO::unbounded_value_sequence <CORBA::ULongLong> & source) {
     ::CORBA::ULong const length = source.length ();
@@ -518,6 +584,24 @@ namespace TAO {
     return true;
   }
 
+  template <typename stream, typename charT, CORBA::ULong BD_STR_MAX>
+  bool marshal_sequence(stream & strm, const TAO::unbounded_bd_string_sequence <charT, BD_STR_MAX> & source) {
+    ::CORBA::ULong const length = source.length ();
+    if (!(strm << length)) {
+      return false;
+    }
+    for(CORBA::ULong i = 0; i < length; ++i) {
+      if (source[i].in () != 0 &&
+          ACE_OS::strlen (source[i]) > source.bd_string_maximum ()) {
+        throw ::CORBA::BAD_PARAM ();
+      }
+      if (!(strm << source[i])) {
+        return false;
+      }
+    }
+    return true;
+  }
+
   template <typename stream, typename object_t, typename object_t_var>
   bool marshal_sequence(stream & strm, const TAO::unbounded_object_reference_sequence<object_t, object_t_var> & source) {
     typedef typename TAO::unbounded_object_reference_sequence<object_t, object_t_var>::object_type objec_t;
