@@ -1,9 +1,10 @@
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Encodable.h
  *
- *  Encodable.h,v 1.1 2005/07/13 12:32:12 jwillemsen Exp
+ *  $Id: Encodable.h 71473 2006-03-10 07:19:20Z jtc $
  *
  *   Defines the interface for classes that wish to be
  *   encodable/decodable into/from a CDR representation.
@@ -23,7 +24,9 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
-#include "utils_export.h"
+#include "tao/Utils/utils_export.h"
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 class TAO_OutputCDR;
 class TAO_InputCDR;
@@ -52,6 +55,8 @@ public:
   virtual CORBA::Boolean _tao_decode (TAO_InputCDR &in_cdr) = 0;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_ENCODABLE_H_ */
