@@ -1,9 +1,10 @@
 // -*- C++ -*-
+
 //=============================================================================
 /**
  * @file Implicit_Deactivator.h
  *
- * Implicit_Deactivator.h,v 1.6 2004/05/07 16:24:44 coryan Exp
+ * $Id: Implicit_Deactivator.h 77151 2007-02-15 13:24:41Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@atdesk.com>
  */
@@ -11,7 +12,7 @@
 #ifndef TAO_UTILS_IMPLICIT_DEACTIVATOR_H
 #define TAO_UTILS_IMPLICIT_DEACTIVATOR_H
 #include /**/ "ace/pre.h"
-#include "utils_export.h"
+#include "tao/Utils/utils_export.h"
 
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
@@ -21,6 +22,7 @@
 #include "tao/PortableServer/PortableServer.h"
 #include "ace/Auto_Functor.h"
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 namespace TAO
 {
@@ -37,8 +39,7 @@ namespace TAO
       typedef PortableServer::ServantBase * argument;
 
       // Deactivate an implicitly activated servant
-      void operator() (PortableServer::ServantBase * servant)
-        ACE_THROW_SPEC (());
+      void operator() (PortableServer::ServantBase * servant) throw ();
     };
 
     /**
@@ -55,5 +56,7 @@ namespace TAO
   } // namespace Utils
 } // namespace TAO
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 #endif /*TAO_UTILS_IMPLICIT_DEACTIVATOR_H*/
