@@ -1,4 +1,4 @@
-// $Id: ORB_Manager.cpp 80229 2007-12-11 10:46:24Z johnnyw $
+// $Id: ORB_Manager.cpp 82875 2008-09-29 14:17:15Z johnnyw $
 
 // ============================================================================
 //
@@ -24,7 +24,7 @@
 
 ACE_RCSID (PortableServer,
            ORB_Manager,
-           "$Id: ORB_Manager.cpp 80229 2007-12-11 10:46:24Z johnnyw $")
+           "$Id: ORB_Manager.cpp 82875 2008-09-29 14:17:15Z johnnyw $")
 
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
@@ -41,7 +41,7 @@ TAO_ORB_Manager::TAO_ORB_Manager (CORBA::ORB_ptr orb,
 
 int
 TAO_ORB_Manager::init (int &argc,
-                       char **argv,
+                       ACE_TCHAR *argv[],
                        const char *orb_name)
 {
   if (CORBA::is_nil (this->orb_.in ()))
@@ -76,7 +76,7 @@ TAO_ORB_Manager::init (int &argc,
 #if !defined (CORBA_E_MICRO)
 int
 TAO_ORB_Manager::init_child_poa (int& argc,
-                                 char **argv,
+                                 ACE_TCHAR **argv,
                                  const char *poa_name,
                                  const char *orb_name)
 {
