@@ -3,7 +3,7 @@
 /**
  * @file PolicyList_Destroyer.h
  *
- * PolicyList_Destroyer.h,v 1.5 2003/10/12 23:02:11 huangming Exp
+ * $Id: PolicyList_Destroyer.h 77151 2007-02-15 13:24:41Z johnnyw $
  *
  * @author Carlos O'Ryan <coryan@atdesk.com>
  */
@@ -11,7 +11,7 @@
 #ifndef TAO_UTILS_POLICYLIST_DESTROYER_H
 #define TAO_UTILS_POLICYLIST_DESTROYER_H
 #include /**/ "ace/pre.h"
-#include "utils_export.h"
+#include "tao/Utils/utils_export.h"
 
 #include "tao/PolicyC.h"
 
@@ -19,6 +19,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 namespace TAO
 {
   namespace Utils
@@ -35,15 +37,16 @@ namespace TAO
     {
     public:
       PolicyList_Destroyer(CORBA::ULong length_hint);
-      ~PolicyList_Destroyer()
-        ACE_THROW_SPEC (());
+      ~PolicyList_Destroyer() throw ();
     };
 
   } // namespace Utils
 } // namespace TAO
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #if defined (__ACE_INLINE__)
-# include "PolicyList_Destroyer.inl"
+# include "tao/Utils/PolicyList_Destroyer.inl"
 #endif /* __ACE_INLINE__ */
 
 #include /**/ "ace/post.h"
