@@ -6,7 +6,7 @@
  * @brief Implement the element manipulation traits for types with
  * value-like semantics.
  *
- * $Id: Value_Traits_T.h 77677 2007-03-12 20:16:37Z ossama $
+ * $Id: Value_Traits_T.h 88803 2010-02-02 11:13:27Z vzykov $
  *
  * @author Carlos O'Ryan
  */
@@ -38,7 +38,13 @@ struct value_traits
     std::fill(begin, end, value_type ());
   }
 
-# ifndef ACE_LACKS_MEMBER_TEMPLATES
+  inline static void release_range(
+      value_type *, value_type *)
+  {
+    // Noop for value sequences
+  }
+
+# if !defined (ACE_LACKS_MEMBER_TEMPLATES)
   // Allow MSVC++ >= 8 checked iterators to be used.
   template <typename iter>
   inline static void copy_range(
@@ -53,6 +59,22 @@ struct value_traits
     std::copy(begin, end, dst);
   }
 # endif  /* !ACE_LACKS_MEMBER_TEMPLATES */
+
+# if !defined (ACE_LACKS_MEMBER_TEMPLATES)
+  // Allow MSVC++ >= 8 checked iterators to be used.
+  template <typename iter>
+  inline static void copy_swap_range(
+      value_type * begin, value_type * end, iter dst)
+  {
+    copy_range(begin, end, dst);
+  }
+# else
+  inline static void copy_swap_range(
+      value_type * begin, value_type * end, value_type * dst)
+  {
+    copy_range(begin, end, dst);
+  }
+# endif  /* !ACE_LACKS_MEMBER_TEMPLATES */
 };
 
 } // namespace details
