@@ -4,7 +4,7 @@
 /**
  *  @file    Value_CORBA_methods.h
  *
- *  Value_CORBA_methods.h,v 1.2 2004/04/27 20:40:43 ossama Exp
+ *  $Id: Value_CORBA_methods.h 72316 2006-04-25 16:31:42Z mesnier_p $
  *
  *  Declarations of common ValueType methods in the CORBA namespace.
  *
@@ -17,7 +17,7 @@
 
 #include /**/ "ace/pre.h"
 
-#include "valuetype_export.h"
+#include "tao/Valuetype/valuetype_export.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -30,6 +30,9 @@
 #endif
 #define TAO_EXPORT_MACRO TAO_Valuetype_Export
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+
 namespace CORBA
 {
   class ValueBase;
@@ -46,6 +49,8 @@ namespace CORBA
 
 }
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif  /* TAO_VALUETYPE_CORBA_METHODS_H */
