@@ -4,7 +4,7 @@
 /**
  *  @file    Valuetype_Adapter.h
  *
- *  $Id: Valuetype_Adapter.h 74014 2006-08-14 13:52:22Z johnnyw $
+ *  $Id: Valuetype_Adapter.h 81455 2008-04-28 10:26:37Z johnnyw $
  *
  *  @author  Jeff Parsons <j.parsons@vanderbilt.edu>
  */
@@ -56,16 +56,14 @@ public:
   virtual ~TAO_Valuetype_Adapter (void);
 
   virtual CORBA::Object_ptr abstractbase_to_object (
-      CORBA::AbstractBase_ptr p
-    ) = 0;
+      CORBA::AbstractBase_ptr p) = 0;
 
   virtual CORBA::Boolean stream_to_value (TAO_InputCDR &,
                                           CORBA::ValueBase *&) = 0;
 
   virtual CORBA::Boolean stream_to_abstract_base (
       TAO_InputCDR &,
-      CORBA::AbstractBase_ptr &
-    ) = 0;
+      CORBA::AbstractBase_ptr &) = 0;
 
   virtual CORBA::Long type_info_single (void) const = 0;
 
@@ -74,8 +72,7 @@ public:
   virtual CORBA::Boolean is_type_info_list (CORBA::Long) const = 0;
   virtual CORBA::Boolean is_value_chunked (CORBA::Long) const = 0;
 
-  virtual int vf_map_rebind (const char *,
-                             CORBA::ValueFactory &) = 0;
+  virtual int vf_map_rebind (const char *, CORBA::ValueFactory &) = 0;
 
   virtual int vf_map_unbind (const char *) = 0;
 
