@@ -1,4 +1,4 @@
-// $Id: Wait_On_LF_No_Upcall.cpp 76687 2007-01-29 19:18:13Z johnnyw $
+// $Id: Wait_On_LF_No_Upcall.cpp 84563 2009-02-23 08:13:54Z johnnyw $
 
 #include "tao/Wait_On_LF_No_Upcall.h"
 
@@ -9,7 +9,7 @@
 
 ACE_RCSID(tao,
           Wait_On_LF_No_Upcall,
-          "$Id: Wait_On_LF_No_Upcall.cpp 76687 2007-01-29 19:18:13Z johnnyw $")
+          "$Id: Wait_On_LF_No_Upcall.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -101,7 +101,7 @@ namespace TAO
 
     if ((this->transport_->opened_as () == TAO::TAO_CLIENT_ROLE) &&
         (this->transport_->bidirectional_flag () == 0) &&
-        (tss->upcalls_temporarily_suspended_on_this_thread_ == true))
+        (tss->upcalls_temporarily_suspended_on_this_thread_))
       return false;
 
     return true;
