@@ -1,4 +1,4 @@
-// Wait_On_Leader_Follower.cpp,v 1.22 2005/06/22 14:03:40 jwillemsen Exp
+// $Id: Wait_On_Leader_Follower.cpp 76593 2007-01-25 19:19:27Z johnnyw $
 
 #include "tao/Wait_On_Leader_Follower.h"
 #include "tao/LF_Follower.h"
@@ -9,9 +9,12 @@
 
 ACE_RCSID (tao,
            Wait_On_Leader_Follower,
-           "Wait_On_Leader_Follower.cpp,v 1.22 2005/06/22 14:03:40 jwillemsen Exp")
+           "$Id: Wait_On_Leader_Follower.cpp 76593 2007-01-25 19:19:27Z johnnyw $")
 
-TAO_Wait_On_Leader_Follower::TAO_Wait_On_Leader_Follower (TAO_Transport *transport)
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
+TAO_Wait_On_Leader_Follower::TAO_Wait_On_Leader_Follower
+  (TAO_Transport *transport)
   : TAO_Wait_Strategy (transport)
 {
 }
@@ -20,10 +23,18 @@ TAO_Wait_On_Leader_Follower::~TAO_Wait_On_Leader_Follower (void)
 {
 }
 
+/*
+ * Hook to specialize the wait strategy when the concrete strategy is
+ * a simple "lf" strategy. Add all public/protected/private methods
+ * within the *COPY* hooks.
+ */
+
+//@@ WAIT_STRATEGY_SPL_COPY_HOOK_START
+
 int
 TAO_Wait_On_Leader_Follower::register_handler (void)
 {
-  if (this->is_registered_ == 0)
+  if (!this->is_registered_)
     {
       return this->transport_->register_handler ();
     }
@@ -42,25 +53,23 @@ TAO_Wait_On_Leader_Follower::sending_request (TAO_ORB_Core *orb_core,
                                               int two_way)
 {
   // Register the handler.
-  if (this->is_registered_ == 0)
+  if (!this->is_registered_)
     {
       this->transport_->register_handler ();
     }
 
   // Send the request.
-  return this->TAO_Wait_Strategy::sending_request (orb_core,
-                                                   two_way);
+//@@ LF_WAIT_STRATEGY_SPL_SENDING_REQUEST_HOOK
+  return this->TAO_Wait_Strategy::sending_request (orb_core, two_way);
 }
 
 int
 TAO_Wait_On_Leader_Follower::wait (ACE_Time_Value *max_wait_time,
                                    TAO_Synch_Reply_Dispatcher &rd)
 {
-  TAO_Leader_Follower& leader_follower =
+  TAO_Leader_Follower &leader_follower =
     this->transport_->orb_core ()->leader_follower ();
-  return leader_follower.wait_for_event (&rd,
-                                         this->transport_,
-                                         max_wait_time);
+  return leader_follower.wait_for_event (&rd, this->transport_, max_wait_time);
 }
 
 bool
@@ -68,3 +77,10 @@ TAO_Wait_On_Leader_Follower::can_process_upcalls (void) const
 {
   return true;
 }
+
+//@@ WAIT_STRATEGY_SPL_COPY_HOOK_END
+/*
+ * End copy hook.
+ */
+
+TAO_END_VERSIONED_NAMESPACE_DECL
