@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Wait_On_Leader_Follower.h
  *
- *  Wait_On_Leader_Follower.h,v 1.10 2005/07/27 10:51:59 jwillemsen Exp
+ *  $Id: Wait_On_Leader_Follower.h 76947 2007-02-07 20:26:03Z johnnyw $
  *
  *  @author  Alexander Babu Arulanthu <alex@cs.wustl.edu>
  */
@@ -21,6 +21,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Wait_On_Leader_Follower
  *
@@ -35,7 +37,7 @@
  * is Muxed and hence there are multiple threads running in the
  * same Transport context.
  */
-class TAO_Export TAO_Wait_On_Leader_Follower : public TAO_Wait_Strategy
+class TAO_Wait_On_Leader_Follower : public TAO_Wait_Strategy
 {
 
 public:
@@ -46,8 +48,7 @@ public:
   virtual ~TAO_Wait_On_Leader_Follower (void);
 
   // = Documented in TAO_Wait_Strategy.
-  virtual int sending_request (TAO_ORB_Core *orb_core,
-                               int two_way);
+  virtual int sending_request (TAO_ORB_Core *orb_core, int two_way);
   virtual int wait (ACE_Time_Value *max_wait_time,
                     TAO_Synch_Reply_Dispatcher &rd);
   virtual int register_handler (void);
@@ -55,6 +56,8 @@ public:
   virtual bool can_process_upcalls (void) const;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_WAIT_ON_LEADER_FOLLOWER_H */
