@@ -1,4 +1,4 @@
-// Wait_On_Reactor.cpp,v 1.11 2005/03/06 08:47:18 lut Exp
+// $Id: Wait_On_Reactor.cpp 76593 2007-01-25 19:19:27Z johnnyw $
 
 #include "tao/Wait_On_Reactor.h"
 #include "tao/ORB_Core.h"
@@ -10,7 +10,9 @@
 
 ACE_RCSID (tao,
            Wait_On_Reactor,
-           "Wait_On_Reactor.cpp,v 1.11 2005/03/06 08:47:18 lut Exp")
+           "$Id: Wait_On_Reactor.cpp 76593 2007-01-25 19:19:27Z johnnyw $")
+
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
 TAO_Wait_On_Reactor::TAO_Wait_On_Reactor (TAO_Transport *transport)
   : TAO_Wait_Strategy (transport)
@@ -30,7 +32,7 @@ TAO_Wait_On_Reactor::wait (ACE_Time_Value *max_wait_time,
   ACE_Countdown_Time countdown (max_wait_time);
 
   // Reactor does not change inside the loop.
-  ACE_Reactor* reactor =
+  ACE_Reactor *const reactor =
     this->transport_->orb_core ()->reactor ();
 
   // Do the event loop, till we fully receive a reply.
@@ -96,7 +98,7 @@ TAO_Wait_On_Reactor::wait (ACE_Time_Value *max_wait_time,
 int
 TAO_Wait_On_Reactor::register_handler (void)
 {
-  if (this->is_registered_ == 0)
+  if (!this->is_registered_)
     {
       return this->transport_->register_handler ();
     }
@@ -115,3 +117,5 @@ TAO_Wait_On_Reactor::can_process_upcalls (void) const
 {
   return true;
 }
+
+TAO_END_VERSIONED_NAMESPACE_DECL
