@@ -1,10 +1,10 @@
-// This may look like C, but it's really -*- C++ -*-
+// -*- C++ -*-
 
 //=============================================================================
 /**
  *  @file    Wait_On_Reactor.h
  *
- *  Wait_On_Reactor.h,v 1.8 2004/10/03 20:26:13 bala Exp
+ *  $Id: Wait_On_Reactor.h 69153 2005-11-02 11:03:27Z ossama $
  *
  *  @author  Alexander Babu Arulanthu <alex@cs.wustl.edu>
  */
@@ -21,6 +21,8 @@
 # pragma once
 #endif /* ACE_LACKS_PRAGMA_ONCE */
 
+TAO_BEGIN_VERSIONED_NAMESPACE_DECL
+
 /**
  * @class TAO_Wait_On_Reactor
  *
@@ -28,7 +30,7 @@
  * environment.
  *
  */
-class TAO_Export TAO_Wait_On_Reactor : public TAO_Wait_Strategy
+class TAO_Wait_On_Reactor : public TAO_Wait_Strategy
 {
 
 public:
@@ -47,6 +49,8 @@ public:
   virtual bool can_process_upcalls (void) const;
 };
 
+TAO_END_VERSIONED_NAMESPACE_DECL
+
 #include /**/ "ace/post.h"
 
 #endif /* TAO_WAIT_ON_REACTOR_H */
