@@ -1,4 +1,4 @@
-// $Id: default_resource.cpp 80609 2008-02-12 12:11:38Z johnnyw $
+// $Id: default_resource.cpp 84443 2009-02-12 20:26:35Z johnnyw $
 
 #include "tao/default_resource.h"
 
@@ -29,7 +29,7 @@
 
 ACE_RCSID (tao,
            default_resource,
-           "$Id: default_resource.cpp 80609 2008-02-12 12:11:38Z johnnyw $")
+           "$Id: default_resource.cpp 84443 2009-02-12 20:26:35Z johnnyw $")
 
 TAO_BEGIN_VERSIONED_NAMESPACE_DECL
 
@@ -169,7 +169,7 @@ TAO_Default_Resource_Factory::init (int argc, ACE_TCHAR *argv[])
   // are useless
   if (this->factory_disabled_) {
     ACE_DEBUG ((LM_WARNING,
-                ACE_TEXT ("TAO (%P|%t) Warning: Resource_Factory options ")
+                ACE_TEXT ("TAO (%P|%t) - Warning: Resource_Factory options ")
                 ACE_TEXT ("ignored\n")
                 ACE_TEXT ("Default Resource Factory is disabled\n")));
     return 0;
@@ -285,9 +285,9 @@ TAO_Default_Resource_Factory::init (int argc, ACE_TCHAR *argv[])
         // @todo: This needs to be removed after a few betas. The
         // note is being written during 1.2.3 timeframe.
         ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("(%P|%t) This option would be deprecated \n")
+                    ACE_TEXT ("(%P|%t) This option would be deprecated\n")
                     ACE_TEXT ("(%P|%t) Please use -ORBConnectionPurgingStrategy ")
-                    ACE_TEXT ("instead \n")));
+                    ACE_TEXT ("instead\n")));
 
         if (curarg < argc)
           {
@@ -571,14 +571,14 @@ TAO_Default_Resource_Factory::init (int argc, ACE_TCHAR *argv[])
         // Can we assume there is an argument after the option?
         // ++curarg;
         ACE_ERROR ((LM_ERROR,
-                    ACE_TEXT ("Default_Resource_Factory - ")
+                    ACE_TEXT ("TAO (%P|%t) - Default_Resource_Factory - ")
                     ACE_TEXT ("unknown option <%s>\n"),
                     argv[curarg]));
       }
     else
       {
         ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("Default_Resource_Factory - ")
+                    ACE_TEXT ("TAO (%P|%t) - Default_Resource_Factory - ")
                     ACE_TEXT ("ignoring option <%s>\n"),
                     argv[curarg]));
       }
@@ -732,9 +732,9 @@ TAO_Default_Resource_Factory::init_protocol_factories (void)
       if ((*factory)->factory () == 0)
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             ACE_TEXT ("TAO (%P|%t) Unable to load ")
-                             ACE_TEXT ("protocol <%s>, %p\n"),
-                             ACE_TEXT_CHAR_TO_TCHAR(name.c_str ()),
+                             ACE_TEXT ("TAO (%P|%t) - Unable to load ")
+                             ACE_TEXT ("protocol <%C>, %p\n"),
+                             name.c_str (),
                              ACE_TEXT ("")),
                             -1);
         }
@@ -742,8 +742,8 @@ TAO_Default_Resource_Factory::init_protocol_factories (void)
       if (TAO_debug_level > 0)
         {
           ACE_DEBUG ((LM_DEBUG,
-                      ACE_TEXT ("TAO (%P|%t) Loaded protocol <%s>\n"),
-                      ACE_TEXT_CHAR_TO_TCHAR(name.c_str ())));
+                      ACE_TEXT ("TAO (%P|%t) - Loaded protocol <%C>\n"),
+                      name.c_str ()));
         }
     }
 
@@ -1230,8 +1230,8 @@ TAO_Default_Resource_Factory::report_option_value_error (
                                  const ACE_TCHAR* option_value)
 {
   ACE_DEBUG((LM_DEBUG,
-             ACE_TEXT ("Default_Resource_Factory - unknown argument")
-             ACE_TEXT (" <%s> for <%s>\n"),
+             ACE_TEXT ("TAO (%P|%t) - Default_Resource_Factory - unknown ")
+             ACE_TEXT ("argument <%s> for <%s>\n"),
              option_value, option_name));
 }
 
@@ -1242,7 +1242,7 @@ TAO_Default_Resource_Factory::disable_factory (void)
   if (this->options_processed_)
     {
       ACE_DEBUG ((LM_WARNING,
-                  ACE_TEXT ("TAO (%P|%t) Warning: Resource_Factory options ignored\n")
+                  ACE_TEXT ("TAO (%P|%t) - Warning: Resource_Factory options ignored\n")
                   ACE_TEXT ("Default Resource Factory is disabled\n")));
     }
 }
@@ -1257,7 +1257,7 @@ TAO_Default_Resource_Factory::codeset_manager(void)
     {
       if (TAO_debug_level >= 2)
         ACE_DEBUG ((LM_DEBUG,
-                    ACE_TEXT ("TAO (%P|%t) Default_Resource_Factory")
+                    ACE_TEXT ("TAO (%P|%t) - Default_Resource_Factory")
                     ACE_TEXT (" - unable to find codeset manager factory.\n")));
       return 0;
     }
@@ -1268,7 +1268,7 @@ TAO_Default_Resource_Factory::codeset_manager(void)
     {
       if (TAO_debug_level >= 2)
         ACE_DEBUG ((LM_INFO,
-                    ACE_TEXT ("TAO (%P|%t) Default_Resource_Factory")
+                    ACE_TEXT ("TAO (%P|%t) - Default_Resource_Factory")
                     ACE_TEXT (" - unable to create codeset manager.\n")));
       return 0;
     }
@@ -1278,7 +1278,7 @@ TAO_Default_Resource_Factory::codeset_manager(void)
 
   if (TAO_debug_level >= 1)
     ACE_DEBUG ((LM_DEBUG,
-                ACE_TEXT ("TAO (%P|%t) Default_Resource_Factory - codeset manager=%@\n"),
+                ACE_TEXT ("TAO (%P|%t) - Default_Resource_Factory - codeset manager=%@\n"),
                 mgr));
 
   this->char_codeset_parameters_.apply_to (mgr->char_codeset_descriptor());
@@ -1300,8 +1300,6 @@ TAO_Default_Resource_Factory::drop_replies_during_shutdown (void) const
   return this->drop_replies_;
 }
 
-TAO_END_VERSIONED_NAMESPACE_DECL
-
 // ****************************************************************
 
 ACE_STATIC_SVC_DEFINE (TAO_Default_Resource_Factory,
@@ -1312,3 +1310,6 @@ ACE_STATIC_SVC_DEFINE (TAO_Default_Resource_Factory,
                        | ACE_Service_Type::DELETE_OBJ,
                        0)
 ACE_FACTORY_DEFINE (TAO, TAO_Default_Resource_Factory)
+
+TAO_END_VERSIONED_NAMESPACE_DECL
+
