@@ -4,7 +4,7 @@
 /**
  *  @file     orbconf.h
  *
- *  $Id: orbconf.h 80443 2008-01-16 19:23:21Z johnnyw $
+ *  $Id: orbconf.h 84936 2009-03-23 09:55:43Z johnnyw $
  *
  *  Build configuration file.
  *
@@ -113,6 +113,19 @@ const size_t TAO_RD_TABLE_SIZE = 16;
 const size_t TAO_DEFAULT_POLICY_FACTORY_REGISTRY_SIZE = 64;
 #endif  /* !TAO_DEFAULT_ORB_TABLE_SIZE */
 
+// Should we use parallel connect
+#if !defined (TAO_USE_PARALLEL_CONNECT)
+const bool TAO_USE_PARALLEL_CONNECT = false;
+#endif /* !TAO_USE_PARALLEL_CONNECT */
+
+#if !defined (TAO_ACCEPT_ERROR_DELAY)
+const time_t TAO_ACCEPT_ERROR_DELAY = 5;
+#endif /* TAO_ACCEPT_ERROR_DELAY */
+
+#if !defined (TAO_SO_LINGER)
+const int TAO_SO_LINGER = -1;
+#endif /* TAO_SO_LINGER */
+
 // The default size of TAO's initial object reference table, i.e. the
 // one used as the underlying implementation for the
 // CORBA::ORB::register_initial_reference() and
@@ -208,9 +221,6 @@ const size_t TAO_DEFAULT_VALUE_FACTORY_TABLE_SIZE = 128;
 # endif /* !defined(_WIN32) */
 #endif /* __WIN32__ */
 
-// Define to `int' if <sys/types.h> doesn't define.
-/* #undef pid_t */
-
 // Define if your processor does not store words with the most significant
 // byte first.
 
@@ -235,6 +245,21 @@ const size_t TAO_DEFAULT_VALUE_FACTORY_TABLE_SIZE = 128;
 // Define if you have the vprintf function.
 #define HAVE_VPRINTF 1
 
+// Comment out to enable only ACE monitors...
+#if defined (ACE_HAS_MONITOR_FRAMEWORK) && (ACE_HAS_MONITOR_FRAMEWORK == 1)
+#  define TAO_HAS_MONITOR_FRAMEWORK 1
+#else
+#  define TAO_HAS_MONITOR_FRAMEWORK 0
+#endif /* ACE_HAS_MONITOR_FRAMEWORK*/
+
+#if !defined (TAO_HAS_MONITOR_POINTS)
+# define TAO_HAS_MONITOR_POINTS ACE_HAS_MONITOR_POINTS
+#endif
+
+#if !defined (TAO_HAS_ZIOP)
+# define TAO_HAS_ZIOP 0
+#endif
+
 // Avoid namespace pollution that's common on older UNIXes...
 #if defined (minor)
 #undef minor
@@ -688,7 +713,7 @@ const size_t TAO_DEFAULT_VALUE_FACTORY_TABLE_SIZE = 128;
 // default for TAO, but we can suppress it also explicitly by set
 // TAO_HAS_SENDFILE to 0.
 #if !defined (TAO_HAS_SENDFILE)
-# if defined ACE_HAS_SENDFILE
+# if defined ACE_HAS_SENDFILE && ACE_HAS_SENDFILE == 1
 #  define TAO_HAS_SENDFILE 1
 # else
 #  define TAO_HAS_SENDFILE 0
@@ -754,6 +779,14 @@ enum TAO_Cached_Policy_Type
 
   TAO_CACHED_POLICY_ENDPOINT,
 
+  TAO_CACHED_COMPRESSION_ENABLING_POLICY,
+
+  TAO_CACHED_COMPRESSION_LOW_VALUE_POLICY,
+
+  TAO_CACHED_MIN_COMPRESSION_RATIO_POLICY,
+
+  TAO_CACHED_COMPRESSION_ID_LEVEL_LIST_POLICY,
+
   /// NOTE: The "TAO_CACHED_POLICY_MAX_CACHED" should always be the last.
   ///       This value is used as the cached_policies_ array size in TAO_Policy_Set,
   ///       Any policy type defined after "TAO_CACHED_POLICY_MAX_CACHED" will cause
@@ -878,6 +911,10 @@ enum TAO_Policy_Scope
 # endif
 #endif
 
+#if !defined (TAO_HAS_SEQUENCE_ITERATORS)
+#  define TAO_HAS_SEQUENCE_ITERATORS 0
+#endif
+
 TAO_END_VERSIONED_NAMESPACE_DECL
 
 #include /**/ "ace/post.h"
