@@ -1,8 +1,36 @@
-// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: client.cpp 83901 2008-11-28 11:29:31Z johnnyw $
 
 #include "TestC.h"
+#include "ace/Get_Opt.h"
+
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
+
+int
+parse_args (int argc, ACE_TCHAR *argv[])
+{
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
+  int c;
+
+  while ((c = get_opts ()) != -1)
+    switch (c)
+      {
+      case 'k':
+        ior = get_opts.opt_arg ();
+        break;
+
+      case '?':
+      default:
+        ACE_ERROR_RETURN ((LM_ERROR,
+                           "usage:  %s "
+                           "-k <ior> "
+                           "\n",
+                           argv [0]),
+                          -1);
+      }
+  // Indicates sucessful parsing of the command line
+  return 0;
+}
 
-const char *ior = "file://test.ior";
 
 int
 ACE_TMAIN(int argc, ACE_TCHAR *argv[])
@@ -13,6 +41,9 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::ORB_var orb =
         CORBA::ORB_init (argc, argv);
 
+      if (parse_args (argc, argv) != 0)
+        return 1;
+
       CORBA::Object_var object =
         orb->string_to_object (ior);
 
