@@ -3,7 +3,7 @@
 /**
  *  @file    ami_test_i.cpp
  *
- *  $Id: ami_test_i.cpp 78184 2007-04-25 07:19:25Z johnnyw $
+ *  $Id: ami_test_i.cpp 83164 2008-10-12 20:03:08Z johnnyw $
  *
  *  Implementation of the AMI Test interface.
  *
@@ -17,7 +17,7 @@
 #include "ami_test_i.h"
 #include "tao/debug.h"
 
-ACE_RCSID(AMI, ami_test_i, "$Id: ami_test_i.cpp 78184 2007-04-25 07:19:25Z johnnyw $")
+ACE_RCSID(AMI, ami_test_i, "$Id: ami_test_i.cpp 83164 2008-10-12 20:03:08Z johnnyw $")
 
 AMI_Test_i::AMI_Test_i (CORBA::ORB_ptr orb,
                         CORBA::Long in_l,
@@ -41,7 +41,7 @@ AMI_Test_i::foo (CORBA::Long_out out_l,
 
   //if (TAO_debug_level > 0)
   ACE_DEBUG ((LM_DEBUG,
-              "%N:%l:(%P:%t):AMI_Test_i::foo:  %d %s\n",
+              "%N:%l:(%P:%t):AMI_Test_i::foo:  %d %C\n",
               in_l,
               in_str));
 
@@ -57,7 +57,7 @@ AMI_Test_i::foo (CORBA::Long_out out_l,
       if (in_l_ != in_l || ACE_OS::strcmp(in_str_.in (), in_str) != 0)
         {
           ACE_ERROR ((LM_ERROR,
-                      "ERROR: Parameter corruption on in parameters: %d %d %s %s.\n",
+                      "ERROR: Parameter corruption on in parameters: %d %d %C %C.\n",
                       in_l_, in_l, in_str_.in (), in_str));
           return 0;
         }
