@@ -3,7 +3,7 @@
 /**
  *  @file   ami_test_i.h
  *
- *  $Id: ami_test_i.h 77092 2007-02-13 08:09:46Z johnnyw $
+ *  $Id: ami_test_i.h 81961 2008-06-16 00:55:02Z sowayaa $
  *
  *  @author Michael Kircher <Michael.Kircher@mchp.siemens.de>
  */
@@ -27,8 +27,9 @@ class AMI_Test_i : public POA_A::AMI_Test
 public:
   /// ctor
   AMI_Test_i (CORBA::ORB_ptr orb,
-        CORBA::Long in_l = 0, const char * in_str = 0,
-	      bool check_params = false);
+              CORBA::Long in_l = 0,
+              const char * in_str = 0,
+              bool check_params = false);
 
   // The AMI_Test methods.
   CORBA::Long foo (CORBA::Long_out out_l,
