@@ -3,7 +3,7 @@
 /**
  *  @file    client.cpp
  *
- *  $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+ *  $Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
  *
  *  A client which uses the AMI callback model.
  *
@@ -20,9 +20,9 @@
 
 ACE_RCSID (AMI,
            client,
-           "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+           "$Id: client.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int nthreads = 5;
 int niterations = 5;
 int debug = 0;
@@ -33,9 +33,9 @@ const char * in_str = "Let's talk AMI.";
 int parameter_corruption = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "dk:n:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dk:n:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -58,7 +58,6 @@ parse_args (int argc, char *argv[])
         ACE_ERROR_RETURN ((LM_ERROR,
                            "usage:  %s "
                            "-d "
-                           "-c"
                            "-k <ior> "
                            "-n <nthreads> "
                            "-i <niterations> "
@@ -129,7 +128,7 @@ public:
     {
 
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <foo_excep> called: \n"));
+                  "Callback method <foo_excep> called:\n"));
       try
         {
           excep_holder->raise_exception ();
@@ -150,19 +149,19 @@ public:
   void get_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <get_yadda_excep> called: \n"));
+                  "Callback method <get_yadda_excep> called:\n"));
     };
 
   void set_yadda (void)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda> called: \n"));
+                  "Callback method <set_yadda> called:\n"));
     };
 
   void set_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda_excep> called: \n"));
+                  "Callback method <set_yadda_excep> called:\n"));
     };
   ~Handler (void)
   {
@@ -171,7 +170,7 @@ public:
   void inout_arg_test (const char *)
   {
     ACE_DEBUG ((LM_DEBUG,
-                "Callback method <set_yadda_excep> called: \n"));
+                "Callback method <set_yadda_excep> called:\n"));
   }
 
   void inout_arg_test_excep (::Messaging::ExceptionHolder *)
@@ -202,7 +201,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (CORBA::is_nil (server.in ()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             "Object reference <%s> is nil\n",
+                             "Object reference <%s> is nil.\n",
                              ior),
                             1);
         }
