@@ -3,7 +3,7 @@
 /**
  *  @file    simple_client.cpp
  *
- *  $Id: simple_client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+ *  $Id: simple_client.cpp 84563 2009-02-23 08:13:54Z johnnyw $
  *
  *  A very simple client which uses the AMI callback model.
  *
@@ -21,18 +21,18 @@
 
 ACE_RCSID (AMI,
            simple_client,
-           "$Id: simple_client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+           "$Id: simple_client.cpp 84563 2009-02-23 08:13:54Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 int niterations = 5;
 int shutdown_flag = 0;
 int debug = 0;
 int result = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "dk:i:x");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dk:i:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -104,7 +104,7 @@ public:
     {
 
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <foo_excep> called: \n"
+                  "Callback method <foo_excep> called:\n"
                   "Testing proper exception handling ...\n"));
       try
         {
@@ -124,7 +124,7 @@ public:
           if (ACE_OS::strcmp (ex.whatDidTheRightThing.in (), "Hello world") != 0)
             {
               ACE_ERROR ((LM_ERROR,
-                          "ERROR: ex.whatDidTheRightThing not ok: <%s>\n",
+                          "ERROR: ex.whatDidTheRightThing not ok: <%C>\n",
                           ex.whatDidTheRightThing.in ()));
               result = 1;
             }
@@ -148,19 +148,19 @@ public:
   void get_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <get_yadda_excep> called: \n"));
+                  "Callback method <get_yadda_excep> called:\n"));
     };
 
   void set_yadda (void)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda> called: \n"));
+                  "Callback method <set_yadda> called:\n"));
     };
 
   void set_yadda_excep (::Messaging::ExceptionHolder *)
     {
       ACE_DEBUG ((LM_DEBUG,
-                  "Callback method <set_yadda_excep> called: \n"));
+                  "Callback method <set_yadda_excep> called:\n"));
     };
 
   void inout_arg_test (
@@ -168,7 +168,7 @@ public:
       )
   {
     ACE_DEBUG ((LM_DEBUG,
-                "Callback method <set_yadda_excep> called: \n"));
+                "Callback method <set_yadda_excep> called:\n"));
   }
 
   void inout_arg_test_excep (::Messaging::ExceptionHolder *)
@@ -209,7 +209,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (CORBA::is_nil (ami_test_var.in ()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             "Object reference <%s> is nil\n",
+                             "Object reference <%s> is nil.\n",
                              ior),
                             1);
         }
