@@ -1,4 +1,4 @@
-// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: client.cpp 82870 2008-09-29 08:47:19Z johnnyw $
 
 #include "Reply_Handler.h"
 #include "Client_Task.h"
@@ -8,10 +8,10 @@
 #include "tao/AnyTypeCode/Any.h"
 #include "ace/Get_Opt.h"
 
-ACE_RCSID(AMI_Buffering, client, "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+ACE_RCSID(AMI_Buffering, client, "$Id: client.cpp 82870 2008-09-29 08:47:19Z johnnyw $")
 
-const char *server_ior = "file://server.ior";
-const char *admin_ior = "file://admin.ior";
+const ACE_TCHAR *server_ior = ACE_TEXT("file://server.ior");
+const ACE_TCHAR *admin_ior = ACE_TEXT("file://admin.ior");
 int iterations = 20;
 
 int run_message_count_test = 0;
@@ -38,9 +38,9 @@ const int LIVENESS_MAX_DEPTH = 256;
 const double GIOP_OVERHEAD = 0.9;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:a:i:ctbr");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:a:i:ctbr"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -531,6 +531,7 @@ run_timeout (CORBA::ORB_ptr orb,
     Test::AMI_AMI_BufferingHandler::_narrow (object_act.in ());
 
   CORBA::ULong send_count = 0;
+  int retry_attempt = 0;
   for (int i = 0; i != iterations; ++i)
     {
       sync_server (orb, flusher.in ());
@@ -578,6 +579,12 @@ run_timeout (CORBA::ORB_ptr orb,
 
           if (elapsed.msec () > TIMEOUT_TOLERANCE)
             {
+              if (retry_attempt++ < 10) {
+                               ACE_DEBUG ((LM_DEBUG, "DEBUG: Retry attempt %d beyond TIMEOUT_TOLERANCE.\n",
+                                           retry_attempt));
+                               continue;
+              }
+
               test_failed = 1;
               ACE_DEBUG ((LM_DEBUG,
                           "DEBUG: Iteration %d no flush past "
@@ -643,6 +650,7 @@ run_timeout_reactive (CORBA::ORB_ptr orb,
     Test::AMI_AMI_BufferingHandler::_narrow (object_act.in ());
 
   CORBA::ULong send_count = 0;
+  int retry_attempt = 0;
   for (int i = 0; i != iterations; ++i)
     {
       sync_server (orb, flusher.in ());
@@ -691,6 +699,12 @@ run_timeout_reactive (CORBA::ORB_ptr orb,
 
           if (elapsed.msec () > TIMEOUT_TOLERANCE)
             {
+              if (retry_attempt++ < 10) {
+                ACE_DEBUG ((LM_DEBUG, "DEBUG: Retry attempt %d beyond TIMEOUT_TOLERANCE.\n",
+                            retry_attempt));
+                continue;
+              }
+
               test_failed = 1;
               ACE_DEBUG ((LM_DEBUG,
                           "DEBUG: Iteration %d no flush past "
