@@ -3,7 +3,7 @@
 /**
  *  @file    client.cpp
  *
- *  $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+ *  $Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $
  *
  *  A client, which uses the AMI callback model and timeouts.
  *
@@ -21,15 +21,15 @@
 
 ACE_RCSID (AMI,
            client,
-           "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+           "$Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 unsigned int msec = 50;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "dk:t:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("dk:t:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -79,7 +79,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (CORBA::is_nil (timeout_var.in ()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             "Object reference <%s> is nil\n",
+                             "Object reference <%s> is nil.\n",
                              ior),
                             1);
         }
