@@ -3,11 +3,10 @@
 /**
  *  @file    server.cpp
  *
- *  $Id: server.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+ *  $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $
  *
  *  Implementation of the server running the Timeout object.
  *
- *
  *  @author Michael Kircher <Michael.Kircher@mchp.siemens.de>
  */
 //=============================================================================
@@ -19,14 +18,14 @@
 
 ACE_RCSID (AMI,
            server,
-           "$Id: server.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+           "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")
 
-const char *ior_output_file = 0;
+const ACE_TCHAR *ior_output_file = 0;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:d");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:d"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -36,7 +35,7 @@ parse_args (int argc, char *argv[])
         ior_output_file = get_opts.opt_arg ();
         break;
       case 'd':
-        TAO_debug_level++;
+        ++TAO_debug_level;
         break;
       case '?':
       default:
@@ -89,7 +88,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::String_var ior =
         orb->object_to_string (timeout_var.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       // If the ior_output_file exists, output the ior to it
       if (ior_output_file != 0)
