@@ -1,4 +1,4 @@
-// $Id: timeout_i.cpp 77008 2007-02-12 11:52:38Z johnnyw $
+// $Id: timeout_i.cpp 82598 2008-08-11 18:36:44Z johnnyw $
 
 // ============================================================================
 //
@@ -73,7 +73,7 @@ TimeoutHandler_i::sendTimeToWait (void)
 {
   ACE_DEBUG ((LM_DEBUG,
               "reply"));
-  reply_counter_++;
+  ++reply_counter_;
   timer_.stop ();
 }
 
@@ -90,7 +90,7 @@ TimeoutHandler_i::sendTimeToWait_excep (::Messaging::ExceptionHolder *excep_hold
     {
       ACE_DEBUG ((LM_DEBUG,
                   "timeout"));
-      reply_excep_counter_++;
+      ++reply_excep_counter_;
     }
   catch (...)
     {
