@@ -1,4 +1,4 @@
-// $Id: server.cpp 80377 2008-01-06 19:06:30Z johnnyw $
+// $Id: server.cpp 83259 2008-10-15 18:51:42Z johnnyw $
 
 #include "test_i.h"
 #include "ace/Get_Opt.h"
@@ -6,14 +6,14 @@
 
 ACE_RCSID (Abstract_Interface,
            server,
-           "$Id: server.cpp 80377 2008-01-06 19:06:30Z johnnyw $")
+           "$Id: server.cpp 83259 2008-10-15 18:51:42Z johnnyw $")
 
-const char *ior_output_file = "test.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -25,9 +25,9 @@ parse_args (int argc, char *argv[])
       case '?':
       default:
         ACE_ERROR_RETURN ((LM_ERROR,
-                           "usage:  %s "
-                                             "-o <iorfile>"
-                           "\n",
+                           ACE_TEXT("usage:  %s ")
+                           ACE_TEXT("-o <iorfile>")
+                           ACE_TEXT("\n"),
                            argv [0]),
                           -1);
       }
@@ -107,7 +107,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
               orb->object_to_string (server.in ());
 
       ACE_DEBUG ((LM_DEBUG,
-                  "Activated as <%s>\n",
+                  "Activated as <%C>\n",
                   ior.in ()));
 
       // If the ior_output_file exists, output the ior to it
