@@ -1,4 +1,4 @@
-// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: client.cpp 82870 2008-09-29 08:47:19Z johnnyw $
 
 #include "TestC.h"
 #include "tao/IFR_Client/IFR_BaseC.h"
@@ -12,15 +12,15 @@
 
 ACE_RCSID (Recursive,
            client,
-           "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+           "$Id: client.cpp 82870 2008-09-29 08:47:19Z johnnyw $")
 
 
-const char * ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
