@@ -1,4 +1,4 @@
-// $Id: destroy.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: destroy.cpp 82861 2008-09-29 07:35:22Z johnnyw $
 
 //========================================================================
 //
@@ -22,11 +22,11 @@
 #include "tao/AnyTypeCode/Any.h"
 #include "tao/BiDir_GIOP/BiDirGIOP.h"
 
-ACE_RCSID(BiDir_Multiple_ORB, destroy, "$Id: destroy.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+ACE_RCSID(BiDir_Multiple_ORB, destroy, "$Id: destroy.cpp 82861 2008-09-29 07:35:22Z johnnyw $")
 
 int
 test_with_bidir_poa (int argc,
-                     char **argv,
+                     ACE_TCHAR **argv,
                      const char *orb_name,
                      int destroy_orb)
 {
