@@ -1,4 +1,4 @@
-// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "test_i.h"
@@ -6,18 +6,18 @@
 #include "tao/BiDir_GIOP/BiDirGIOP.h"
 #include "tao/AnyTypeCode/Any.h"
 
-ACE_RCSID(BiDirectional, client, "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+ACE_RCSID(BiDirectional, client, "$Id: client.cpp 83154 2008-10-12 19:03:33Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 
 void do_nothing (void)
 {
 }
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -102,7 +102,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       if (CORBA::is_nil (server.in ()))
         {
           ACE_ERROR_RETURN ((LM_ERROR,
-                             "Object reference <%s> is nil\n",
+                             "Object reference <%s> is nil.\n",
                              ior),
                             1);
         }
