@@ -1,4 +1,4 @@
-// $Id: server.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $
 
 #include "ace/Get_Opt.h"
 #include "test_i.h"
@@ -6,15 +6,15 @@
 #include "tao/AnyTypeCode/Any.h"
 #include "ace/OS_NS_stdio.h"
 
-ACE_RCSID(BiDirectional, server, "$Id: server.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+ACE_RCSID(BiDirectional, server, "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")
 
-const char *ior_output_file = 0;
+const ACE_TCHAR *ior_output_file = 0;
 int no_iterations = 10;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:i:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:i:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -113,7 +113,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       CORBA::String_var ior =
         orb->object_to_string (obj.in ());
 
-      ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));
+      ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));
 
       // If the ior_output_file exists, output the ior to it
       if (ior_output_file != 0)
