@@ -1,5 +1,5 @@
 //
-// Peer.h,v 1.9 2005/07/04 07:06:16 jwillemsen Exp
+// $Id: Peer.h 77008 2007-02-12 11:52:38Z johnnyw $
 //
 
 #ifndef BIG_ONEWAYS_PEER_H
@@ -24,11 +24,8 @@ public:
                                             CORBA::ULong payload_size,
                                             CORBA::ULong thread_count,
                                             CORBA::ULong message_count,
-                                            CORBA::ULong peer_count
-                                            ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+                                            CORBA::ULong peer_count);
+  virtual void shutdown (void);
 
 private:
   /// Keep a pointer to the ORB to shutdown cleanly
