@@ -1,6 +1,6 @@
 // -*- C++ -*-
 //
-// Session.h,v 1.13 2005/07/04 07:06:16 jwillemsen Exp
+// $Id: Session.h 80166 2007-12-03 13:53:49Z sowayaa $
 
 #ifndef BIG_ONEWAYS_SESSION_H
 #define BIG_ONEWAYS_SESSION_H
@@ -35,39 +35,29 @@ public:
   int svc (void);
 
   // = The skeleton methods
-  virtual void start (const Test::Session_List &other_sessions
-                      ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException,
-                     Test::Already_Running,
-                     Test::No_Peers));
+  virtual void start (const Test::Session_List &other_sessions);
 
-  virtual void ping (ACE_ENV_SINGLE_ARG_DECL_NOT_USED)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void ping (void);
 
-  virtual void receive_payload (const Test::Payload &the_payload
-                                ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void receive_payload (const Test::Payload &the_payload);
 
-  virtual void destroy (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void destroy (void);
 
 private:
   /// Helper function used to report any problems and destroy local
   /// resources
-  void terminate (CORBA::Boolean success
-                  ACE_ENV_ARG_DECL)
-    ACE_THROW_SPEC (());
+  void terminate (CORBA::Boolean success);
 
   /// Return 1 if all the work in this session has been completed
   int more_work (void) const;
 
   /// Make sure that all threads have connections avaiable to the
   /// other sessions.
-  void validate_connections (ACE_ENV_SINGLE_ARG_DECL);
+  void validate_connections (void);
 
 private:
   /// Synchronize the internal state
-  ACE_SYNCH_MUTEX mutex_;
+  TAO_SYNCH_MUTEX mutex_;
 
   /// Keep a reference to the Session_Control, this is used to report
   /// when the test finishes.
