@@ -3,7 +3,7 @@
 /**
  *  @file   Big_Reply_i.h
  *
- *  Big_Reply_i.h,v 1.8 2005/07/04 08:48:58 jwillemsen Exp
+ *  $Id: Big_Reply_i.h 77008 2007-02-12 11:52:38Z johnnyw $
  *
  *  @author Balachandran Natarajan <bala@cs.wustl.edu>
  **/
@@ -32,14 +32,11 @@ public:
   virtual ~Big_Reply_i (void);
 
   // = The skeleton methods
-  virtual Test::Octet_Seq *get_big_reply (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual Test::Octet_Seq *get_big_reply (void);
 
-  virtual void ping (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void ping (void);
 
-  virtual void shutdown (ACE_ENV_SINGLE_ARG_DECL)
-    ACE_THROW_SPEC ((CORBA::SystemException));
+  virtual void shutdown (void);
 
 private:
   /// Our local ORB ptr
