@@ -1,16 +1,17 @@
-// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: client.cpp 85150 2009-04-23 07:20:57Z johnnyw $
 
 #include "Client_Task.h"
 #include "ace/Get_Opt.h"
 
-ACE_RCSID(Muxing, client, "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+ACE_RCSID(Big_Reply, client, "$Id: client.cpp 85150 2009-04-23 07:20:57Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT ("file://test.ior");
+bool server_shutdown = false;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:x"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -19,11 +20,15 @@ parse_args (int argc, char *argv[])
       case 'k':
         ior = get_opts.opt_arg ();
         break;
+      case 'x':
+        server_shutdown = true;
+        break;
       case '?':
       default:
         ACE_ERROR_RETURN ((LM_ERROR,
                            "usage:  %s "
                            "-k <ior>"
+                           "-x shutdown"
                            "\n",
                            argv [0]),
                           -1);
@@ -33,7 +38,7 @@ parse_args (int argc, char *argv[])
 }
 
 int
-ACE_TMAIN(int argc, ACE_TCHAR *argv[])
+ACE_TMAIN (int argc, ACE_TCHAR *argv[])
 {
   try
     {
@@ -44,10 +49,10 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
         return 1;
 
       CORBA::Object_var tmp =
-        orb->string_to_object(ior);
+        orb->string_to_object (ior);
 
       Test::Big_Reply_var reply_gen =
-        Test::Big_Reply::_narrow(tmp.in ());
+        Test::Big_Reply::_narrow (tmp.in ());
 
       if (CORBA::is_nil (reply_gen.in ()))
         {
@@ -57,7 +62,6 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
                             1);
         }
 
-
       Client_Task client_task (reply_gen.in (),
                                10,
                                ACE_Thread_Manager::instance ());
@@ -70,8 +74,11 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
 
       ACE_DEBUG ((LM_DEBUG, "Got all the replies...\n"));
 
-      // Request the server to shutdown
-      reply_gen->shutdown ();
+      if (server_shutdown)
+        {
+          // Request the server to shutdown
+          reply_gen->shutdown ();
+        }
 
       orb->destroy ();
     }
