@@ -1,13 +1,13 @@
-// $Id: server.cpp 80246 2007-12-12 13:22:54Z johnnyw $
+// $Id: server.cpp 86859 2009-10-01 13:03:08Z msmit $
 
 #include "ace/Get_Opt.h"
 #include "Big_Reply_i.h"
 #include "ace/OS_NS_stdio.h"
 #include "ace/Task.h"
 
-ACE_RCSID(Big_Reply, server, "$Id: server.cpp 80246 2007-12-12 13:22:54Z johnnyw $")
+ACE_RCSID(Big_Reply, server, "$Id: server.cpp 86859 2009-10-01 13:03:08Z msmit $")
 
-const char *ior_output_file = "test.ior";
+const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
 
 // We can change this value if wanted..
 const CORBA::ULong data_size = 4000000;
@@ -39,9 +39,9 @@ private:
 static int n_threads = 1;
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:s:t:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:s:t:"));
   int c;
 
   while ((c = get_opts ()) != -1)
@@ -120,7 +120,7 @@ ACE_TMAIN(int argc, ACE_TCHAR *argv[])
       FILE *output_file= ACE_OS::fopen (ior_output_file, "w");
       if (output_file == 0)
         ACE_ERROR_RETURN ((LM_ERROR,
-                           "Cannot open output file for writing IOR: %s",
+                           "Cannot open output file for writing IOR: %s\n",
                            ior_output_file),
                               1);
       ACE_OS::fprintf (output_file, "%s", ior.in ());
