@@ -1,11 +1,11 @@
 //
-// $Id: Client_Task.cpp 80201 2007-12-06 15:11:06Z johnnyw $
+// $Id: Client_Task.cpp 82688 2008-09-05 20:01:05Z johnc $
 //
 
 #include "Client_Task.h"
 #include "tao/AnyTypeCode/Any.h"
 
-ACE_RCSID(Big_Request_Muxing, Client_Task, "$Id: Client_Task.cpp 80201 2007-12-06 15:11:06Z johnnyw $")
+ACE_RCSID(Big_Request_Muxing, Client_Task, "$Id: Client_Task.cpp 82688 2008-09-05 20:01:05Z johnc $")
 
 namespace
 {
@@ -153,9 +153,7 @@ Client_Task::validate_connection (void)
         {
           try
             {
-              this->payload_receiver_->more_data (
-                payload,
-                this->sync_scope_ != Messaging::SYNC_WITH_TARGET);
+              this->payload_receiver_->ping();
               transient_count= 0;
             }
           catch (const CORBA::TRANSIENT &)
