@@ -1,5 +1,5 @@
 //
-// Client_Task.h,v 1.7 2003/07/21 23:51:39 dhinton Exp
+// $Id: Client_Task.h 79404 2007-08-20 07:58:06Z fields_t $
 //
 
 #ifndef BIG_REQUEST_MUXING_CLIENT_TASK_H
@@ -9,6 +9,9 @@
 #include "TestC.h"
 #include "tao/Messaging/Messaging.h"
 #include "ace/Task.h"
+#include "ace/SString.h"
+#include "ace/OS_NS_unistd.h"
+#include "ace/Atomic_Op.h"
 
 #if !defined (ACE_LACKS_PRAGMA_ONCE)
 # pragma once
@@ -24,15 +27,19 @@ public:
                CORBA::Long event_count,
                CORBA::ULong event_size,
                CORBA::ORB_ptr orb,
-               Messaging::SyncScope sync_scope);
+               Messaging::SyncScope sync_scope,
+               const ACE_CString& ident);
 
   /// Thread entry point
   int svc (void);
 
+  bool done(void) const;
+  const char *ID (void) const;
+
 private:
   /// Make sure that all threads have connections available to
   /// workaround bug 189
-  void validate_connection (ACE_ENV_SINGLE_ARG_DECL);
+  void validate_connection (void);
 
 private:
   /// Reference to the test interface
@@ -50,6 +57,13 @@ private:
 
   /// The SyncScope used in this Task
   Messaging::SyncScope sync_scope_;
+
+  /// Track the number of tasks still running.
+  ACE_Atomic_Op<TAO_SYNCH_MUTEX, unsigned long> tasks_running_;
+
+  bool done_;
+
+  ACE_CString id_;
 };
 
 #include /**/ "ace/post.h"
