@@ -1,12 +1,12 @@
-// $Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $
+// $Id: client.cpp 82836 2008-09-25 20:52:21Z johnnyw $
 
 #include "Client_Task.h"
 #include "ace/Get_Opt.h"
 #include "tao/Messaging/Messaging.h"
 
-ACE_RCSID(Muxing, client, "$Id: client.cpp 78703 2007-06-30 18:43:31Z sowayaa $")
+ACE_RCSID(Muxing, client, "$Id: client.cpp 82836 2008-09-25 20:52:21Z johnnyw $")
 
-const char *ior = "file://test.ior";
+const ACE_TCHAR *ior = ACE_TEXT("file://test.ior");
 
 namespace
 {
@@ -18,9 +18,9 @@ namespace
 }
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "k:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("k:"));
   int c;
 
   while ((c = get_opts ()) != -1)
