@@ -1,24 +1,24 @@
-// $Id: server.cpp 79404 2007-08-20 07:58:06Z fields_t $
+// $Id: server.cpp 82836 2008-09-25 20:52:21Z johnnyw $
 
 #include "Payload_Receiver.h"
 #include "ace/Get_Opt.h"
 #include "ace/OS_NS_stdio.h"
 #include "ace/OS_NS_sys_time.h"
 
-ACE_RCSID(Big_Request_Muxing, server, "$Id: server.cpp 79404 2007-08-20 07:58:06Z fields_t $")
+ACE_RCSID(Big_Request_Muxing, server, "$Id: server.cpp 82836 2008-09-25 20:52:21Z johnnyw $")
 
 namespace
 {
   // defaults only
-  const char *ior_output_file = "test.ior";
+  const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");
   int expected   = 200;
   int maybe_lost = 400;
 }
 
 int
-parse_args (int argc, char *argv[])
+parse_args (int argc, ACE_TCHAR *argv[])
 {
-  ACE_Get_Opt get_opts (argc, argv, "o:e:l:");
+  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:e:l:"));
   int c;
 
   while ((c = get_opts ()) != -1)
